@import "../lib/page.scss";
@import '../lib/form-layout.scss';

.fa-check-circle-o {
    color: var(--pf-global--success-color--100);
}

.fa-info-circle {
    color: var(--pf-global--info-color--100);
}

.fa-exclamation-triangle {
    color: var(--pf-global--warning-color--100);
}

.fa-exclamation-circle {
    color: var(--pf-global--danger-color--100);
}

.nav-tabs-pf > li:first-child > a {
    padding-left: 20px;
}

.nav li a {
    font-size: 13px;
}

/* Extra content header */

.content-header-extra {
    border-bottom: 1px solid #ddd;
    padding: 10px 20px;
    width: 100%;
    position: sticky;
    z-index: 900;
    top: 0;
}

.content-header-extra .btn-group {
    padding-left: 5px;
    padding-right: 30px;
}

a.disabled {
    text-decoration: none;
    pointer-events: none;
    cursor: default;
    color: var(--ct-color-text);
}

.popover {
    max-width: none;
    white-space: nowrap;
}
