cockpit.locale({
 "": {'plural-forms':function(n) {
var nplurals, plural;
nplurals=2; plural=n != 1;
return plural;
},
  "language": "nb_NO",
  "x-generator": "Weblate 4.5.1"
 },
 "$0 active zone": [
  null,
  "$0 aktiv sone"
 ],
 "$0 active zones": [
  null,
  "$0 aktive soner"
 ],
 "$0 day": [
  "$0 days",
  "$0 dag",
  "$0 dager"
 ],
 "$0 exited with code $1": [
  null,
  "$0 avsluttet med koden $1"
 ],
 "$0 failed": [
  null,
  "$0 feilet"
 ],
 "$0 hour": [
  "$0 hours",
  "$0 time",
  "$0 timer"
 ],
 "$0 killed with signal $1": [
  null,
  "$0 drept med signal $1"
 ],
 "$0 minute": [
  "$0 minutes",
  "$0 minutt",
  "$0 minutter"
 ],
 "$0 month": [
  "$0 months",
  "$0 måned",
  "$0 måneder"
 ],
 "$0 week": [
  "$0 weeks",
  "$0 uke",
  "$0 uker"
 ],
 "$0 year": [
  "$0 years",
  "$0 år",
  "$0 år"
 ],
 "$0 zone": [
  null,
  "$0 sone"
 ],
 "(Optional)": [
  null,
  "(Valgfri)"
 ],
 "1 day": [
  null,
  "1 dag"
 ],
 "1 hour": [
  null,
  "1 time"
 ],
 "1 week": [
  null,
  "1 uke"
 ],
 "5 minutes": [
  null,
  "5 minutter"
 ],
 "6 hours": [
  null,
  "6 timer"
 ],
 "802.3ad": [
  null,
  "802.3ad"
 ],
 "802.3ad LACP": [
  null,
  "802.3ad LACP"
 ],
 "A network bond combines multiple network interfaces into one logical interface with higher throughput or redundancy.": [
  null,
  "En nettverksbinding kombinerer flere nettverksgrensesnitt til ett logisk grensesnitt med høyere gjennomstrømning eller redundans."
 ],
 "ARP": [
  null,
  "ARP"
 ],
 "ARP monitoring": [
  null,
  "ARP overvåking"
 ],
 "ARP ping": [
  null,
  "ARP ping"
 ],
 "Active": [
  null,
  "Aktiv"
 ],
 "Active backup": [
  null,
  ""
 ],
 "Adaptive load balancing": [
  null,
  "Adaptiv lastbalansering"
 ],
 "Adaptive transmit load balancing": [
  null,
  ""
 ],
 "Add $0": [
  null,
  "Legg til $0"
 ],
 "Add VLAN": [
  null,
  "Legg til VLAN"
 ],
 "Add a new zone": [
  null,
  "Legg til en ny sone"
 ],
 "Add bond": [
  null,
  "Legg til binding"
 ],
 "Add bridge": [
  null,
  "Legg til bridge"
 ],
 "Add member": [
  null,
  "Legg til medlem"
 ],
 "Add ports": [
  null,
  "Legg til porter"
 ],
 "Add ports to $0 zone": [
  null,
  "Legg til porter i $0 sonen"
 ],
 "Add services": [
  null,
  "Legg til tjenester"
 ],
 "Add services to $0 zone": [
  null,
  "Legg til tjenester i $0-sonen"
 ],
 "Add services to zone $0": [
  null,
  "Legg til tjenester i sone $0"
 ],
 "Add team": [
  null,
  "Legg til team"
 ],
 "Add zone": [
  null,
  "Legg til sone"
 ],
 "Adding <b>$0</b> will break the connection to the server, and will make the administration UI unavailable.": [
  null,
  "Hvis du legger til <b>$0</b>, brytes forbindelsen til serveren, og administrasjonsgrensesnittet gjøres utilgjengelig."
 ],
 "Adding custom ports will reload firewalld. A reload will result in the loss of any runtime-only configuration!": [
  null,
  "Hvis du legger til egendefinerte porter, lastes firewalld på nytt. En omlasting vil resultere i tap av en hvilken som helst kjøretidskonfigurasjon!"
 ],
 "Additional DNS $val": [
  null,
  "Ekstra DNS $val"
 ],
 "Additional DNS search domains $val": [
  null,
  "Ekstra DNS-søkedomener $val"
 ],
 "Additional address $val": [
  null,
  "Ekstra adresse $val"
 ],
 "Additional ports": [
  null,
  "Ekstra porter"
 ],
 "Address $val": [
  null,
  "Adresse $val"
 ],
 "Addresses": [
  null,
  "Adresser"
 ],
 "All logs": [
  null,
  "Alle logger"
 ],
 "Allowed addresses": [
  null,
  "Tillatte adresser"
 ],
 "Apply": [
  null,
  "Bruk"
 ],
 "Authenticating": [
  null,
  "Autentiserer"
 ],
 "Automatic": [
  null,
  "Automatisk"
 ],
 "Automatic (DHCP only)": [
  null,
  "Automatisk (kun DHCP)"
 ],
 "Automatic (DHCP)": [
  null,
  "Automatisk (DHCP)"
 ],
 "Balancer": [
  null,
  ""
 ],
 "Bond": [
  null,
  "Binding"
 ],
 "Bond settings": [
  null,
  "Binding-innstillinger"
 ],
 "Bridge": [
  null,
  "Bro"
 ],
 "Bridge port": [
  null,
  "Bro port"
 ],
 "Bridge port settings": [
  null,
  "Bro port innstillinger"
 ],
 "Bridge settings": [
  null,
  "Bro-innstillinger"
 ],
 "Broadcast": [
  null,
  "Broadcast"
 ],
 "Broken configuration": [
  null,
  "Ødelagt konfigurasjon"
 ],
 "Cancel": [
  null,
  "Avbryt"
 ],
 "Cannot forward login credentials": [
  null,
  "Kan ikke videresende påloggingsinformasjonen"
 ],
 "Carrier": [
  null,
  "Transportør"
 ],
 "Change the settings": [
  null,
  "Endre innstillingene"
 ],
 "Changing the settings will break the connection to the server, and will make the administration UI unavailable.": [
  null,
  "Endring av innstillingene vil bryte forbindelsen til serveren, og gjøre administrasjonsgrensesnittet utilgjengelig."
 ],
 "Checking IP": [
  null,
  "Sjekker IP"
 ],
 "Close": [
  null,
  "Lukk"
 ],
 "Cockpit could not contact the given host.": [
  null,
  "Cockpit kunne ikke kontakte den angitte verten."
 ],
 "Cockpit is not compatible with the software on the system.": [
  null,
  "Cockpit er ikke kompatibel med programvaren på systemet."
 ],
 "Cockpit is not installed on the system.": [
  null,
  "Cockpit er ikke installert på systemet."
 ],
 "Comma-separated ports, ranges, and aliases are accepted": [
  null,
  "Kommaseparerte porter, områder og alias aksepteres"
 ],
 "Configuring": [
  null,
  "Konfigurerer"
 ],
 "Configuring IP": [
  null,
  "Konfigurerer IP"
 ],
 "Confirm removal of $0": [
  null,
  "Bekreft fjerning av $0"
 ],
 "Connect automatically": [
  null,
  "Koble til automatisk"
 ],
 "Connection has timed out.": [
  null,
  "Tidsavbrudd for tilkoblingen."
 ],
 "Connection will be lost": [
  null,
  "Tilkoblingen går tapt"
 ],
 "Create it": [
  null,
  "Opprett den"
 ],
 "Creating this VLAN will break the connection to the server, and will make the administration UI unavailable.": [
  null,
  "Hvis du oppretter dette VLANet, brytes forbindelsen til serveren, og administrasjonsgrensesnittet blir utilgjengelig."
 ],
 "Creating this bond will break the connection to the server, and will make the administration UI unavailable.": [
  null,
  "Hvis du oppretter denne bindingen, brytes forbindelsen til serveren og administrasjonsgrensesnittet blir utilgjengelig."
 ],
 "Creating this bridge will break the connection to the server, and will make the administration UI unavailable.": [
  null,
  "Hvis du oppretter denne bridgen, brytes forbindelsen til serveren og administrasjonsgrensesnittet blir utilgjengelig."
 ],
 "Creating this team will break the connection to the server, and will make the administration UI unavailable.": [
  null,
  "Hvis du oppretter dette teamet, brytes forbindelsen til serveren og administrasjonsgrensesnittet blir utilgjengelig."
 ],
 "Custom ports": [
  null,
  "Egendefinerte porter"
 ],
 "Custom zones": [
  null,
  "Egendefinerte soner"
 ],
 "DNS": [
  null,
  "DNS"
 ],
 "DNS $val": [
  null,
  "DNS $val"
 ],
 "DNS search domains": [
  null,
  "DNS-søkedomener"
 ],
 "DNS search domains $val": [
  null,
  "DNS-søkedomener $val"
 ],
 "Deactivating": [
  null,
  "Deaktiverer"
 ],
 "Delete": [
  null,
  "Slett"
 ],
 "Delete $0": [
  null,
  "Slett $0"
 ],
 "Deleting <b>$0</b> will break the connection to the server, and will make the administration UI unavailable.": [
  null,
  "Hvis du sletter <b>$0</b> , brytes forbindelsen til serveren, og administrasjonsgrensesnittet blir utilgjengelig."
 ],
 "Description": [
  null,
  "Beskrivelse"
 ],
 "Disable the firewall": [
  null,
  "Deaktiver brannmuren"
 ],
 "Disabled": [
  null,
  "Deaktivert"
 ],
 "Edit rules and zones": [
  null,
  "Rediger regler og soner"
 ],
 "Enable or disable the device": [
  null,
  "Aktiver eller deaktiver enheten"
 ],
 "Enable service": [
  null,
  "Aktiver tjeneste"
 ],
 "Enable the firewall": [
  null,
  "Aktiver brannmuren"
 ],
 "Entire subnet": [
  null,
  "Hele subnettet"
 ],
 "Error message": [
  null,
  "Feilmelding"
 ],
 "Ethernet MAC": [
  null,
  "Ethernet MAC"
 ],
 "Ethernet MTU": [
  null,
  "Ethernet MTU"
 ],
 "Ethtool": [
  null,
  "Ethtool"
 ],
 "Example: 22,ssh,8080,5900-5910": [
  null,
  "Eksempel: 22,ssh,8080,5900-5910"
 ],
 "Example: 88,2019,nfs,rsync": [
  null,
  "Eksempel: 88,2019,nfs,rsync"
 ],
 "Failed": [
  null,
  "Feilet"
 ],
 "Failed to add port": [
  null,
  "Kunne ikke legge til port"
 ],
 "Failed to add service": [
  null,
  "Kunne ikke legge til tjeneste"
 ],
 "Failed to add zone": [
  null,
  "Kunne ikke legge til sone"
 ],
 "Filter services": [
  null,
  "Filtrer tjenester"
 ],
 "Firewall": [
  null,
  "Brannmur"
 ],
 "Firewall is not available": [
  null,
  "Brannmur er ikke tilgjengelig"
 ],
 "Forward delay $forward_delay": [
  null,
  ""
 ],
 "General": [
  null,
  "Generelt"
 ],
 "Go to now": [
  null,
  "Gå til nå"
 ],
 "Group": [
  null,
  "Gruppe"
 ],
 "Hair pin mode": [
  null,
  ""
 ],
 "Hairpin mode": [
  null,
  ""
 ],
 "Hello time $hello_time": [
  null,
  ""
 ],
 "Host key is incorrect": [
  null,
  "Vertsnøkkelen er feil"
 ],
 "ID": [
  null,
  "ID"
 ],
 "ID $id": [
  null,
  "ID $id"
 ],
 "IP address": [
  null,
  "IP adresse"
 ],
 "IP address with routing prefix. Separate multiple values with a comma. Example: 192.0.2.0/24, 2001:db8::/32": [
  null,
  "IP-adresse med ruteprefiks. Separer flere verdier med komma. Eksempel: 192.0.2.0/24, 2001:db8::/32"
 ],
 "IP settings": [
  null,
  "IP-innstillinger"
 ],
 "IPv4": [
  null,
  "IPv4"
 ],
 "IPv4 settings": [
  null,
  "IPv4-innstillinger"
 ],
 "IPv6": [
  null,
  "IPv6"
 ],
 "IPv6 settings": [
  null,
  "IPv6-innstillinger"
 ],
 "Ignore": [
  null,
  "Ignorer"
 ],
 "Inactive": [
  null,
  "Inaktiv"
 ],
 "Included services": [
  null,
  "Inkluderte tjenester"
 ],
 "Interface members": [
  null,
  "Grensesnittmedlemmer"
 ],
 "Interfaces": [
  null,
  "Grensesnitt"
 ],
 "Internal error": [
  null,
  "Intern feil"
 ],
 "Invalid address $0": [
  null,
  "Ugyldig adresse $0"
 ],
 "Invalid metric $0": [
  null,
  "Ugyldig metrikk $0"
 ],
 "Invalid port number": [
  null,
  "Ugyldig portnummer"
 ],
 "Invalid prefix $0": [
  null,
  "Ugyldig prefiks $0"
 ],
 "Invalid prefix or netmask $0": [
  null,
  "Ugyldig prefiks eller nettmaske $0"
 ],
 "Invalid range": [
  null,
  "Ugyldig område"
 ],
 "Keep connection": [
  null,
  "Hold forbindelsen"
 ],
 "LACP key": [
  null,
  "LACP-nøkkel"
 ],
 "Learn more": [
  null,
  "Lær mer"
 ],
 "Link down delay": [
  null,
  ""
 ],
 "Link local": [
  null,
  ""
 ],
 "Link monitoring": [
  null,
  "Linkovervåking"
 ],
 "Link up delay": [
  null,
  ""
 ],
 "Link watch": [
  null,
  ""
 ],
 "Load balancing": [
  null,
  "Lastbalansering"
 ],
 "Login failed": [
  null,
  "Innlogging feilet"
 ],
 "MAC": [
  null,
  "MAC"
 ],
 "MII (recommended)": [
  null,
  "MII (anbefalt)"
 ],
 "MTU": [
  null,
  "MTU"
 ],
 "MTU must be a positive number": [
  null,
  "MTU må være et positivt tall"
 ],
 "Managed interfaces": [
  null,
  "Administrerte grensesnitt"
 ],
 "Managing VLANs": [
  null,
  "Administrere VLAN"
 ],
 "Managing firewall": [
  null,
  "Administrere brannmur"
 ],
 "Managing networking bonds": [
  null,
  "Administrere nettverksbindinger"
 ],
 "Managing networking bridges": [
  null,
  "Administrere nettverksbroer"
 ],
 "Managing networking teams": [
  null,
  "Administrere nettverksteam"
 ],
 "Manual": [
  null,
  "Manuell"
 ],
 "Maximum message age $max_age": [
  null,
  "Maksimal meldingsalder $ max_age"
 ],
 "Mode": [
  null,
  "Modus"
 ],
 "Monitoring interval": [
  null,
  "Overvåkingsintervall"
 ],
 "Monitoring targets": [
  null,
  "Overvåker mål"
 ],
 "NSNA ping": [
  null,
  "NSNA ping"
 ],
 "Name": [
  null,
  "Navn"
 ],
 "Network bond": [
  null,
  ""
 ],
 "Network devices and graphs require NetworkManager": [
  null,
  "Nettverksenheter og grafer krever NetworkManager"
 ],
 "Network logs": [
  null,
  "Nettverkslogger"
 ],
 "NetworkManager is not installed": [
  null,
  "NetworkManager er ikke installert"
 ],
 "NetworkManager is not running": [
  null,
  "NetworkManager kjører ikke"
 ],
 "Networking": [
  null,
  "Nettverk"
 ],
 "No": [
  null,
  "Nei"
 ],
 "No carrier": [
  null,
  "Ingen transportør"
 ],
 "No description available": [
  null,
  "Ingen beskrivelse tilgjengelig"
 ],
 "None": [
  null,
  "Ingen"
 ],
 "Not authorized to disable the firewall": [
  null,
  "Ikke autorisert til å deaktivere brannmuren"
 ],
 "Not authorized to enable the firewall": [
  null,
  "Ikke autorisert til å aktivere brannmuren"
 ],
 "Not authorized to remove zone $0": [
  null,
  "Ikke autorisert til å fjerne sone $0"
 ],
 "Not available": [
  null,
  "Ikke tilgjengelig"
 ],
 "Not permitted to perform this action.": [
  null,
  "Ikke tillatt å utføre denne handlingen."
 ],
 "Parent": [
  null,
  ""
 ],
 "Parent $parent": [
  null,
  ""
 ],
 "Part of ": [
  null,
  "Del av "
 ],
 "Passive": [
  null,
  "Passiv"
 ],
 "Path cost": [
  null,
  "Sti kostnad"
 ],
 "Path cost $path_cost": [
  null,
  "Sti kostnad $path_cost"
 ],
 "Permanent": [
  null,
  "Permanent"
 ],
 "Ping interval": [
  null,
  "Ping-intervall"
 ],
 "Ping target": [
  null,
  "Ping mål"
 ],
 "Please install the $0 package": [
  null,
  "Vennligst installer $0-pakken"
 ],
 "Port number and type do not match": [
  null,
  "Portnummer og type samsvarer ikke"
 ],
 "Ports": [
  null,
  "Porter"
 ],
 "Prefix length": [
  null,
  "Prefikslengde"
 ],
 "Prefix length or netmask": [
  null,
  "Prefikslengde eller nettmaske"
 ],
 "Preparing": [
  null,
  "Forbereder"
 ],
 "Preserve": [
  null,
  "Bevar"
 ],
 "Primary": [
  null,
  "Primær"
 ],
 "Priority": [
  null,
  "Prioritet"
 ],
 "Priority $priority": [
  null,
  "Prioritet $priority"
 ],
 "Random": [
  null,
  "Tilfeldig"
 ],
 "Range": [
  null,
  ""
 ],
 "Range must be strictly ordered": [
  null,
  ""
 ],
 "Reboot": [
  null,
  "Omstart"
 ],
 "Receiving": [
  null,
  "Mottar"
 ],
 "Remove $0": [
  null,
  "Fjern $0"
 ],
 "Remove $0 service from $1 zone": [
  null,
  "Fjern $0-tjenesten fra $1-sonen"
 ],
 "Remove service $0": [
  null,
  "Fjern tjenesten $0"
 ],
 "Remove zone $0": [
  null,
  "Fjern sone $0"
 ],
 "Removing <b>$0</b> will break the connection to the server, and will make the administration UI unavailable.": [
  null,
  "Hvis du fjerner <b>$0</b> , brytes forbindelsen til serveren og administrasjonsgrensesnittet blir utilgjengelig."
 ],
 "Removing the cockpit service might result in the web console becoming unreachable. Make sure that this zone does not apply to your current web console connection.": [
  null,
  "Fjerning av cockpit-tjenesten kan føre til at web konsollet blir utilgjengelig. Forsikre deg om at denne sonen ikke gjelder for din nåværende web konsoll forbindelse."
 ],
 "Removing the zone will remove all services within it.": [
  null,
  "Hvis du fjerner sonen, fjernes alle tjenester i den."
 ],
 "Restoring connection": [
  null,
  "Gjenoppretter tilkoblingen"
 ],
 "Round robin": [
  null,
  ""
 ],
 "Routes": [
  null,
  "Ruter"
 ],
 "Runner": [
  null,
  ""
 ],
 "STP forward delay": [
  null,
  ""
 ],
 "STP hello time": [
  null,
  ""
 ],
 "STP maximum message age": [
  null,
  "STP maksimal meldingsalder"
 ],
 "STP priority": [
  null,
  "STP-prioritet"
 ],
 "Sending": [
  null,
  "Sender"
 ],
 "Server has closed the connection.": [
  null,
  "Serveren har lukket forbindelsen."
 ],
 "Service": [
  null,
  "Tjeneste"
 ],
 "Services": [
  null,
  "Tjenester"
 ],
 "Set to": [
  null,
  "Satt til"
 ],
 "Shared": [
  null,
  "Delt"
 ],
 "Sorted from least to most trusted": [
  null,
  "Sortert fra minst til mest betrodd"
 ],
 "Spanning tree protocol": [
  null,
  "Spanning tree protokoll"
 ],
 "Spanning tree protocol (STP)": [
  null,
  "Spanning tree protokoll (STP)"
 ],
 "Stable": [
  null,
  "Stabil"
 ],
 "Start service": [
  null,
  "Start tjenesten"
 ],
 "Status": [
  null,
  "Status"
 ],
 "Sticky": [
  null,
  ""
 ],
 "Switch of $0": [
  null,
  "Slå av $0"
 ],
 "Switch off $0": [
  null,
  "Slå av $0"
 ],
 "Switch on $0": [
  null,
  "Slå på $0"
 ],
 "Switching off <b>$0</b>  will break the connection to the server, and will make the administration UI unavailable.": [
  null,
  "Hvis du slår av <b>$0</b>, brytes forbindelsen til serveren, og gjør administrasjonsgrensesnittet utilgjengelig."
 ],
 "Switching off <b>$0</b> will break the connection to the server, and will make the administration UI unavailable.": [
  null,
  "Hvis du slår av <b>$0</b>, brytes forbindelsen til serveren, og gjør administrasjonsgrensesnittet utilgjengelig."
 ],
 "Switching on <b>$0</b> will break the connection to the server, and will make the administration UI unavailable.": [
  null,
  "Hvis du slår på <b>$0</b>, brytes forbindelsen til serveren, og gjør administrasjonsgrensesnittet utilgjengelig."
 ],
 "TCP": [
  null,
  "TCP"
 ],
 "Team": [
  null,
  "Team"
 ],
 "Team port": [
  null,
  "Team port"
 ],
 "Team port settings": [
  null,
  "Team Port innstillinger"
 ],
 "Team settings": [
  null,
  "Team innstillinger"
 ],
 "Testing connection": [
  null,
  "Tester tilkobling"
 ],
 "The cockpit service is automatically included": [
  null,
  "Cockpit tjenesten er automatisk inkludert"
 ],
 "The server refused to authenticate using any supported methods.": [
  null,
  "Serveren nektet å godkjenne ved hjelp av de støttede metodene."
 ],
 "There are no active services in this zone": [
  null,
  "Det er ingen aktive tjenester i denne sonen"
 ],
 "This device cannot be managed here.": [
  null,
  "Denne enheten kan ikke administreres her."
 ],
 "This zone contains the cockpit service. Make sure that this zone does not apply to your current web console connection.": [
  null,
  "Denne sonen inneholder cockpit-tjenesten. Forsikre deg om at denne sonen ikke gjelder for din nåværende web konsoll forbindelse."
 ],
 "Too much data": [
  null,
  "For mye data"
 ],
 "Troubleshoot…": [
  null,
  "Feilsøk…"
 ],
 "Trust level": [
  null,
  ""
 ],
 "UDP": [
  null,
  "UDP"
 ],
 "Unexpected error": [
  null,
  "Uventet feil"
 ],
 "Unknown": [
  null,
  "Ukjent"
 ],
 "Unknown \"$0\"": [
  null,
  "Ukjent \"$0\""
 ],
 "Unknown configuration": [
  null,
  "Ukjent konfigurasjon"
 ],
 "Unknown service name": [
  null,
  "Ukjent tjenestenavn"
 ],
 "Unmanaged interfaces": [
  null,
  "Ikke-administrerte grensesnitt"
 ],
 "Untrusted host": [
  null,
  ""
 ],
 "VLAN": [
  null,
  "VLAN"
 ],
 "VLAN ID": [
  null,
  "VLAN ID"
 ],
 "VLAN settings": [
  null,
  "VLAN-innstillinger"
 ],
 "Waiting": [
  null,
  "Venter"
 ],
 "XOR": [
  null,
  "XOR"
 ],
 "Yes": [
  null,
  "Ja"
 ],
 "You are not authorized to modify the firewall.": [
  null,
  "Du er ikke autorisert til å endre brannmuren."
 ],
 "Your session has been terminated.": [
  null,
  "Økten din er avsluttet."
 ],
 "Your session has expired. Please log in again.": [
  null,
  "Økten din har utløpt. Vennligst logg inn igjen."
 ],
 "[$0 bytes of binary data]": [
  null,
  "[$0 bytes med binære data]"
 ],
 "[binary data]": [
  null,
  "[binære data]"
 ],
 "[no data]": [
  null,
  "[ingen data]"
 ],
 "bond": [
  null,
  "binding"
 ],
 "bridge": [
  null,
  "bro"
 ],
 "edit": [
  null,
  "rediger"
 ],
 "firewall": [
  null,
  "brannmur"
 ],
 "firewalld": [
  null,
  "firewalld"
 ],
 "interface": [
  null,
  "grensesnitt"
 ],
 "ipv4": [
  null,
  "ipv4"
 ],
 "ipv6": [
  null,
  "ipv6"
 ],
 "mac": [
  null,
  "mac"
 ],
 "network": [
  null,
  "nettverk"
 ],
 "port": [
  null,
  "port"
 ],
 "show less": [
  null,
  "vis mindre"
 ],
 "show more": [
  null,
  "vis mer"
 ],
 "tcp": [
  null,
  "tcp"
 ],
 "team": [
  null,
  "team"
 ],
 "udp": [
  null,
  "udp"
 ],
 "vlan": [
  null,
  "vlan"
 ],
 "zone": [
  null,
  "sone"
 ]
});
