cockpit.locale({
 "": {'plural-forms':function(n) {
var nplurals, plural;
nplurals=2; plural=n != 1;
return plural;
},
  "language": "ca",
  "x-generator": "Weblate 4.0.3"
 },
 "$0 block device": [
  null,
  "Dispositiu de blocs $0"
 ],
 "$0 chunk size": [
  null,
  "$0 de mida del tros"
 ],
 "$0 data + $1 overhead used of $2 ($3)": [
  null,
  ""
 ],
 "$0 day": [
  "$0 days",
  "$0 dia",
  "$0 dies"
 ],
 "$0 disk is missing": [
  "$0 disks are missing",
  "falta $0 disc",
  "falten $0 discs"
 ],
 "$0 disks": [
  null,
  "$0 discs"
 ],
 "$0 exited with code $1": [
  null,
  "$0 va sortir amb el codi $1"
 ],
 "$0 failed": [
  null,
  "$0 ha fallat"
 ],
 "$0 filesystems can not be made larger.": [
  null,
  ""
 ],
 "$0 filesystems can not be made smaller.": [
  null,
  ""
 ],
 "$0 filesystems can not be resized here.": [
  null,
  ""
 ],
 "$0 hour": [
  "$0 hours",
  "$0 hora",
  "$0 hores"
 ],
 "$0 is in active use": [
  null,
  ""
 ],
 "$0 is not available from any repository.": [
  null,
  ""
 ],
 "$0 killed with signal $1": [
  null,
  "$0 es va matar amb el senyal $1"
 ],
 "$0 minute": [
  "$0 minutes",
  "$0 minut",
  "$0 minuts"
 ],
 "$0 month": [
  "$0 months",
  "$0 mes",
  "$0 mesos"
 ],
 "$0 of $1": [
  null,
  "$0 de $1"
 ],
 "$0 slot remains": [
  "$0 slots remain",
  "",
  ""
 ],
 "$0 used of $1 ($2 saved)": [
  null,
  "$0 utilitzats de $1 ($2 estalviat)"
 ],
 "$0 week": [
  "$0 weeks",
  "$0 setmana",
  "$0 setmanes"
 ],
 "$0 will be installed.": [
  null,
  ""
 ],
 "$0 year": [
  "$0 years",
  "$0 any",
  "$0 anys"
 ],
 "$0, $1 free": [
  null,
  "$0 amb $1 lliures"
 ],
 "$name (from $host)": [
  null,
  "$name (de $host)"
 ],
 "(none)": [
  null,
  "(sense)"
 ],
 "1 MiB": [
  null,
  "1 MiB"
 ],
 "1 day": [
  null,
  "1 dia"
 ],
 "1 hour": [
  null,
  "1 hora"
 ],
 "1 week": [
  null,
  "1 setmana"
 ],
 "128 KiB": [
  null,
  "128 KiB"
 ],
 "16 KiB": [
  null,
  "16 KiB"
 ],
 "2 MiB": [
  null,
  "2 MiB"
 ],
 "32 KiB": [
  null,
  "32 KiB"
 ],
 "4 KiB": [
  null,
  "4 KiB"
 ],
 "5 minutes": [
  null,
  "5 minuts"
 ],
 "512 KiB": [
  null,
  "512 KiB"
 ],
 "6 hours": [
  null,
  "6 hores"
 ],
 "64 KiB": [
  null,
  "64 KiB"
 ],
 "8 KiB": [
  null,
  "8 KiB"
 ],
 "A disk is needed.": [
  null,
  "Es necessita un disc."
 ],
 "A spare disk needs to be added first before this disk can be removed.": [
  null,
  ""
 ],
 "Activate": [
  null,
  "Activa"
 ],
 "Activating $target": [
  null,
  "S'està activant $target"
 ],
 "Active since": [
  null,
  ""
 ],
 "Add": [
  null,
  "Afegeix"
 ],
 "Add disks": [
  null,
  "Afegeix discs"
 ],
 "Add iSCSI portal": [
  null,
  "Afegeix un portal iSCSI"
 ],
 "Add key": [
  null,
  "Afegeix una clau"
 ],
 "Adding physical volume to $target": [
  null,
  "S'està afegint el volum físic a $target"
 ],
 "Additional packages:": [
  null,
  ""
 ],
 "Address": [
  null,
  "Adreça"
 ],
 "Address cannot be empty": [
  null,
  ""
 ],
 "Address is not a valid URL": [
  null,
  ""
 ],
 "All logs": [
  null,
  ""
 ],
 "Apply": [
  null,
  "Aplica"
 ],
 "At least one disk is needed.": [
  null,
  "Com a mínim es necessita un disc."
 ],
 "Authentication required": [
  null,
  "Autenticació requerida"
 ],
 "Available targets on $0": [
  null,
  "Objectius disponibles en $0"
 ],
 "Backing device": [
  null,
  ""
 ],
 "Block": [
  null,
  "Bloc"
 ],
 "Block device for filesystems": [
  null,
  "Dispositiu de blocs per al sistema de fitxers"
 ],
 "Blocked": [
  null,
  "Bloquejat"
 ],
 "Cancel": [
  null,
  "Cancel·la"
 ],
 "Cannot forward login credentials": [
  null,
  ""
 ],
 "Change": [
  null,
  "Canvia"
 ],
 "Change iSCSI initiator name": [
  null,
  "Canvia el nom d'iniciador iSCSI"
 ],
 "Change passphrase": [
  null,
  ""
 ],
 "Checking $target": [
  null,
  "S’està comprovant $target"
 ],
 "Checking RAID device $target": [
  null,
  "S’està comprovant el dispositiu RAID $target"
 ],
 "Checking and repairing RAID device $target": [
  null,
  ""
 ],
 "Checking installed software": [
  null,
  ""
 ],
 "Chunk size": [
  null,
  "Mida del tros"
 ],
 "Cleaning up for $target": [
  null,
  "Neteja de $target"
 ],
 "Clear mount point configuration": [
  null,
  ""
 ],
 "Close": [
  null,
  "Tanca"
 ],
 "Cockpit could not contact the given host.": [
  null,
  "Cockpit no ha pogut contactar amb l'amfitrió indicat."
 ],
 "Cockpit is not compatible with the software on the system.": [
  null,
  "Cockpit no és compatible amb el programari del sistema."
 ],
 "Cockpit is not installed on the system.": [
  null,
  "Cockpit no està instal·lat al sistema."
 ],
 "Compatible with all systems and devices (MBR)": [
  null,
  "Compatible amb tots els sistemes i dispositius (MBR)"
 ],
 "Compatible with modern system and hard disks > 2TB (GPT)": [
  null,
  "Compatible amb els sistemes moderns i els discs durs > 2TB (GPT)"
 ],
 "Compression": [
  null,
  "Compressió"
 ],
 "Confirm": [
  null,
  "Confirmació"
 ],
 "Confirm removal with passphrase": [
  null,
  ""
 ],
 "Connection has timed out.": [
  null,
  "La connexió ha excedit el temps."
 ],
 "Content": [
  null,
  "Contingut"
 ],
 "Create": [
  null,
  "Crea"
 ],
 "Create RAID device": [
  null,
  "Crea un dispositiu RAID"
 ],
 "Create VDO device": [
  null,
  "Crea un dispositiu VDO"
 ],
 "Create devices": [
  null,
  ""
 ],
 "Create logical volume": [
  null,
  "Crea un volum lògic"
 ],
 "Create new logical volume": [
  null,
  "Crea un volum lògic nou"
 ],
 "Create partition": [
  null,
  "Crea una partició"
 ],
 "Create partition on $0": [
  null,
  "Crea la partició a $0"
 ],
 "Create partition table": [
  null,
  ""
 ],
 "Create snapshot": [
  null,
  "Crea una instantània"
 ],
 "Create thin volume": [
  null,
  "Crea un volum disgregat"
 ],
 "Create volume group": [
  null,
  "Crea un grup de volums"
 ],
 "Creating RAID device $target": [
  null,
  "S'està creant el dispositiu RAID $target"
 ],
 "Creating filesystem on $target": [
  null,
  "S'està creant el sistema de fitxers a $target"
 ],
 "Creating logical volume $target": [
  null,
  "S'està creant el volum lògic $target"
 ],
 "Creating partition $target": [
  null,
  "S'està creant la partició $target"
 ],
 "Creating snapshot of $target": [
  null,
  "S'està creant una instantània de $target"
 ],
 "Creating volume group $target": [
  null,
  "S'està creant el grup de volums $target"
 ],
 "Custom encryption options": [
  null,
  "Opcions personalitzades de xifrat"
 ],
 "Custom mount options": [
  null,
  "Opcions personalitzades de muntatge"
 ],
 "DISK IS FAILING": [
  null,
  "EL DISC ESTÀ FALLANT"
 ],
 "Data used": [
  null,
  "Dades utilitzades"
 ],
 "Deactivate": [
  null,
  "Desactiva"
 ],
 "Deactivating $target": [
  null,
  "S'està desactivant $target"
 ],
 "Deduplication": [
  null,
  "Deduplicació"
 ],
 "Delete": [
  null,
  "Suprimeix"
 ],
 "Deleting $target": [
  null,
  "S'està suprimint $target"
 ],
 "Deleting a RAID device will erase all data on it.": [
  null,
  "La supressió d'un dispositiu RAID n'esborrarà totes les dades."
 ],
 "Deleting a VDO device will erase all data on it.": [
  null,
  "Si suprimiu un dispositiu VDO, s'esborraran totes les dades."
 ],
 "Deleting a logical volume will delete all data in it.": [
  null,
  "La supressió d'un volum lògic n'esborrarà totes les dades."
 ],
 "Deleting a partition will delete all data in it.": [
  null,
  "La supressió d'una partició n'esborrarà totes les dades."
 ],
 "Deleting a volume group will erase all data on it.": [
  null,
  "La supressió d'un grup de volums n'esborrarà totes les dades."
 ],
 "Deleting volume group $target": [
  null,
  "S'està suprimint el grup de volums $target"
 ],
 "Device": [
  null,
  "Dispositiu"
 ],
 "Device file": [
  null,
  "Fitxer de dispositiu"
 ],
 "Device is read-only": [
  null,
  "El dispositiu és de només lectura"
 ],
 "Devices": [
  null,
  "Dispositius"
 ],
 "Disk": [
  null,
  "Disc"
 ],
 "Disk is OK": [
  null,
  "El disc està bé"
 ],
 "Disk passphrase": [
  null,
  ""
 ],
 "Disks": [
  null,
  "Discs"
 ],
 "Do not mount automatically on boot": [
  null,
  ""
 ],
 "Don't overwrite existing data": [
  null,
  "No sobreescriguis les dades existents"
 ],
 "Downloading $0": [
  null,
  ""
 ],
 "Drive": [
  null,
  "Unitat"
 ],
 "Drives": [
  null,
  "Unitats"
 ],
 "Edit": [
  null,
  "Edita"
 ],
 "Edit Tang keyserver": [
  null,
  ""
 ],
 "Editing a key requires a free slot": [
  null,
  ""
 ],
 "Ejecting $target": [
  null,
  "S'està expulsant $target"
 ],
 "Emptying $target": [
  null,
  "S'està buidant $target"
 ],
 "Encrypt data": [
  null,
  "Xifra les dades"
 ],
 "Encrypted $0": [
  null,
  "$0 xifrat"
 ],
 "Encrypted logical volume of $0": [
  null,
  "Volum lògic xifrat de $0"
 ],
 "Encrypted partition of $0": [
  null,
  "Partició xifrada de $0"
 ],
 "Encrypted volumes can not be resized here.": [
  null,
  ""
 ],
 "Encrypted volumes need to be unlocked before they can be resized.": [
  null,
  ""
 ],
 "Encryption": [
  null,
  "Xifratge"
 ],
 "Encryption options": [
  null,
  "Opcions del xifratge"
 ],
 "Erase": [
  null,
  "Esborra"
 ],
 "Erasing $target": [
  null,
  "S'està esborrant $target"
 ],
 "Error": [
  null,
  "Error"
 ],
 "Extended partition": [
  null,
  "Partició estesa"
 ],
 "Failed": [
  null,
  "Ha fallat"
 ],
 "Filesystem": [
  null,
  "Sistema de fitxers"
 ],
 "Filesystem name": [
  null,
  "Nom del sistema de fitxers"
 ],
 "Filesystems": [
  null,
  "Sistemes de fitxers"
 ],
 "For legacy applications only. Reduces performance.": [
  null,
  ""
 ],
 "Force remove passphrase in $0": [
  null,
  ""
 ],
 "Format": [
  null,
  "Formata"
 ],
 "Format $0": [
  null,
  "Formata $0"
 ],
 "Format disk $0": [
  null,
  "Formata el disc $0"
 ],
 "Formatting a disk will erase all data on it.": [
  null,
  "La formatació d'un disc eliminarà totes les dades contingudes."
 ],
 "Formatting a storage device will erase all data on it.": [
  null,
  "La formatació d'un dispositiu d'emmagatzematge eliminarà totes les dades contingudes."
 ],
 "Free": [
  null,
  "Lliure"
 ],
 "Free space": [
  null,
  "Espai lliure"
 ],
 "Free up space in this group: Shrink or delete other logical volumes or add another physical volume.": [
  null,
  ""
 ],
 "Go to now": [
  null,
  "Vés a ara"
 ],
 "Grow": [
  null,
  "Fes créixer"
 ],
 "Grow content": [
  null,
  ""
 ],
 "Grow logical size of $0": [
  null,
  "Fes créixer la mida lògica de $0"
 ],
 "Grow logical volume": [
  null,
  ""
 ],
 "Grow to take all space": [
  null,
  "Fes créixer per agafar tot l'espai"
 ],
 "Host key is incorrect": [
  null,
  "La clau d'amfitrió és incorrecta"
 ],
 "If tang-show-keys is not available, run the following:": [
  null,
  ""
 ],
 "In sync": [
  null,
  "En sincronització"
 ],
 "Inactive volume": [
  null,
  "Volum inactiu"
 ],
 "Inconsistent filesystem mount": [
  null,
  ""
 ],
 "Index memory": [
  null,
  ""
 ],
 "Install": [
  null,
  "Instal·la"
 ],
 "Install NFS support": [
  null,
  ""
 ],
 "Install VDO support": [
  null,
  ""
 ],
 "Install software": [
  null,
  ""
 ],
 "Installing $0": [
  null,
  ""
 ],
 "Internal error": [
  null,
  "Error intern"
 ],
 "Invalid username or password": [
  null,
  "El nom d'usuari o la contrasenya no són vàlids"
 ],
 "Jobs": [
  null,
  "Treballs"
 ],
 "Key slots with unknown types can not be edited here": [
  null,
  ""
 ],
 "Key source": [
  null,
  ""
 ],
 "Keys": [
  null,
  ""
 ],
 "Keyserver": [
  null,
  ""
 ],
 "Keyserver address": [
  null,
  ""
 ],
 "Keyserver removal may prevent unlocking $0.": [
  null,
  ""
 ],
 "Loading...": [
  null,
  "S'està carregant..."
 ],
 "Local mount point": [
  null,
  "Punt de muntatge local"
 ],
 "Lock": [
  null,
  "Bloqueja"
 ],
 "Locking $target": [
  null,
  "S'està bloquejant $target"
 ],
 "Logical": [
  null,
  "Lògica"
 ],
 "Logical size": [
  null,
  "Mida lògica"
 ],
 "Logical volume": [
  null,
  "Volum lògic"
 ],
 "Logical volume (snapshot)": [
  null,
  "Volum lògic (instantània)"
 ],
 "Logical volume of $0": [
  null,
  "Volum lògic de $0"
 ],
 "Login failed": [
  null,
  "Ha fallat l'inici de sessió"
 ],
 "Make sure the key hash from the Tang server matches:": [
  null,
  ""
 ],
 "Manually check with SSH: ": [
  null,
  ""
 ],
 "Marking $target as faulty": [
  null,
  "S'està ficant $target com a defectuós"
 ],
 "Member of RAID device": [
  null,
  "Membre del dispositiu RAID"
 ],
 "Member of RAID device $0": [
  null,
  "Membre del dispositiu RAID $0"
 ],
 "Metadata used": [
  null,
  "Metadades utilitzades"
 ],
 "Modifying $target": [
  null,
  "S'està modificant $target"
 ],
 "Mount": [
  null,
  "Munta"
 ],
 "Mount also automatically on boot": [
  null,
  ""
 ],
 "Mount at boot": [
  null,
  "Munta a l'arrencada"
 ],
 "Mount automatically on $0 on boot": [
  null,
  ""
 ],
 "Mount configuration": [
  null,
  ""
 ],
 "Mount filesystem": [
  null,
  ""
 ],
 "Mount now": [
  null,
  ""
 ],
 "Mount on $0 now": [
  null,
  ""
 ],
 "Mount options": [
  null,
  "Opcions de muntatge"
 ],
 "Mount point": [
  null,
  "Punt de muntatge"
 ],
 "Mount point cannot be empty": [
  null,
  ""
 ],
 "Mount point cannot be empty.": [
  null,
  "El punt de muntatge no pot estar en blanc."
 ],
 "Mount point is already used for $0": [
  null,
  ""
 ],
 "Mount point must start with \"/\".": [
  null,
  "El punt de muntatge ha de començar amb «/»."
 ],
 "Mount read only": [
  null,
  "Munta només de lectura"
 ],
 "Mounting $target": [
  null,
  "S'està muntat $target"
 ],
 "NFS mount": [
  null,
  "Muntatge NFS"
 ],
 "NFS mounts": [
  null,
  "Muntatges NFS"
 ],
 "NFS support not installed": [
  null,
  ""
 ],
 "Name": [
  null,
  "Nom"
 ],
 "Name can not be empty.": [
  null,
  "El nom no pot estar en blanc."
 ],
 "Name cannot be empty.": [
  null,
  "El nom no pot estar en blanc."
 ],
 "Name cannot be longer than $0 bytes": [
  null,
  ""
 ],
 "Name cannot be longer than $0 characters": [
  null,
  ""
 ],
 "Name cannot be longer than 127 characters.": [
  null,
  "El nom no pot ser superior als 127 caràcters."
 ],
 "Name cannot contain the character '$0'.": [
  null,
  "El nom no pot contenir el caràcter «$0»."
 ],
 "Name cannot contain whitespace.": [
  null,
  "El nom no pot contenir l'espai en blanc."
 ],
 "New NFS mount": [
  null,
  "Muntatge NFS nou"
 ],
 "New passphrase": [
  null,
  ""
 ],
 "Next": [
  null,
  "Següent"
 ],
 "No NFS mounts set up": [
  null,
  "Cap emmagatzematge NFS preparat"
 ],
 "No available slots": [
  null,
  ""
 ],
 "No devices": [
  null,
  ""
 ],
 "No disks are available.": [
  null,
  "No hi ha disponible cap disc."
 ],
 "No drives attached": [
  null,
  "Sense unitats connectades"
 ],
 "No filesystem": [
  null,
  "Sense sistema de fitxers"
 ],
 "No free key slots": [
  null,
  ""
 ],
 "No free space": [
  null,
  "Sense espai lliure"
 ],
 "No iSCSI targets set up": [
  null,
  "Cap destinació iSCSI preparada"
 ],
 "No keys added": [
  null,
  ""
 ],
 "No logical volumes": [
  null,
  "Sense volums lògics"
 ],
 "No media inserted": [
  null,
  "Sense mitjans inserits"
 ],
 "No partitioning": [
  null,
  "Sense particionatge"
 ],
 "Not enough space to grow.": [
  null,
  ""
 ],
 "Not found": [
  null,
  "No s'ha trobat"
 ],
 "Not mounted": [
  null,
  "No muntat"
 ],
 "Not permitted to perform this action.": [
  null,
  "No es permet realitzar aquesta acció."
 ],
 "Not running": [
  null,
  "No s'està executant"
 ],
 "Ok": [
  null,
  "D'acord"
 ],
 "Old passphrase": [
  null,
  ""
 ],
 "Only $0 of $1 are used.": [
  null,
  "Només s'utilitzen $0 de $1."
 ],
 "Operation '$operation' on $target": [
  null,
  "L'operació '$operation' en $target"
 ],
 "Options": [
  null,
  "Opcions"
 ],
 "Other devices": [
  null,
  "Altres dispositius"
 ],
 "Overwrite existing data with zeros": [
  null,
  "Sobreescriu les dades existents amb zeros"
 ],
 "PackageKit crashed": [
  null,
  "PackageKit s'ha estavellat."
 ],
 "Partition": [
  null,
  "Partició"
 ],
 "Partition of $0": [
  null,
  "Partició de $0"
 ],
 "Partitioning": [
  null,
  "Particionatge"
 ],
 "Passphrase": [
  null,
  "Contrasenya"
 ],
 "Passphrase cannot be empty": [
  null,
  "La contrasenya no pot estar en blanc"
 ],
 "Passphrase removal may prevent unlocking $0.": [
  null,
  ""
 ],
 "Passphrases do not match": [
  null,
  "Les contrasenyes no coincideixen"
 ],
 "Password": [
  null,
  "Contrasenya"
 ],
 "Path on server": [
  null,
  "Camí al servidor"
 ],
 "Path on server cannot be empty.": [
  null,
  "El camí al servidor no pot estar en blanc."
 ],
 "Path on server must start with \"/\".": [
  null,
  "El camí al servidor ha de començar amb «/»."
 ],
 "Physical": [
  null,
  ""
 ],
 "Physical volume": [
  null,
  "Volum físic"
 ],
 "Physical volume of $0": [
  null,
  "Volum físic de $0"
 ],
 "Physical volumes": [
  null,
  "Volums físics"
 ],
 "Physical volumes can not be resized here.": [
  null,
  ""
 ],
 "Please confirm deletion of $0": [
  null,
  "Si us plau, confirmeu la supressió de $0"
 ],
 "Please confirm stopping of $0": [
  null,
  "Confirmeu l'aturada de $0"
 ],
 "Pool": [
  null,
  "Agrupació"
 ],
 "Pool for thin logical volumes": [
  null,
  "Agrupació per als volums lògics disgregats"
 ],
 "Pool for thin volumes": [
  null,
  "Agrupació per als volums disgregats"
 ],
 "Pool for thinly provisioned volumes": [
  null,
  ""
 ],
 "Port": [
  null,
  "Port"
 ],
 "Process": [
  null,
  "Procés"
 ],
 "Purpose": [
  null,
  "Propòsit"
 ],
 "RAID ($0)": [
  null,
  "RAID ($0)"
 ],
 "RAID 0": [
  null,
  "RAID 0"
 ],
 "RAID 0 (stripe)": [
  null,
  "RAID 0 (segmentació)"
 ],
 "RAID 1": [
  null,
  "RAID 1"
 ],
 "RAID 1 (mirror)": [
  null,
  "RAID 1 (rèplica)"
 ],
 "RAID 10": [
  null,
  "RAID 10"
 ],
 "RAID 10 (stripe of mirrors)": [
  null,
  "RAID 10 (segmentació de rèpliques)"
 ],
 "RAID 4": [
  null,
  "RAID 4"
 ],
 "RAID 4 (dedicated parity)": [
  null,
  "RAID 4 (paritat dedicada)"
 ],
 "RAID 5": [
  null,
  "RAID 5"
 ],
 "RAID 5 (distributed parity)": [
  null,
  "RAID 5 (paritat distribuïda)"
 ],
 "RAID 6": [
  null,
  "RAID 6"
 ],
 "RAID 6 (double distributed parity)": [
  null,
  "RAID 5 (doble paritat distribuïda)"
 ],
 "RAID device": [
  null,
  "Dispositiu RAID"
 ],
 "RAID device $0": [
  null,
  "Dispositiu RAID $0"
 ],
 "RAID level": [
  null,
  "Nivell RAID"
 ],
 "RAID member": [
  null,
  "Membre RAID"
 ],
 "Reboot": [
  null,
  "Rearrencada"
 ],
 "Recommended default": [
  null,
  ""
 ],
 "Recovering": [
  null,
  "Recuperació"
 ],
 "Recovering RAID device $target": [
  null,
  ""
 ],
 "Removals:": [
  null,
  ""
 ],
 "Remove": [
  null,
  "Suprimeix"
 ],
 "Remove $0?": [
  null,
  ""
 ],
 "Remove Tang keyserver": [
  null,
  ""
 ],
 "Remove device": [
  null,
  "Treu el dispositiu"
 ],
 "Remove passphrase": [
  null,
  ""
 ],
 "Remove passphrase in $0?": [
  null,
  ""
 ],
 "Removing $0": [
  null,
  ""
 ],
 "Removing $target from RAID device": [
  null,
  "S'està eliminant $target  del dispositiu RAID"
 ],
 "Removing physical volume from $target": [
  null,
  "S'està eliminant el volum físic de $target"
 ],
 "Rename": [
  null,
  "Reanomena"
 ],
 "Rename logical volume": [
  null,
  "Reanomena el volum lògic"
 ],
 "Rename volume group": [
  null,
  "Reanomena un grup de volums"
 ],
 "Renaming $target": [
  null,
  "S'està reanomenant $target"
 ],
 "Repairing $target": [
  null,
  ""
 ],
 "Repeat passphrase": [
  null,
  ""
 ],
 "Resizing $target": [
  null,
  "S'està redimensionant $target"
 ],
 "Resizing an encrypted filesystem requires unlocking the disk. Please provide a current disk passphrase.": [
  null,
  ""
 ],
 "Running": [
  null,
  "En execució"
 ],
 "SMART self-test of $target": [
  null,
  "Autotest SMART de $target."
 ],
 "Save": [
  null,
  "Desa"
 ],
 "Save space by compressing individual blocks with LZ4": [
  null,
  ""
 ],
 "Save space by storing identical data blocks just once": [
  null,
  ""
 ],
 "Saving a new passphrase requires unlocking the disk. Please provide a current disk passphrase.": [
  null,
  ""
 ],
 "Securely erasing $target": [
  null,
  "S'està eliminant de forma segura $target"
 ],
 "Server": [
  null,
  "Servidor"
 ],
 "Server address": [
  null,
  "Adreça del servidor"
 ],
 "Server address cannot be empty.": [
  null,
  "L'adreça del servidor no pot estar en blanc."
 ],
 "Server cannot be empty.": [
  null,
  "El servidor no pot estar en blanc."
 ],
 "Server has closed the connection.": [
  null,
  "El servidor ha tancat la connexió."
 ],
 "Service": [
  null,
  "Servei"
 ],
 "Session": [
  null,
  "Sessió"
 ],
 "Setting up loop device $target": [
  null,
  "S'està preparant el dispositiu de bucles $target"
 ],
 "Show $0 drive": [
  "Show all $0 drives",
  "",
  ""
 ],
 "Show all": [
  null,
  ""
 ],
 "Shrink": [
  null,
  ""
 ],
 "Shrink logical volume": [
  null,
  ""
 ],
 "Shrink volume": [
  null,
  ""
 ],
 "Size": [
  null,
  "Mida"
 ],
 "Size cannot be negative": [
  null,
  "La mida no pot ser negativa"
 ],
 "Size cannot be zero": [
  null,
  "La mida no pot ser zero"
 ],
 "Size is too large": [
  null,
  "La mida és massa gran"
 ],
 "Size must be a number": [
  null,
  "La mida ha de ser un número"
 ],
 "Size must be at least $0": [
  null,
  "La mida com a mínim ha de ser $0"
 ],
 "Slot $0": [
  null,
  ""
 ],
 "Spare": [
  null,
  "Recanvi"
 ],
 "Start": [
  null,
  "Inicia"
 ],
 "Start multipath": [
  null,
  "Inicia el multicamí"
 ],
 "Starting RAID device $target": [
  null,
  "S'està iniciant el dispositiu RAID $target"
 ],
 "Starting swapspace $target": [
  null,
  "S'està iniciant l'espai d'intercanvi $target"
 ],
 "Stop": [
  null,
  "Atura"
 ],
 "Stop and remove": [
  null,
  "Atura i treu"
 ],
 "Stop and unmount": [
  null,
  "Atura i desmunta"
 ],
 "Stop device": [
  null,
  "Atura el dispositiu"
 ],
 "Stopping RAID device $target": [
  null,
  "S'està aturant el dispositiu RAID $target"
 ],
 "Stopping swapspace $target": [
  null,
  "S'està aturant l'espai d'intercanvi $target"
 ],
 "Storage": [
  null,
  "Emmagatzematge"
 ],
 "Storage can not be managed on this system.": [
  null,
  ""
 ],
 "Storage logs": [
  null,
  "Registres de l'emmagatzematge"
 ],
 "Store passphrase": [
  null,
  "Emmagatzema la contrasenya"
 ],
 "Stored passphrase": [
  null,
  "Contrasenya emmagatzemada"
 ],
 "Support is installed.": [
  null,
  ""
 ],
 "Swap": [
  null,
  "Intercanvi"
 ],
 "Synchronizing RAID device $target": [
  null,
  "Sincronització del dispositiu RAID $target"
 ],
 "Tang keyserver": [
  null,
  ""
 ],
 "The $0 package must be installed to create VDO devices.": [
  null,
  ""
 ],
 "The RAID array is in a degraded state": [
  null,
  ""
 ],
 "The RAID device must be running in order to add spare disks.": [
  null,
  ""
 ],
 "The RAID device must be running in order to remove disks.": [
  null,
  ""
 ],
 "The creation of this VDO device did not finish and the device can't be used.": [
  null,
  "No s'ha finalitzat la creació d'aquest dispositiu VDO i no es pot utilitzar aquest dispositiu."
 ],
 "The currently logged in user is not permitted to see information about keys.": [
  null,
  ""
 ],
 "The filesystem has no permanent mount point.": [
  null,
  ""
 ],
 "The filesystem is already mounted at $0. Proceeding will unmount it.": [
  null,
  ""
 ],
 "The filesystem is configured to be automatically mounted on boot but its encryption container will not be unlocked at that time.": [
  null,
  ""
 ],
 "The filesystem is currently mounted but will not be mounted after the next boot.": [
  null,
  ""
 ],
 "The filesystem is currently mounted on $0 but will be mounted on $1 on the next boot.": [
  null,
  ""
 ],
 "The filesystem is currently mounted on $0 but will not be mounted after the next boot.": [
  null,
  ""
 ],
 "The filesystem is currently not mounted but will be mounted on the next boot.": [
  null,
  ""
 ],
 "The filesystem is in use by login sessions and system services. Proceeding will stop these.": [
  null,
  ""
 ],
 "The filesystem is in use by login sessions. Proceeding will stop these.": [
  null,
  ""
 ],
 "The filesystem is in use by system services. Proceeding will stop these.": [
  null,
  ""
 ],
 "The filesystem is not mounted.": [
  null,
  ""
 ],
 "The last disk of a RAID device cannot be removed.": [
  null,
  "No es pot treure l'últim disc d'un dispositiu RAID."
 ],
 "The last key slot can not be removed": [
  null,
  ""
 ],
 "The last physical volume of a volume group cannot be removed.": [
  null,
  "No es pot treure l'últim volum físic d'un grup de volums."
 ],
 "The server refused to authenticate using any supported methods.": [
  null,
  "El servidor ha refusat l'autenticació mitjançant qualsevol dels mètodes compatibles."
 ],
 "There are devices with multiple paths on the system, but the multipath service is not running.": [
  null,
  "Hi ha dispositius amb diversos camins al sistema, però no s'està executant el servei multipath."
 ],
 "There is not enough free space elsewhere to remove this physical volume. At least $0 more free space is needed.": [
  null,
  "No hi ha prou espai lliure als altres llocs per suprimir aquest volum físic. Es necessiten almenys $0 més d'espai lliure."
 ],
 "Thin logical volume": [
  null,
  "Volums lògics disgregats"
 ],
 "This NFS mount is in use and only its options can be changed.": [
  null,
  ""
 ],
 "This VDO device does not use all of its backing device.": [
  null,
  ""
 ],
 "This device has filesystems that are currently in use. Proceeding will unmount all filesystems on it.": [
  null,
  ""
 ],
 "This device is currently used for RAID devices.": [
  null,
  "Aquest dispositiu s'utilitza actualment amb dispositius RAID."
 ],
 "This device is currently used for RAID devices. Proceeding will remove it from its RAID devices.": [
  null,
  ""
 ],
 "This device is currently used for VDO devices.": [
  null,
  "Aquest dispositiu s'utilitza actualment per als dispositiu VDO."
 ],
 "This device is currently used for volume groups.": [
  null,
  "Aquest dispositiu s'utilitza actualment amb grups de volums."
 ],
 "This device is currently used for volume groups. Proceeding will remove it from its volume groups.": [
  null,
  ""
 ],
 "This disk cannot be removed while the device is recovering.": [
  null,
  "Aquest disc no es pot treure quan s'està recuperant el dispositiu."
 ],
 "This logical volume is not completely used by its content.": [
  null,
  ""
 ],
 "This volume needs to be activated before it can be resized.": [
  null,
  ""
 ],
 "Toggle": [
  null,
  ""
 ],
 "Toggle bitmap": [
  null,
  ""
 ],
 "Too much data": [
  null,
  "Hi ha massa dades"
 ],
 "Total size: $0": [
  null,
  ""
 ],
 "Trust key": [
  null,
  ""
 ],
 "Type": [
  null,
  "Tipus"
 ],
 "UUID": [
  null,
  "UUID"
 ],
 "Unable to reach server": [
  null,
  "No es pot arribar al servidor"
 ],
 "Unable to remove mount": [
  null,
  "No es pot treure el punt de muntatge"
 ],
 "Unable to unmount filesystem": [
  null,
  "No es pot desmuntar el sistema de fitxers"
 ],
 "Unit": [
  null,
  ""
 ],
 "Unknown": [
  null,
  "Desconegut"
 ],
 "Unknown ($0)": [
  null,
  "Desconegut ($0)"
 ],
 "Unknown host name": [
  null,
  "Nom d'amfitrió desconegut"
 ],
 "Unknown type": [
  null,
  ""
 ],
 "Unlock": [
  null,
  "Desbloqueja"
 ],
 "Unlock at boot": [
  null,
  "Desbloqueja a l'arrencada"
 ],
 "Unlock read only": [
  null,
  "Desbloqueja només lectura"
 ],
 "Unlocking $target": [
  null,
  "S'està desbloquejant $target"
 ],
 "Unlocking disk...": [
  null,
  ""
 ],
 "Unmount": [
  null,
  "Desmunta"
 ],
 "Unmount filesystem": [
  null,
  ""
 ],
 "Unmount now": [
  null,
  ""
 ],
 "Unmounting $target": [
  null,
  "S'està desmuntat $target"
 ],
 "Unrecognized data": [
  null,
  "Dades no reconegudes"
 ],
 "Unrecognized data can not be made smaller here.": [
  null,
  ""
 ],
 "Unsupported volume": [
  null,
  "Volum no admès"
 ],
 "Untrusted host": [
  null,
  "Amfitrió no fiable"
 ],
 "Usage": [
  null,
  "Ús"
 ],
 "Use 512 byte emulation": [
  null,
  ""
 ],
 "Used": [
  null,
  "Utilitzat"
 ],
 "Username": [
  null,
  "Nom d'usuari"
 ],
 "Using LUKS encryption": [
  null,
  ""
 ],
 "Using Tang server": [
  null,
  ""
 ],
 "VDO backing": [
  null,
  ""
 ],
 "VDO backing devices can not be made smaller": [
  null,
  ""
 ],
 "VDO device": [
  null,
  "Dispositiu VDO"
 ],
 "VDO device $0": [
  null,
  "Dispositiu VDO $0"
 ],
 "Verify key": [
  null,
  ""
 ],
 "Very securely erasing $target": [
  null,
  "S'està eliminant de forma molt segura $target"
 ],
 "Volume": [
  null,
  "Volum"
 ],
 "Volume group": [
  null,
  "Grup de volums"
 ],
 "Volume group $0": [
  null,
  "Grup de volums $0"
 ],
 "Volume size is $0. Content size is $1.": [
  null,
  ""
 ],
 "Waiting for other software management operations to finish": [
  null,
  ""
 ],
 "What if tang-show-keys is not available?": [
  null,
  ""
 ],
 "Write-mostly": [
  null,
  "Escriptura-majoritària"
 ],
 "Your session has been terminated.": [
  null,
  "La vostra sessió ha estat finalitzada."
 ],
 "Your session has expired. Please log in again.": [
  null,
  "La vostra sessió ha vençut. Si us plau, torneu a iniciar la sessió."
 ],
 "[$0 bytes of binary data]": [
  null,
  "[$0 bytes de dades binàries]"
 ],
 "[binary data]": [
  null,
  "[dades binàries]"
 ],
 "[no data]": [
  null,
  "[sense dades]"
 ],
 "disk": [
  null,
  "disc"
 ],
 "drive": [
  null,
  ""
 ],
 "encryption": [
  null,
  ""
 ],
 "filesystem": [
  null,
  ""
 ],
 "format": [
  null,
  ""
 ],
 "fstab": [
  null,
  ""
 ],
 "iSCSI targets": [
  null,
  "Destinacions iSCSI"
 ],
 "iscsi": [
  null,
  ""
 ],
 "key slot $0": [
  null,
  ""
 ],
 "luks": [
  null,
  ""
 ],
 "lvm2": [
  null,
  ""
 ],
 "mkfs": [
  null,
  ""
 ],
 "mount": [
  null,
  ""
 ],
 "nbde": [
  null,
  ""
 ],
 "nfs": [
  null,
  ""
 ],
 "partition": [
  null,
  ""
 ],
 "raid": [
  null,
  ""
 ],
 "read only": [
  null,
  ""
 ],
 "tang": [
  null,
  ""
 ],
 "udisks": [
  null,
  ""
 ],
 "unknown target": [
  null,
  "objectiu desconegut"
 ],
 "unmount": [
  null,
  ""
 ],
 "unpartitioned space on $0": [
  null,
  "espai sense particionar a $0"
 ],
 "vdo": [
  null,
  ""
 ],
 "volume": [
  null,
  ""
 ],
 "storage-id-desc\u0004$0 file system": [
  null,
  "Sistema de fitxers $0"
 ],
 "storage-id-desc\u0004Encrypted data": [
  null,
  "Dades xifrades"
 ],
 "storage-id-desc\u0004Other data": [
  null,
  "Altres dades"
 ],
 "storage-id-desc\u0004Swap space": [
  null,
  "Espai d'intercanvi"
 ],
 "storage-id-desc\u0004Unrecognized data": [
  null,
  "Dades no reconegudes"
 ],
 "storage-id-desc\u0004VDO backing": [
  null,
  ""
 ],
 "storage\u0004Assessment": [
  null,
  ""
 ],
 "storage\u0004Bitmap": [
  null,
  ""
 ],
 "storage\u0004Capacity": [
  null,
  "Capacitat"
 ],
 "storage\u0004Device": [
  null,
  "Dispositiu"
 ],
 "storage\u0004Device file": [
  null,
  "Fitxer de dispositiu"
 ],
 "storage\u0004Optical drive": [
  null,
  "Unitat òptica"
 ],
 "storage\u0004Removable drive": [
  null,
  "Disc extraïble"
 ],
 "storage\u0004Serial number": [
  null,
  ""
 ],
 "storage\u0004World wide name": [
  null,
  ""
 ],
 "format-bytes\u0004bytes": [
  null,
  "bytes"
 ]
});
