cockpit.locale({
 "": {'plural-forms':function(n) {
var nplurals, plural;
nplurals=2; plural=n != 1;
return plural;
},
  "language": "ca",
  "x-generator": "Weblate 4.0.3"
 },
 "$0 exited with code $1": [
  null,
  "$0 va sortir amb el codi $1"
 ],
 "$0 failed": [
  null,
  "$0 ha fallat"
 ],
 "$0 killed with signal $1": [
  null,
  "$0 es va matar amb el senyal $1"
 ],
 "Access": [
  null,
  "Accés"
 ],
 "Account expiration": [
  null,
  "Venciment del compte"
 ],
 "Account not available or cannot be edited.": [
  null,
  "El compte no està disponible o no es pot editar."
 ],
 "Accounts": [
  null,
  "Comptes"
 ],
 "Add": [
  null,
  "Afegeix"
 ],
 "Add key": [
  null,
  "Afegeix una clau"
 ],
 "Add public key": [
  null,
  "Afegeix una clau pública"
 ],
 "Adding key": [
  null,
  "S'està afegint la clau"
 ],
 "Authorized public SSH keys": [
  null,
  "Claus SSH públiques autoritzades"
 ],
 "Back to accounts": [
  null,
  "Torna als comptes"
 ],
 "Cancel": [
  null,
  "Cancel·la"
 ],
 "Cannot forward login credentials": [
  null,
  ""
 ],
 "Change": [
  null,
  "Canvia"
 ],
 "Click $0 again to use the password anyway.": [
  null,
  ""
 ],
 "Close": [
  null,
  "Tanca"
 ],
 "Cockpit could not contact the given host.": [
  null,
  "Cockpit no ha pogut contactar amb l'amfitrió indicat."
 ],
 "Cockpit is not compatible with the software on the system.": [
  null,
  "Cockpit no és compatible amb el programari del sistema."
 ],
 "Cockpit is not installed on the system.": [
  null,
  "Cockpit no està instal·lat al sistema."
 ],
 "Confirm": [
  null,
  "Confirmació"
 ],
 "Connection has timed out.": [
  null,
  "La connexió ha excedit el temps."
 ],
 "Container administrator": [
  null,
  "Administrador del contenidor"
 ],
 "Create": [
  null,
  "Crea"
 ],
 "Create new account": [
  null,
  "Crea un compte nou"
 ],
 "Delete": [
  null,
  "Suprimeix"
 ],
 "Delete $0": [
  null,
  "Suprimeix $0"
 ],
 "Delete files": [
  null,
  "Suprimeix els fitxers"
 ],
 "Error saving authorized keys: ": [
  null,
  "Error en desar les claus autoritzades: "
 ],
 "Excellent password": [
  null,
  "Contrasenya excel·lent"
 ],
 "Failed to change password": [
  null,
  "Ha fallat el canvi de contrasenya"
 ],
 "Failed to load authorized keys.": [
  null,
  "Ha fallat la càrrega de les claus autoritzades."
 ],
 "Force change": [
  null,
  "Obliga el canvi"
 ],
 "Force password change": [
  null,
  "Obliga el canvi de contrasenya"
 ],
 "Full name": [
  null,
  "Nom complet"
 ],
 "Host key is incorrect": [
  null,
  "La clau d'amfitrió és incorrecta"
 ],
 "Image builder": [
  null,
  ""
 ],
 "Internal error": [
  null,
  "Error intern"
 ],
 "Invalid expiration date": [
  null,
  "Data de venciment no vàlida"
 ],
 "Invalid key": [
  null,
  "Clau no vàlida"
 ],
 "Invalid number of days": [
  null,
  "Nombre de dies no vàlid"
 ],
 "Last login": [
  null,
  "Últim inici de sessió"
 ],
 "Local accounts": [
  null,
  "Comptes locals"
 ],
 "Lock account": [
  null,
  "Bloqueja el compte"
 ],
 "Lock account on $0": [
  null,
  "Bloqueja el compte el $0"
 ],
 "Logged in": [
  null,
  "Autenticat"
 ],
 "Login failed": [
  null,
  "Ha fallat l'inici de sessió"
 ],
 "Managing user accounts": [
  null,
  ""
 ],
 "Never": [
  null,
  "Mai"
 ],
 "Never expire password": [
  null,
  "Mai venç la contrasenya"
 ],
 "Never lock account": [
  null,
  "No es bloqueja mai el compte"
 ],
 "New password": [
  null,
  "Contrasenya nova"
 ],
 "New password was not accepted": [
  null,
  "No s'ha acceptat la nova contrasenya"
 ],
 "No real name specified": [
  null,
  "Sense especificar el nom real"
 ],
 "No user name specified": [
  null,
  "Sense especificar el nom d'usuari"
 ],
 "Not permitted to perform this action.": [
  null,
  "No es permet realitzar aquesta acció."
 ],
 "Ok": [
  null,
  "D'acord"
 ],
 "Old password": [
  null,
  "Contrasenya antiga"
 ],
 "Old password not accepted": [
  null,
  "Contrasenya antiga no acceptada"
 ],
 "Password": [
  null,
  "Contrasenya"
 ],
 "Password expiration": [
  null,
  "Venciment de la contrasenya"
 ],
 "Password is not acceptable": [
  null,
  "La contrasenya no és acceptable"
 ],
 "Password is too weak": [
  null,
  "La contrasenya és massa feble"
 ],
 "Password must be changed": [
  null,
  "S'ha de canviar la contrasenya"
 ],
 "Paste the contents of your public SSH key file here": [
  null,
  "Enganxeu aquí el contingut del fitxer de la vostra clau SSH pública"
 ],
 "Please specify an expiration date": [
  null,
  "Si us plau, especifiqueu una data de venciment"
 ],
 "Prompting via passwd timed out": [
  null,
  "Per mitjà del temps d'espera de passwd"
 ],
 "Remove": [
  null,
  "Suprimeix"
 ],
 "Require password change every $0 days": [
  null,
  "Requereix el canvi de la contrasenya cada $0 dies"
 ],
 "Require password change on $0": [
  null,
  "Requereix el canvi de la contrasenya el $0"
 ],
 "Roles": [
  null,
  "Rols"
 ],
 "Server administrator": [
  null,
  "Administrador del servidor"
 ],
 "Server has closed the connection.": [
  null,
  "El servidor ha tancat la connexió."
 ],
 "Set password": [
  null,
  "Estableix la contrasenya"
 ],
 "Terminate session": [
  null,
  "Acaba la sessió"
 ],
 "The account '$0' will be forced to change their password on next login": [
  null,
  "El compte '$0' es veurà forçat a canviar de contrasenya el pròxim com que iniciï la sessió."
 ],
 "The key you provided was not valid.": [
  null,
  "La clau que heu proporcionat no era vàlida."
 ],
 "The passwords do not match": [
  null,
  "Les contrasenyes no coincideixen"
 ],
 "The server refused to authenticate using any supported methods.": [
  null,
  "El servidor ha refusat l'autenticació mitjançant qualsevol dels mètodes compatibles."
 ],
 "The user must log out and log back in to fully change roles.": [
  null,
  ""
 ],
 "The user name can only consist of letters from a-z, digits, dots, dashes and underscores.": [
  null,
  "El nom d'usuari només pot contenir lletres a-z, dígits, punts, guions baixos i guions."
 ],
 "There are no authorized public keys for this account.": [
  null,
  "No hi ha cap clau pública autoritzada per aquest compte."
 ],
 "This user name already exists": [
  null,
  "Aquest nom d'usuari ja existeix"
 ],
 "Too much data": [
  null,
  "Hi ha massa dades"
 ],
 "Unexpected error": [
  null,
  "Error inesperat"
 ],
 "Unix group: $0": [
  null,
  ""
 ],
 "Unnamed": [
  null,
  "Sense nom"
 ],
 "Untrusted host": [
  null,
  "Amfitrió no fiable"
 ],
 "User name": [
  null,
  "Nom d'usuari"
 ],
 "Validating key": [
  null,
  "S'està validant la clau"
 ],
 "You do not have permission to view the authorized public keys for this account.": [
  null,
  "No teniu el permís per visualitzar les claus públiques autoritzades per aquest compte."
 ],
 "You must wait longer to change your password": [
  null,
  ""
 ],
 "Your session has been terminated.": [
  null,
  "La vostra sessió ha estat finalitzada."
 ],
 "Your session has expired. Please log in again.": [
  null,
  "La vostra sessió ha vençut. Si us plau, torneu a iniciar la sessió."
 ],
 "access": [
  null,
  ""
 ],
 "keys": [
  null,
  ""
 ],
 "login": [
  null,
  ""
 ],
 "passwd": [
  null,
  ""
 ],
 "password": [
  null,
  ""
 ],
 "password quality": [
  null,
  ""
 ],
 "roles": [
  null,
  ""
 ],
 "ssh": [
  null,
  ""
 ],
 "user": [
  null,
  "usuari"
 ],
 "useradd": [
  null,
  ""
 ],
 "username": [
  null,
  ""
 ]
});
