cockpit.locale({
 "": {'plural-forms':function(n) {
var nplurals, plural;
nplurals=2; plural=n != 1;
return plural;
},
  "language": "nb_NO",
  "x-generator": "Weblate 4.5.1"
 },
 "$0 exited with code $1": [
  null,
  "$0 avsluttet med koden $1"
 ],
 "$0 failed": [
  null,
  "$0 feilet"
 ],
 "$0 killed with signal $1": [
  null,
  "$0 drept med signal $1"
 ],
 "Apply": [
  null,
  "Bruk"
 ],
 "Cancel": [
  null,
  "Avbryt"
 ],
 "Cannot forward login credentials": [
  null,
  "Kan ikke videresende påloggingsinformasjonen"
 ],
 "Cockpit could not contact the given host.": [
  null,
  "Cockpit kunne ikke kontakte den angitte verten."
 ],
 "Cockpit is not compatible with the software on the system.": [
  null,
  "Cockpit er ikke kompatibel med programvaren på systemet."
 ],
 "Cockpit is not installed on the system.": [
  null,
  "Cockpit er ikke installert på systemet."
 ],
 "Compress crash dumps to save space": [
  null,
  "Komprimer krasjdumper for å spare plass"
 ],
 "Compression": [
  null,
  "Komprimering"
 ],
 "Configuring kdump": [
  null,
  "Konfigurerer kdump"
 ],
 "Connection has timed out.": [
  null,
  "Tidsavbrudd for tilkoblingen."
 ],
 "Crash dump location": [
  null,
  "Crash dump plassering"
 ],
 "Crash system": [
  null,
  "Krasj system"
 ],
 "Directory": [
  null,
  "Katalog"
 ],
 "Directory $0 isn't writable or doesn't exist.": [
  null,
  "Katalogen $0 er ikke skrivbar eller eksisterer ikke."
 ],
 "Host key is incorrect": [
  null,
  "Vertsnøkkelen er feil"
 ],
 "Internal error": [
  null,
  "Intern feil"
 ],
 "Kdump service not installed. Please ensure package kexec-tools is installed.": [
  null,
  "Kdump-tjenesten er ikke installert. Forsikre deg om at pakke kexec-tools er installert."
 ],
 "Kernel Dump": [
  null,
  "Kjerne dump"
 ],
 "Kernel dump": [
  null,
  "Kjerne dump"
 ],
 "Learn more": [
  null,
  "Lær mer"
 ],
 "Loading...": [
  null,
  "Laster..."
 ],
 "Local filesystem": [
  null,
  "Lokalt filsystem"
 ],
 "Location": [
  null,
  "Plassering"
 ],
 "Login failed": [
  null,
  "Innlogging feilet"
 ],
 "Mount": [
  null,
  "Montér"
 ],
 "No configuration found": [
  null,
  "Ingen konfigurasjon funnet"
 ],
 "No memory reserved. Append a crashkernel option to the kernel command line (e.g. in /etc/default/grub) to reserve memory at boot time. Example: crashkernel=512M": [
  null,
  ""
 ],
 "None": [
  null,
  "Ingen"
 ],
 "Not permitted to perform this action.": [
  null,
  "Ikke tillatt å utføre denne handlingen."
 ],
 "Ok": [
  null,
  "Ok"
 ],
 "On a mounted device": [
  null,
  "På en montert enhet"
 ],
 "Raw to a device": [
  null,
  ""
 ],
 "Reading...": [
  null,
  "Lesing..."
 ],
 "Remote over NFS": [
  null,
  ""
 ],
 "Remote over SSH": [
  null,
  ""
 ],
 "Reserved memory": [
  null,
  "Reservert minne"
 ],
 "Server": [
  null,
  "Server"
 ],
 "Server has closed the connection.": [
  null,
  "Serveren har lukket forbindelsen."
 ],
 "Service has an error": [
  null,
  "Tjenesten har en feil"
 ],
 "Service is running": [
  null,
  "Tjenesten kjører"
 ],
 "Service is starting": [
  null,
  "Tjenesten starter"
 ],
 "Service is stopped": [
  null,
  "Tjenesten er stoppet"
 ],
 "Service is stopping": [
  null,
  "Tjenesten stopper"
 ],
 "Status": [
  null,
  "Status"
 ],
 "Test configuration": [
  null,
  "Test konfigurasjon"
 ],
 "Test is only available while the kdump service is running.": [
  null,
  "Test er bare tilgjengelig mens kdump-tjenesten kjører."
 ],
 "Test kdump settings": [
  null,
  "Test kdump-innstillinger"
 ],
 "The server refused to authenticate using any supported methods.": [
  null,
  "Serveren nektet å godkjenne ved hjelp av de støttede metodene."
 ],
 "This will test kdump settings by crashing the kernel and thereby the system. Depending on the settings, the system may not automatically reboot and the process may take a while.": [
  null,
  "Dette vil teste kdump-innstillinger ved å krasje kjernen og derved systemet. Avhengig av innstillingene, kan det hende at systemet ikke starter på nytt automatisk, og prosessen kan ta en stund."
 ],
 "This will test the kdump configuration by crashing the kernel.": [
  null,
  "Dette vil teste kdump-konfigurasjonen ved å krasje kjernen."
 ],
 "Too much data": [
  null,
  "For mye data"
 ],
 "Unable to apply settings: $0": [
  null,
  "Kan ikke bruke innstillingene: $0"
 ],
 "Untrusted host": [
  null,
  ""
 ],
 "Your session has been terminated.": [
  null,
  "Økten din er avsluttet."
 ],
 "Your session has expired. Please log in again.": [
  null,
  "Økten din har utløpt. Vennligst logg inn igjen."
 ],
 "crash": [
  null,
  "krasj"
 ],
 "invalid: multiple targets defined": [
  null,
  "ugyldig: flere mål er definert"
 ],
 "kdump": [
  null,
  "kdump"
 ],
 "kdump status": [
  null,
  "kdump status"
 ],
 "locally in $0": [
  null,
  "lokalt i $0"
 ],
 "nfs dump target isn't formatted as server:path": [
  null,
  "nfs dump mål er ikke formatert som server:sti"
 ],
 "ssh key": [
  null,
  "ssh nøkkel"
 ],
 "ssh key isn't a path": [
  null,
  "ssh-nøkkel er ikke en bane"
 ],
 "ssh server is empty": [
  null,
  "ssh server er tom"
 ]
});
