cockpit.locale({
 "": {'plural-forms':function(n) {
var nplurals, plural;
nplurals=2; plural=n != 1;
return plural;
},
  "language": "nb_NO",
  "x-generator": "Weblate 4.5.1"
 },
 "$0 CPU": [
  "$0 CPUs",
  "$0 CPU",
  "$0 CPUer"
 ],
 "$0 GiB available": [
  null,
  "$0 GiB tilgjengelig"
 ],
 "$0 GiB total": [
  null,
  "$0 GiB totalt"
 ],
 "$0 exited with code $1": [
  null,
  "$0 avsluttet med koden $1"
 ],
 "$0 failed": [
  null,
  "$0 feilet"
 ],
 "$0 free": [
  null,
  "$0 ledig"
 ],
 "$0 is not available from any repository.": [
  null,
  "$0 er ikke tilgjengelig fra noe depot."
 ],
 "$0 killed with signal $1": [
  null,
  "$0 drept med signal $1"
 ],
 "$0 page": [
  "$0 pages",
  "$0 side",
  "$0 sider"
 ],
 "$0 total": [
  null,
  "$0 totalt"
 ],
 "$0 will be installed.": [
  null,
  "$0 vil bli installert."
 ],
 "1 min": [
  null,
  "1 min"
 ],
 "15 min": [
  null,
  "15 min"
 ],
 "5 min": [
  null,
  "5 min"
 ],
 "Absent": [
  null,
  "Fraværende"
 ],
 "Additional packages:": [
  null,
  "Ekstra pakker:"
 ],
 "Advanced TCA": [
  null,
  "Avansert TCA"
 ],
 "All logs": [
  null,
  "Alle logger"
 ],
 "All-in-one": [
  null,
  "Alt i ett"
 ],
 "Blade": [
  null,
  "Blad"
 ],
 "Blade enclosure": [
  null,
  "Blad-kabinett"
 ],
 "Bus expansion chassis": [
  null,
  ""
 ],
 "CPU": [
  null,
  "CPU"
 ],
 "CPU spike": [
  null,
  "CPU-topp"
 ],
 "CPU usage": [
  null,
  "CPU-bruk"
 ],
 "Cancel": [
  null,
  "Avbryt"
 ],
 "Cannot forward login credentials": [
  null,
  "Kan ikke videresende påloggingsinformasjonen"
 ],
 "Checking installed software": [
  null,
  "Kontrollerer installert programvare"
 ],
 "Cockpit could not contact the given host.": [
  null,
  "Cockpit kunne ikke kontakte den angitte verten."
 ],
 "Cockpit is not compatible with the software on the system.": [
  null,
  "Cockpit er ikke kompatibel med programvaren på systemet."
 ],
 "Cockpit is not installed on the system.": [
  null,
  "Cockpit er ikke installert på systemet."
 ],
 "Compact PCI": [
  null,
  ""
 ],
 "Connection has timed out.": [
  null,
  "Tidsavbrudd for tilkoblingen."
 ],
 "Convertible": [
  null,
  "Konverterbar"
 ],
 "Core $0": [
  null,
  "Kjerne $0"
 ],
 "Desktop": [
  null,
  ""
 ],
 "Detachable": [
  null,
  ""
 ],
 "Disk I/O": [
  null,
  "Disk I/U"
 ],
 "Disk I/O spike": [
  null,
  "Disk I/O-topp"
 ],
 "Disks": [
  null,
  "Disker"
 ],
 "Docking station": [
  null,
  "Dokkingstasjon"
 ],
 "Downloading $0": [
  null,
  "Laster ned $0"
 ],
 "Dual rank": [
  null,
  "Dobbel rangering"
 ],
 "Embedded PC": [
  null,
  "Innebygd PC"
 ],
 "Error has occurred": [
  null,
  "Det har oppstått en feil"
 ],
 "Event": [
  null,
  "Hendelse"
 ],
 "Event logs": [
  null,
  "Hendelseslogger"
 ],
 "Expansion chassis": [
  null,
  ""
 ],
 "Handheld": [
  null,
  "Håndholdt"
 ],
 "Host key is incorrect": [
  null,
  "Vertsnøkkelen er feil"
 ],
 "In": [
  null,
  "Inn"
 ],
 "Install": [
  null,
  "Installer"
 ],
 "Install cockpit-pcp": [
  null,
  "Installer cockpit-pcp"
 ],
 "Install software": [
  null,
  "Installer programvare"
 ],
 "Installing $0": [
  null,
  "Installerer $0"
 ],
 "Interface": [
  null,
  "Grensesnitt"
 ],
 "Internal error": [
  null,
  "Intern feil"
 ],
 "IoT gateway": [
  null,
  "IoT-gateway"
 ],
 "Is 'pmlogger' service running?": [
  null,
  "Kjører 'pmlogger' -tjenesten?"
 ],
 "Jump to": [
  null,
  "Gå til"
 ],
 "Laptop": [
  null,
  ""
 ],
 "Learn more": [
  null,
  "Lær mer"
 ],
 "Load": [
  null,
  "Last"
 ],
 "Load earlier data": [
  null,
  "Last tidligere data"
 ],
 "Load spike": [
  null,
  "Last-topp"
 ],
 "Loading...": [
  null,
  "Laster..."
 ],
 "Log out": [
  null,
  "Logg ut"
 ],
 "Login failed": [
  null,
  "Innlogging feilet"
 ],
 "Low profile desktop": [
  null,
  ""
 ],
 "Lunch box": [
  null,
  "Lunsjboks"
 ],
 "Main server chassis": [
  null,
  ""
 ],
 "Memory": [
  null,
  "Minne"
 ],
 "Memory spike": [
  null,
  "Minne topp"
 ],
 "Memory usage": [
  null,
  "Minnebruk"
 ],
 "Metrics history could not be loaded": [
  null,
  ""
 ],
 "Mini PC": [
  null,
  "Mini-PC"
 ],
 "Mini tower": [
  null,
  ""
 ],
 "Multi-system chassis": [
  null,
  ""
 ],
 "Network": [
  null,
  "Nettverk"
 ],
 "Network I/O": [
  null,
  "Nettverk I/U"
 ],
 "Network I/O spike": [
  null,
  "Nettverk I/O topp"
 ],
 "Network usage": [
  null,
  "Nettverksbruk"
 ],
 "No data available": [
  null,
  "Ingen data tilgjengelig"
 ],
 "No data available between $0 and $1": [
  null,
  "Ingen data tilgjengelig mellom $0 og $1"
 ],
 "No logs found": [
  null,
  "Ingen logger funnet"
 ],
 "Not permitted to perform this action.": [
  null,
  "Ikke tillatt å utføre denne handlingen."
 ],
 "Notebook": [
  null,
  ""
 ],
 "Ok": [
  null,
  "Ok"
 ],
 "Other": [
  null,
  "Annen"
 ],
 "Out": [
  null,
  "Ut"
 ],
 "Overview": [
  null,
  "Oversikt"
 ],
 "Package cockpit-pcp is missing for metrics history": [
  null,
  "Pakke cockpit-pcp mangler i metrikk-historikken"
 ],
 "PackageKit crashed": [
  null,
  "PackageKit krasjet"
 ],
 "Performance Metrics": [
  null,
  "Ytelsesmålinger"
 ],
 "Peripheral chassis": [
  null,
  "Perifert chassis"
 ],
 "Pizza box": [
  null,
  "Pizzaboks"
 ],
 "Portable": [
  null,
  "Bærbar"
 ],
 "Present": [
  null,
  "Til stede"
 ],
 "RAID chassis": [
  null,
  "RAID chassis"
 ],
 "RAM": [
  null,
  "RAM"
 ],
 "Rack mount chassis": [
  null,
  ""
 ],
 "Read": [
  null,
  "Les"
 ],
 "Reboot": [
  null,
  "Omstart"
 ],
 "Removals:": [
  null,
  ""
 ],
 "Removing $0": [
  null,
  "Fjerner $0"
 ],
 "Sealed-case PC": [
  null,
  ""
 ],
 "Server has closed the connection.": [
  null,
  "Serveren har lukket forbindelsen."
 ],
 "Service": [
  null,
  "Tjeneste"
 ],
 "Single rank": [
  null,
  ""
 ],
 "Space-saving computer": [
  null,
  "Plassbesparende datamaskin"
 ],
 "Stick PC": [
  null,
  ""
 ],
 "Sub-Chassis": [
  null,
  ""
 ],
 "Sub-Notebook": [
  null,
  ""
 ],
 "Swap": [
  null,
  "Swap"
 ],
 "Swap out": [
  null,
  "Swap ut"
 ],
 "Tablet": [
  null,
  "Nettbrett"
 ],
 "The server refused to authenticate using any supported methods.": [
  null,
  "Serveren nektet å godkjenne ved hjelp av de støttede metodene."
 ],
 "Today": [
  null,
  "I dag"
 ],
 "Too much data": [
  null,
  "For mye data"
 ],
 "Top 5 CPU services": [
  null,
  "Topp 5 CPU-tjenester"
 ],
 "Top 5 memory services": [
  null,
  "Topp 5 minnetjenester"
 ],
 "Total size: $0": [
  null,
  "Total størrelse: $0"
 ],
 "Tower": [
  null,
  ""
 ],
 "Troubleshoot": [
  null,
  "Feilsøk"
 ],
 "Unknown": [
  null,
  "Ukjent"
 ],
 "Untrusted host": [
  null,
  ""
 ],
 "Usage": [
  null,
  "Bruk"
 ],
 "Used": [
  null,
  "Brukt"
 ],
 "Waiting for other software management operations to finish": [
  null,
  "Venter på at andre programvareadministrasjons-operasjoner skal fullføres"
 ],
 "Write": [
  null,
  "Skriv"
 ],
 "You need to relogin to be able to see metrics": [
  null,
  ""
 ],
 "Your session has been terminated.": [
  null,
  "Økten din er avsluttet."
 ],
 "Your session has expired. Please log in again.": [
  null,
  "Økten din har utløpt. Vennligst logg inn igjen."
 ],
 "[$0 bytes of binary data]": [
  null,
  "[$0 bytes med binære data]"
 ],
 "[binary data]": [
  null,
  "[binære data]"
 ],
 "[no data]": [
  null,
  "[ingen data]"
 ],
 "nice": [
  null,
  ""
 ],
 "sys": [
  null,
  "sys"
 ],
 "user": [
  null,
  "bruker"
 ]
});
