cockpit.locale({
 "": {'plural-forms':function(n) {
var nplurals, plural;
nplurals=2; plural=n != 1;
return plural;
},
  "language": "ca",
  "x-generator": "Weblate 4.0.3"
 },
 "$0 exited with code $1": [
  null,
  "$0 va sortir amb el codi $1"
 ],
 "$0 failed": [
  null,
  "$0 ha fallat"
 ],
 "$0 killed with signal $1": [
  null,
  "$0 es va matar amb el senyal $1"
 ],
 "Applications": [
  null,
  "Aplicacions"
 ],
 "Cancel": [
  null,
  "Cancel·la"
 ],
 "Cannot forward login credentials": [
  null,
  ""
 ],
 "Checking for new applications": [
  null,
  "Comprovació per si hi ha aplicacions noves"
 ],
 "Close": [
  null,
  "Tanca"
 ],
 "Cockpit could not contact the given host.": [
  null,
  "Cockpit no ha pogut contactar amb l'amfitrió indicat."
 ],
 "Cockpit is not compatible with the software on the system.": [
  null,
  "Cockpit no és compatible amb el programari del sistema."
 ],
 "Cockpit is not installed on the system.": [
  null,
  "Cockpit no està instal·lat al sistema."
 ],
 "Connection has timed out.": [
  null,
  "La connexió ha excedit el temps."
 ],
 "Error": [
  null,
  "Error"
 ],
 "Go to application": [
  null,
  "Vés a l'aplicació"
 ],
 "Host key is incorrect": [
  null,
  "La clau d'amfitrió és incorrecta"
 ],
 "Install": [
  null,
  "Instal·la"
 ],
 "Installing": [
  null,
  "S'està instal·lant"
 ],
 "Internal error": [
  null,
  "Error intern"
 ],
 "Login failed": [
  null,
  "Ha fallat l'inici de sessió"
 ],
 "No applications installed or available": [
  null,
  "No hi ha cap aplicació instal·lada o disponible"
 ],
 "No description provided.": [
  null,
  "No s'ha proporcionat cap descripció."
 ],
 "No installation package found for this application.": [
  null,
  "No s'ha trobat cap paquet d'instal·lació per a aquesta aplicació."
 ],
 "Not permitted to perform this action.": [
  null,
  "No es permet realitzar aquesta acció."
 ],
 "Ok": [
  null,
  "D'acord"
 ],
 "PackageKit crashed": [
  null,
  "PackageKit s'ha estavellat."
 ],
 "Remove": [
  null,
  "Suprimeix"
 ],
 "Removing": [
  null,
  ""
 ],
 "Server has closed the connection.": [
  null,
  "El servidor ha tancat la connexió."
 ],
 "The server refused to authenticate using any supported methods.": [
  null,
  "El servidor ha refusat l'autenticació mitjançant qualsevol dels mètodes compatibles."
 ],
 "Too much data": [
  null,
  "Hi ha massa dades"
 ],
 "Unknown application": [
  null,
  "Aplicació desconeguda"
 ],
 "Untrusted host": [
  null,
  "Amfitrió no fiable"
 ],
 "Waiting for other programs to finish using the package manager...": [
  null,
  ""
 ],
 "Your session has been terminated.": [
  null,
  "La vostra sessió ha estat finalitzada."
 ],
 "Your session has expired. Please log in again.": [
  null,
  "La vostra sessió ha vençut. Si us plau, torneu a iniciar la sessió."
 ],
 "add-on": [
  null,
  ""
 ],
 "addon": [
  null,
  ""
 ],
 "apps": [
  null,
  ""
 ],
 "extension": [
  null,
  ""
 ],
 "install": [
  null,
  ""
 ],
 "plugin": [
  null,
  ""
 ]
});
