cockpit.locale({
 "": {'plural-forms':function(n) {
var nplurals, plural;
nplurals=2; plural=n != 1;
return plural;
},
  "language": "ca",
  "x-generator": "Weblate 4.0.3"
 },
 "$0 exited with code $1": [
  null,
  "$0 va sortir amb el codi $1"
 ],
 "$0 failed": [
  null,
  "$0 ha fallat"
 ],
 "$0 is not available from any repository.": [
  null,
  ""
 ],
 "$0 killed with signal $1": [
  null,
  "$0 es va matar amb el senyal $1"
 ],
 "$0 package needs a system reboot": [
  "$0 packages need a system reboot",
  "",
  ""
 ],
 "$0 service needs to be restarted": [
  "$0 services need to be restarted",
  "",
  ""
 ],
 "$0 will be installed.": [
  null,
  ""
 ],
 ", including $1 security fix": [
  ", including $1 security fixes",
  ", incloent-hi $1 correcció de seguretat",
  ", incloent-hi $1 correccions de seguretat"
 ],
 "1 minute": [
  null,
  "1 minut"
 ],
 "20 minutes": [
  null,
  "20 minuts"
 ],
 "40 minutes": [
  null,
  "40 minuts"
 ],
 "5 minutes": [
  null,
  "5 minuts"
 ],
 "60 minutes": [
  null,
  "60 minuts"
 ],
 "A service needs to be restarted for the updates to take effect:": [
  "Some services need to be restarted for the updates to take effect:",
  "",
  ""
 ],
 "Additional packages:": [
  null,
  ""
 ],
 "Applying updates": [
  null,
  "Aplicació de les actualitzacions"
 ],
 "Applying updates failed": [
  null,
  "Ha fallat l'aplicació de les actualitzacions"
 ],
 "Automatic updates": [
  null,
  "Actualitzacions automàtiques"
 ],
 "Automatically using NTP": [
  null,
  "Automàticament mitjançant NTP"
 ],
 "Automatically using specific NTP servers": [
  null,
  "Automàticament mitjançant servidors NTP específics"
 ],
 "Available updates": [
  null,
  "Actualitzacions disponibles"
 ],
 "Bug fix updates available": [
  null,
  "Hi ha disponibles actualitzacions de correcció d'errors"
 ],
 "CVE": [
  null,
  ""
 ],
 "Cancel": [
  null,
  "Cancel·la"
 ],
 "Cannot forward login credentials": [
  null,
  ""
 ],
 "Cannot schedule event in the past": [
  null,
  "No es pot planificar un esdeveniment del passat"
 ],
 "Change": [
  null,
  "Canvia"
 ],
 "Change system time": [
  null,
  "Canvia l'hora del sistema"
 ],
 "Check for updates": [
  null,
  "Comprova si hi ha actualitzacions"
 ],
 "Checking for package updates...": [
  null,
  ""
 ],
 "Checking installed software": [
  null,
  ""
 ],
 "Cockpit could not contact the given host.": [
  null,
  "Cockpit no ha pogut contactar amb l'amfitrió indicat."
 ],
 "Cockpit is not compatible with the software on the system.": [
  null,
  "Cockpit no és compatible amb el programari del sistema."
 ],
 "Cockpit is not installed on the system.": [
  null,
  "Cockpit no està instal·lat al sistema."
 ],
 "Connection has timed out.": [
  null,
  "La connexió ha excedit el temps."
 ],
 "Danger alert:": [
  null,
  ""
 ],
 "Delay": [
  null,
  "Retard"
 ],
 "Details": [
  null,
  "Detalls"
 ],
 "Disabled": [
  null,
  "Inhabilitat"
 ],
 "Downloaded": [
  null,
  "Baixat"
 ],
 "Downloading": [
  null,
  "S'està baixant"
 ],
 "Downloading $0": [
  null,
  ""
 ],
 "Edit": [
  null,
  "Edita"
 ],
 "Enhancement updates available": [
  null,
  ""
 ],
 "Failed to parse unit files for dnf-automatic.timer or dnf-automatic-install.timer. Please remove custom overrides to enable this feature.": [
  null,
  ""
 ],
 "Fridays": [
  null,
  ""
 ],
 "Host key is incorrect": [
  null,
  "La clau d'amfitrió és incorrecta"
 ],
 "Ignore": [
  null,
  "Ignora"
 ],
 "Info": [
  null,
  ""
 ],
 "Initializing...": [
  null,
  "S'està inicialitzant..."
 ],
 "Install": [
  null,
  "Instal·la"
 ],
 "Install all updates": [
  null,
  "Instal·la totes les actualitzacions"
 ],
 "Install security updates": [
  null,
  "Instal·la les actualitzacions de seguretat"
 ],
 "Install software": [
  null,
  ""
 ],
 "Installed": [
  null,
  "Instal·lat"
 ],
 "Installing": [
  null,
  "S'està instal·lant"
 ],
 "Installing $0": [
  null,
  ""
 ],
 "Internal error": [
  null,
  "Error intern"
 ],
 "Invalid date format": [
  null,
  "Format de data no vàlid"
 ],
 "Invalid date format and invalid time format": [
  null,
  "Format no vàlid de la data i l'hora"
 ],
 "Invalid time format": [
  null,
  "Format d'hora no vàlid"
 ],
 "Loading available updates failed": [
  null,
  "Ha fallat la càrrega de les actualitzacions disponibles"
 ],
 "Loading available updates, please wait...": [
  null,
  "S'estan carregant les actualitzacions disponibles, espereu..."
 ],
 "Log messages": [
  null,
  "Missatges del registre"
 ],
 "Login failed": [
  null,
  "Ha fallat l'inici de sessió"
 ],
 "Manually": [
  null,
  "Manualment"
 ],
 "Message to logged in users": [
  null,
  "Missatge per als usuaris que hagin iniciat la sessió"
 ],
 "Mondays": [
  null,
  ""
 ],
 "NTP server": [
  null,
  "Servidor NTP"
 ],
 "Name": [
  null,
  "Nom"
 ],
 "Need at least one NTP server": [
  null,
  "Com a mínim es necessita un servidor NTP"
 ],
 "No delay": [
  null,
  "Sense retard"
 ],
 "Not permitted to perform this action.": [
  null,
  "No es permet realitzar aquesta acció."
 ],
 "Not registered": [
  null,
  ""
 ],
 "Not synchronized": [
  null,
  "No sincronitzat"
 ],
 "Ok": [
  null,
  "D'acord"
 ],
 "Package information": [
  null,
  "Informació dels paquets"
 ],
 "PackageKit crashed": [
  null,
  "PackageKit s'ha estavellat."
 ],
 "PackageKit is not installed": [
  null,
  "PackageKit no està instal·lat"
 ],
 "PackageKit reported error code $0": [
  null,
  "PackageKit ha informat un codi d'error $0"
 ],
 "Pick date": [
  null,
  ""
 ],
 "Please reload the page after resolving the issue.": [
  null,
  ""
 ],
 "Reboot": [
  null,
  "Rearrencada"
 ],
 "Reboot system...": [
  null,
  ""
 ],
 "Refreshing package information": [
  null,
  "Refrescament de la informació dels paquets"
 ],
 "Register…": [
  null,
  "Registra..."
 ],
 "Reloading the state of remaining services": [
  null,
  ""
 ],
 "Removals:": [
  null,
  ""
 ],
 "Removing $0": [
  null,
  ""
 ],
 "Restarting": [
  null,
  "S'està reiniciant"
 ],
 "Saturdays": [
  null,
  ""
 ],
 "Security updates available": [
  null,
  ""
 ],
 "Server has closed the connection.": [
  null,
  "El servidor ha tancat la connexió."
 ],
 "Set time": [
  null,
  "Ajusta l'hora"
 ],
 "Set up": [
  null,
  "Configurat"
 ],
 "Setting up": [
  null,
  "S'està configurant"
 ],
 "Severity": [
  null,
  "Gravetat"
 ],
 "Shut down": [
  null,
  "Apaga"
 ],
 "Software updates": [
  null,
  "Actualitzacions"
 ],
 "Some other program is currently using the package manager, please wait...": [
  null,
  ""
 ],
 "Some software needs to be restarted manually": [
  null,
  ""
 ],
 "Specific time": [
  null,
  "Instant concret"
 ],
 "Status": [
  null,
  "Estat"
 ],
 "Sundays": [
  null,
  ""
 ],
 "Synchronized": [
  null,
  "Sincronitzat"
 ],
 "System is up to date": [
  null,
  "El sistema està al dia"
 ],
 "The following service will be restarted:": [
  "The following services will be restarted:",
  "",
  ""
 ],
 "The server refused to authenticate using any supported methods.": [
  null,
  "El servidor ha refusat l'autenticació mitjançant qualsevol dels mètodes compatibles."
 ],
 "This host will reboot after updates are installed.": [
  null,
  ""
 ],
 "This system is not registered": [
  null,
  "Aquest sistema no està registrat"
 ],
 "Thursdays": [
  null,
  ""
 ],
 "Time zone": [
  null,
  "Zona horària"
 ],
 "To get software updates, this system needs to be registered with Red Hat, either using the Red Hat Customer Portal or a local subscription server.": [
  null,
  "Per obtenir actualitzacions de programari, aquest sistema ha d'estar registrat a Red Hat, ja sigui utilitzant Red Hat Customer Portal o un servidor de subscripció local."
 ],
 "Too much data": [
  null,
  "Hi ha massa dades"
 ],
 "Total size: $0": [
  null,
  ""
 ],
 "Tuesdays": [
  null,
  ""
 ],
 "Type": [
  null,
  "Tipus"
 ],
 "Untrusted host": [
  null,
  "Amfitrió no fiable"
 ],
 "Update history": [
  null,
  "Historial d'actualitzacions"
 ],
 "Update log": [
  null,
  "Registre d'actualitzacions"
 ],
 "Updated": [
  null,
  "Actualitzat"
 ],
 "Updates available": [
  null,
  "Actualitzacions disponibles"
 ],
 "Updating": [
  null,
  "S'està actualitzant"
 ],
 "Verified": [
  null,
  "Verificat"
 ],
 "Verifying": [
  null,
  "S'està verificant"
 ],
 "Version": [
  null,
  "Versió"
 ],
 "Waiting for other software management operations to finish": [
  null,
  ""
 ],
 "Wednesdays": [
  null,
  ""
 ],
 "When": [
  null,
  ""
 ],
 "When the Web Console is restarted, you will no longer see progress information. However, the update process will continue in the background. Reconnect to continue watching the update process.": [
  null,
  ""
 ],
 "Your server will close the connection soon. You can reconnect after it has restarted.": [
  null,
  "El vostre servidor tancarà la connexió aviat. Podeu tornar a connectar un cop s'hagi reiniciat."
 ],
 "Your session has been terminated.": [
  null,
  "La vostra sessió ha estat finalitzada."
 ],
 "Your session has expired. Please log in again.": [
  null,
  "La vostra sessió ha vençut. Si us plau, torneu a iniciar la sessió."
 ],
 "apt-get": [
  null,
  ""
 ],
 "bug fix": [
  null,
  ""
 ],
 "dnf": [
  null,
  ""
 ],
 "enhancement": [
  null,
  ""
 ],
 "every day": [
  null,
  "cada dia"
 ],
 "package": [
  null,
  ""
 ],
 "packagekit": [
  null,
  ""
 ],
 "security": [
  null,
  ""
 ],
 "show less": [
  null,
  "mostra menys"
 ],
 "show more": [
  null,
  "mostra més"
 ],
 "will be applied $0 at $1": [
  null,
  ""
 ],
 "yum": [
  null,
  ""
 ]
});
