window.cockpit_po = {
 "": {'plural-forms':function(n) {
var nplurals, plural;
nplurals=2; plural=n != 1;
return plural;
},
  "language": "nb_NO",
  "x-generator": "Weblate 4.5.1"
 },
 "$0 error": [
  null,
  "$0 feil"
 ],
 "$0 exited with code $1": [
  null,
  "$0 avsluttet med koden $1"
 ],
 "$0 failed": [
  null,
  "$0 feilet"
 ],
 "$0 key changed": [
  null,
  "$0 nøkkel endret"
 ],
 "$0 killed with signal $1": [
  null,
  "$0 drept med signal $1"
 ],
 "A modern browser is required for security, reliability, and performance.": [
  null,
  "Det kreves en moderne nettleser for sikkerhet, pålitelighet og ytelse."
 ],
 "Accept key and log in": [
  null,
  "Godta nøkkel og logg inn"
 ],
 "Authentication failed": [
  null,
  "Autentisering feilet"
 ],
 "Authentication failed: Server closed connection": [
  null,
  "Autentisering feilet: Serveren lukket tilkoblingen"
 ],
 "Cancel": [
  null,
  "Avbryt"
 ],
 "Cannot forward login credentials": [
  null,
  "Kan ikke videresende påloggingsinformasjonen"
 ],
 "Changed keys are often the result of an operating system reinstallation. However, an unexpected change may indicate a third-party attempt to intercept your connection.": [
  null,
  "Endrede nøkler er ofte resultatet av reinstallering av operativsystemet. Imidlertid kan en uventet endring indikere et tredjepartsforsøk på å fange opp forbindelsen din."
 ],
 "Cockpit": [
  null,
  "Cockpit"
 ],
 "Cockpit authentication is configured incorrectly.": [
  null,
  "Cockpit autentisering er konfigurert feil."
 ],
 "Cockpit could not contact the given host.": [
  null,
  "Cockpit kunne ikke kontakte den angitte verten."
 ],
 "Cockpit is a server manager that makes it easy to administer your Linux servers via a web browser. Jumping between the terminal and the web tool is no problem. A service started via Cockpit can be stopped via the terminal. Likewise, if an error occurs in the terminal, it can be seen in the Cockpit journal interface.": [
  null,
  "Cockpit er en serveradministrator som gjør det enkelt å administrere Linux-serverne dine via en nettleser. Å bytte mellom terminalen og nettverktøyet er ikke noe problem. En tjeneste startet via Cockpit kan stoppes via terminalen. På samme måte, hvis det oppstår en feil i terminalen, kan den sees i Cockpit journal-grensesnittet."
 ],
 "Cockpit is not compatible with the software on the system.": [
  null,
  "Cockpit er ikke kompatibel med programvaren på systemet."
 ],
 "Cockpit is not installed on the system.": [
  null,
  "Cockpit er ikke installert på systemet."
 ],
 "Cockpit is perfect for new sysadmins, allowing them to easily perform simple tasks such as storage administration, inspecting journals and starting and stopping services. You can monitor and administer several servers at the same time. Just add them with a single click and your machines will look after its buddies.": [
  null,
  "Cockpit er perfekt for nye sysadminer, slik at de enkelt kan utføre enkle oppgaver som lagringsadministrasjon, inspisere journaler og starte og stoppe tjenester. Du kan overvåke og administrere flere servere samtidig. Bare legg dem til med et enkelt klikk, så vil maskinene dine se etter kompisene."
 ],
 "Connect to": [
  null,
  "Koble til"
 ],
 "Connection has timed out.": [
  null,
  "Tidsavbrudd for tilkoblingen."
 ],
 "Download a new browser for free": [
  null,
  "Last ned en ny nettleser gratis"
 ],
 "Host key is incorrect": [
  null,
  "Vertsnøkkelen er feil"
 ],
 "If the fingerprint matches, click \"Accept key and log in\". Otherwise, do not log in and contact your administrator.": [
  null,
  "Hvis fingeravtrykket stemmer overens, klikker du på \"Godta nøkkel og logg inn\". Ellers ikke logg inn og kontakt administratoren din."
 ],
 "Internal error": [
  null,
  "Intern feil"
 ],
 "Internal error: Invalid challenge header": [
  null,
  ""
 ],
 "Log in": [
  null,
  "Logg inn"
 ],
 "Log in with your server user account.": [
  null,
  "Logg inn med server brukerkontoen din."
 ],
 "Login again": [
  null,
  "Logg inn igjen"
 ],
 "Login failed": [
  null,
  "Innlogging feilet"
 ],
 "Logout successful": [
  null,
  ""
 ],
 "New host": [
  null,
  "Ny vert"
 ],
 "Not permitted to perform this action.": [
  null,
  "Ikke tillatt å utføre denne handlingen."
 ],
 "Once Cockpit is installed, enable it with \"systemctl enable --now cockpit.socket\".": [
  null,
  "Når Cockpit er installert, kan den aktiveres med \"systemctl enable --now cockpit.socket\"."
 ],
 "Or use a bundled browser": [
  null,
  "Eller bruk en nettleser som følger med"
 ],
 "Other options": [
  null,
  "Andre alternativer"
 ],
 "Password": [
  null,
  "Passord"
 ],
 "Permission denied": [
  null,
  "Ingen tilgang"
 ],
 "Please enable JavaScript to use the Web Console.": [
  null,
  "Aktiver JavaScript for å bruke Web konsollet."
 ],
 "Please specify the host to connect to": [
  null,
  "Vennligst angi verten du vil koble til"
 ],
 "Refusing to connect. Host is unknown": [
  null,
  "Nekter å koble til. Verten er ukjent"
 ],
 "Refusing to connect. Hostkey does not match": [
  null,
  "Nekter å koble til. Vertsnøkkel samsvarer ikke"
 ],
 "Refusing to connect. Hostkey is unknown": [
  null,
  "Nekter å koble til. Vertsnøkkel er ukjent"
 ],
 "Server": [
  null,
  "Server"
 ],
 "Server has closed the connection.": [
  null,
  "Serveren har lukket forbindelsen."
 ],
 "The resulting fingerprint is fine to share via public methods, including email.": [
  null,
  "Det resulterende fingeravtrykket er greit å dele via offentlige metoder, inkludert e-post."
 ],
 "The server refused to authenticate '$0' using password authentication, and no other supported authentication methods are available.": [
  null,
  "Serveren nektet å autentisere '$0' ved hjelp av passordgodkjenning, og ingen andre støttede godkjenningsmetoder er tilgjengelige."
 ],
 "The server refused to authenticate using any supported methods.": [
  null,
  "Serveren nektet å godkjenne ved hjelp av de støttede metodene."
 ],
 "The web browser configuration prevents Cockpit from running (inaccessible $0)": [
  null,
  "Nettleserkonfigurasjonen forhindrer Cockpit i å kjøre (utilgjengelig $0)"
 ],
 "This web browser is too old to run the Web Console (missing $0)": [
  null,
  "Denne nettleseren er for gammel til å kjøre web konsollet (mangler $0)"
 ],
 "To ensure that your connection is not intercepted by a malicious third-party, please verify the host key fingerprint:": [
  null,
  "For å sikre at forbindelsen din ikke blir fanget opp av en ondsinnet tredjepart, må du verifisere vertsnøkkelens fingeravtrykk:"
 ],
 "To verify a fingerprint, run the following on $0 while physically sitting at the machine or through a trusted network:": [
  null,
  "For å bekrefte et fingeravtrykk, kjør følgende på $ 0 mens du sitter fysisk ved maskinen eller gjennom et pålitelig nettverk:"
 ],
 "Too much data": [
  null,
  "For mye data"
 ],
 "Try again": [
  null,
  "Prøv på nytt"
 ],
 "Unable to connect to that address": [
  null,
  "Kan ikke koble til den adressen"
 ],
 "Untrusted host": [
  null,
  ""
 ],
 "User name": [
  null,
  "Brukernavn"
 ],
 "User name cannot be empty": [
  null,
  "Brukernavnet kan ikke være tomt"
 ],
 "Validating authentication token": [
  null,
  "Validerer godkjenningstoken"
 ],
 "Web Console for Linux servers": [
  null,
  "Web konsoll for Linux servere"
 ],
 "Wrong user name or password": [
  null,
  "Feil brukernavn eller passord"
 ],
 "You are connecting to $0 for the first time.": [
  null,
  "Du kobler til $0 for første gang."
 ],
 "Your session has been terminated.": [
  null,
  "Økten din er avsluttet."
 ],
 "Your session has expired. Please log in again.": [
  null,
  "Økten din har utløpt. Vennligst logg inn igjen."
 ]
};
