cockpit.locale({
 "": {'plural-forms':function(n) {
var nplurals, plural;
nplurals=2; plural=n != 1;
return plural;
},
  "language": "ca",
  "x-generator": "Weblate 4.0.3"
 },
 "$0 exited with code $1": [
  null,
  "$0 va sortir amb el codi $1"
 ],
 "$0 failed": [
  null,
  "$0 ha fallat"
 ],
 "$0 killed with signal $1": [
  null,
  "$0 es va matar amb el senyal $1"
 ],
 "Apply": [
  null,
  "Aplica"
 ],
 "Cancel": [
  null,
  "Cancel·la"
 ],
 "Cannot forward login credentials": [
  null,
  ""
 ],
 "Cockpit could not contact the given host.": [
  null,
  "Cockpit no ha pogut contactar amb l'amfitrió indicat."
 ],
 "Cockpit is not compatible with the software on the system.": [
  null,
  "Cockpit no és compatible amb el programari del sistema."
 ],
 "Cockpit is not installed on the system.": [
  null,
  "Cockpit no està instal·lat al sistema."
 ],
 "Compress crash dumps to save space": [
  null,
  "Comprimeix els estavellaments per estalviar espai"
 ],
 "Compression": [
  null,
  "Compressió"
 ],
 "Connection has timed out.": [
  null,
  "La connexió ha excedit el temps."
 ],
 "Crash dump location": [
  null,
  "Ubicació del bolcat de l'estavellament"
 ],
 "Crash system": [
  null,
  ""
 ],
 "Directory": [
  null,
  "Directori"
 ],
 "Directory $0 isn't writable or doesn't exist.": [
  null,
  "No es pot escriure al directori $0 o bé no existeix."
 ],
 "Host key is incorrect": [
  null,
  "La clau d'amfitrió és incorrecta"
 ],
 "Internal error": [
  null,
  "Error intern"
 ],
 "Kdump service not installed. Please ensure package kexec-tools is installed.": [
  null,
  "El servei de Kdump no està instal·lat. Assegureu-vos que el paquet kexec-tools estigui instal·lat."
 ],
 "Kernel dump": [
  null,
  "Bolcat del kernel"
 ],
 "Loading...": [
  null,
  "S'està carregant..."
 ],
 "Local filesystem": [
  null,
  "Sistema de fitxers local"
 ],
 "Location": [
  null,
  "Ubicació"
 ],
 "Login failed": [
  null,
  "Ha fallat l'inici de sessió"
 ],
 "Mount": [
  null,
  "Munta"
 ],
 "No configuration found": [
  null,
  "No s'ha trobat cap configuració"
 ],
 "No memory reserved. Append a crashkernel option to the kernel command line (e.g. in /etc/default/grub) to reserve memory at boot time. Example: crashkernel=512M": [
  null,
  "No hi ha memòria reservada. Afegiu crashkernel a la línia d'ordres del kernel (p. ex. a /etc/default/grub) per reservar memòria en temps d'arrencada. Exemple: crashkernel=512M"
 ],
 "None": [
  null,
  "Cap"
 ],
 "Not permitted to perform this action.": [
  null,
  "No es permet realitzar aquesta acció."
 ],
 "Ok": [
  null,
  "D'acord"
 ],
 "On a mounted device": [
  null,
  "Amb un dispositiu muntat"
 ],
 "Raw to a device": [
  null,
  ""
 ],
 "Reading...": [
  null,
  "S'està llegint..."
 ],
 "Remote over NFS": [
  null,
  "Remot sobre NFS"
 ],
 "Remote over SSH": [
  null,
  "Remot sobre SSH"
 ],
 "Reserved memory": [
  null,
  "Memòria reservada"
 ],
 "Server": [
  null,
  "Servidor"
 ],
 "Server has closed the connection.": [
  null,
  "El servidor ha tancat la connexió."
 ],
 "Service has an error": [
  null,
  "El servei té un error"
 ],
 "Service is running": [
  null,
  "El servei s'està executant"
 ],
 "Service is starting": [
  null,
  "El servei s'està iniciant"
 ],
 "Service is stopped": [
  null,
  "El servei està aturat"
 ],
 "Service is stopping": [
  null,
  "El servei s'està aturant"
 ],
 "Status": [
  null,
  "Estat"
 ],
 "Test configuration": [
  null,
  "Prova la configuració"
 ],
 "Test is only available while the kdump service is running.": [
  null,
  "Això només està disponible mentre el servei kdump està en execució."
 ],
 "Test kdump settings": [
  null,
  "Prova els ajusts de kdump"
 ],
 "The server refused to authenticate using any supported methods.": [
  null,
  "El servidor ha refusat l'autenticació mitjançant qualsevol dels mètodes compatibles."
 ],
 "This will test kdump settings by crashing the kernel and thereby the system. Depending on the settings, the system may not automatically reboot and the process may take a while.": [
  null,
  "Això provarà la configuració de kdump en fer estavellar el kernel i, per tant, el sistema. En funció dels ajusts, el sistema pot no reiniciar-se automàticament i el procés pot trigar una estona."
 ],
 "This will test the kdump configuration by crashing the kernel.": [
  null,
  "Això provarà la configuració de kdump en fer estavellar el kernel."
 ],
 "Too much data": [
  null,
  "Hi ha massa dades"
 ],
 "Unable to apply settings: $0": [
  null,
  "No es poden aplicar els ajusts: $0"
 ],
 "Untrusted host": [
  null,
  "Amfitrió no fiable"
 ],
 "Your session has been terminated.": [
  null,
  "La vostra sessió ha estat finalitzada."
 ],
 "Your session has expired. Please log in again.": [
  null,
  "La vostra sessió ha vençut. Si us plau, torneu a iniciar la sessió."
 ],
 "crash": [
  null,
  ""
 ],
 "invalid: multiple targets defined": [
  null,
  "no és vàlid: s'han definit diversos objectius"
 ],
 "kdump": [
  null,
  ""
 ],
 "kdump status": [
  null,
  "Estat de kdump"
 ],
 "locally in $0": [
  null,
  "localment a $0"
 ],
 "nfs dump target isn't formatted as server:path": [
  null,
  ""
 ],
 "ssh key": [
  null,
  "clau ssh"
 ],
 "ssh key isn't a path": [
  null,
  ""
 ],
 "ssh server is empty": [
  null,
  ""
 ]
});
