cockpit.locale({
 "": {'plural-forms':function(n) {
var nplurals, plural;
nplurals=2; plural=n != 1;
return plural;
},
  "language": "nb_NO",
  "x-generator": "Weblate 4.5.1"
 },
 "$0 exited with code $1": [
  null,
  "$0 avsluttet med koden $1"
 ],
 "$0 failed": [
  null,
  "$0 feilet"
 ],
 "$0 killed with signal $1": [
  null,
  "$0 drept med signal $1"
 ],
 "Access": [
  null,
  "Tilgang"
 ],
 "Account expiration": [
  null,
  "Konto utløper"
 ],
 "Account not available or cannot be edited.": [
  null,
  "Kontoen er ikke tilgjengelig eller kan ikke redigeres."
 ],
 "Accounts": [
  null,
  "Kontoer"
 ],
 "Add": [
  null,
  "Legg til"
 ],
 "Add key": [
  null,
  "Legg til nøkkel"
 ],
 "Add public key": [
  null,
  "Legg til offentlig nøkkel"
 ],
 "Adding key": [
  null,
  "Legger til nøkkel"
 ],
 "Authorized public SSH keys": [
  null,
  "Autoriserte offentlige SSH-nøkler"
 ],
 "Back to accounts": [
  null,
  "Tilbake til kontoer"
 ],
 "Cancel": [
  null,
  "Avbryt"
 ],
 "Cannot forward login credentials": [
  null,
  "Kan ikke videresende påloggingsinformasjonen"
 ],
 "Change": [
  null,
  "Endre"
 ],
 "Click $0 again to use the password anyway.": [
  null,
  "Klikk $0 på nytt for å bruke passordet allikevel."
 ],
 "Close": [
  null,
  "Lukk"
 ],
 "Cockpit could not contact the given host.": [
  null,
  "Cockpit kunne ikke kontakte den angitte verten."
 ],
 "Cockpit is not compatible with the software on the system.": [
  null,
  "Cockpit er ikke kompatibel med programvaren på systemet."
 ],
 "Cockpit is not installed on the system.": [
  null,
  "Cockpit er ikke installert på systemet."
 ],
 "Confirm": [
  null,
  "Bekreft"
 ],
 "Confirm new password": [
  null,
  "Bekreft nytt passord"
 ],
 "Connection has timed out.": [
  null,
  "Tidsavbrudd for tilkoblingen."
 ],
 "Container administrator": [
  null,
  "Container administrator"
 ],
 "Create": [
  null,
  "Opprett"
 ],
 "Create new account": [
  null,
  "Opprett ny konto"
 ],
 "Delete": [
  null,
  "Slett"
 ],
 "Delete $0": [
  null,
  "Slett $0"
 ],
 "Delete files": [
  null,
  "Slett filer"
 ],
 "Error saving authorized keys: ": [
  null,
  "Feil ved lagring av autoriserte nøkler: "
 ],
 "Excellent password": [
  null,
  "Utmerket passord"
 ],
 "Failed to change password": [
  null,
  "Kunne ikke endre passord"
 ],
 "Failed to load authorized keys.": [
  null,
  "Kunne ikke laste autoriserte nøkler."
 ],
 "Force change": [
  null,
  "Tving endring"
 ],
 "Force password change": [
  null,
  "Tving passordendring"
 ],
 "Full name": [
  null,
  "Fullt navn"
 ],
 "Host key is incorrect": [
  null,
  "Vertsnøkkelen er feil"
 ],
 "Image builder": [
  null,
  ""
 ],
 "Internal error": [
  null,
  "Intern feil"
 ],
 "Invalid expiration date": [
  null,
  "Ugyldig utløpsdato"
 ],
 "Invalid key": [
  null,
  "Ugyldig nøkkel"
 ],
 "Invalid number of days": [
  null,
  "Ugyldig antall dager"
 ],
 "Last login": [
  null,
  "Siste innlogging"
 ],
 "Learn more": [
  null,
  "Lær mer"
 ],
 "Local accounts": [
  null,
  "Lokale kontoer"
 ],
 "Lock account": [
  null,
  "Lås konto"
 ],
 "Lock account on $0": [
  null,
  "Lås konto på $0"
 ],
 "Logged in": [
  null,
  "Logget inn"
 ],
 "Login failed": [
  null,
  "Innlogging feilet"
 ],
 "Managing user accounts": [
  null,
  "Administrere brukerkontoer"
 ],
 "Never": [
  null,
  "Aldri"
 ],
 "Never expire password": [
  null,
  "Passordet utløper aldri"
 ],
 "Never lock account": [
  null,
  "Lås aldri kontoen"
 ],
 "New password": [
  null,
  "Nytt passord"
 ],
 "New password was not accepted": [
  null,
  "Nytt passord ble ikke godtatt"
 ],
 "No real name specified": [
  null,
  "Ingen virkelige navn angitt"
 ],
 "No user name specified": [
  null,
  "Ingen brukernavn spesifisert"
 ],
 "Not permitted to perform this action.": [
  null,
  "Ikke tillatt å utføre denne handlingen."
 ],
 "Ok": [
  null,
  "Ok"
 ],
 "Old password": [
  null,
  "Gammelt passord"
 ],
 "Old password not accepted": [
  null,
  "Gammelt passord aksepteres ikke"
 ],
 "Password": [
  null,
  "Passord"
 ],
 "Password expiration": [
  null,
  "Passord utløper"
 ],
 "Password is not acceptable": [
  null,
  "Passord er ikke akseptabelt"
 ],
 "Password is too weak": [
  null,
  "Passordet er for svakt"
 ],
 "Password must be changed": [
  null,
  "Passord må endres"
 ],
 "Paste the contents of your public SSH key file here": [
  null,
  "Lim inn innholdet i den offentlige SSH-nøkkelfilen din her"
 ],
 "Please specify an expiration date": [
  null,
  "Angi en utløpsdato"
 ],
 "Prompting via passwd timed out": [
  null,
  "Spørring via passwd ble tidsavbrutt"
 ],
 "Remove": [
  null,
  "Fjern"
 ],
 "Require password change every $0 days": [
  null,
  "Krev passordendring hver $0 dager"
 ],
 "Require password change on $0": [
  null,
  "Krev passordendring på $0"
 ],
 "Reset password": [
  null,
  "Tilbakestill passord"
 ],
 "Roles": [
  null,
  "Roller"
 ],
 "Server administrator": [
  null,
  "Server administrator"
 ],
 "Server has closed the connection.": [
  null,
  "Serveren har lukket forbindelsen."
 ],
 "Set password": [
  null,
  "Angi passord"
 ],
 "Terminate session": [
  null,
  "Avslutt økt"
 ],
 "The account '$0' will be forced to change their password on next login": [
  null,
  "Kontoen '$0' vil bli tvunget til å endre passordet ved neste pålogging"
 ],
 "The key you provided was not valid.": [
  null,
  "Nøkkelen du oppga var ikke gyldig."
 ],
 "The passwords do not match": [
  null,
  "Passordene samsvarer ikke"
 ],
 "The server refused to authenticate using any supported methods.": [
  null,
  "Serveren nektet å godkjenne ved hjelp av de støttede metodene."
 ],
 "The user must log out and log back in to fully change roles.": [
  null,
  "Brukeren må logge ut og logge inn for å endre rolle fullstendig."
 ],
 "The user name can only consist of letters from a-z, digits, dots, dashes and underscores.": [
  null,
  "Brukernavnet kan bare bestå av bokstaver fra a-z, sifre, prikker, bindestreker og understrekninger."
 ],
 "There are no authorized public keys for this account.": [
  null,
  "Det er ingen autoriserte offentlige nøkler for denne kontoen."
 ],
 "This user name already exists": [
  null,
  "Dette brukernavnet finnes allerede"
 ],
 "Too much data": [
  null,
  "For mye data"
 ],
 "Unexpected error": [
  null,
  "Uventet feil"
 ],
 "Unix group: $0": [
  null,
  "Unix-gruppe: $0"
 ],
 "Unnamed": [
  null,
  "Uten navn"
 ],
 "Untrusted host": [
  null,
  ""
 ],
 "User name": [
  null,
  "Brukernavn"
 ],
 "Validating key": [
  null,
  "Validerer nøkkel"
 ],
 "You do not have permission to view the authorized public keys for this account.": [
  null,
  "Du har ikke tillatelse til å se de autoriserte offentlige nøklene for denne kontoen."
 ],
 "You must wait longer to change your password": [
  null,
  "Du må vente lenger på å endre passordet ditt"
 ],
 "Your account": [
  null,
  "Din konto"
 ],
 "Your session has been terminated.": [
  null,
  "Økten din er avsluttet."
 ],
 "Your session has expired. Please log in again.": [
  null,
  "Økten din har utløpt. Vennligst logg inn igjen."
 ],
 "access": [
  null,
  "tilgang"
 ],
 "keys": [
  null,
  "nøkler"
 ],
 "login": [
  null,
  ""
 ],
 "passwd": [
  null,
  "passwd"
 ],
 "password": [
  null,
  "passord"
 ],
 "password quality": [
  null,
  "passordkvalitet"
 ],
 "roles": [
  null,
  "roller"
 ],
 "ssh": [
  null,
  "ssh"
 ],
 "user": [
  null,
  "bruker"
 ],
 "useradd": [
  null,
  "useradd"
 ],
 "username": [
  null,
  "brukernavn"
 ]
});
