cockpit.locale({
 "": {'plural-forms':function(n) {
var nplurals, plural;
nplurals=2; plural=n != 1;
return plural;
},
  "language": "nb_NO",
  "x-generator": "Weblate 4.5.1"
 },
 "$0 documentation": [
  null,
  "$0 dokumentasjon"
 ],
 "$0 exited with code $1": [
  null,
  "$0 avsluttet med koden $1"
 ],
 "$0 failed": [
  null,
  "$0 feilet"
 ],
 "$0 killed with signal $1": [
  null,
  "$0 drept med signal $1"
 ],
 "A compatible version of Cockpit is not installed on {{#strong}}{{host}}{{/strong}}.": [
  null,
  "En kompatibel versjon av Cockpit er ikke installert på {{#strong}}{{host}}{{/strong}}."
 ],
 "A new SSH key at ${key} will be created for ${luser} on ${lhost} and it will be added to the ${afile} file of ${ruser} on ${rhost}.": [
  null,
  "En ny SSH-nøkkel på ${key} blir opprettet for ${luser} på ${lhost}, og den vil bli lagt til ${afile}-filen på ${ruser} på ${rhost}."
 ],
 "About Web Console": [
  null,
  "Om Web konsoll"
 ],
 "Accept key and connect": [
  null,
  "Godta nøkkel og koble til"
 ],
 "Accounts": [
  null,
  "Kontoer"
 ],
 "Active pages": [
  null,
  "Aktive sider"
 ],
 "Add": [
  null,
  "Legg til"
 ],
 "Add key": [
  null,
  "Legg til nøkkel"
 ],
 "Add new host": [
  null,
  "Legg til ny vert"
 ],
 "Administrative access": [
  null,
  "Administrativ tilgang"
 ],
 "Applications": [
  null,
  "Applikasjoner"
 ],
 "Apps": [
  null,
  "Apper"
 ],
 "Authenticate": [
  null,
  "Autentiser"
 ],
 "Authentication": [
  null,
  "Autentisering"
 ],
 "Authentication failed": [
  null,
  "Autentisering feilet"
 ],
 "Authorize SSH key.": [
  null,
  "Autoriser SSH-nøkkel."
 ],
 "Automatic login": [
  null,
  "Automatisk pålogging"
 ],
 "By changing the password of the SSH key ${key} to the login password of ${luser} on ${lhost}, the key will be automatically made available and you can log in to ${rhost} without password in the future.": [
  null,
  "Ved å endre passordet til SSH-nøkkelen ${key} til påloggingspassordet på ${luser} på ${lhost}, blir nøkkelen automatisk tilgjengelig, og du kan logge på ${rhost} uten passord i fremtiden."
 ],
 "Can be a hostname, IP address, alias name, or ssh:// URI": [
  null,
  "Kan være et vertsnavn, IP-adresse, aliasnavn eller ssh:// URI"
 ],
 "Cancel": [
  null,
  "Avbryt"
 ],
 "Cannot connect to an unknown host": [
  null,
  "Kan ikke koble til en ukjent vert"
 ],
 "Cannot forward login credentials": [
  null,
  "Kan ikke videresende påloggingsinformasjonen"
 ],
 "Change password": [
  null,
  "Endre passord"
 ],
 "Change the password of ${key}.": [
  null,
  "Endre passordet på ${key}."
 ],
 "Choose the language to be used in the application": [
  null,
  ""
 ],
 "Clear search": [
  null,
  "Tøm søket"
 ],
 "Close": [
  null,
  "Lukk"
 ],
 "Close selected pages": [
  null,
  "Lukk valgte sider"
 ],
 "Cockpit could not contact the given host.": [
  null,
  "Cockpit kunne ikke kontakte den angitte verten."
 ],
 "Cockpit had an unexpected internal error.": [
  null,
  "Cockpit hadde en uventet intern feil."
 ],
 "Cockpit is an interactive Linux server admin interface.": [
  null,
  "Cockpit er et interaktivt administrasjonsgrensesnitt for Linux-server."
 ],
 "Cockpit is not compatible with the software on the system.": [
  null,
  "Cockpit er ikke kompatibel med programvaren på systemet."
 ],
 "Cockpit is not installed": [
  null,
  "Cockpit er ikke installert"
 ],
 "Cockpit is not installed on the system.": [
  null,
  "Cockpit er ikke installert på systemet."
 ],
 "Color": [
  null,
  "Farge"
 ],
 "Comment": [
  null,
  "Kommentar"
 ],
 "Configuring kdump": [
  null,
  "Konfigurerer kdump"
 ],
 "Configuring system settings": [
  null,
  "Konfigurere systeminnstillinger"
 ],
 "Confirm": [
  null,
  "Bekreft"
 ],
 "Confirm key password": [
  null,
  "Bekreft nøkkel-passord"
 ],
 "Confirm new key password": [
  null,
  "Bekreft nytt nøkkel-passord"
 ],
 "Connecting simultaneously to more than {{ limit }} machines is unsupported.": [
  null,
  "Tilkobling samtidig til mer enn {{ limit }} maskiner støttes ikke."
 ],
 "Connecting to the machine": [
  null,
  "Kobler til maskinen"
 ],
 "Connection error": [
  null,
  "Tilkoblingsfeil"
 ],
 "Connection failed": [
  null,
  "Tilkoblingen feilet"
 ],
 "Connection has timed out.": [
  null,
  "Tidsavbrudd for tilkoblingen."
 ],
 "Contains:": [
  null,
  "Inneholder:"
 ],
 "Continue session": [
  null,
  "Fortsett økt"
 ],
 "Could not contact {{host}}": [
  null,
  "Kunne ikke kontakte {{host}}"
 ],
 "Create": [
  null,
  "Opprett"
 ],
 "Create a new SSH key and authorize it.": [
  null,
  "Opprett en ny SSH-nøkkel og godkjenn den."
 ],
 "Ctrl-Shift-J": [
  null,
  "Ctrl-Shift-J"
 ],
 "Details": [
  null,
  "Detaljer"
 ],
 "Development": [
  null,
  "Utvikling"
 ],
 "Diagnostic Reports": [
  null,
  "Diagnose rapporter"
 ],
 "Disconnected": [
  null,
  "Frakoblet"
 ],
 "Display language": [
  null,
  "Visnings språk"
 ],
 "Edit": [
  null,
  "Rediger"
 ],
 "Edit host": [
  null,
  "Rediger vert"
 ],
 "Edit hosts": [
  null,
  "Rediger verter"
 ],
 "Error message": [
  null,
  "Feilmelding"
 ],
 "Failed to add machine: $0": [
  null,
  "Kunne ikke legge til maskin: $0"
 ],
 "Failed to change password": [
  null,
  "Kunne ikke endre passord"
 ],
 "Failed to edit machine: $0": [
  null,
  "Kunne ikke redigere maskin: $0"
 ],
 "Fingerprint": [
  null,
  "Fingeravtrykk"
 ],
 "GNU LGPL version 2.1": [
  null,
  "GNU LGPL versjon 2.1"
 ],
 "Help": [
  null,
  "Hjelp"
 ],
 "Host": [
  null,
  "Vert"
 ],
 "Host key is incorrect": [
  null,
  "Vertsnøkkelen er feil"
 ],
 "Hosts": [
  null,
  "Verter"
 ],
 "If the fingerprint matches, click \"Accept key and connect\". Otherwise, do not connect and contact your administrator.": [
  null,
  "Hvis fingeravtrykket stemmer overens, klikker du på \"Godta nøkkel og koble til\". Ellers må du ikke koble til og kontakte administratoren din."
 ],
 "In order to allow log in to ${rhost} as ${ruser} without password in the future, use the login password of ${luser} on ${lhost} as the key password, or leave the key password blank.": [
  null,
  "For å tillate pålogging til ${rhost} som ${ruser} uten passord i fremtiden, bruk påloggingspassordet på ${luser} på ${lhost} som nøkkelpassord, eller la nøkkelpassordet være tomt."
 ],
 "Internal error": [
  null,
  "Intern feil"
 ],
 "Invalid file permissions": [
  null,
  "Ugyldige filtillatelser"
 ],
 "Is sshd running on a different port?": [
  null,
  "Kjører sshd på en annen port?"
 ],
 "Kerberos based SSO": [
  null,
  "Kerberos-basert SSO"
 ],
 "Kernel Dump": [
  null,
  "Kjerne dump"
 ],
 "Key password": [
  null,
  "Nøkkel-passord"
 ],
 "Learn more": [
  null,
  "Lær mer"
 ],
 "Licensed under:": [
  null,
  "Lisensiert under:"
 ],
 "Limit access": [
  null,
  "Begrens tilgang"
 ],
 "Limited access": [
  null,
  "Begrenset tilgang"
 ],
 "Limited access mode restricts administrative privileges. Some parts of the web console will have reduced functionality.": [
  null,
  "Begrenset tilgangsmodus begrenser administrative rettigheter. Noen deler av webkonsollet har redusert funksjonalitet."
 ],
 "Log in": [
  null,
  "Logg inn"
 ],
 "Log in to {{host}}": [
  null,
  "Logg på {{host}}"
 ],
 "Log out": [
  null,
  "Logg ut"
 ],
 "Login failed": [
  null,
  "Innlogging feilet"
 ],
 "Logs": [
  null,
  "Logger"
 ],
 "Managing LVMs": [
  null,
  "Administrere LVMer"
 ],
 "Managing NFS mounts": [
  null,
  "Administrere NFS-monteringer"
 ],
 "Managing RAIDs": [
  null,
  "Administrere RAIDer"
 ],
 "Managing VDOs": [
  null,
  "Administrere VDOer"
 ],
 "Managing VLANs": [
  null,
  "Administrere VLAN"
 ],
 "Managing firewall": [
  null,
  "Administrere brannmur"
 ],
 "Managing networking bonds": [
  null,
  "Administrere nettverksbindinger"
 ],
 "Managing networking bridges": [
  null,
  "Administrere nettverksbroer"
 ],
 "Managing networking teams": [
  null,
  "Administrere nettverksteam"
 ],
 "Managing partitions": [
  null,
  "Administrere partisjoner"
 ],
 "Managing physical drives": [
  null,
  "Administrere fysiske disker"
 ],
 "Managing services": [
  null,
  "Administrere tjenester"
 ],
 "Managing software updates": [
  null,
  "Administrere programvareoppdateringer"
 ],
 "Managing user accounts": [
  null,
  "Administrere brukerkontoer"
 ],
 "Messages related to the failure might be found in the journal:": [
  null,
  "Meldinger relatert til feilen kan finnes i journalen:"
 ],
 "Method": [
  null,
  "Metode"
 ],
 "Networking": [
  null,
  "Nettverk"
 ],
 "New host": [
  null,
  "Ny vert"
 ],
 "New key password": [
  null,
  "Nytt nøkkelpassord"
 ],
 "New password": [
  null,
  "Nytt passord"
 ],
 "New password was not accepted": [
  null,
  "Nytt passord ble ikke godtatt"
 ],
 "No results found": [
  null,
  "Ingen resultater funnet"
 ],
 "No such file or directory": [
  null,
  "Ingen slik fil eller katalog"
 ],
 "Not a valid private key": [
  null,
  "Ikke en gyldig privat nøkkel"
 ],
 "Not connected to host": [
  null,
  "Ikke koblet til verten"
 ],
 "Not permitted to perform this action.": [
  null,
  "Ikke tillatt å utføre denne handlingen."
 ],
 "Ok": [
  null,
  "Ok"
 ],
 "Old password": [
  null,
  "Gammelt passord"
 ],
 "Old password not accepted": [
  null,
  "Gammelt passord aksepteres ikke"
 ],
 "Ooops!": [
  null,
  ""
 ],
 "Overview": [
  null,
  "Oversikt"
 ],
 "Page name": [
  null,
  "Sidenavn"
 ],
 "Password": [
  null,
  "Passord"
 ],
 "Password not accepted": [
  null,
  "Passord ikke akseptert"
 ],
 "Path to file": [
  null,
  "Sti til fil"
 ],
 "Please authenticate to gain administrative access": [
  null,
  "Autentiser for å få administrativ tilgang"
 ],
 "Port": [
  null,
  "Port"
 ],
 "Project website": [
  null,
  "Prosjektets nettsted"
 ],
 "Prompting via ssh-add timed out": [
  null,
  "Spørring via ssh-add ble tidsavbrutt"
 ],
 "Prompting via ssh-keygen timed out": [
  null,
  "Spørring via ssh-keygen ble tidsavbrutt"
 ],
 "Public key": [
  null,
  "Offentlig nøkkel"
 ],
 "Reconnect": [
  null,
  "Koble til på nytt"
 ],
 "Reviewing logs": [
  null,
  ""
 ],
 "SELinux": [
  null,
  "SELinux"
 ],
 "SSH key": [
  null,
  "SSH-nøkkel"
 ],
 "SSH keys": [
  null,
  "SSH-nøkler"
 ],
 "Safari users need to import and trust the certificate of the self-signing CA:": [
  null,
  "Safari-brukere må importere og stole på sertifikatet for den selvsignerende CA:"
 ],
 "Search": [
  null,
  "Søk"
 ],
 "Select": [
  null,
  "Velg"
 ],
 "Server has closed the connection.": [
  null,
  "Serveren har lukket forbindelsen."
 ],
 "Services": [
  null,
  "Tjenester"
 ],
 "Session is about to expire": [
  null,
  "Økten er i ferd med å utløpe"
 ],
 "Set": [
  null,
  "Sett"
 ],
 "Skip main navigation": [
  null,
  ""
 ],
 "Skip to content": [
  null,
  "Gå til innhold"
 ],
 "Software Updates": [
  null,
  "Programvare oppdateringer"
 ],
 "Something went wrong": [
  null,
  "Noe gikk galt"
 ],
 "Stop editing hosts": [
  null,
  "Slutt å redigere verter"
 ],
 "Storage": [
  null,
  "Lagring"
 ],
 "Switch to limited access": [
  null,
  "Bytt til begrenset tilgang"
 ],
 "System": [
  null,
  "System"
 ],
 "Terminal": [
  null,
  "Terminal"
 ],
 "The IP address or hostname cannot contain whitespace.": [
  null,
  "IP-adressen eller vertsnavnet kan ikke inneholde mellomrom."
 ],
 "The SSH key ${key} of ${luser} on ${lhost} will be added to the ${afile} file of ${ruser} on ${rhost}.": [
  null,
  "SSH-nøkkelen ${key} på ${luser} på ${lhost} vil bli lagt til ${afile}-filen på ${ruser} på ${rhost}."
 ],
 "The SSH key for logging in to {{#strong}}{{full_address}}{{/strong}} is protected. You can log in with either your login password or by providing the password of the key at {{#strong}}{{key}}{{/strong}}.": [
  null,
  "SSH-nøkkelen for pålogging til {{#strong}}{{full_address}}{{/strong}} er beskyttet. Du kan logge på med enten påloggingspassordet ditt eller ved å oppgi passordet til nøkkelen på {{#strong}}{{key}}{{/strong}}."
 ],
 "The SSH key {{#strong}}{{key}}{{/strong}} will be made available for the remainder of the session and will be available for login to other hosts as well.": [
  null,
  "SSH-nøkkelen {{#strong}}{{key}}{{/strong}} blir gjort tilgjengelig for resten av økten og vil også være tilgjengelig for pålogging til andre verter."
 ],
 "The key password can not be empty": [
  null,
  "Nøkkelpassordet kan ikke være tomt"
 ],
 "The key passwords do not match": [
  null,
  "Nøkkelpassordene stemmer ikke overens"
 ],
 "The machine is rebooting": [
  null,
  "Maskinen starter på nytt"
 ],
 "The new key password can not be empty": [
  null,
  "Det nye nøkkelpassordet kan ikke være tomt"
 ],
 "The new key passwords do not match": [
  null,
  "De nye passordene til nøkkelen stemmer ikke overens"
 ],
 "The passwords do not match.": [
  null,
  "Passordene samsvarer ikke."
 ],
 "The resulting fingerprint is fine to share via public methods, including email.": [
  null,
  "Det resulterende fingeravtrykket er greit å dele via offentlige metoder, inkludert e-post."
 ],
 "The server refused to authenticate using any supported methods.": [
  null,
  "Serveren nektet å godkjenne ved hjelp av de støttede metodene."
 ],
 "There are currently no active pages": [
  null,
  "Det er for øyeblikket ingen aktive sider"
 ],
 "There was an unexpected error while connecting to the machine.": [
  null,
  "Det oppsto en uventet feil under tilkoblingen til maskinen."
 ],
 "This didn't work, please try again": [
  null,
  "Dette fungerte ikke. Prøv på nytt"
 ],
 "This machine has already been added.": [
  null,
  "Denne maskinen er allerede lagt til."
 ],
 "This will allow you to log in without password in the future.": [
  null,
  "Dette vil tillate deg å logge på uten passord i fremtiden."
 ],
 "Tip: Make your key password match your login password to automatically authenticate against other systems.": [
  null,
  "Tips: Gjør at nøkkelpassordet ditt samsvarer med påloggingspassordet ditt for automatisk autentisering mot andre systemer."
 ],
 "To ensure that your connection is not intercepted by a malicious third-party, please verify the host key fingerprint:": [
  null,
  "For å sikre at forbindelsen din ikke blir fanget opp av en ondsinnet tredjepart, må du verifisere vertsnøkkelens fingeravtrykk:"
 ],
 "To verify a fingerprint, run the following on {{host}} while physically sitting at the machine or through a trusted network:": [
  null,
  "For å bekrefte et fingeravtrykk, kjør følgende på {{host}} mens du sitter fysisk ved maskinen eller gjennom et pålitelig nettverk:"
 ],
 "Toggle session settings": [
  null,
  ""
 ],
 "Too much data": [
  null,
  "For mye data"
 ],
 "Tools": [
  null,
  "Verktøy"
 ],
 "Type": [
  null,
  "Type"
 ],
 "Unable to contact the given host $0. Make sure it has ssh running on port $1, or specify another port in the address.": [
  null,
  "Kan ikke kontakte den angitte verten $0. Forsikre deg om at den har ssh på port $1, eller angi en annen port i adressen."
 ],
 "Unable to contact {{#strong}}{{host}}{{/strong}}.": [
  null,
  "Kan ikke kontakte {{#strong}}{{host}}{{/strong}}."
 ],
 "Unable to log in to {{#strong}}{{full_address}}{{/strong}} using SSH key authentication. Please provide the password. You may want to set up your SSH keys for automatic login.": [
  null,
  "Kan ikke logge på {{#strong}}{{full_address}}{{/strong}} ved hjelp av SSH-nøkkel autentisering. Oppgi passordet. Det kan være lurt å konfigurere SSH-nøklene for automatisk pålogging."
 ],
 "Unable to log in to {{#strong}}{{full_address}}{{/strong}}. The host does not accept password login or any of your SSH keys.": [
  null,
  "Kan ikke logge på {{#strong}}{{full_address}}{{/strong}}. Verten godtar ikke passordinnlogging eller noen av SSH-nøklene dine."
 ],
 "Unable to log in to {{#strong}}{{host}}{{/strong}}. For more authentication options and troubleshooting support please upgrade cockpit-ws to a newer version.": [
  null,
  "Kan ikke logge på {{#strong}}{{host}}{{/strong}}. For flere autentiseringsalternativer og feilsøkingsstøtte kan du oppgradere cockpit-ws til en nyere versjon."
 ],
 "Unable to log in to {{#strong}}{{host}}{{/strong}}. To connect to this host you will need to enable one of the following authentication methods in the sshd config on {{#strong}}{{host}}{{/strong}}:": [
  null,
  "Kan ikke logge på {{#strong}}{{host}}{{/strong}}. For å koble deg til denne verten må du aktivere en av følgende autentiseringsmetoder i sshd-konfigurasjonen på {{#strong}}{{host}}{{/strong}}:"
 ],
 "Unexpected error": [
  null,
  "Uventet feil"
 ],
 "Unlock key": [
  null,
  "Lås opp nøkkel"
 ],
 "Untrusted host": [
  null,
  ""
 ],
 "Update": [
  null,
  "Oppdater"
 ],
 "Use key": [
  null,
  "Bruk nøkkel"
 ],
 "Use the following keys to authenticate against other systems": [
  null,
  "Bruk følgende nøkler for å autentisere mot andre systemer"
 ],
 "User name": [
  null,
  "Brukernavn"
 ],
 "Using LUKS encryption": [
  null,
  "Bruker LUKS-kryptering"
 ],
 "Using Tang server": [
  null,
  "Bruker Tang-server"
 ],
 "Version": [
  null,
  "Versjon"
 ],
 "Web Console": [
  null,
  "Web konsoll"
 ],
 "When empty, connect with the current user": [
  null,
  ""
 ],
 "You are connecting to {{host}} for the first time.": [
  null,
  "Du kobler til {{host}} for første gang."
 ],
 "You can not gain administrative access.": [
  null,
  "Du kan ikke få administrativ tilgang."
 ],
 "You have been logged out due to inactivity.": [
  null,
  "Du har blitt logget ut på grunn av inaktivitet."
 ],
 "You may want to change the password of the key for automatic login.": [
  null,
  "Det kan være lurt å endre passordet til nøkkelen for automatisk pålogging."
 ],
 "You now have administrative access.": [
  null,
  "Du har nå administrativ tilgang."
 ],
 "You will be logged out in $0 seconds.": [
  null,
  "Du blir logget ut om $0 sekunder."
 ],
 "Your browser will remember your access level across sessions.": [
  null,
  "Nettleseren din husker tilgangsnivået ditt på tvers av øktene."
 ],
 "Your session has been terminated.": [
  null,
  "Økten din er avsluttet."
 ],
 "Your session has expired. Please log in again.": [
  null,
  "Økten din har utløpt. Vennligst logg inn igjen."
 ],
 "abrt": [
  null,
  "abrt"
 ],
 "access": [
  null,
  "tilgang"
 ],
 "active": [
  null,
  "aktiv"
 ],
 "add-on": [
  null,
  "tillegg"
 ],
 "addon": [
  null,
  "tillegg"
 ],
 "apps": [
  null,
  "apper"
 ],
 "apt-get": [
  null,
  "apt-get"
 ],
 "asset tag": [
  null,
  "eiendomsmerke"
 ],
 "avc": [
  null,
  "avc"
 ],
 "bash": [
  null,
  "bash"
 ],
 "bios": [
  null,
  "bios"
 ],
 "bond": [
  null,
  "binding"
 ],
 "boot": [
  null,
  "oppstart"
 ],
 "bridge": [
  null,
  "bro"
 ],
 "cgroups": [
  null,
  "cgroups"
 ],
 "command": [
  null,
  "kommando"
 ],
 "console": [
  null,
  "konsoll"
 ],
 "coredump": [
  null,
  "coredump"
 ],
 "cpu": [
  null,
  "cpu"
 ],
 "crash": [
  null,
  "krasj"
 ],
 "date": [
  null,
  "dato"
 ],
 "debug": [
  null,
  "debug"
 ],
 "dimm": [
  null,
  "dimm"
 ],
 "disable": [
  null,
  "deaktiver"
 ],
 "disk": [
  null,
  "disk"
 ],
 "disks": [
  null,
  "disker"
 ],
 "dnf": [
  null,
  "dnf"
 ],
 "domain": [
  null,
  "domene"
 ],
 "drive": [
  null,
  "dIsk"
 ],
 "enable": [
  null,
  "aktiver"
 ],
 "encryption": [
  null,
  "kryptering"
 ],
 "error": [
  null,
  "feil"
 ],
 "extension": [
  null,
  "utvidelse"
 ],
 "filesystem": [
  null,
  "filsystem"
 ],
 "firewall": [
  null,
  "brannmur"
 ],
 "firewalld": [
  null,
  "firewalld"
 ],
 "format": [
  null,
  "format"
 ],
 "fstab": [
  null,
  "fstab"
 ],
 "graphs": [
  null,
  "grafer"
 ],
 "hardware": [
  null,
  "maskinvare"
 ],
 "history": [
  null,
  "historikk"
 ],
 "host": [
  null,
  "vert"
 ],
 "in most browsers": [
  null,
  "i de fleste nettlesere"
 ],
 "install": [
  null,
  "installer"
 ],
 "interface": [
  null,
  "grensesnitt"
 ],
 "ipv4": [
  null,
  "ipv4"
 ],
 "ipv6": [
  null,
  "ipv6"
 ],
 "iscsi": [
  null,
  "iscsi"
 ],
 "journal": [
  null,
  "journal"
 ],
 "kdump": [
  null,
  "kdump"
 ],
 "keys": [
  null,
  "nøkler"
 ],
 "login": [
  null,
  ""
 ],
 "luks": [
  null,
  "luks"
 ],
 "lvm2": [
  null,
  "lvm2"
 ],
 "mac": [
  null,
  "mac"
 ],
 "machine": [
  null,
  "maskin"
 ],
 "mask": [
  null,
  "maske"
 ],
 "memory": [
  null,
  "minne"
 ],
 "metrics": [
  null,
  ""
 ],
 "mitigation": [
  null,
  ""
 ],
 "mkfs": [
  null,
  "mkfs"
 ],
 "mount": [
  null,
  "monter"
 ],
 "nbde": [
  null,
  "nbde"
 ],
 "network": [
  null,
  "nettverk"
 ],
 "nfs": [
  null,
  "nfs"
 ],
 "operating system": [
  null,
  "operativsystem"
 ],
 "os": [
  null,
  "os"
 ],
 "package": [
  null,
  "pakke"
 ],
 "packagekit": [
  null,
  "packagekit"
 ],
 "partition": [
  null,
  "partisjon"
 ],
 "passwd": [
  null,
  "passwd"
 ],
 "password": [
  null,
  "passord"
 ],
 "path": [
  null,
  "sti"
 ],
 "pci": [
  null,
  "pci"
 ],
 "pcp": [
  null,
  "pcp"
 ],
 "plugin": [
  null,
  "utvidelse"
 ],
 "port": [
  null,
  "port"
 ],
 "power": [
  null,
  ""
 ],
 "raid": [
  null,
  "raid"
 ],
 "ram": [
  null,
  "ram"
 ],
 "restart": [
  null,
  "omstart"
 ],
 "roles": [
  null,
  "roller"
 ],
 "security": [
  null,
  "sikkerhet"
 ],
 "semanage": [
  null,
  "semanage"
 ],
 "serial": [
  null,
  ""
 ],
 "service": [
  null,
  "tjeneste"
 ],
 "setroubleshoot": [
  null,
  "setroubleshoot"
 ],
 "shell": [
  null,
  "skall"
 ],
 "show less": [
  null,
  "vis mindre"
 ],
 "show more": [
  null,
  "vis mer"
 ],
 "shut": [
  null,
  ""
 ],
 "socket": [
  null,
  ""
 ],
 "sos": [
  null,
  "sos"
 ],
 "ssh": [
  null,
  "ssh"
 ],
 "systemctl": [
  null,
  "systemctl"
 ],
 "systemd": [
  null,
  "systemd"
 ],
 "tang": [
  null,
  "tang"
 ],
 "target": [
  null,
  "mål"
 ],
 "tcp": [
  null,
  "tcp"
 ],
 "team": [
  null,
  "team"
 ],
 "time": [
  null,
  "tid"
 ],
 "timer": [
  null,
  "timer"
 ],
 "udisks": [
  null,
  "udisks"
 ],
 "udp": [
  null,
  "udp"
 ],
 "unit": [
  null,
  "enhet"
 ],
 "unmask": [
  null,
  "unmask"
 ],
 "unmount": [
  null,
  "unmount"
 ],
 "user": [
  null,
  "bruker"
 ],
 "useradd": [
  null,
  "useradd"
 ],
 "username": [
  null,
  "brukernavn"
 ],
 "vdo": [
  null,
  "vdo"
 ],
 "version": [
  null,
  "versjon"
 ],
 "vlan": [
  null,
  "vlan"
 ],
 "volume": [
  null,
  "volum"
 ],
 "warning": [
  null,
  "advarsel"
 ],
 "yum": [
  null,
  "yum"
 ],
 "zone": [
  null,
  "sone"
 ],
 "{{host}} key changed": [
  null,
  "{{host}} nøkkel endret"
 ]
});
