cockpit.locale({
 "": {'plural-forms':function(n) {
var nplurals, plural;
nplurals=2; plural=n != 1;
return plural;
},
  "language": "nl",
  "x-generator": "Weblate 4.5.3"
 },
 "$0 exited with code $1": [
  null,
  "$0 verlaten met code $1"
 ],
 "$0 failed": [
  null,
  "$0 mislukte"
 ],
 "$0 killed with signal $1": [
  null,
  "$0 is afgeschoten met signaal $1"
 ],
 "Cancel": [
  null,
  "Annuleren"
 ],
 "Cannot forward login credentials": [
  null,
  "Kan inloggegevens niet doorsturen"
 ],
 "Close": [
  null,
  "Sluiten"
 ],
 "Cockpit could not contact the given host.": [
  null,
  "Cockpit kon geen contact maken met de opgegeven host."
 ],
 "Cockpit is not compatible with the software on the system.": [
  null,
  "Cockpit is niet compatibel met de software op het systeem."
 ],
 "Cockpit is not installed on the system.": [
  null,
  "Cockpit is niet op het systeem geïnstalleerd."
 ],
 "Connection has timed out.": [
  null,
  "Er is een time-out opgetreden voor de verbinding."
 ],
 "Create diagnostic report                    ": [
  null,
  "Maak diagnostisch rapport aan                    "
 ],
 "Create report": [
  null,
  "Maak rapport aan"
 ],
 "Diagnostic Reports": [
  null,
  "Diagnostische rapporten"
 ],
 "Diagnostic reports": [
  null,
  "Diagnostische rapporten"
 ],
 "Done!": [
  null,
  "Klaar!"
 ],
 "Download report": [
  null,
  "Download rapport"
 ],
 "Generating report": [
  null,
  "Rapport genereren"
 ],
 "Host key is incorrect": [
  null,
  "Hostsleutel is onjuist"
 ],
 "Internal error": [
  null,
  "Interne fout"
 ],
 "Login failed": [
  null,
  "Inloggen mislukte"
 ],
 "No archive has been created.": [
  null,
  "Er is geen archief aangemaakt."
 ],
 "Not permitted to perform this action.": [
  null,
  "Niet toegestaan om deze actie uit te voeren."
 ],
 "Server has closed the connection.": [
  null,
  "Server heeft de verbinding verbroken."
 ],
 "The collected information will be stored locally on the system.": [
  null,
  "De verzamelde informatie wordt lokaal op het systeem opgeslagen."
 ],
 "The generated archive contains data considered sensitive and its content should be reviewed by the originating organization before being passed to any third party.": [
  null,
  "Het gegenereerde archief bevat data die als gevoelig wordt beschouwd en de inhoud ervan moet door de oorspronkelijke organisatie worden beoordeeld voordat deze aan derden wordt doorgegeven."
 ],
 "The server refused to authenticate using any supported methods.": [
  null,
  "De server weigerde te verifiëren met behulp van ondersteunde methoden."
 ],
 "This tool will collect system configuration and diagnostic information from this system for use with diagnosing problems with the system.": [
  null,
  "Deze tool verzamelt systeemconfiguratie en diagnostische informatie van dit systeem voor gebruik bij het diagnosticeren van problemen met het systeem."
 ],
 "Too much data": [
  null,
  "Teveel data"
 ],
 "Untrusted host": [
  null,
  "Niet vertrouwde host"
 ],
 "You need to switch to \"Administrative access\" in order to create reports.": [
  null,
  "Je moet overschakelen naar \"Beheerderstoegang\" om rapporten aan te maken."
 ],
 "Your session has been terminated.": [
  null,
  "Je sessie is beëindigd."
 ],
 "Your session has expired. Please log in again.": [
  null,
  "Je sessie is verlopen. Log nogmaals in."
 ],
 "sos": [
  null,
  "sos"
 ]
});
