cockpit.locale({
 "": {'plural-forms':function(n) {
var nplurals, plural;
nplurals=2; plural=n != 1;
return plural;
},
  "language": "nb_NO",
  "x-generator": "Weblate 4.5.1"
 },
 "$0 exited with code $1": [
  null,
  "$0 avsluttet med koden $1"
 ],
 "$0 failed": [
  null,
  "$0 feilet"
 ],
 "$0 killed with signal $1": [
  null,
  "$0 drept med signal $1"
 ],
 "Actions": [
  null,
  "Handlinger"
 ],
 "Applications": [
  null,
  "Applikasjoner"
 ],
 "Applications list": [
  null,
  "Applikasjonsliste"
 ],
 "Cancel": [
  null,
  "Avbryt"
 ],
 "Cannot forward login credentials": [
  null,
  "Kan ikke videresende påloggingsinformasjonen"
 ],
 "Checking for new applications": [
  null,
  "Ser etter nye applikasjoner"
 ],
 "Close": [
  null,
  "Lukk"
 ],
 "Cockpit could not contact the given host.": [
  null,
  "Cockpit kunne ikke kontakte den angitte verten."
 ],
 "Cockpit is not compatible with the software on the system.": [
  null,
  "Cockpit er ikke kompatibel med programvaren på systemet."
 ],
 "Cockpit is not installed on the system.": [
  null,
  "Cockpit er ikke installert på systemet."
 ],
 "Connection has timed out.": [
  null,
  "Tidsavbrudd for tilkoblingen."
 ],
 "Error": [
  null,
  "Feil"
 ],
 "Go to application": [
  null,
  "Gå til applikasjon"
 ],
 "Host key is incorrect": [
  null,
  "Vertsnøkkelen er feil"
 ],
 "Install": [
  null,
  "Installer"
 ],
 "Installing": [
  null,
  "Installerer"
 ],
 "Internal error": [
  null,
  "Intern feil"
 ],
 "Learn more": [
  null,
  "Lær mer"
 ],
 "Login failed": [
  null,
  "Innlogging feilet"
 ],
 "No applications installed or available": [
  null,
  "Ingen applikasjoner installert eller tilgjengelig"
 ],
 "No description provided.": [
  null,
  "Ingen beskrivelse gitt."
 ],
 "No installation package found for this application.": [
  null,
  "Ingen installasjonspakke funnet for dette programmet."
 ],
 "Not permitted to perform this action.": [
  null,
  "Ikke tillatt å utføre denne handlingen."
 ],
 "Ok": [
  null,
  "Ok"
 ],
 "PackageKit crashed": [
  null,
  "PackageKit krasjet"
 ],
 "Remove": [
  null,
  "Fjern"
 ],
 "Removing": [
  null,
  "Fjerner"
 ],
 "Server has closed the connection.": [
  null,
  "Serveren har lukket forbindelsen."
 ],
 "The server refused to authenticate using any supported methods.": [
  null,
  "Serveren nektet å godkjenne ved hjelp av de støttede metodene."
 ],
 "Too much data": [
  null,
  "For mye data"
 ],
 "Unknown application": [
  null,
  "Ukjent program"
 ],
 "Untrusted host": [
  null,
  ""
 ],
 "Update package information": [
  null,
  "Oppdater pakkeinformasjon"
 ],
 "View project website": [
  null,
  "Vis prosjektets nettsted"
 ],
 "Waiting for other programs to finish using the package manager...": [
  null,
  "Venter på at andre programmer skal bli ferdige å bruke pakkebehandling..."
 ],
 "Your session has been terminated.": [
  null,
  "Økten din er avsluttet."
 ],
 "Your session has expired. Please log in again.": [
  null,
  "Økten din har utløpt. Vennligst logg inn igjen."
 ],
 "add-on": [
  null,
  "tillegg"
 ],
 "addon": [
  null,
  "tillegg"
 ],
 "apps": [
  null,
  "apper"
 ],
 "extension": [
  null,
  "utvidelse"
 ],
 "install": [
  null,
  "installer"
 ],
 "plugin": [
  null,
  "utvidelse"
 ]
});
