cockpit.locale({
 "": {'plural-forms':function(n) {
var nplurals, plural;
nplurals=2; plural=n != 1;
return plural;
},
  "language": "ca",
  "x-generator": "Weblate 4.0.3"
 },
 "$0 exited with code $1": [
  null,
  "$0 va sortir amb el codi $1"
 ],
 "$0 failed": [
  null,
  "$0 ha fallat"
 ],
 "$0 killed with signal $1": [
  null,
  "$0 es va matar amb el senyal $1"
 ],
 "Cancel": [
  null,
  "Cancel·la"
 ],
 "Cannot forward login credentials": [
  null,
  ""
 ],
 "Close": [
  null,
  "Tanca"
 ],
 "Cockpit could not contact the given host.": [
  null,
  "Cockpit no ha pogut contactar amb l'amfitrió indicat."
 ],
 "Cockpit is not compatible with the software on the system.": [
  null,
  "Cockpit no és compatible amb el programari del sistema."
 ],
 "Cockpit is not installed on the system.": [
  null,
  "Cockpit no està instal·lat al sistema."
 ],
 "Connection has timed out.": [
  null,
  "La connexió ha excedit el temps."
 ],
 "Create report": [
  null,
  "Crea l'informe"
 ],
 "Diagnostic reports": [
  null,
  "Informes de diagnòstic"
 ],
 "Done!": [
  null,
  "Fet!"
 ],
 "Download report": [
  null,
  "Baixa l'informe"
 ],
 "Generating report": [
  null,
  "S'està generant l'informe"
 ],
 "Host key is incorrect": [
  null,
  "La clau d'amfitrió és incorrecta"
 ],
 "Internal error": [
  null,
  "Error intern"
 ],
 "Login failed": [
  null,
  "Ha fallat l'inici de sessió"
 ],
 "No archive has been created.": [
  null,
  "No s'ha creat cap arxiu."
 ],
 "Not permitted to perform this action.": [
  null,
  "No es permet realitzar aquesta acció."
 ],
 "Server has closed the connection.": [
  null,
  "El servidor ha tancat la connexió."
 ],
 "The collected information will be stored locally on the system.": [
  null,
  "La informació recopilada s'emmagatzemarà localment al sistema."
 ],
 "The generated archive contains data considered sensitive and its content should be reviewed by the originating organization before being passed to any third party.": [
  null,
  ""
 ],
 "The server refused to authenticate using any supported methods.": [
  null,
  "El servidor ha refusat l'autenticació mitjançant qualsevol dels mètodes compatibles."
 ],
 "This tool will collect system configuration and diagnostic information from this system for use with diagnosing problems with the system.": [
  null,
  "Aquesta eina recopilarà la configuració i la informació de diagnòstic d'aquest sistema per a l'ús amb el diagnòstic de problemes amb el sistema."
 ],
 "Too much data": [
  null,
  "Hi ha massa dades"
 ],
 "Untrusted host": [
  null,
  "Amfitrió no fiable"
 ],
 "You need to switch to \"Administrative access\" in order to create reports.": [
  null,
  ""
 ],
 "Your session has been terminated.": [
  null,
  "La vostra sessió ha estat finalitzada."
 ],
 "Your session has expired. Please log in again.": [
  null,
  "La vostra sessió ha vençut. Si us plau, torneu a iniciar la sessió."
 ],
 "sos": [
  null,
  ""
 ]
});
