cockpit.locale({
 "": {'plural-forms':function(n) {
var nplurals, plural;
nplurals=1; plural=0;
return plural;
},
  "language": "ko",
  "x-generator": "Weblate 4.6"
 },
 "$0 exited with code $1": [
  null,
  "$0가 코드 $1로 종료"
 ],
 "$0 failed": [
  null,
  "$0 가 실패했습니다"
 ],
 "$0 is not available from any repository.": [
  null,
  "$0는 저장소에서 사용 할 수 없습니다."
 ],
 "$0 killed with signal $1": [
  null,
  "$1 시그널에 의해 $0가 종료되었습니다"
 ],
 "$0 package": [
  "$0 packages",
  "$0 꾸러미"
 ],
 "$0 package needs a system reboot": [
  "$0 packages need a system reboot",
  "$0 꾸러미의 경우 시스템을 재시작해야 합니다"
 ],
 "$0 security fix available": [
  "$0 security fixes available",
  "$0 보안 픽스 이용 가능"
 ],
 "$0 service needs to be restarted": [
  "$0 services need to be restarted",
  "$0 서비스를 재시작해야 합니다"
 ],
 "$0 update available": [
  "$0 updates available",
  "$0 업데이트 이용 가능"
 ],
 "$0 will be installed.": [
  null,
  "$0가 설치됩니다."
 ],
 ", including $1 security fix": [
  ", including $1 security fixes",
  "$1 보안 수정 포함"
 ],
 "1 minute": [
  null,
  "1분"
 ],
 "20 minutes": [
  null,
  "20분"
 ],
 "40 minutes": [
  null,
  "40 분"
 ],
 "5 minutes": [
  null,
  "5분"
 ],
 "60 minutes": [
  null,
  "60 분"
 ],
 "A package needs a system reboot for the updates to take effect:": [
  "Some packages need a system reboot for the updates to take effect:",
  "최신화를 적용하려면 꾸러미의 시스템을 재시작해야 합니다:"
 ],
 "A service needs to be restarted for the updates to take effect:": [
  "Some services need to be restarted for the updates to take effect:",
  "최신화를 적용하려면 서비스를 다시 시작해야 합니다:"
 ],
 "Additional packages:": [
  null,
  "추가 꾸러미 :"
 ],
 "All updates": [
  null,
  "모든 업데이트"
 ],
 "Applying updates": [
  null,
  "업데이트 적용 중"
 ],
 "Applying updates failed": [
  null,
  "업데이트 적용 실패"
 ],
 "Automatic updates": [
  null,
  "자동 최신화"
 ],
 "Automatically using NTP": [
  null,
  "자동으로 NTP 사용"
 ],
 "Automatically using specific NTP servers": [
  null,
  "특정 NTP 서버를 자동으로 사용"
 ],
 "Available updates": [
  null,
  "사용 가능한 업데이트"
 ],
 "Bug fix updates available": [
  null,
  "사용 가능한 버그 수정 업데이트"
 ],
 "Bugs": [
  null,
  "버그"
 ],
 "CVE": [
  null,
  "CVE"
 ],
 "Cancel": [
  null,
  "취소"
 ],
 "Cannot forward login credentials": [
  null,
  "로그인 정보를 전송할 수 없습니다"
 ],
 "Cannot schedule event in the past": [
  null,
  "이전 이벤트를 예약할 수 없습니다"
 ],
 "Change": [
  null,
  "변경"
 ],
 "Change system time": [
  null,
  "시스템 시간 변경"
 ],
 "Check for updates": [
  null,
  "업데이트 확인"
 ],
 "Checking for package updates...": [
  null,
  "꾸러미 최신화 점검 중 ..."
 ],
 "Checking installed software": [
  null,
  "설치된 소프트웨어 확인 중"
 ],
 "Checking software status": [
  null,
  "소프트웨어 상태 확인 중"
 ],
 "Cockpit could not contact the given host.": [
  null,
  "Cockpit을 지정된 호스트에 연결 할 수 없습니다."
 ],
 "Cockpit is not compatible with the software on the system.": [
  null,
  "Cockpit은 시스템의 소프트웨어와 호환성이 없습니다."
 ],
 "Cockpit is not installed on the system.": [
  null,
  "시스템에 Cockpit이 설치되어 있지 않습니다."
 ],
 "Connection has timed out.": [
  null,
  "연결 시간 초과."
 ],
 "Continue": [
  null,
  "진행"
 ],
 "Danger alert:": [
  null,
  "위험 경고:"
 ],
 "Delay": [
  null,
  "지연"
 ],
 "Details": [
  null,
  "상세 정보"
 ],
 "Disabled": [
  null,
  "사용 안함"
 ],
 "Downloaded": [
  null,
  "내려받기 되었습니다"
 ],
 "Downloading": [
  null,
  "내려받기 중"
 ],
 "Downloading $0": [
  null,
  "$0 내려받기 중"
 ],
 "Edit": [
  null,
  "편집"
 ],
 "Enhancement updates available": [
  null,
  "기능 업데이트를 사용할 수 있습니다"
 ],
 "Errata": [
  null,
  "에라타"
 ],
 "Error message": [
  null,
  "오류 메시지"
 ],
 "Failed to parse unit files for dnf-automatic.timer or dnf-automatic-install.timer. Please remove custom overrides to enable this feature.": [
  null,
  ""
 ],
 "Failed to restart service": [
  null,
  "서비스를 재시작하지 못했습니다"
 ],
 "Fridays": [
  null,
  "금요일"
 ],
 "History package count": [
  null,
  "기록 꾸러미 수"
 ],
 "Host key is incorrect": [
  null,
  "호스트 키가 잘못되었습니다"
 ],
 "Hours must be a number between 0 and 23": [
  null,
  "시간은 0에서 23 사이의 숫자 여야합니다"
 ],
 "Ignore": [
  null,
  "무시"
 ],
 "Info": [
  null,
  "정보"
 ],
 "Initializing...": [
  null,
  "초기화 중..."
 ],
 "Install": [
  null,
  "설치"
 ],
 "Install all updates": [
  null,
  "모든 업데이트 설치"
 ],
 "Install security updates": [
  null,
  "보안 업데이트 설치"
 ],
 "Install software": [
  null,
  "소프트웨어 설치"
 ],
 "Installed": [
  null,
  "설치되었습니다"
 ],
 "Installing": [
  null,
  "설치 중"
 ],
 "Installing $0": [
  null,
  "$0 설치 중"
 ],
 "Internal error": [
  null,
  "내부 오류"
 ],
 "Invalid date format": [
  null,
  "잘못된 날짜 형식"
 ],
 "Invalid date format and invalid time format": [
  null,
  "잘못된 날짜 형식 및 잘못된 시간 형식"
 ],
 "Invalid time format": [
  null,
  "잘못된 시간 형식"
 ],
 "Invalid timezone": [
  null,
  "잘못된 시간대"
 ],
 "Last checked: $0": [
  null,
  "마지막 접속 날짜: $0"
 ],
 "Learn more": [
  null,
  "더 알아보기"
 ],
 "Loading available updates failed": [
  null,
  "사용 가능한 최신화 적재에 실패했습니다"
 ],
 "Loading available updates, please wait...": [
  null,
  "사용 가능한 업데이트를 로딩하고 있습니다. 잠시만 기다리십시오..."
 ],
 "Log messages": [
  null,
  "로그 메세지"
 ],
 "Login failed": [
  null,
  "로그인 실패"
 ],
 "Managing software updates": [
  null,
  "소프트웨어 업데이트 관리"
 ],
 "Manually": [
  null,
  "수동"
 ],
 "Message to logged in users": [
  null,
  "로그인한 사용자에게 보내는 메세지"
 ],
 "Minutes must be a number between 0 and 59": [
  null,
  "분은 0에서 59 사이의 숫자이어야합니다"
 ],
 "Mondays": [
  null,
  "월요일"
 ],
 "More info...": [
  null,
  "자세한 정보..."
 ],
 "NTP server": [
  null,
  "NTP 서버"
 ],
 "Name": [
  null,
  "이름"
 ],
 "Need at least one NTP server": [
  null,
  "최소 하나의 NTP 서버가 필요합니다"
 ],
 "No delay": [
  null,
  "지연 없음"
 ],
 "No updates": [
  null,
  "업데이트 없음"
 ],
 "Not permitted to perform this action.": [
  null,
  "이 작업을 실행할 수 있는 권한이 없습니다."
 ],
 "Not registered": [
  null,
  "등록되지 않음"
 ],
 "Not synchronized": [
  null,
  "동기화 되어 있지 않습니다"
 ],
 "Ok": [
  null,
  "확인"
 ],
 "Package information": [
  null,
  "꾸러미 정보"
 ],
 "PackageKit crashed": [
  null,
  "PackageKit가 충돌했습니다"
 ],
 "PackageKit is not installed": [
  null,
  "PackageKit이 설치되어 있지 않습니다"
 ],
 "PackageKit reported error code $0": [
  null,
  "PackageKit가 오류 코드 $0를 보고했습니다"
 ],
 "Packages": [
  null,
  "꾸러미"
 ],
 "Pick date": [
  null,
  "날짜 선택"
 ],
 "Please reload the page after resolving the issue.": [
  null,
  "문제를 해결한 후 페이지를 다시 로드하십시오."
 ],
 "Reboot": [
  null,
  "재시작"
 ],
 "Reboot recommended": [
  null,
  "재시작 권장"
 ],
 "Reboot system...": [
  null,
  "시스템 재시작..."
 ],
 "Refreshing package information": [
  null,
  "꾸러미 정보 새로고침 중"
 ],
 "Register…": [
  null,
  "등록 중…"
 ],
 "Reloading the state of remaining services": [
  null,
  "나머지 서비스의 상태 재로딩 중"
 ],
 "Removals:": [
  null,
  "삭제:"
 ],
 "Removing $0": [
  null,
  "$0 삭제 중"
 ],
 "Restart services": [
  null,
  "서비스 재시작"
 ],
 "Restart services...": [
  null,
  "서비스 재시작..."
 ],
 "Restarting": [
  null,
  "재시작 중"
 ],
 "Saturdays": [
  null,
  "토요일"
 ],
 "Save changes": [
  null,
  "변경 사항 저장"
 ],
 "Security updates ": [
  null,
  "보안 업데이트 "
 ],
 "Security updates available": [
  null,
  "사용 가능한 보안 업데이트"
 ],
 "Security updates only": [
  null,
  "보안 업데이트만"
 ],
 "Server has closed the connection.": [
  null,
  "서버 연결이 종료되었습니다."
 ],
 "Set time": [
  null,
  "시간 설정"
 ],
 "Set up": [
  null,
  "설정"
 ],
 "Setting up": [
  null,
  "설정 중"
 ],
 "Severity": [
  null,
  "심각도"
 ],
 "Shut down": [
  null,
  "종료"
 ],
 "Software Updates": [
  null,
  "소프트웨어 최신화"
 ],
 "Software updates": [
  null,
  "소프트웨어 최신화"
 ],
 "Some other program is currently using the package manager, please wait...": [
  null,
  "다른 프로그램이 꾸러미 관리자를 사용 중입니다. 잠시 기다려주세요..."
 ],
 "Some software needs to be restarted manually": [
  null,
  "일부 소프트웨어는 수동으로 다시 시작해야 합니다"
 ],
 "Specific time": [
  null,
  "특정 시간"
 ],
 "Status": [
  null,
  "상태"
 ],
 "Sundays": [
  null,
  "일요일"
 ],
 "Synchronized": [
  null,
  "동기화됩니다"
 ],
 "Synchronized with $0": [
  null,
  "$0와 동기화됩니다"
 ],
 "Synchronizing": [
  null,
  "동기화 중"
 ],
 "System is up to date": [
  null,
  "시스템이 최신 상태입니다"
 ],
 "The following service will be restarted:": [
  "The following services will be restarted:",
  "다음 서비스가 다시 시작됩니다:"
 ],
 "The server refused to authenticate using any supported methods.": [
  null,
  "서버가 지원되는 방법을 사용하여 인증을 거부했습니다."
 ],
 "This host will reboot after updates are installed.": [
  null,
  "최신화가 설치되면 이 호스트가 재시작됩니다."
 ],
 "This system is not registered": [
  null,
  "이 시스템은 등록되어 있지 않습니다"
 ],
 "Thursdays": [
  null,
  "목요일"
 ],
 "Time": [
  null,
  "시간"
 ],
 "Time zone": [
  null,
  "시간대"
 ],
 "To get software updates, this system needs to be registered with Red Hat, either using the Red Hat Customer Portal or a local subscription server.": [
  null,
  "소프트웨어 업데이트를 받으려면 Red Hat 고객 포털이나 로컬 서브스크립션 서버를 사용하여 시스템을 Red Hat에 등록해야 합니다."
 ],
 "Too much data": [
  null,
  "데이터가 너무 많습니다"
 ],
 "Total size: $0": [
  null,
  "전체 크기: $0"
 ],
 "Trying to synchronize with $0": [
  null,
  "$0와 동기화를 시도 중입니다"
 ],
 "Tuesdays": [
  null,
  "화요일"
 ],
 "Type": [
  null,
  "유형"
 ],
 "Untrusted host": [
  null,
  "지원되지 않는 호스트"
 ],
 "Update Success Table": [
  null,
  "업데이트 성공 테이블"
 ],
 "Update history": [
  null,
  "최신화 내역"
 ],
 "Update log": [
  null,
  "업데이트 로그"
 ],
 "Update was successful": [
  null,
  "업데이트에 성공했습니다"
 ],
 "Updated": [
  null,
  "최신화됩니다"
 ],
 "Updated packages may require a reboot to take effect.": [
  null,
  "최신화된 꾸러미를 적용하려면 시스템을 재시작해야 합니다."
 ],
 "Updates ": [
  null,
  "업데이트 "
 ],
 "Updates available": [
  null,
  "사용 가능한 업데이트"
 ],
 "Updates history": [
  null,
  "최신화 내역"
 ],
 "Updating": [
  null,
  "최신화 중"
 ],
 "Verified": [
  null,
  "확인"
 ],
 "Verifying": [
  null,
  "확인 중"
 ],
 "Version": [
  null,
  "버전"
 ],
 "Waiting for other software management operations to finish": [
  null,
  "다른 소프트웨어 관리 작업이 완료될 때 까지 대기 중"
 ],
 "Web Console will restart": [
  null,
  "웹 콘솔이 재시작됩니다"
 ],
 "Wednesdays": [
  null,
  "수요일"
 ],
 "When": [
  null,
  "날짜"
 ],
 "When the Web Console is restarted, you will no longer see progress information. However, the update process will continue in the background. Reconnect to continue watching the update process.": [
  null,
  "웹 콘솔이 다시 시작되면 더 이상 진행률 정보가 표시되지 않지만 업데이트 프로세스는 백그라운드에서 계속됩니다. 업데이트 프로세스를 계속 확인하려면 다시 연결하십시오."
 ],
 "Your server will close the connection soon. You can reconnect after it has restarted.": [
  null,
  "서버 연결이 종료됩니다. 다시 시작하여 연결을 재개할 수 있습니다."
 ],
 "Your session has been terminated.": [
  null,
  "세션이 종료되었습니다."
 ],
 "Your session has expired. Please log in again.": [
  null,
  "세션이 만료되었습니다. 다시 로그인하십시오."
 ],
 "apt-get": [
  null,
  "apt-get"
 ],
 "at": [
  null,
  "시간"
 ],
 "bug fix": [
  null,
  "버그 수정"
 ],
 "dnf": [
  null,
  "dnf"
 ],
 "enhancement": [
  null,
  "기능 개선"
 ],
 "every day": [
  null,
  "매일"
 ],
 "package": [
  null,
  "꾸러미"
 ],
 "packagekit": [
  null,
  "packagekit"
 ],
 "security": [
  null,
  "보안"
 ],
 "show less": [
  null,
  "덜 보기"
 ],
 "show more": [
  null,
  "더 보기"
 ],
 "will be applied $0 at $1": [
  null,
  "$1에서 $0에 적용됩니다"
 ],
 "yum": [
  null,
  "yum"
 ]
});
