cockpit.locale({
 "": {'plural-forms':function(n) {
var nplurals, plural;
nplurals=2; plural=n != 1;
return plural;
},
  "language": "ca",
  "x-generator": "Weblate 4.0.3"
 },
 "$0 GiB total": [
  null,
  ""
 ],
 "$0 exited with code $1": [
  null,
  "$0 va sortir amb el codi $1"
 ],
 "$0 failed": [
  null,
  "$0 ha fallat"
 ],
 "$0 is not available from any repository.": [
  null,
  ""
 ],
 "$0 killed with signal $1": [
  null,
  "$0 es va matar amb el senyal $1"
 ],
 "$0 will be installed.": [
  null,
  ""
 ],
 "1 min": [
  null,
  "1 min"
 ],
 "5 min": [
  null,
  "5 min"
 ],
 "Absent": [
  null,
  ""
 ],
 "Additional packages:": [
  null,
  ""
 ],
 "Advanced TCA": [
  null,
  ""
 ],
 "All logs": [
  null,
  ""
 ],
 "All-in-one": [
  null,
  ""
 ],
 "Blade": [
  null,
  ""
 ],
 "Blade enclosure": [
  null,
  ""
 ],
 "Bus expansion chassis": [
  null,
  ""
 ],
 "CPU": [
  null,
  "CPU"
 ],
 "Cancel": [
  null,
  "Cancel·la"
 ],
 "Cannot forward login credentials": [
  null,
  ""
 ],
 "Checking installed software": [
  null,
  ""
 ],
 "Cockpit could not contact the given host.": [
  null,
  "Cockpit no ha pogut contactar amb l'amfitrió indicat."
 ],
 "Cockpit is not compatible with the software on the system.": [
  null,
  "Cockpit no és compatible amb el programari del sistema."
 ],
 "Cockpit is not installed on the system.": [
  null,
  "Cockpit no està instal·lat al sistema."
 ],
 "Compact PCI": [
  null,
  "PCI compacte"
 ],
 "Connection has timed out.": [
  null,
  "La connexió ha excedit el temps."
 ],
 "Convertible": [
  null,
  "Convertible"
 ],
 "Desktop": [
  null,
  "Escriptori"
 ],
 "Detachable": [
  null,
  ""
 ],
 "Disk I/O": [
  null,
  "E/S de disc"
 ],
 "Disks": [
  null,
  "Discs"
 ],
 "Docking station": [
  null,
  ""
 ],
 "Downloading $0": [
  null,
  ""
 ],
 "Dual rank": [
  null,
  ""
 ],
 "Embedded PC": [
  null,
  ""
 ],
 "Error has occurred": [
  null,
  ""
 ],
 "Event": [
  null,
  ""
 ],
 "Expansion chassis": [
  null,
  ""
 ],
 "Handheld": [
  null,
  ""
 ],
 "Host key is incorrect": [
  null,
  "La clau d'amfitrió és incorrecta"
 ],
 "In": [
  null,
  ""
 ],
 "Install": [
  null,
  "Instal·la"
 ],
 "Install cockpit-pcp": [
  null,
  ""
 ],
 "Install software": [
  null,
  ""
 ],
 "Installing $0": [
  null,
  ""
 ],
 "Internal error": [
  null,
  "Error intern"
 ],
 "IoT gateway": [
  null,
  ""
 ],
 "Is 'pmlogger' service running?": [
  null,
  ""
 ],
 "Jump to": [
  null,
  ""
 ],
 "Laptop": [
  null,
  ""
 ],
 "Load": [
  null,
  ""
 ],
 "Load spike": [
  null,
  ""
 ],
 "Loading...": [
  null,
  "S'està carregant..."
 ],
 "Log out": [
  null,
  "Tanca la sessió"
 ],
 "Login failed": [
  null,
  "Ha fallat l'inici de sessió"
 ],
 "Low profile desktop": [
  null,
  ""
 ],
 "Lunch box": [
  null,
  ""
 ],
 "Main server chassis": [
  null,
  ""
 ],
 "Memory": [
  null,
  "Memòria"
 ],
 "Metrics history could not be loaded": [
  null,
  ""
 ],
 "Mini PC": [
  null,
  "Mini PC"
 ],
 "Mini tower": [
  null,
  "Mini torre"
 ],
 "Multi-system chassis": [
  null,
  ""
 ],
 "No logs found": [
  null,
  ""
 ],
 "Not permitted to perform this action.": [
  null,
  "No es permet realitzar aquesta acció."
 ],
 "Notebook": [
  null,
  ""
 ],
 "Ok": [
  null,
  "D'acord"
 ],
 "Other": [
  null,
  "Altres"
 ],
 "Out": [
  null,
  ""
 ],
 "Overview": [
  null,
  "Visió de conjunt"
 ],
 "Package cockpit-pcp is missing for metrics history": [
  null,
  ""
 ],
 "PackageKit crashed": [
  null,
  "PackageKit s'ha estavellat."
 ],
 "Performance Metrics": [
  null,
  ""
 ],
 "Peripheral chassis": [
  null,
  ""
 ],
 "Pizza box": [
  null,
  ""
 ],
 "Portable": [
  null,
  "Portable"
 ],
 "Present": [
  null,
  ""
 ],
 "RAID chassis": [
  null,
  ""
 ],
 "RAM": [
  null,
  ""
 ],
 "Rack mount chassis": [
  null,
  ""
 ],
 "Reboot": [
  null,
  "Rearrencada"
 ],
 "Removals:": [
  null,
  ""
 ],
 "Removing $0": [
  null,
  ""
 ],
 "Sealed-case PC": [
  null,
  ""
 ],
 "Server has closed the connection.": [
  null,
  "El servidor ha tancat la connexió."
 ],
 "Service": [
  null,
  "Servei"
 ],
 "Single rank": [
  null,
  ""
 ],
 "Space-saving computer": [
  null,
  ""
 ],
 "Stick PC": [
  null,
  ""
 ],
 "Sub-Chassis": [
  null,
  ""
 ],
 "Sub-Notebook": [
  null,
  ""
 ],
 "Swap": [
  null,
  "Intercanvi"
 ],
 "Tablet": [
  null,
  "Tauleta"
 ],
 "The server refused to authenticate using any supported methods.": [
  null,
  "El servidor ha refusat l'autenticació mitjançant qualsevol dels mètodes compatibles."
 ],
 "Today": [
  null,
  ""
 ],
 "Too much data": [
  null,
  "Hi ha massa dades"
 ],
 "Total size: $0": [
  null,
  ""
 ],
 "Tower": [
  null,
  "Torre"
 ],
 "Troubleshoot": [
  null,
  "Soluciona el problema"
 ],
 "Unknown": [
  null,
  "Desconegut"
 ],
 "Untrusted host": [
  null,
  "Amfitrió no fiable"
 ],
 "Usage": [
  null,
  "Ús"
 ],
 "Used": [
  null,
  "Utilitzat"
 ],
 "Waiting for other software management operations to finish": [
  null,
  ""
 ],
 "You need to relogin to be able to see metrics": [
  null,
  ""
 ],
 "Your session has been terminated.": [
  null,
  "La vostra sessió ha estat finalitzada."
 ],
 "Your session has expired. Please log in again.": [
  null,
  "La vostra sessió ha vençut. Si us plau, torneu a iniciar la sessió."
 ],
 "[$0 bytes of binary data]": [
  null,
  "[$0 bytes de dades binàries]"
 ],
 "[binary data]": [
  null,
  "[dades binàries]"
 ],
 "[no data]": [
  null,
  "[sense dades]"
 ],
 "nice": [
  null,
  ""
 ],
 "user": [
  null,
  "usuari"
 ]
});
