cockpit.locale({
 "": {'plural-forms':function(n) {
var nplurals, plural;
nplurals=2; plural=n != 1;
return plural;
},
  "language": "fi",
  "x-generator": "Weblate 4.5.1"
 },
 "$0 exited with code $1": [
  null,
  "$0 poistui koodilla $1"
 ],
 "$0 failed": [
  null,
  "$0 epäonnistui"
 ],
 "$0 killed with signal $1": [
  null,
  "$0 tapettu signaalilla $1"
 ],
 "Actions": [
  null,
  "Toimet"
 ],
 "Applications": [
  null,
  "Sovellukset"
 ],
 "Applications list": [
  null,
  "Sovellusten luettelo"
 ],
 "Cancel": [
  null,
  "Peru"
 ],
 "Cannot forward login credentials": [
  null,
  "Kirjautumistietoja ei voi välittää eteenpäin"
 ],
 "Checking for new applications": [
  null,
  "Etsitään uusia sovelluksia"
 ],
 "Close": [
  null,
  "Sulje"
 ],
 "Cockpit could not contact the given host.": [
  null,
  "Cockpit ei saanut yhteyttä isäntään."
 ],
 "Cockpit is not compatible with the software on the system.": [
  null,
  "Cockpit ei ole yhteensopiva järjestelmän ohjelmiston kanssa."
 ],
 "Cockpit is not installed on the system.": [
  null,
  "Cockpit ei ole asennettu järjestelmässä."
 ],
 "Connection has timed out.": [
  null,
  "Yhteys aikakatkaistiin."
 ],
 "Error": [
  null,
  "Virhe"
 ],
 "Go to application": [
  null,
  "Siirry sovellukseen"
 ],
 "Host key is incorrect": [
  null,
  "Koneen avain on väärin"
 ],
 "Install": [
  null,
  "Asennus"
 ],
 "Installing": [
  null,
  "Asennetaan"
 ],
 "Internal error": [
  null,
  "Sisäinen virhe"
 ],
 "Learn more": [
  null,
  "Opi lisää"
 ],
 "Login failed": [
  null,
  "Kirjautuminen epäonnistui"
 ],
 "No applications installed or available": [
  null,
  "Ei sovelluksia asennettuna tai saatavilla"
 ],
 "No description provided.": [
  null,
  "Kuvausta ei annettu."
 ],
 "No installation package found for this application.": [
  null,
  "Tälle sovellukselle ei löytynyt asennuspakettia."
 ],
 "Not permitted to perform this action.": [
  null,
  "Ei oikeutta suorittaa tätä toimintoa."
 ],
 "Ok": [
  null,
  "OK"
 ],
 "PackageKit crashed": [
  null,
  "PackageKit kaatui"
 ],
 "Remove": [
  null,
  "Poista"
 ],
 "Removing": [
  null,
  "Poistetaan"
 ],
 "Server has closed the connection.": [
  null,
  "Palvelin on sulkenut yhteyden."
 ],
 "The server refused to authenticate using any supported methods.": [
  null,
  "Palvelin kieltäytyi tunnistautumista käyttäen mitään tuetuista tavoista."
 ],
 "Too much data": [
  null,
  "Liian paljon dataa"
 ],
 "Unknown application": [
  null,
  "Tuntematon sovellus"
 ],
 "Untrusted host": [
  null,
  "Epäluotettava isäntä"
 ],
 "Update package information": [
  null,
  "Päivitä paketin tiedot"
 ],
 "View project website": [
  null,
  "Näytä hankkeen verkkosivusto"
 ],
 "Waiting for other programs to finish using the package manager...": [
  null,
  "Odotetaan muiden ohjelmien paketinhallinnan käyttämisen päättymistä..."
 ],
 "Your session has been terminated.": [
  null,
  "Istuntosi on päätetty."
 ],
 "Your session has expired. Please log in again.": [
  null,
  "Istuntosi on vahventunut. Ole hyvä ja kirjaudu uudelleen sisään."
 ],
 "add-on": [
  null,
  "lisäosa"
 ],
 "addon": [
  null,
  "lisäosa"
 ],
 "apps": [
  null,
  "sovellukset"
 ],
 "extension": [
  null,
  "laajennus"
 ],
 "install": [
  null,
  "asenna"
 ],
 "plugin": [
  null,
  "kytkettävä"
 ]
});
