cockpit.locale({
 "": {'plural-forms':function(n) {
var nplurals, plural;
nplurals=2; plural=n != 1;
return plural;
},
  "language": "ca",
  "x-generator": "Weblate 4.0.3"
 },
 "$0 exited with code $1": [
  null,
  "$0 va sortir amb el codi $1"
 ],
 "$0 failed": [
  null,
  "$0 ha fallat"
 ],
 "$0 killed with signal $1": [
  null,
  "$0 es va matar amb el senyal $1"
 ],
 "Alert": [
  null,
  ""
 ],
 "Ansible": [
  null,
  ""
 ],
 "Ansible roles documentation": [
  null,
  ""
 ],
 "Apply this solution": [
  null,
  "Aplica aquesta solució"
 ],
 "Applying solution...": [
  null,
  "S'està aplicant la solució..."
 ],
 "Audit log": [
  null,
  "Registre d'auditoria"
 ],
 "Automation script": [
  null,
  ""
 ],
 "Cannot forward login credentials": [
  null,
  ""
 ],
 "Close": [
  null,
  "Tanca"
 ],
 "Cockpit could not contact the given host.": [
  null,
  "Cockpit no ha pogut contactar amb l'amfitrió indicat."
 ],
 "Cockpit is not compatible with the software on the system.": [
  null,
  "Cockpit no és compatible amb el programari del sistema."
 ],
 "Cockpit is not installed on the system.": [
  null,
  "Cockpit no està instal·lat al sistema."
 ],
 "Connecting to SETroubleshoot daemon...": [
  null,
  "S'està connectant al dimoni de SETroubleshoot..."
 ],
 "Connection has timed out.": [
  null,
  "La connexió ha excedit el temps."
 ],
 "Copy to clipboard": [
  null,
  ""
 ],
 "Create new task file with this content.": [
  null,
  ""
 ],
 "Dismiss": [
  null,
  ""
 ],
 "Enforcing": [
  null,
  ""
 ],
 "Error running semanage to discover system modifications": [
  null,
  ""
 ],
 "Error while deleting alert: $0": [
  null,
  "Error mentre se suprimia l'alerta: $0"
 ],
 "Error while setting SELinux mode: '$0'": [
  null,
  "Error mentre s'establia el mode de SELinux: '$0'"
 ],
 "Failed to delete alert: $0": [
  null,
  "Ha fallat la supressió de l'alerta: $0"
 ],
 "Host key is incorrect": [
  null,
  "La clau d'amfitrió és incorrecta"
 ],
 "Install setroubleshoot-server to troubleshoot SELinux events.": [
  null,
  "Instal·leu setroubleshoot-server per resoldre els esdeveniments de SELinux."
 ],
 "Internal error": [
  null,
  "Error intern"
 ],
 "Loading system modifications...": [
  null,
  ""
 ],
 "Login failed": [
  null,
  "Ha fallat l'inici de sessió"
 ],
 "No SELinux alerts.": [
  null,
  "Sense alertes de SELinux."
 ],
 "No system modifications": [
  null,
  ""
 ],
 "Not connected": [
  null,
  "No connectat"
 ],
 "Not permitted to perform this action.": [
  null,
  "No es permet realitzar aquesta acció."
 ],
 "Occurred $0": [
  null,
  "S'ha produït $0"
 ],
 "Occurred between $0 and $1": [
  null,
  "S'ha produït entre $0 i $1"
 ],
 "Permissive": [
  null,
  ""
 ],
 "SELinux": [
  null,
  ""
 ],
 "SELinux access control errors": [
  null,
  "Errors de control d'accés de SELinux"
 ],
 "SELinux is disabled on the system": [
  null,
  "SELinux no està inhabilitat al sistema"
 ],
 "SELinux is disabled on the system.": [
  null,
  "SELinux no està inhabilitat al sistema."
 ],
 "SELinux policy": [
  null,
  "Política de SELinux"
 ],
 "SELinux system status is unknown.": [
  null,
  "Es desconeix l'estat del sistema SELinux."
 ],
 "SELinux troubleshoot": [
  null,
  "Solució de problema de SELinux"
 ],
 "Server has closed the connection.": [
  null,
  "El servidor ha tancat la connexió."
 ],
 "Setting deviates from the configured state and will revert on the next boot.": [
  null,
  ""
 ],
 "Shell script": [
  null,
  ""
 ],
 "Solution applied successfully": [
  null,
  "S'ha aplicat la solució amb èxit"
 ],
 "Solution failed": [
  null,
  "Ha fallat la solució"
 ],
 "Solutions": [
  null,
  "Solucions"
 ],
 "System modifications": [
  null,
  ""
 ],
 "The configured state is unknown, it might change on the next boot.": [
  null,
  ""
 ],
 "The logged in user is not permitted to view system modifications": [
  null,
  ""
 ],
 "The server refused to authenticate using any supported methods.": [
  null,
  "El servidor ha refusat l'autenticació mitjançant qualsevol dels mètodes compatibles."
 ],
 "Too much data": [
  null,
  "Hi ha massa dades"
 ],
 "Unable to apply this solution automatically": [
  null,
  "No es pot aplicar automàticament aquesta solució"
 ],
 "Unable to get alert details.": [
  null,
  "No es poden obtenir els detalls de l'alerta."
 ],
 "Unable to get alert: $0": [
  null,
  "No es pot obtenir l'alerta: $0"
 ],
 "Unable to run fix: %0": [
  null,
  "No es pot executar la correcció: %0"
 ],
 "Unable to start setroubleshootd": [
  null,
  "No es pot iniciar setroubleshootd"
 ],
 "Untrusted host": [
  null,
  "Amfitrió no fiable"
 ],
 "View automation script": [
  null,
  ""
 ],
 "Waiting for details...": [
  null,
  "S'estan esperant els detalls..."
 ],
 "Your session has been terminated.": [
  null,
  "La vostra sessió ha estat finalitzada."
 ],
 "Your session has expired. Please log in again.": [
  null,
  "La vostra sessió ha vençut. Si us plau, torneu a iniciar la sessió."
 ],
 "avc": [
  null,
  ""
 ],
 "semanage": [
  null,
  ""
 ],
 "setroubleshoot": [
  null,
  ""
 ],
 "solution details": [
  null,
  "detalls de la solució"
 ]
});
