cockpit.locale({
 "": {'plural-forms':function(n) {
var nplurals, plural;
nplurals=1; plural=0;
return plural;
},
  "language": "ko",
  "x-generator": "Weblate 4.6"
 },
 "$0 exited with code $1": [
  null,
  "$0가 코드 $1로 종료"
 ],
 "$0 failed": [
  null,
  "$0 가 실패했습니다"
 ],
 "$0 killed with signal $1": [
  null,
  "$1 시그널에 의해 $0가 종료되었습니다"
 ],
 "Cannot forward login credentials": [
  null,
  "로그인 정보를 전송할 수 없습니다"
 ],
 "Cockpit could not contact the given host.": [
  null,
  "Cockpit을 지정된 호스트에 연결 할 수 없습니다."
 ],
 "Cockpit is not compatible with the software on the system.": [
  null,
  "Cockpit은 시스템의 소프트웨어와 호환성이 없습니다."
 ],
 "Cockpit is not installed on the system.": [
  null,
  "시스템에 Cockpit이 설치되어 있지 않습니다."
 ],
 "Connection has timed out.": [
  null,
  "연결 시간 초과."
 ],
 "Host key is incorrect": [
  null,
  "호스트 키가 잘못되었습니다"
 ],
 "Internal error": [
  null,
  "내부 오류"
 ],
 "Login failed": [
  null,
  "로그인 실패"
 ],
 "Not permitted to perform this action.": [
  null,
  "이 작업을 실행할 수 있는 권한이 없습니다."
 ],
 "Server has closed the connection.": [
  null,
  "서버 연결이 종료되었습니다."
 ],
 "The server refused to authenticate using any supported methods.": [
  null,
  "서버가 지원되는 방법을 사용하여 인증을 거부했습니다."
 ],
 "Too much data": [
  null,
  "데이터가 너무 많습니다"
 ],
 "Untrusted host": [
  null,
  "지원되지 않는 호스트"
 ],
 "Your session has been terminated.": [
  null,
  "세션이 종료되었습니다."
 ],
 "Your session has expired. Please log in again.": [
  null,
  "세션이 만료되었습니다. 다시 로그인하십시오."
 ],
 "[$0 bytes of binary data]": [
  null,
  "[바이너리 데이터의 $0 바이트]"
 ],
 "[binary data]": [
  null,
  "[바이너리 데이터]"
 ],
 "[no data]": [
  null,
  "[데이터 없음]"
 ]
});
