cockpit.locale({
 "": {'plural-forms':function(n) {
var nplurals, plural;
nplurals=2; plural=n != 1;
return plural;
},
  "language": "ca",
  "x-generator": "Weblate 4.0.3"
 },
 "$0 exited with code $1": [
  null,
  "$0 va sortir amb el codi $1"
 ],
 "$0 failed": [
  null,
  "$0 ha fallat"
 ],
 "$0 killed with signal $1": [
  null,
  "$0 es va matar amb el senyal $1"
 ],
 "Cancel": [
  null,
  "Cancel·la"
 ],
 "Cannot forward login credentials": [
  null,
  ""
 ],
 "Change performance profile": [
  null,
  "Canvia el perfil de rendiment"
 ],
 "Change profile": [
  null,
  "Canvia el perfil"
 ],
 "Cockpit could not contact the given host.": [
  null,
  "Cockpit no ha pogut contactar amb l'amfitrió indicat."
 ],
 "Cockpit is not compatible with the software on the system.": [
  null,
  "Cockpit no és compatible amb el programari del sistema."
 ],
 "Cockpit is not installed on the system.": [
  null,
  "Cockpit no està instal·lat al sistema."
 ],
 "Communication with tuned has failed": [
  null,
  "Ha fallat la comunicació amb tuned"
 ],
 "Connection has timed out.": [
  null,
  "La connexió ha excedit el temps."
 ],
 "Disable tuned": [
  null,
  "Inhabilita tuned"
 ],
 "Failed to disable tuned": [
  null,
  "Ha fallat la inhabilitació de tuned"
 ],
 "Failed to disable tuned profile": [
  null,
  "Ha fallat la inhabilitació del perfil de tuned"
 ],
 "Failed to enable tuned": [
  null,
  "Ha fallat l'habilitació de tuned"
 ],
 "Failed to switch profile": [
  null,
  "Ha fallat el canvi de perfil"
 ],
 "Host key is incorrect": [
  null,
  "La clau d'amfitrió és incorrecta"
 ],
 "Internal error": [
  null,
  "Error intern"
 ],
 "Login failed": [
  null,
  "Ha fallat l'inici de sessió"
 ],
 "None": [
  null,
  "Cap"
 ],
 "Not permitted to perform this action.": [
  null,
  "No es permet realitzar aquesta acció."
 ],
 "Ok": [
  null,
  "D'acord"
 ],
 "Server has closed the connection.": [
  null,
  "El servidor ha tancat la connexió."
 ],
 "The server refused to authenticate using any supported methods.": [
  null,
  "El servidor ha refusat l'autenticació mitjançant qualsevol dels mètodes compatibles."
 ],
 "This system is using a custom profile": [
  null,
  "El sistema està utilitzant un perfil personalitzat"
 ],
 "This system is using the recommended profile": [
  null,
  "El sistema està utilitzant el perfil recomanat"
 ],
 "Too much data": [
  null,
  "Hi ha massa dades"
 ],
 "Tuned has failed to start": [
  null,
  "Tuned ha fallat en iniciar-se"
 ],
 "Tuned is a service that monitors your system and optimizes the performance under certain workloads. The core of Tuned are profiles, which tune your system for different use cases.": [
  null,
  ""
 ],
 "Tuned is not available": [
  null,
  "Tuned no està disponible"
 ],
 "Tuned is not running": [
  null,
  "Tuned no s'està executant"
 ],
 "Tuned is off": [
  null,
  "Tuned no està aturat"
 ],
 "Untrusted host": [
  null,
  "Amfitrió no fiable"
 ],
 "Your session has been terminated.": [
  null,
  "La vostra sessió ha estat finalitzada."
 ],
 "Your session has expired. Please log in again.": [
  null,
  "La vostra sessió ha vençut. Si us plau, torneu a iniciar la sessió."
 ],
 "active": [
  null,
  "actiu"
 ],
 "none": [
  null,
  "cap"
 ],
 "recommended": [
  null,
  "recomanat"
 ]
});
