cockpit.locale({
 "": {'plural-forms':function(n) {
var nplurals, plural;
nplurals=2; plural=(n>1);
return plural;
},
  "language": "tr",
  "x-generator": "Weblate 4.5.1"
 },
 "$0 exited with code $1": [
  null,
  "$0, $1 koduyla çıkış yaptı"
 ],
 "$0 failed": [
  null,
  "$0 başarısız oldu"
 ],
 "$0 is not available from any repository.": [
  null,
  "$0, hiçbir depoda yok."
 ],
 "$0 killed with signal $1": [
  null,
  "$0, $1 sinyali ile sonlandırıldı"
 ],
 "$0 package": [
  "$0 packages",
  "$0 paket",
  "$0 paket"
 ],
 "$0 package needs a system reboot": [
  "$0 packages need a system reboot",
  "$0 paketin, sistemin yeniden başlatılmasına ihtiyacı var",
  "$0 paketin, sistemin yeniden başlatılmasına ihtiyacı var"
 ],
 "$0 security fix available": [
  "$0 security fixes available",
  "$0 güvenlik düzeltmesi mevcut",
  "$0 güvenlik düzeltmesi mevcut"
 ],
 "$0 service needs to be restarted": [
  "$0 services need to be restarted",
  "$0 hizmetin yeniden başlatılması gerekiyor",
  "$0 hizmetin yeniden başlatılması gerekiyor"
 ],
 "$0 update available": [
  "$0 updates available",
  "$0 güncelleme mevcut",
  "$0 güncelleme mevcut"
 ],
 "$0 will be installed.": [
  null,
  "$0 yüklenecektir."
 ],
 ", including $1 security fix": [
  ", including $1 security fixes",
  ", $1 güvenlik düzeltmesi dahil",
  ", $1 güvenlik düzeltmesi dahil"
 ],
 "1 minute": [
  null,
  "1 dakika"
 ],
 "20 minutes": [
  null,
  "20 dakika"
 ],
 "40 minutes": [
  null,
  "40 dakika"
 ],
 "5 minutes": [
  null,
  "5 dakika"
 ],
 "60 minutes": [
  null,
  "60 dakika"
 ],
 "A package needs a system reboot for the updates to take effect:": [
  "Some packages need a system reboot for the updates to take effect:",
  "Güncellemelerin etkili olması için bir paket, sistemin yeniden başlatılmasını gerektiriyor:",
  "Güncellemelerin etkili olması için bazı paketler, sistemin yeniden başlatılmasını gerektiriyor:"
 ],
 "A service needs to be restarted for the updates to take effect:": [
  "Some services need to be restarted for the updates to take effect:",
  "Güncellemelerin etkili olması için bir hizmetin yeniden başlatılması gerekiyor:",
  "Güncellemelerin etkili olması için bazı hizmetlerin yeniden başlatılması gerekiyor:"
 ],
 "Additional packages:": [
  null,
  "Ek paketler:"
 ],
 "All updates": [
  null,
  "Tüm güncellemeler"
 ],
 "Applying updates": [
  null,
  "Güncellemeler uygulanıyor"
 ],
 "Applying updates failed": [
  null,
  "Güncellemeleri uygulama başarısız oldu"
 ],
 "Automatic updates": [
  null,
  "Otomatik güncellemeler"
 ],
 "Automatically using NTP": [
  null,
  "Otomatik olarak NTP kullanarak"
 ],
 "Automatically using specific NTP servers": [
  null,
  "Otomatik olarak belirli NTP sunucularını kullanarak"
 ],
 "Available updates": [
  null,
  "Mevcut güncellemeler"
 ],
 "Bug fix updates available": [
  null,
  "Hata düzeltme güncellemeleri mevcut"
 ],
 "Bugs": [
  null,
  "Hatalar"
 ],
 "CVE": [
  null,
  "CVE"
 ],
 "Cancel": [
  null,
  "İptal"
 ],
 "Cannot forward login credentials": [
  null,
  "Oturum açma kimlik bilgileri yönlendirilemiyor"
 ],
 "Cannot schedule event in the past": [
  null,
  "Geçmişteki olay zamanlanamıyor"
 ],
 "Change": [
  null,
  "Değiştir"
 ],
 "Change system time": [
  null,
  "Sistem saatini değiştir"
 ],
 "Check for updates": [
  null,
  "Güncellemeleri denetle"
 ],
 "Checking for package updates...": [
  null,
  "Paket güncellemeleri denetleniyor..."
 ],
 "Checking installed software": [
  null,
  "Yüklü yazılımlar denetleniyor"
 ],
 "Checking software status": [
  null,
  "Yazılım durumu denetleniyor"
 ],
 "Cockpit could not contact the given host.": [
  null,
  "Cockpit, verilen anamakineyle iletişim kuramadı."
 ],
 "Cockpit is not compatible with the software on the system.": [
  null,
  "Cockpit, sistemdeki yazılımla uyumlu değil."
 ],
 "Cockpit is not installed on the system.": [
  null,
  "Cockpit sistemde yüklü değil."
 ],
 "Connection has timed out.": [
  null,
  "Bağlantı zaman aşımına uğradı."
 ],
 "Continue": [
  null,
  "Devam"
 ],
 "Danger alert:": [
  null,
  "Tehlike uyarısı:"
 ],
 "Delay": [
  null,
  "Gecikme"
 ],
 "Details": [
  null,
  "Ayrıntılar"
 ],
 "Disabled": [
  null,
  "Etkisizleştirildi"
 ],
 "Downloaded": [
  null,
  "İndirildi"
 ],
 "Downloading": [
  null,
  "İndiriliyor"
 ],
 "Downloading $0": [
  null,
  "$0 indiriliyor"
 ],
 "Edit": [
  null,
  "Düzenle"
 ],
 "Enhancement updates available": [
  null,
  "İyileştirme güncellemeleri mevcut"
 ],
 "Errata": [
  null,
  "Düzeltme"
 ],
 "Error message": [
  null,
  "Hata iletisi"
 ],
 "Failed to parse unit files for dnf-automatic.timer or dnf-automatic-install.timer. Please remove custom overrides to enable this feature.": [
  null,
  ""
 ],
 "Failed to restart service": [
  null,
  "Hizmeti yeniden başlatma başarısız oldu"
 ],
 "Fridays": [
  null,
  "Cuma günleri"
 ],
 "History package count": [
  null,
  "Geçmiş paket sayısı"
 ],
 "Host key is incorrect": [
  null,
  "Anamakine anahtarı yanlış"
 ],
 "Hours must be a number between 0 and 23": [
  null,
  "Saat, 0 ile 23 arasında bir sayı olmak zorundadır"
 ],
 "Ignore": [
  null,
  "Yoksay"
 ],
 "Info": [
  null,
  "Bilgi"
 ],
 "Initializing...": [
  null,
  "Başlatılıyor..."
 ],
 "Install": [
  null,
  "Yükle"
 ],
 "Install all updates": [
  null,
  "Tüm güncellemeleri yükle"
 ],
 "Install security updates": [
  null,
  "Güvenlik güncellemelerini yükle"
 ],
 "Install software": [
  null,
  "Yazılım yükle"
 ],
 "Installed": [
  null,
  "Yüklendi"
 ],
 "Installing": [
  null,
  "Yükleniyor"
 ],
 "Installing $0": [
  null,
  "$0 yükleniyor"
 ],
 "Internal error": [
  null,
  "Dahili hata"
 ],
 "Invalid date format": [
  null,
  "Geçersiz tarih biçimi"
 ],
 "Invalid date format and invalid time format": [
  null,
  "Geçersiz tarih ve saat biçimi"
 ],
 "Invalid time format": [
  null,
  "Geçersiz saat biçimi"
 ],
 "Invalid timezone": [
  null,
  "Geçersiz saat dilimi"
 ],
 "Last checked: $0": [
  null,
  "Son denetleme: $0"
 ],
 "Learn more": [
  null,
  "Daha fazla bilgi edinin"
 ],
 "Loading available updates failed": [
  null,
  "Mevcut güncellemeleri yükleme başarısız oldu"
 ],
 "Loading available updates, please wait...": [
  null,
  "Mevcut güncellemeler yükleniyor, lütfen bekleyin..."
 ],
 "Log messages": [
  null,
  "Günlük iletileri"
 ],
 "Login failed": [
  null,
  "Oturum açma başarısız oldu"
 ],
 "Managing software updates": [
  null,
  "Yazılım güncellemelerini yönetme"
 ],
 "Manually": [
  null,
  "El ile"
 ],
 "Message to logged in users": [
  null,
  "Oturum açmış kullanıcılar için ileti"
 ],
 "Minutes must be a number between 0 and 59": [
  null,
  "Dakika, 0 ile 59 arasında bir sayı olmak zorundadır"
 ],
 "Mondays": [
  null,
  "Pazartesi günleri"
 ],
 "More info...": [
  null,
  "Daha fazla bilgi..."
 ],
 "NTP server": [
  null,
  "NTP sunucusu"
 ],
 "Name": [
  null,
  "Ad"
 ],
 "Need at least one NTP server": [
  null,
  "En az bir NTP sunucusu gerekli"
 ],
 "No delay": [
  null,
  "Gecikme yok"
 ],
 "No updates": [
  null,
  "Güncellemeler yok"
 ],
 "Not permitted to perform this action.": [
  null,
  "Bu eylemi gerçekleştirmeye izinli değil."
 ],
 "Not registered": [
  null,
  "Kayıtlı değil"
 ],
 "Not synchronized": [
  null,
  "Eşitlenmedi"
 ],
 "Ok": [
  null,
  "Tamam"
 ],
 "Package information": [
  null,
  "Paket bilgileri"
 ],
 "PackageKit crashed": [
  null,
  "PackageKit çöktü"
 ],
 "PackageKit is not installed": [
  null,
  "PackageKit yüklü değil"
 ],
 "PackageKit reported error code $0": [
  null,
  "PackageKit $0 hata kodunu bildirdi"
 ],
 "Packages": [
  null,
  "Paketler"
 ],
 "Pick date": [
  null,
  "Tarih seçin"
 ],
 "Please reload the page after resolving the issue.": [
  null,
  "Lütfen sorunu çözdükten sonra sayfayı yeniden yükleyin."
 ],
 "Reboot": [
  null,
  "Yeniden başlat"
 ],
 "Reboot recommended": [
  null,
  "Yeniden başlatma önerilir"
 ],
 "Reboot system...": [
  null,
  "Sistemi yeniden başlat..."
 ],
 "Refreshing package information": [
  null,
  "Paket bilgileri yenileniyor"
 ],
 "Register…": [
  null,
  "Kaydol…"
 ],
 "Reloading the state of remaining services": [
  null,
  "Kalan hizmetlerin durumu yeniden yükleniyor"
 ],
 "Removals:": [
  null,
  "Kaldırılanlar:"
 ],
 "Removing $0": [
  null,
  "$0 kaldırılıyor"
 ],
 "Restart services": [
  null,
  "Hizmetleri yeniden başlat"
 ],
 "Restart services...": [
  null,
  "Hizmetleri yeniden başlat..."
 ],
 "Restarting": [
  null,
  "Yeniden başlatılıyor"
 ],
 "Saturdays": [
  null,
  "Cumartesi günleri"
 ],
 "Save changes": [
  null,
  "Değişiklikleri kaydet"
 ],
 "Security updates ": [
  null,
  "Güvenlik güncellemeleri "
 ],
 "Security updates available": [
  null,
  "Güvenlik güncellemeleri mevcut"
 ],
 "Security updates only": [
  null,
  "Sadece güvenlik güncellemeleri"
 ],
 "Server has closed the connection.": [
  null,
  "Sunucu bağlantıyı kapattı."
 ],
 "Set time": [
  null,
  "Saati ayarla"
 ],
 "Set up": [
  null,
  "Ayarlandı"
 ],
 "Setting up": [
  null,
  "Ayarlanıyor"
 ],
 "Severity": [
  null,
  "Önem derecesi"
 ],
 "Shut down": [
  null,
  "Kapat"
 ],
 "Software Updates": [
  null,
  "Yazılım Güncellemeleri"
 ],
 "Software updates": [
  null,
  "Yazılım güncellemeleri"
 ],
 "Some other program is currently using the package manager, please wait...": [
  null,
  "Şu anda başka bir program paket yöneticisini kullanıyor, lütfen bekleyin..."
 ],
 "Some software needs to be restarted manually": [
  null,
  "Bazı yazılımların el ile yeniden başlatılması gerekiyor"
 ],
 "Specific time": [
  null,
  "Belirli bir zaman"
 ],
 "Status": [
  null,
  "Durum"
 ],
 "Sundays": [
  null,
  "Pazar günleri"
 ],
 "Synchronized": [
  null,
  "Eşitlendi"
 ],
 "Synchronized with $0": [
  null,
  "$0 ile eşitlendi"
 ],
 "Synchronizing": [
  null,
  "Eşitleniyor"
 ],
 "System is up to date": [
  null,
  "Sistem güncel"
 ],
 "The following service will be restarted:": [
  "The following services will be restarted:",
  "Aşağıdaki hizmet yeniden başlatılacaktır:",
  "Aşağıdaki hizmetler yeniden başlatılacaktır:"
 ],
 "The server refused to authenticate using any supported methods.": [
  null,
  "Sunucu, desteklenen herhangi bir yöntemi kullanarak kimlik doğrulamayı reddetti."
 ],
 "This host will reboot after updates are installed.": [
  null,
  "Güncellemeler yüklendikten sonra bu anamakine yeniden başlayacak."
 ],
 "This system is not registered": [
  null,
  "Bu sistem kayıtlı değil"
 ],
 "Thursdays": [
  null,
  "Perşembe günleri"
 ],
 "Time": [
  null,
  "Zaman"
 ],
 "Time zone": [
  null,
  "Saat dilimi"
 ],
 "To get software updates, this system needs to be registered with Red Hat, either using the Red Hat Customer Portal or a local subscription server.": [
  null,
  "Yazılım güncellemelerini almak için bu sistemin Red Hat Müşteri Portalı veya yerel bir abonelik sunucusu kullanılarak Red Hat'e kaydedilmesi gerekir."
 ],
 "Too much data": [
  null,
  "Çok fazla veri"
 ],
 "Total size: $0": [
  null,
  "Toplam boyut: $0"
 ],
 "Trying to synchronize with $0": [
  null,
  "$0 ile eşitlemeye çalışılıyor"
 ],
 "Tuesdays": [
  null,
  "Salı günleri"
 ],
 "Type": [
  null,
  "Tür"
 ],
 "Untrusted host": [
  null,
  "Güvenilmeyen anamakine"
 ],
 "Update Success Table": [
  null,
  "Başarı Tablosunu Güncelle"
 ],
 "Update history": [
  null,
  "Güncelleme geçmişi"
 ],
 "Update log": [
  null,
  "Güncelleme günlüğü"
 ],
 "Update was successful": [
  null,
  "Güncelleme başarılı oldu"
 ],
 "Updated": [
  null,
  "Güncellendi"
 ],
 "Updated packages may require a reboot to take effect.": [
  null,
  "Güncellenen paketlerin etkili olması için yeniden başlatma gerekebilir."
 ],
 "Updates ": [
  null,
  "Güncellemeler "
 ],
 "Updates available": [
  null,
  "Güncellemeler mevcut"
 ],
 "Updates history": [
  null,
  "Güncellemelerin geçmişi"
 ],
 "Updating": [
  null,
  "Güncellenen"
 ],
 "Verified": [
  null,
  "Doğrulandı"
 ],
 "Verifying": [
  null,
  "Doğrulanıyor"
 ],
 "Version": [
  null,
  "Sürüm"
 ],
 "Waiting for other software management operations to finish": [
  null,
  "Diğer yazılım yönetimi işlemlerinin bitmesi bekleniyor"
 ],
 "Web Console will restart": [
  null,
  "Web Konsolu yeniden başlayacak"
 ],
 "Wednesdays": [
  null,
  "Çarşamba günleri"
 ],
 "When": [
  null,
  "Zamanı"
 ],
 "When the Web Console is restarted, you will no longer see progress information. However, the update process will continue in the background. Reconnect to continue watching the update process.": [
  null,
  "Web Konsolu yeniden başlatıldığında, ilerleme bilgilerini artık görmeyeceksiniz. Ancak güncelleme işlemi arka planda devam edecek. Güncelleme işlemini izlemeye devam etmek için yeniden bağlanın."
 ],
 "Your server will close the connection soon. You can reconnect after it has restarted.": [
  null,
  "Sunucunuz bağlantıyı yakında kapatacak. Yeniden başlatıldıktan sonra yeniden bağlanabilirsiniz."
 ],
 "Your session has been terminated.": [
  null,
  "Oturumunuz sonlandırıldı."
 ],
 "Your session has expired. Please log in again.": [
  null,
  "Oturumunuzun süresi doldu. Lütfen tekrar oturum açın."
 ],
 "apt-get": [
  null,
  "apt-get"
 ],
 "at": [
  null,
  "saat"
 ],
 "bug fix": [
  null,
  "hata düzeltme"
 ],
 "dnf": [
  null,
  "dnf"
 ],
 "enhancement": [
  null,
  "iyileştirme"
 ],
 "every day": [
  null,
  "her gün"
 ],
 "package": [
  null,
  "paket"
 ],
 "packagekit": [
  null,
  "packagekit"
 ],
 "security": [
  null,
  "güvenlik"
 ],
 "show less": [
  null,
  "daha az göster"
 ],
 "show more": [
  null,
  "daha fazla göster"
 ],
 "will be applied $0 at $1": [
  null,
  "$0 saat $1'da uygulanacaktır"
 ],
 "yum": [
  null,
  "yum"
 ]
});
