cockpit.locale({
 "": {'plural-forms':function(n) {
var nplurals, plural;
nplurals=2; plural=n != 1;
return plural;
},
  "language": "nb_NO",
  "x-generator": "Weblate 4.5.1"
 },
 "$0 exited with code $1": [
  null,
  "$0 avsluttet med koden $1"
 ],
 "$0 failed": [
  null,
  "$0 feilet"
 ],
 "$0 killed with signal $1": [
  null,
  "$0 drept med signal $1"
 ],
 "$0 occurrence": [
  "$0 occurrences",
  "$0 forekomst",
  "$0 forekomster"
 ],
 "Alert": [
  null,
  "Varsel"
 ],
 "Ansible": [
  null,
  "Ansible"
 ],
 "Ansible roles documentation": [
  null,
  "Ansible roller dokumentasjon"
 ],
 "Apply this solution": [
  null,
  "Bruk denne løsningen"
 ],
 "Applying solution...": [
  null,
  "Bruker løsning ..."
 ],
 "Audit log": [
  null,
  ""
 ],
 "Automation script": [
  null,
  "Automatiseringsskript"
 ],
 "Cannot forward login credentials": [
  null,
  "Kan ikke videresende påloggingsinformasjonen"
 ],
 "Close": [
  null,
  "Lukk"
 ],
 "Cockpit could not contact the given host.": [
  null,
  "Cockpit kunne ikke kontakte den angitte verten."
 ],
 "Cockpit is not compatible with the software on the system.": [
  null,
  "Cockpit er ikke kompatibel med programvaren på systemet."
 ],
 "Cockpit is not installed on the system.": [
  null,
  "Cockpit er ikke installert på systemet."
 ],
 "Connecting to SETroubleshoot daemon...": [
  null,
  "Kobler til SETroubleshoot daemon ..."
 ],
 "Connection has timed out.": [
  null,
  "Tidsavbrudd for tilkoblingen."
 ],
 "Copy to clipboard": [
  null,
  "Kopier til utklippstavle"
 ],
 "Create new task file with this content.": [
  null,
  "Opprett ny oppgavefil med dette innholdet."
 ],
 "Dismiss": [
  null,
  "Forkast"
 ],
 "Enforcing": [
  null,
  ""
 ],
 "Error message": [
  null,
  "Feilmelding"
 ],
 "Error running semanage to discover system modifications": [
  null,
  "Feil ved kjøring av semanage for å oppdage systemendringer"
 ],
 "Error while deleting alert: $0": [
  null,
  "Feil under sletting av varsel: $0"
 ],
 "Error while setting SELinux mode: '$0'": [
  null,
  "Feil under innstilling av SELinux-modus: '$0'"
 ],
 "Failed to delete alert: $0": [
  null,
  "Kunne ikke slette varselet: $0"
 ],
 "Host key is incorrect": [
  null,
  "Vertsnøkkelen er feil"
 ],
 "Install setroubleshoot-server to troubleshoot SELinux events.": [
  null,
  "Installer setroubleshoot-server for å feilsøke SELinux-hendelser."
 ],
 "Internal error": [
  null,
  "Intern feil"
 ],
 "Loading system modifications...": [
  null,
  "Laster inn systemendringer ..."
 ],
 "Login failed": [
  null,
  "Innlogging feilet"
 ],
 "No SELinux alerts.": [
  null,
  "Ingen SELinux-varsler."
 ],
 "No system modifications": [
  null,
  "Ingen systemendringer"
 ],
 "Not connected": [
  null,
  "Ikke tilkoblet"
 ],
 "Not permitted to perform this action.": [
  null,
  "Ikke tillatt å utføre denne handlingen."
 ],
 "Occurances": [
  null,
  "Forekomster"
 ],
 "Occurred $0": [
  null,
  "Forekom $0"
 ],
 "Occurred between $0 and $1": [
  null,
  "Forekom mellom $0 og $1"
 ],
 "Permissive": [
  null,
  ""
 ],
 "SELinux": [
  null,
  "SELinux"
 ],
 "SELinux access control errors": [
  null,
  "SELinux tilgangskontroll feil"
 ],
 "SELinux is disabled on the system": [
  null,
  "SELinux er deaktivert på systemet"
 ],
 "SELinux is disabled on the system.": [
  null,
  "SELinux er deaktivert på systemet."
 ],
 "SELinux policy": [
  null,
  "SELinux-policy"
 ],
 "SELinux system status is unknown.": [
  null,
  "SELinux-systemstatus er ukjent."
 ],
 "SELinux troubleshoot": [
  null,
  "Feilsøking av SELinux"
 ],
 "Server has closed the connection.": [
  null,
  "Serveren har lukket forbindelsen."
 ],
 "Setting deviates from the configured state and will revert on the next boot.": [
  null,
  "Innstillingen avviker fra den konfigurerte tilstanden og vil tilbakestilles ved neste oppstart."
 ],
 "Shell script": [
  null,
  "Shell-skript"
 ],
 "Solution applied successfully": [
  null,
  "Løsningen ble brukt"
 ],
 "Solution failed": [
  null,
  "Løsningen feilet"
 ],
 "Solutions": [
  null,
  "Løsninger"
 ],
 "System modifications": [
  null,
  "Systemendringer"
 ],
 "The configured state is unknown, it might change on the next boot.": [
  null,
  "Den konfigurerte tilstanden er ukjent, den kan endres ved neste oppstart."
 ],
 "The logged in user is not permitted to view system modifications": [
  null,
  "Den påloggede brukeren har ikke lov til å se systemendringer"
 ],
 "The server refused to authenticate using any supported methods.": [
  null,
  "Serveren nektet å godkjenne ved hjelp av de støttede metodene."
 ],
 "Too much data": [
  null,
  "For mye data"
 ],
 "Unable to apply this solution automatically": [
  null,
  "Kan ikke bruke denne løsningen automatisk"
 ],
 "Unable to get alert details.": [
  null,
  "Kan ikke få varslingsdetaljer."
 ],
 "Unable to get alert: $0": [
  null,
  "Kan ikke bli varslet: $0"
 ],
 "Unable to run fix: %0": [
  null,
  "Kan ikke kjøre fix:%0"
 ],
 "Unable to start setroubleshootd": [
  null,
  "Kan ikke starte setroubleshootd"
 ],
 "Untrusted host": [
  null,
  ""
 ],
 "View automation script": [
  null,
  "Vis automatiseringsskript"
 ],
 "Waiting for details...": [
  null,
  "Venter på detaljer..."
 ],
 "Your session has been terminated.": [
  null,
  "Økten din er avsluttet."
 ],
 "Your session has expired. Please log in again.": [
  null,
  "Økten din har utløpt. Vennligst logg inn igjen."
 ],
 "avc": [
  null,
  "avc"
 ],
 "semanage": [
  null,
  "semanage"
 ],
 "setroubleshoot": [
  null,
  "setroubleshoot"
 ],
 "solution": [
  null,
  "løsning"
 ],
 "solution details": [
  null,
  "løsningsdetaljer"
 ]
});
