cockpit.locale({
 "": {'plural-forms':function(n) {
var nplurals, plural;
nplurals=2; plural=n != 1;
return plural;
},
  "language": "nb_NO",
  "x-generator": "Weblate 4.5.1"
 },
 "$0 exited with code $1": [
  null,
  "$0 avsluttet med koden $1"
 ],
 "$0 failed": [
  null,
  "$0 feilet"
 ],
 "$0 killed with signal $1": [
  null,
  "$0 drept med signal $1"
 ],
 "Cancel": [
  null,
  "Avbryt"
 ],
 "Cannot forward login credentials": [
  null,
  "Kan ikke videresende påloggingsinformasjonen"
 ],
 "Change performance profile": [
  null,
  "Endre ytelsesprofil"
 ],
 "Change profile": [
  null,
  "Endre profil"
 ],
 "Cockpit could not contact the given host.": [
  null,
  "Cockpit kunne ikke kontakte den angitte verten."
 ],
 "Cockpit is not compatible with the software on the system.": [
  null,
  "Cockpit er ikke kompatibel med programvaren på systemet."
 ],
 "Cockpit is not installed on the system.": [
  null,
  "Cockpit er ikke installert på systemet."
 ],
 "Communication with tuned has failed": [
  null,
  "Kommunikasjonen med tuned feilet"
 ],
 "Connection has timed out.": [
  null,
  "Tidsavbrudd for tilkoblingen."
 ],
 "Disable tuned": [
  null,
  "Deaktiver tuned"
 ],
 "Failed to disable tuned": [
  null,
  "Kunne ikke deaktivere tuned"
 ],
 "Failed to disable tuned profile": [
  null,
  "Kunne ikke deaktivere tuned profil"
 ],
 "Failed to enable tuned": [
  null,
  "Kunne ikke aktivere tuned"
 ],
 "Failed to switch profile": [
  null,
  "Kunne ikke bytte profil"
 ],
 "Host key is incorrect": [
  null,
  "Vertsnøkkelen er feil"
 ],
 "Internal error": [
  null,
  "Intern feil"
 ],
 "Learn more": [
  null,
  "Lær mer"
 ],
 "Login failed": [
  null,
  "Innlogging feilet"
 ],
 "None": [
  null,
  "Ingen"
 ],
 "Not permitted to perform this action.": [
  null,
  "Ikke tillatt å utføre denne handlingen."
 ],
 "Ok": [
  null,
  "Ok"
 ],
 "Server has closed the connection.": [
  null,
  "Serveren har lukket forbindelsen."
 ],
 "The server refused to authenticate using any supported methods.": [
  null,
  "Serveren nektet å godkjenne ved hjelp av de støttede metodene."
 ],
 "This system is using a custom profile": [
  null,
  "Dette systemet bruker en tilpasset profil"
 ],
 "This system is using the recommended profile": [
  null,
  "Dette systemet bruker den anbefalte profilen"
 ],
 "Too much data": [
  null,
  "For mye data"
 ],
 "Tuned has failed to start": [
  null,
  "Tuned kunne ikke starte"
 ],
 "Tuned is a service that monitors your system and optimizes the performance under certain workloads. The core of Tuned are profiles, which tune your system for different use cases.": [
  null,
  "Tuned er en tjeneste som overvåker systemet ditt og optimaliserer ytelsen under visse arbeidsbelastninger. Kjernen i Tuned er profiler som justerer systemet ditt for forskjellige brukstilfeller."
 ],
 "Tuned is not available": [
  null,
  "Tuned er ikke tilgjengelig"
 ],
 "Tuned is not running": [
  null,
  "Tuned kjører ikke"
 ],
 "Tuned is off": [
  null,
  "Tuned er av"
 ],
 "Untrusted host": [
  null,
  ""
 ],
 "Your session has been terminated.": [
  null,
  "Økten din er avsluttet."
 ],
 "Your session has expired. Please log in again.": [
  null,
  "Økten din har utløpt. Vennligst logg inn igjen."
 ],
 "active": [
  null,
  "aktiv"
 ],
 "none": [
  null,
  "ingen"
 ],
 "recommended": [
  null,
  "anbefalt"
 ]
});
