cockpit.locale({
 "": {'plural-forms':function(n) {
var nplurals, plural;
nplurals=2; plural=n != 1;
return plural;
},
  "language": "ca",
  "x-generator": "Weblate 4.0.3"
 },
 "$0 active zone": [
  null,
  "$0 zona activa"
 ],
 "$0 active zones": [
  null,
  "$0 zones actives"
 ],
 "$0 day": [
  "$0 days",
  "$0 dia",
  "$0 dies"
 ],
 "$0 exited with code $1": [
  null,
  "$0 va sortir amb el codi $1"
 ],
 "$0 failed": [
  null,
  "$0 ha fallat"
 ],
 "$0 hour": [
  "$0 hours",
  "$0 hora",
  "$0 hores"
 ],
 "$0 killed with signal $1": [
  null,
  "$0 es va matar amb el senyal $1"
 ],
 "$0 minute": [
  "$0 minutes",
  "$0 minut",
  "$0 minuts"
 ],
 "$0 month": [
  "$0 months",
  "$0 mes",
  "$0 mesos"
 ],
 "$0 week": [
  "$0 weeks",
  "$0 setmana",
  "$0 setmanes"
 ],
 "$0 year": [
  "$0 years",
  "$0 any",
  "$0 anys"
 ],
 "$0 zone": [
  null,
  ""
 ],
 "(Optional)": [
  null,
  ""
 ],
 "1 day": [
  null,
  "1 dia"
 ],
 "1 hour": [
  null,
  "1 hora"
 ],
 "1 week": [
  null,
  "1 setmana"
 ],
 "5 minutes": [
  null,
  "5 minuts"
 ],
 "6 hours": [
  null,
  "6 hores"
 ],
 "802.3ad": [
  null,
  "802.3ad"
 ],
 "802.3ad LACP": [
  null,
  "802.3ad LACP"
 ],
 "A network bond combines multiple network interfaces into one logical interface with higher throughput or redundancy.": [
  null,
  ""
 ],
 "ARP": [
  null,
  "ARP"
 ],
 "ARP monitoring": [
  null,
  "Monitoratge ARP"
 ],
 "ARP ping": [
  null,
  "Ping ARP"
 ],
 "Active": [
  null,
  "Activa"
 ],
 "Active backup": [
  null,
  "Còpia de seguretat activa"
 ],
 "Adaptive load balancing": [
  null,
  "Balanceig de càrrega adaptativa"
 ],
 "Adaptive transmit load balancing": [
  null,
  "Balanceig de càrrega de transmissió adaptativa"
 ],
 "Add $0": [
  null,
  "Afegeix $0"
 ],
 "Add VLAN": [
  null,
  "Afegeix una VLAN"
 ],
 "Add a new zone": [
  null,
  "Afegeix una zona nova"
 ],
 "Add bond": [
  null,
  "Afegeix un enllaç"
 ],
 "Add bridge": [
  null,
  "Afegeix un pont"
 ],
 "Add ports": [
  null,
  "Afegeix ports"
 ],
 "Add ports to $0 zone": [
  null,
  ""
 ],
 "Add services": [
  null,
  "Afegeix serveis"
 ],
 "Add services to $0 zone": [
  null,
  ""
 ],
 "Add services to zone $0": [
  null,
  ""
 ],
 "Add team": [
  null,
  "Afegeix un equip"
 ],
 "Add zone": [
  null,
  "Afegeix una zona"
 ],
 "Adding <b>$0</b> will break the connection to the server, and will make the administration UI unavailable.": [
  null,
  ""
 ],
 "Adding custom ports will reload firewalld. A reload will result in the loss of any runtime-only configuration!": [
  null,
  ""
 ],
 "Additional DNS $val": [
  null,
  "DNS addicional $val"
 ],
 "Additional DNS search domains $val": [
  null,
  "Dominis de cerca DNS addicionals $val"
 ],
 "Additional address $val": [
  null,
  "Adreça addicional $val"
 ],
 "Address $val": [
  null,
  "Adreça $val"
 ],
 "Addresses": [
  null,
  "Adreces"
 ],
 "All logs": [
  null,
  ""
 ],
 "Allowed addresses": [
  null,
  ""
 ],
 "Apply": [
  null,
  "Aplica"
 ],
 "Authenticating": [
  null,
  "S'està autenticant"
 ],
 "Automatic": [
  null,
  "Automàtic"
 ],
 "Automatic (DHCP only)": [
  null,
  "Automàtica, tan sols DHCP"
 ],
 "Automatic (DHCP)": [
  null,
  "Automàtica (DHCP)"
 ],
 "Balancer": [
  null,
  "Eina de balanceig"
 ],
 "Bond": [
  null,
  "Enllaç"
 ],
 "Bridge": [
  null,
  "Pont"
 ],
 "Bridge port": [
  null,
  "Port del pont"
 ],
 "Bridge port settings": [
  null,
  "Ajusts del port del pont"
 ],
 "Bridge settings": [
  null,
  "Ajusts del pont"
 ],
 "Broadcast": [
  null,
  "Difusió"
 ],
 "Broken configuration": [
  null,
  "Configuració trencada"
 ],
 "Cancel": [
  null,
  "Cancel·la"
 ],
 "Cannot forward login credentials": [
  null,
  ""
 ],
 "Carrier": [
  null,
  "Portadora"
 ],
 "Change the settings": [
  null,
  "Canvia els ajusts"
 ],
 "Changing the settings will break the connection to the server, and will make the administration UI unavailable.": [
  null,
  ""
 ],
 "Checking IP": [
  null,
  "S'està comprovant la IP"
 ],
 "Close": [
  null,
  "Tanca"
 ],
 "Cockpit could not contact the given host.": [
  null,
  "Cockpit no ha pogut contactar amb l'amfitrió indicat."
 ],
 "Cockpit is not compatible with the software on the system.": [
  null,
  "Cockpit no és compatible amb el programari del sistema."
 ],
 "Cockpit is not installed on the system.": [
  null,
  "Cockpit no està instal·lat al sistema."
 ],
 "Comma-separated ports, ranges, and aliases are accepted": [
  null,
  ""
 ],
 "Configuring": [
  null,
  "S'està configurant"
 ],
 "Configuring IP": [
  null,
  "S'està configurant la IP"
 ],
 "Confirm removal of $0": [
  null,
  ""
 ],
 "Connect automatically": [
  null,
  "Connecta automàticament"
 ],
 "Connection has timed out.": [
  null,
  "La connexió ha excedit el temps."
 ],
 "Connection will be lost": [
  null,
  "Es perdrà la connexió"
 ],
 "Create it": [
  null,
  "Crea-ho"
 ],
 "Creating this VLAN will break the connection to the server, and will make the administration UI unavailable.": [
  null,
  ""
 ],
 "Creating this bond will break the connection to the server, and will make the administration UI unavailable.": [
  null,
  ""
 ],
 "Creating this bridge will break the connection to the server, and will make the administration UI unavailable.": [
  null,
  ""
 ],
 "Creating this team will break the connection to the server, and will make the administration UI unavailable.": [
  null,
  ""
 ],
 "Custom ports": [
  null,
  ""
 ],
 "Custom zones": [
  null,
  ""
 ],
 "DNS": [
  null,
  "DNS"
 ],
 "DNS $val": [
  null,
  "DNS $val"
 ],
 "DNS search domains": [
  null,
  "Dominis de cerca DNS"
 ],
 "DNS search domains $val": [
  null,
  "Dominis de cerca DNS $val"
 ],
 "Deactivating": [
  null,
  "S'està desactivant"
 ],
 "Delete": [
  null,
  "Suprimeix"
 ],
 "Delete $0": [
  null,
  "Suprimeix $0"
 ],
 "Deleting <b>$0</b> will break the connection to the server, and will make the administration UI unavailable.": [
  null,
  ""
 ],
 "Description": [
  null,
  "Descripció"
 ],
 "Disable the firewall": [
  null,
  ""
 ],
 "Disabled": [
  null,
  "Inhabilitat"
 ],
 "Edit rules and zones": [
  null,
  ""
 ],
 "Enable service": [
  null,
  ""
 ],
 "Enable the firewall": [
  null,
  ""
 ],
 "Entire subnet": [
  null,
  "Tota la subxarxa"
 ],
 "Ethernet MAC": [
  null,
  "MAC d'ethernet"
 ],
 "Ethernet MTU": [
  null,
  "MTU d'ethernet"
 ],
 "Ethtool": [
  null,
  "Ethtool"
 ],
 "Example: 22,ssh,8080,5900-5910": [
  null,
  ""
 ],
 "Example: 88,2019,nfs,rsync": [
  null,
  ""
 ],
 "Failed": [
  null,
  "Ha fallat"
 ],
 "Failed to add port": [
  null,
  ""
 ],
 "Failed to add service": [
  null,
  ""
 ],
 "Failed to add zone": [
  null,
  ""
 ],
 "Filter services": [
  null,
  "Filtra els serveis"
 ],
 "Firewall": [
  null,
  "Tallafoc"
 ],
 "Firewall is not available": [
  null,
  "El tallafoc no està disponible"
 ],
 "Forward delay $forward_delay": [
  null,
  "Retard del reenviament $forward_delay"
 ],
 "General": [
  null,
  "General"
 ],
 "Go to now": [
  null,
  "Vés a ara"
 ],
 "Group": [
  null,
  ""
 ],
 "Hair pin mode": [
  null,
  "Mode hairpin"
 ],
 "Hairpin mode": [
  null,
  "Mode hairpin"
 ],
 "Hello time $hello_time": [
  null,
  "Hello time $hello_time"
 ],
 "Host key is incorrect": [
  null,
  "La clau d'amfitrió és incorrecta"
 ],
 "ID": [
  null,
  ""
 ],
 "IP address": [
  null,
  "Adreça IP"
 ],
 "IP address with routing prefix. Separate multiple values with a comma. Example: 192.0.2.0/24, 2001:db8::/32": [
  null,
  ""
 ],
 "IPv4": [
  null,
  "IPv4"
 ],
 "IPv4 settings": [
  null,
  "Ajusts d'IPv4"
 ],
 "IPv6": [
  null,
  "IPv6"
 ],
 "IPv6 settings": [
  null,
  "Ajusts d'IPv6"
 ],
 "Ignore": [
  null,
  "Ignora"
 ],
 "Inactive": [
  null,
  "Inactiu"
 ],
 "Included services": [
  null,
  ""
 ],
 "Interfaces": [
  null,
  "Interfícies"
 ],
 "Internal error": [
  null,
  "Error intern"
 ],
 "Invalid address $0": [
  null,
  "Adreça no vàlida $0"
 ],
 "Invalid metric $0": [
  null,
  "Mètrica no vàlida $0"
 ],
 "Invalid port number": [
  null,
  ""
 ],
 "Invalid prefix $0": [
  null,
  "Prefix no vàlid $0"
 ],
 "Invalid prefix or netmask $0": [
  null,
  "Prefix o màscara de xarxa no vàlid $0"
 ],
 "Invalid range": [
  null,
  ""
 ],
 "Keep connection": [
  null,
  "Mantén la connexió"
 ],
 "LACP key": [
  null,
  "Clau LACP"
 ],
 "Link down delay": [
  null,
  "Retard del baixament de l'enllaç"
 ],
 "Link local": [
  null,
  "Enllaç local"
 ],
 "Link monitoring": [
  null,
  "Monitoratge de l'enllaç"
 ],
 "Link up delay": [
  null,
  "Retard de l'aixecament de l'enllaç"
 ],
 "Link watch": [
  null,
  "Observació de l'enllaç"
 ],
 "Load balancing": [
  null,
  "Balanceig de càrrega"
 ],
 "Login failed": [
  null,
  "Ha fallat l'inici de sessió"
 ],
 "MAC": [
  null,
  "MAC"
 ],
 "MII (recommended)": [
  null,
  "MII (recomanat)"
 ],
 "MTU": [
  null,
  "MTU"
 ],
 "MTU must be a positive number": [
  null,
  "El valor de la MTU ha de ser un nombre positiu"
 ],
 "Managing firewall": [
  null,
  ""
 ],
 "Manual": [
  null,
  "Manual"
 ],
 "Maximum message age $max_age": [
  null,
  "Envelliment màxim del missatge $max_age"
 ],
 "Mode": [
  null,
  "Mode"
 ],
 "Monitoring interval": [
  null,
  "Interval del monitoratge"
 ],
 "Monitoring targets": [
  null,
  "Objectius del monitoratge"
 ],
 "NSNA ping": [
  null,
  "Ping NSNA"
 ],
 "Name": [
  null,
  "Nom"
 ],
 "Network devices and graphs require NetworkManager": [
  null,
  ""
 ],
 "Networking": [
  null,
  "Xarxa"
 ],
 "No": [
  null,
  "No"
 ],
 "No carrier": [
  null,
  "Sense portadora"
 ],
 "No description available": [
  null,
  ""
 ],
 "None": [
  null,
  "Cap"
 ],
 "Not authorized to disable the firewall": [
  null,
  ""
 ],
 "Not authorized to enable the firewall": [
  null,
  ""
 ],
 "Not authorized to remove zone $0": [
  null,
  ""
 ],
 "Not available": [
  null,
  "No disponible"
 ],
 "Not permitted to perform this action.": [
  null,
  "No es permet realitzar aquesta acció."
 ],
 "Parent": [
  null,
  "Pare"
 ],
 "Parent $parent": [
  null,
  "Pare $parent"
 ],
 "Part of ": [
  null,
  "Part de"
 ],
 "Passive": [
  null,
  "Passiu"
 ],
 "Path cost": [
  null,
  "Cost del camí"
 ],
 "Path cost $path_cost": [
  null,
  "Cost del camí $path_cost"
 ],
 "Permanent": [
  null,
  "Permanent"
 ],
 "Ping interval": [
  null,
  "Interval de ping"
 ],
 "Ping target": [
  null,
  "Objectiu de ping"
 ],
 "Please install the $0 package": [
  null,
  ""
 ],
 "Port number and type do not match": [
  null,
  ""
 ],
 "Ports": [
  null,
  "Ports"
 ],
 "Prefix length": [
  null,
  "Longitud del prefix"
 ],
 "Prefix length or netmask": [
  null,
  "Longitud del prefix o Màscara de xarxa"
 ],
 "Preparing": [
  null,
  "S'està preparant"
 ],
 "Preserve": [
  null,
  "Preserva"
 ],
 "Primary": [
  null,
  "Principal"
 ],
 "Priority": [
  null,
  "Prioritat"
 ],
 "Priority $priority": [
  null,
  "Prioritat $priority"
 ],
 "Random": [
  null,
  "Aleatòria"
 ],
 "Range": [
  null,
  ""
 ],
 "Range must be strictly ordered": [
  null,
  ""
 ],
 "Reboot": [
  null,
  "Rearrencada"
 ],
 "Receiving": [
  null,
  "Recepció"
 ],
 "Remove $0": [
  null,
  "Suprimeix $0"
 ],
 "Remove $0 service from $1 zone": [
  null,
  ""
 ],
 "Remove service $0": [
  null,
  ""
 ],
 "Remove zone $0": [
  null,
  ""
 ],
 "Removing <b>$0</b> will break the connection to the server, and will make the administration UI unavailable.": [
  null,
  ""
 ],
 "Removing the cockpit service might result in the web console becoming unreachable. Make sure that this zone does not apply to your current web console connection.": [
  null,
  ""
 ],
 "Removing the zone will remove all services within it.": [
  null,
  ""
 ],
 "Restoring connection": [
  null,
  "S'està restaurant la connexió"
 ],
 "Round robin": [
  null,
  "Round robin"
 ],
 "Routes": [
  null,
  "Encaminaments"
 ],
 "Runner": [
  null,
  "Runner"
 ],
 "STP forward delay": [
  null,
  "Retard del reenviament STP"
 ],
 "STP hello time": [
  null,
  "STP hello time"
 ],
 "STP maximum message age": [
  null,
  "Envelliment màxim del missatge STP"
 ],
 "STP priority": [
  null,
  "Prioritat STP"
 ],
 "Sending": [
  null,
  "Enviament"
 ],
 "Server has closed the connection.": [
  null,
  "El servidor ha tancat la connexió."
 ],
 "Service": [
  null,
  "Servei"
 ],
 "Services": [
  null,
  "Serveis"
 ],
 "Set to": [
  null,
  "Estableix a"
 ],
 "Shared": [
  null,
  "Compartida"
 ],
 "Sorted from least to most trusted": [
  null,
  ""
 ],
 "Spanning tree protocol": [
  null,
  "STP (Spanning tree protocol)"
 ],
 "Spanning tree protocol (STP)": [
  null,
  "STP (Spanning tree protocol)"
 ],
 "Stable": [
  null,
  "Estable"
 ],
 "Start service": [
  null,
  ""
 ],
 "Status": [
  null,
  "Estat"
 ],
 "Sticky": [
  null,
  ""
 ],
 "Switch off $0": [
  null,
  "Apaga $0"
 ],
 "Switch on $0": [
  null,
  "Engega $0"
 ],
 "Switching off <b>$0</b>  will break the connection to the server, and will make the administration UI unavailable.": [
  null,
  ""
 ],
 "Switching off <b>$0</b> will break the connection to the server, and will make the administration UI unavailable.": [
  null,
  ""
 ],
 "Switching on <b>$0</b> will break the connection to the server, and will make the administration UI unavailable.": [
  null,
  ""
 ],
 "TCP": [
  null,
  "TCP"
 ],
 "Team": [
  null,
  "Equip"
 ],
 "Team port": [
  null,
  "Port de l'equip"
 ],
 "Team port settings": [
  null,
  "Ajusts del port de l'equip"
 ],
 "Team settings": [
  null,
  "Ajusts de l'equip"
 ],
 "Testing connection": [
  null,
  ""
 ],
 "The cockpit service is automatically included": [
  null,
  ""
 ],
 "The server refused to authenticate using any supported methods.": [
  null,
  "El servidor ha refusat l'autenticació mitjançant qualsevol dels mètodes compatibles."
 ],
 "There are no active services in this zone": [
  null,
  ""
 ],
 "This device cannot be managed here.": [
  null,
  "Aquest dispositiu no es pot gestionar aquí."
 ],
 "This zone contains the cockpit service. Make sure that this zone does not apply to your current web console connection.": [
  null,
  ""
 ],
 "Too much data": [
  null,
  "Hi ha massa dades"
 ],
 "Trust level": [
  null,
  ""
 ],
 "UDP": [
  null,
  "UDP"
 ],
 "Unexpected error": [
  null,
  "Error inesperat"
 ],
 "Unknown": [
  null,
  "Desconegut"
 ],
 "Unknown \"$0\"": [
  null,
  "\"$0\" desconegut"
 ],
 "Unknown configuration": [
  null,
  "Configuració desconeguda"
 ],
 "Unknown service name": [
  null,
  ""
 ],
 "Unmanaged interfaces": [
  null,
  "Interfícies sense gestionar"
 ],
 "Untrusted host": [
  null,
  "Amfitrió no fiable"
 ],
 "VLAN": [
  null,
  "VLAN"
 ],
 "VLAN settings": [
  null,
  "Ajusts de la VLAN"
 ],
 "Waiting": [
  null,
  "S'està esperant"
 ],
 "XOR": [
  null,
  "XOR"
 ],
 "Yes": [
  null,
  "Sí"
 ],
 "You are not authorized to modify the firewall.": [
  null,
  ""
 ],
 "Your session has been terminated.": [
  null,
  "La vostra sessió ha estat finalitzada."
 ],
 "Your session has expired. Please log in again.": [
  null,
  "La vostra sessió ha vençut. Si us plau, torneu a iniciar la sessió."
 ],
 "[$0 bytes of binary data]": [
  null,
  "[$0 bytes de dades binàries]"
 ],
 "[binary data]": [
  null,
  "[dades binàries]"
 ],
 "[no data]": [
  null,
  "[sense dades]"
 ],
 "bond": [
  null,
  ""
 ],
 "bridge": [
  null,
  "pont"
 ],
 "edit": [
  null,
  ""
 ],
 "firewall": [
  null,
  ""
 ],
 "interface": [
  null,
  ""
 ],
 "ipv4": [
  null,
  ""
 ],
 "ipv6": [
  null,
  ""
 ],
 "mac": [
  null,
  ""
 ],
 "network": [
  null,
  "xarxa"
 ],
 "port": [
  null,
  ""
 ],
 "show less": [
  null,
  "mostra menys"
 ],
 "show more": [
  null,
  "mostra més"
 ],
 "tcp": [
  null,
  ""
 ],
 "team": [
  null,
  ""
 ],
 "udp": [
  null,
  "udp"
 ],
 "vlan": [
  null,
  ""
 ],
 "zone": [
  null,
  ""
 ]
});
