cockpit.locale({
 "": {'plural-forms':function(n) {
var nplurals, plural;
nplurals=2; plural=n != 1;
return plural;
},
  "language": "nb_NO",
  "x-generator": "Weblate 4.5.1"
 },
 "$0 exited with code $1": [
  null,
  "$0 avsluttet med koden $1"
 ],
 "$0 failed": [
  null,
  "$0 feilet"
 ],
 "$0 killed with signal $1": [
  null,
  "$0 drept med signal $1"
 ],
 "Cancel": [
  null,
  "Avbryt"
 ],
 "Cannot forward login credentials": [
  null,
  "Kan ikke videresende påloggingsinformasjonen"
 ],
 "Close": [
  null,
  "Lukk"
 ],
 "Cockpit could not contact the given host.": [
  null,
  "Cockpit kunne ikke kontakte den angitte verten."
 ],
 "Cockpit is not compatible with the software on the system.": [
  null,
  "Cockpit er ikke kompatibel med programvaren på systemet."
 ],
 "Cockpit is not installed on the system.": [
  null,
  "Cockpit er ikke installert på systemet."
 ],
 "Connection has timed out.": [
  null,
  "Tidsavbrudd for tilkoblingen."
 ],
 "Create diagnostic report                    ": [
  null,
  "Lag diagnoserapport                    "
 ],
 "Create report": [
  null,
  "Opprett rapport"
 ],
 "Diagnostic Reports": [
  null,
  "Diagnose rapporter"
 ],
 "Diagnostic reports": [
  null,
  "Diagnose rapporter"
 ],
 "Done!": [
  null,
  "Ferdig!"
 ],
 "Download report": [
  null,
  "Last ned rapport"
 ],
 "Generating report": [
  null,
  "Genererer rapport"
 ],
 "Host key is incorrect": [
  null,
  "Vertsnøkkelen er feil"
 ],
 "Internal error": [
  null,
  "Intern feil"
 ],
 "Login failed": [
  null,
  "Innlogging feilet"
 ],
 "No archive has been created.": [
  null,
  "Ingen arkiv er opprettet."
 ],
 "Not permitted to perform this action.": [
  null,
  "Ikke tillatt å utføre denne handlingen."
 ],
 "Server has closed the connection.": [
  null,
  "Serveren har lukket forbindelsen."
 ],
 "The collected information will be stored locally on the system.": [
  null,
  "Den innsamlede informasjonen lagres lokalt på systemet."
 ],
 "The generated archive contains data considered sensitive and its content should be reviewed by the originating organization before being passed to any third party.": [
  null,
  "Det genererte arkivet inneholder data som anses som sensitive, og innholdet bør gjennomgås av den opprinnelige organisasjonen før det sendes til tredjepart."
 ],
 "The server refused to authenticate using any supported methods.": [
  null,
  "Serveren nektet å godkjenne ved hjelp av de støttede metodene."
 ],
 "This tool will collect system configuration and diagnostic information from this system for use with diagnosing problems with the system.": [
  null,
  "Dette verktøyet vil samle systemkonfigurasjon og diagnose-informasjon fra dette systemet for bruk ved diagnostisering av problemer med systemet."
 ],
 "Too much data": [
  null,
  "For mye data"
 ],
 "Untrusted host": [
  null,
  ""
 ],
 "You need to switch to \"Administrative access\" in order to create reports.": [
  null,
  "Du må bytte til \"Administrativ tilgang\" for å opprette rapporter."
 ],
 "Your session has been terminated.": [
  null,
  "Økten din er avsluttet."
 ],
 "Your session has expired. Please log in again.": [
  null,
  "Økten din har utløpt. Vennligst logg inn igjen."
 ],
 "sos": [
  null,
  "sos"
 ]
});
