cockpit.locale({
 "": {'plural-forms':function(n) {
var nplurals, plural;
nplurals=2; plural=n != 1;
return plural;
},
  "language": "nb_NO",
  "x-generator": "Weblate 4.5.1"
 },
 "$0 day": [
  "$0 days",
  "$0 dag",
  "$0 dager"
 ],
 "$0 disk is missing": [
  "$0 disks are missing",
  "$0 disk mangler",
  "$0 disker mangler"
 ],
 "$0 exited with code $1": [
  null,
  "$0 avsluttet med koden $1"
 ],
 "$0 failed": [
  null,
  "$0 feilet"
 ],
 "$0 hour": [
  "$0 hours",
  "$0 time",
  "$0 timer"
 ],
 "$0 killed with signal $1": [
  null,
  "$0 drept med signal $1"
 ],
 "$0 minute": [
  "$0 minutes",
  "$0 minutt",
  "$0 minutter"
 ],
 "$0 month": [
  "$0 months",
  "$0 måned",
  "$0 måneder"
 ],
 "$0 week": [
  "$0 weeks",
  "$0 uke",
  "$0 uker"
 ],
 "$0 year": [
  "$0 years",
  "$0 år",
  "$0 år"
 ],
 "1 day": [
  null,
  "1 dag"
 ],
 "1 hour": [
  null,
  "1 time"
 ],
 "1 week": [
  null,
  "1 uke"
 ],
 "5 minutes": [
  null,
  "5 minutter"
 ],
 "6 hours": [
  null,
  "6 timer"
 ],
 "Accounts": [
  null,
  "Kontoer"
 ],
 "All logs": [
  null,
  "Alle logger"
 ],
 "Cancel": [
  null,
  "Avbryt"
 ],
 "Cannot forward login credentials": [
  null,
  "Kan ikke videresende påloggingsinformasjonen"
 ],
 "Cockpit could not contact the given host.": [
  null,
  "Cockpit kunne ikke kontakte den angitte verten."
 ],
 "Cockpit is not compatible with the software on the system.": [
  null,
  "Cockpit er ikke kompatibel med programvaren på systemet."
 ],
 "Cockpit is not installed on the system.": [
  null,
  "Cockpit er ikke installert på systemet."
 ],
 "Connection has timed out.": [
  null,
  "Tidsavbrudd for tilkoblingen."
 ],
 "Control": [
  null,
  "Kontroll"
 ],
 "Create": [
  null,
  "Opprett"
 ],
 "Development": [
  null,
  "Utvikling"
 ],
 "Empty": [
  null,
  "Tom"
 ],
 "Error": [
  null,
  "Feil"
 ],
 "Go to now": [
  null,
  "Gå til nå"
 ],
 "Host key is incorrect": [
  null,
  "Vertsnøkkelen er feil"
 ],
 "Internal error": [
  null,
  "Intern feil"
 ],
 "Learn more": [
  null,
  "Lær mer"
 ],
 "Login failed": [
  null,
  "Innlogging feilet"
 ],
 "Memory": [
  null,
  "Minne"
 ],
 "No such file or directory": [
  null,
  "Ingen slik fil eller katalog"
 ],
 "Not permitted to perform this action.": [
  null,
  "Ikke tillatt å utføre denne handlingen."
 ],
 "Not ready": [
  null,
  "Ikke klar"
 ],
 "Ok": [
  null,
  "Ok"
 ],
 "Path to file": [
  null,
  "Sti til fil"
 ],
 "Ready": [
  null,
  "Klar"
 ],
 "Reboot": [
  null,
  "Omstart"
 ],
 "Server has closed the connection.": [
  null,
  "Serveren har lukket forbindelsen."
 ],
 "The server refused to authenticate using any supported methods.": [
  null,
  "Serveren nektet å godkjenne ved hjelp av de støttede metodene."
 ],
 "Too much data": [
  null,
  "For mye data"
 ],
 "Unavailable": [
  null,
  "Utilgjengelig"
 ],
 "Untrusted host": [
  null,
  ""
 ],
 "User": [
  null,
  "Bruker"
 ],
 "Your session has been terminated.": [
  null,
  "Økten din er avsluttet."
 ],
 "Your session has expired. Please log in again.": [
  null,
  "Økten din har utløpt. Vennligst logg inn igjen."
 ],
 "[$0 bytes of binary data]": [
  null,
  "[$0 bytes med binære data]"
 ],
 "[binary data]": [
  null,
  "[binære data]"
 ],
 "[no data]": [
  null,
  "[ingen data]"
 ],
 "disk-non-rotational\u0004$0 disk is missing": [
  "$0 disks are missing",
  "$0 disk mangler",
  "$0 disker mangler"
 ],
 "key\u0004Control": [
  null,
  "Kontroll"
 ],
 "verb\u0004Empty": [
  null,
  "Tom"
 ],
 "verb\u0004Ready": [
  null,
  "Klar"
 ]
});
