cockpit.locale({
 "": {'plural-forms':function(n) {
var nplurals, plural;
nplurals=2; plural=n != 1;
return plural;
},
  "language": "fi",
  "x-generator": "Weblate 4.5.1"
 },
 "$0 critical hit": [
  "$0 hits, including critical",
  "$0 kriittinen osuma",
  "$0 osumaa, sisältäen kriittisiä"
 ],
 "$0 exited with code $1": [
  null,
  "$0 poistui koodilla $1"
 ],
 "$0 failed": [
  null,
  "$0 epäonnistui"
 ],
 "$0 important hit": [
  "$0 hits, including important",
  "$0 tärkeä osuma",
  "$0 osumaa, mukaan lukien tärkeät"
 ],
 "$0 is not available from any repository.": [
  null,
  "$0 ei ole saatavilla mistään ohjelmistovarastosta."
 ],
 "$0 killed with signal $1": [
  null,
  "$0 tapettu signaalilla $1"
 ],
 "$0 low severity hit": [
  "$0 low severity hits",
  "$0 matala vakavuus -osuma",
  "$0 matala vakavuus -osumaa"
 ],
 "$0 moderate hit": [
  "$0 hits, including moderate",
  "$0 kohtalainen osuma",
  "$0 osumia, mukaan lukien kohtalaiset"
 ],
 "$0 service has failed": [
  "$0 services have failed",
  "$0 palvelu on epäonnistunut",
  "$0 palvelua on epäonnistunut"
 ],
 "$0 will be installed.": [
  null,
  "$0 asennetaan."
 ],
 "$0: crash at $1": [
  null,
  "$0: kaatuu $1:lla"
 ],
 "1 minute": [
  null,
  "1 minuutti"
 ],
 "10th": [
  null,
  "10."
 ],
 "11th": [
  null,
  "11."
 ],
 "12th": [
  null,
  "12."
 ],
 "13th": [
  null,
  "13."
 ],
 "14th": [
  null,
  "14."
 ],
 "15th": [
  null,
  "15."
 ],
 "16th": [
  null,
  "16."
 ],
 "17th": [
  null,
  "17."
 ],
 "18th": [
  null,
  "18."
 ],
 "19th": [
  null,
  "19."
 ],
 "1st": [
  null,
  "1."
 ],
 "20 minutes": [
  null,
  "20 minuuttia"
 ],
 "20th": [
  null,
  "20."
 ],
 "21th": [
  null,
  "21."
 ],
 "22th": [
  null,
  "22."
 ],
 "23th": [
  null,
  "23."
 ],
 "24th": [
  null,
  "24."
 ],
 "25th": [
  null,
  "25."
 ],
 "26th": [
  null,
  "26."
 ],
 "27th": [
  null,
  "27."
 ],
 "28th": [
  null,
  "28."
 ],
 "29th": [
  null,
  "29."
 ],
 "2nd": [
  null,
  "2."
 ],
 "30th": [
  null,
  "30."
 ],
 "31st": [
  null,
  "31."
 ],
 "3rd": [
  null,
  "3."
 ],
 "40 minutes": [
  null,
  "40 minuuttia"
 ],
 "4th": [
  null,
  "4."
 ],
 "5 minutes": [
  null,
  "5 minuuttia"
 ],
 "5th": [
  null,
  "5."
 ],
 "60 minutes": [
  null,
  "60 minuuttia"
 ],
 "6th": [
  null,
  "6."
 ],
 "7th": [
  null,
  "7."
 ],
 "8th": [
  null,
  "8."
 ],
 "9th": [
  null,
  "9."
 ],
 "Absent": [
  null,
  "Poissa"
 ],
 "Active since ": [
  null,
  "Aktiivinen lähtien "
 ],
 "Add": [
  null,
  "Lisää"
 ],
 "Additional actions": [
  null,
  "Ylimääräiset toimet"
 ],
 "Additional packages:": [
  null,
  "Ylimääräiset paketit:"
 ],
 "Administrative access": [
  null,
  "Hallinnollinen käyttöoikeus"
 ],
 "Administrator password": [
  null,
  "Ylläpidon salasana"
 ],
 "Advanced TCA": [
  null,
  "Edistynyt TCA"
 ],
 "After": [
  null,
  "Jälkeen"
 ],
 "After leaving the domain, only users with local credentials will be able to log into this machine. This may also affect other services as DNS resolution settings and the list of trusted CAs may change.": [
  null,
  "Kun olet poistunut toimialueesta, vain käyttäjät, joilla on paikalliset kirjautumistiedot, voivat kirjautua tähän koneeseen. Tämä voi vaikuttaa myös muihin palveluihin, kuten DNS-ratkaisimen asetukset, ja luotettujen varmentajien CA-luettelo voi muuttua."
 ],
 "After system boot": [
  null,
  "Järjestelmän käynnistyksen jälkeen"
 ],
 "Alert and above": [
  null,
  "Varoitus ja yli"
 ],
 "All": [
  null,
  "Kaikki"
 ],
 "All logs": [
  null,
  "Kaikki lokit"
 ],
 "All-in-one": [
  null,
  "Kaikki yhdessä"
 ],
 "Allow running (unmask)": [
  null,
  "Salli, että suoritetaan (paljastaa)"
 ],
 "Appearance": [
  null,
  "Ulkomuoto"
 ],
 "Asset tag": [
  null,
  "Sisältötunniste"
 ],
 "At specific time": [
  null,
  "Tiettynä aikana"
 ],
 "Authenticate": [
  null,
  "Tunnistaudu"
 ],
 "Authentication": [
  null,
  "Tunnistautuminen"
 ],
 "Automatic": [
  null,
  "Automaattinen"
 ],
 "Automatically starts": [
  null,
  "Käynnistyy automaattisesti"
 ],
 "Automatically using NTP": [
  null,
  "Käytetään automaattisesti NTP:tä"
 ],
 "Automatically using specific NTP servers": [
  null,
  "Käytetään automaattisesti tiettyjä NTP-palvelimia"
 ],
 "BIOS": [
  null,
  "BIOS"
 ],
 "BIOS date": [
  null,
  "BIOS-päiväys"
 ],
 "BIOS version": [
  null,
  "BIOS-versio"
 ],
 "Before": [
  null,
  "Ennen"
 ],
 "Binds to": [
  null,
  "Sitoo tähän"
 ],
 "Black": [
  null,
  "Musta"
 ],
 "Blade": [
  null,
  "Terä"
 ],
 "Blade enclosure": [
  null,
  "Teräkotelo"
 ],
 "Bound by": [
  null,
  "Sillä sidottu"
 ],
 "Bus expansion chassis": [
  null,
  "Väylän laajennusalusta"
 ],
 "CPU": [
  null,
  "Suoritin"
 ],
 "CPU security": [
  null,
  "Suorittimen turvallisuus"
 ],
 "CPU security toggles": [
  null,
  "Suorittimen turvallisuus vaihtuu"
 ],
 "Can not find any logs using the current combination of filters.": [
  null,
  "Lokeja ei löydy käyttämällä nykyistä suodatinten yhdistelmää."
 ],
 "Cancel": [
  null,
  "Peru"
 ],
 "Cannot be enabled": [
  null,
  "Ei voida ottaa käyttöön"
 ],
 "Cannot forward login credentials": [
  null,
  "Kirjautumistietoja ei voi välittää eteenpäin"
 ],
 "Cannot join a domain because realmd is not available on this system": [
  null,
  "Toimialueeseen ei voi liittyä, koska realmd ei ole käytettävissä tässä järjestelmässä"
 ],
 "Cannot schedule event in the past": [
  null,
  "Tapahtumaa ei voi aikatauluttaa menneisyyteen"
 ],
 "Change": [
  null,
  "Vaihda"
 ],
 "Change host name": [
  null,
  "Vaihda isäntänimi"
 ],
 "Change system time": [
  null,
  "Vaihda järjestelmän aika"
 ],
 "Checking installed software": [
  null,
  "Tarkistetaan asennettu ohjelmisto"
 ],
 "Class": [
  null,
  "Luokka"
 ],
 "Clear 'Failed to start'": [
  null,
  "Tyhjennä \"Aloitus epäonnistui\""
 ],
 "Clear all filters": [
  null,
  "Tyhjennä kaikki suodattimet"
 ],
 "Client software": [
  null,
  "Asiakasohjelmisto"
 ],
 "Close": [
  null,
  "Sulje"
 ],
 "Cockpit could not contact the given host.": [
  null,
  "Cockpit ei saanut yhteyttä isäntään."
 ],
 "Cockpit is not compatible with the software on the system.": [
  null,
  "Cockpit ei ole yhteensopiva järjestelmän ohjelmiston kanssa."
 ],
 "Cockpit is not installed on the system.": [
  null,
  "Cockpit ei ole asennettu järjestelmässä."
 ],
 "Command": [
  null,
  "Komento"
 ],
 "Compact PCI": [
  null,
  "Kompakti PCI"
 ],
 "Computer OU": [
  null,
  "Tietokone-OU"
 ],
 "Condition $0=$1 was not met": [
  null,
  "Ehto $0=$1 ei toteutunut"
 ],
 "Condition failed": [
  null,
  "Ehto epäonnistui"
 ],
 "Configuration": [
  null,
  "Kokoonpano"
 ],
 "Configuring system settings": [
  null,
  "Järjestelmäasetusten määrittäminen"
 ],
 "Conflicted by": [
  null,
  "Näiden kanssa ristiriitainen"
 ],
 "Conflicts": [
  null,
  "Ristiriidat"
 ],
 "Connection has timed out.": [
  null,
  "Yhteys aikakatkaistiin."
 ],
 "Consists of": [
  null,
  "Näistä koostuu"
 ],
 "Contacted domain": [
  null,
  "Toimialue, johon otettiin yhteyttä"
 ],
 "Convertible": [
  null,
  "Muunnettavissa"
 ],
 "Copy": [
  null,
  "Kopio"
 ],
 "Crash reporting": [
  null,
  "Kaatumisraportointi"
 ],
 "Create timer": [
  null,
  "Luo ajastin"
 ],
 "Create timers": [
  null,
  "Luo ajastimet"
 ],
 "Critical and above": [
  null,
  "Kriittinen ja yli"
 ],
 "Ctrl+Insert": [
  null,
  "Ctrl+Insert"
 ],
 "Current boot": [
  null,
  "Tämänhetkinen käynnistys"
 ],
 "Daily": [
  null,
  "Joka päivä"
 ],
 "Dark": [
  null,
  "Tumma"
 ],
 "Debug and above": [
  null,
  "Virheenkorjaus ja yli"
 ],
 "Decrease by one": [
  null,
  "Vähennä yhdellä"
 ],
 "Delay": [
  null,
  "Viive"
 ],
 "Delete": [
  null,
  "Poista"
 ],
 "Description": [
  null,
  "Kuvaus"
 ],
 "Desktop": [
  null,
  "Työpöytä"
 ],
 "Detachable": [
  null,
  "Irrotettava"
 ],
 "Disable simultaneous multithreading": [
  null,
  "Poista samanaikainen monisäikeisyys käytöstä"
 ],
 "Disabled": [
  null,
  "Ei käytössä"
 ],
 "Disallow running (mask)": [
  null,
  "Estä suorittaminen (piilota)"
 ],
 "Docking station": [
  null,
  "Telakka"
 ],
 "Does not automatically start": [
  null,
  "Ei käynnisty automaattisesti"
 ],
 "Domain": [
  null,
  "Toimialue"
 ],
 "Domain $0 could not be contacted": [
  null,
  "Toimialueeseen $0 ei saatu yhteyttä"
 ],
 "Domain $0 is not supported": [
  null,
  "Toimialue $0 ei ole tuettu"
 ],
 "Domain address": [
  null,
  "Toimialue-osoite"
 ],
 "Domain administrator name": [
  null,
  "Toimialueen ylläpitäjän nimi"
 ],
 "Domain administrator password": [
  null,
  "Toimialueen ylläpitäjän salasana"
 ],
 "Don't repeat": [
  null,
  "Älä toista"
 ],
 "Downloading $0": [
  null,
  "Ladataan $0"
 ],
 "Dual rank": [
  null,
  "Kaksinkertainen sijoitus"
 ],
 "Edit /etc/motd": [
  null,
  "Muokkaa /etc/motd"
 ],
 "Edit motd": [
  null,
  "Muokkaa motd"
 ],
 "Embedded PC": [
  null,
  "Sulautettu tietokone"
 ],
 "Enable stored metrics": [
  null,
  "Ota tallennetut mittarit käyttöön"
 ],
 "Enabled": [
  null,
  "Käytössä"
 ],
 "Entry at $0": [
  null,
  "Merkintä $0:lla"
 ],
 "Error": [
  null,
  "Virhe"
 ],
 "Error and above": [
  null,
  "Virhe ja yli"
 ],
 "Error message": [
  null,
  "Virheviesti"
 ],
 "Expansion chassis": [
  null,
  "Laajennusrunko"
 ],
 "Extended information": [
  null,
  "Laajennettu tieto"
 ],
 "Failed to save changes in /etc/motd": [
  null,
  "Muutosten tallentaminen /etc/motd:een epäonnistui"
 ],
 "Failed to start": [
  null,
  "Käynnistäminen epäonnistui"
 ],
 "Filter": [
  null,
  "Suodin"
 ],
 "Filter by name or description": [
  null,
  "Suodata nimen tai kuvauksen mukaan"
 ],
 "Font size": [
  null,
  "Kirjasinkoko"
 ],
 "Forbidden from running": [
  null,
  "Kielletty suorittamasta"
 ],
 "Frame number": [
  null,
  "Kehyksen numero"
 ],
 "Fridays": [
  null,
  "Perjantai"
 ],
 "General": [
  null,
  "Yleinen"
 ],
 "Go to $0": [
  null,
  "Mene kohteeseen $0"
 ],
 "Handheld": [
  null,
  "Kädessä pidettävä"
 ],
 "Hardware information": [
  null,
  "Laitteistotiedot"
 ],
 "Health": [
  null,
  "Terveys"
 ],
 "Hide filters": [
  null,
  "Piilota suodattimet"
 ],
 "Host key is incorrect": [
  null,
  "Koneen avain on väärin"
 ],
 "Host name should not be changed in a domain": [
  null,
  "Isäntänimeä ei tule muuttaa toimialueessa"
 ],
 "Hostname": [
  null,
  "Koneen nimi"
 ],
 "Hourly": [
  null,
  "Joka tunti"
 ],
 "Hours": [
  null,
  "Tuntia"
 ],
 "Hours must be a number between 0 and 23": [
  null,
  "Tunnin on oltava luku välillä 0 ja 23"
 ],
 "ID": [
  null,
  "Tunniste"
 ],
 "Identifier": [
  null,
  "Tunniste"
 ],
 "Increase by one": [
  null,
  "Lisää yhdellä"
 ],
 "Info and above": [
  null,
  "Tiedot ja yli"
 ],
 "Insights: ": [
  null,
  "Oivalluksia: "
 ],
 "Install": [
  null,
  "Asennus"
 ],
 "Install software": [
  null,
  "Asennetaan ohjelmistoja"
 ],
 "Installing $0": [
  null,
  "Asennetaan $0"
 ],
 "Internal error": [
  null,
  "Sisäinen virhe"
 ],
 "Invalid date format": [
  null,
  "Virheellinen päivämuoto"
 ],
 "Invalid date format and invalid time format": [
  null,
  "Virheellinen päivämuoto ja aikamuoto"
 ],
 "Invalid time format": [
  null,
  "Virheellinen aikamuoto"
 ],
 "Invalid timezone": [
  null,
  "Virheellinen aikavyöhyke"
 ],
 "IoT gateway": [
  null,
  "IoT -yhdyskäytävä"
 ],
 "Join": [
  null,
  "Liity"
 ],
 "Join a domain": [
  null,
  "Liity toimialueeseen"
 ],
 "Join domain": [
  null,
  "Liity toimialueeseen"
 ],
 "Joining a domain requires installation of realmd": [
  null,
  "Toimialueeseen liittyminen vaatii realmd:n asentamisen"
 ],
 "Joining this domain is not supported": [
  null,
  "Liittyminen tähän toimialueeseen ei ole tuettu"
 ],
 "Joins namespace of": [
  null,
  "Liittyy tämän nimitilaan"
 ],
 "Journal": [
  null,
  "Päiväkirja"
 ],
 "Journal entry": [
  null,
  "Päiväkirjan tietue"
 ],
 "Journal entry not found": [
  null,
  "Päiväkirjan tietuetta ei löytynyt"
 ],
 "Laptop": [
  null,
  "Kannettava"
 ],
 "Last 24 hours": [
  null,
  "Viimeiset 24 tuntia"
 ],
 "Last 7 days": [
  null,
  "Viimeiset 7 päivää"
 ],
 "Last failed login:": [
  null,
  "Edellinen epäonnistunut kirjautuminen:"
 ],
 "Last login:": [
  null,
  "Edellinen kirjautuminen:"
 ],
 "Learn more": [
  null,
  "Opi lisää"
 ],
 "Leave domain": [
  null,
  "Jätä toimialue"
 ],
 "Light": [
  null,
  "Kevyt"
 ],
 "Limit access": [
  null,
  "Rajoita pääsyä"
 ],
 "Limited access": [
  null,
  "Rajoitettu pääsy"
 ],
 "Limited access mode restricts administrative privileges. Some parts of the web console will have reduced functionality.": [
  null,
  "Rajoitettu pääsy -tila rajoittaa hallinnollisia oikeuksia. Joidenkin verkkokonsolin osien toiminnot ovat vähentyneet."
 ],
 "Load earlier entries": [
  null,
  "Lataa aiemmat merkinnät"
 ],
 "Loading keys...": [
  null,
  "Ladataan avaimet..."
 ],
 "Loading of SSH keys failed": [
  null,
  "SSH-avainten lataaminen epäonnistui"
 ],
 "Loading...": [
  null,
  "Ladataan..."
 ],
 "Log messages": [
  null,
  "Kirjaa viestit"
 ],
 "Login failed": [
  null,
  "Kirjautuminen epäonnistui"
 ],
 "Login format": [
  null,
  "Sisäänkirjautumisen muoto"
 ],
 "Logs": [
  null,
  "Lokit"
 ],
 "Low profile desktop": [
  null,
  "Matalan tason työpöytä"
 ],
 "Lunch box": [
  null,
  "Eväslaatikko"
 ],
 "Machine ID": [
  null,
  "Koneen ID"
 ],
 "Machine SSH key fingerprints": [
  null,
  "Koneen SSH-avaimen sormenjäljet"
 ],
 "Main server chassis": [
  null,
  "Pääpalvelimen runko"
 ],
 "Managing services": [
  null,
  "Palvelujen hallinta"
 ],
 "Manually": [
  null,
  "Manuaalisesti"
 ],
 "Mask service": [
  null,
  "Peitepalvelu"
 ],
 "Masked": [
  null,
  "Piilotettu"
 ],
 "Masking service prevents all dependent units from running. This can have bigger impact than anticipated. Please confirm that you want to mask this unit.": [
  null,
  "Peittopalvelu estää kaikkia riippuvaisia yksiköitä toimimasta. Tällä voi olla odotettua suurempi vaikutus. Vahvista, että haluat peittää tämän yksikön."
 ],
 "Memory": [
  null,
  "Muisti"
 ],
 "Memory technology": [
  null,
  "Muistitekniikka"
 ],
 "Message to logged in users": [
  null,
  "Viesti sisäänkirjautuneille käyttäjille"
 ],
 "Method": [
  null,
  "Menetelmä"
 ],
 "Mini PC": [
  null,
  "Mini-tietokone"
 ],
 "Mini tower": [
  null,
  "Mini-torni"
 ],
 "Minute needs to be a number between 0-59": [
  null,
  "Minuutit tulee olla esitetty numerovälillä 0-59"
 ],
 "Minutes": [
  null,
  "Minuutit"
 ],
 "Minutes must be a number between 0 and 59": [
  null,
  "Minuuttien on oltava luku välillä 0 ja 59"
 ],
 "Mitigations": [
  null,
  "Lievennykset"
 ],
 "Model": [
  null,
  "Malli"
 ],
 "Mondays": [
  null,
  "Maanantai"
 ],
 "Monthly": [
  null,
  "Joka kuukausi"
 ],
 "More": [
  null,
  "Lisää"
 ],
 "Multi-system chassis": [
  null,
  "Monijärjestelmäinen alusta"
 ],
 "NTP server": [
  null,
  "NTP-palvelin"
 ],
 "Name": [
  null,
  "Nimi"
 ],
 "Need at least one NTP server": [
  null,
  "Tarvitaan vähintään yksi NTP-palvelin"
 ],
 "Next": [
  null,
  "Seuraava"
 ],
 "No": [
  null,
  "Ei"
 ],
 "No delay": [
  null,
  "Ei v iivettä"
 ],
 "No host keys found.": [
  null,
  "Isäntäavaimia ei löytynyt."
 ],
 "No log entries": [
  null,
  "Ei lokimerkintöjä"
 ],
 "No logs found": [
  null,
  "Ei löytynyt lokeja"
 ],
 "No matching results": [
  null,
  "Ei vastaavia tuloksia"
 ],
 "No results match the filter criteria. Clear all filters to show results.": [
  null,
  "Ei tuloksia, jotka vastaavat suodatinkriteerejä. Tyhjennä kaikki suodattimet nähdäksesi tulokset."
 ],
 "No rule hits": [
  null,
  "Ei sääntöosumia"
 ],
 "Not connected to Insights": [
  null,
  "Ei yhdistetty tilastoihin"
 ],
 "Not joined": [
  null,
  "Ei liittynyt"
 ],
 "Not permitted to perform this action.": [
  null,
  "Ei oikeutta suorittaa tätä toimintoa."
 ],
 "Not running": [
  null,
  "Ei käynnissä"
 ],
 "Not synchronized": [
  null,
  "Ei synkronisoitu"
 ],
 "Note": [
  null,
  "Huomautus"
 ],
 "Notebook": [
  null,
  "Muistikirja"
 ],
 "Notice and above": [
  null,
  "Ilmoitus ja yli"
 ],
 "Ok": [
  null,
  "OK"
 ],
 "On failure": [
  null,
  "Epäonnistumisesta"
 ],
 "One time password": [
  null,
  "Kertakäyttöinen salasana"
 ],
 "Only alphabets, numbers, : , _ , . , @ , - are allowed": [
  null,
  "Vain aakkoset, numerot, : , _ , . , @ , - ovat sallittuja"
 ],
 "Only emergency": [
  null,
  "Vain hätätilanne"
 ],
 "Other": [
  null,
  "Muu"
 ],
 "Overview": [
  null,
  "Esittely"
 ],
 "PCI": [
  null,
  "PCI"
 ],
 "PCP": [
  null,
  "PCP"
 ],
 "PackageKit crashed": [
  null,
  "PackageKit kaatui"
 ],
 "Part of": [
  null,
  "Osa tätä"
 ],
 "Password": [
  null,
  "Salasana"
 ],
 "Paste": [
  null,
  "Siirrä"
 ],
 "Path": [
  null,
  "Polku"
 ],
 "Paths": [
  null,
  "Polut"
 ],
 "Pause": [
  null,
  "Keskeytä"
 ],
 "Performance profile": [
  null,
  "Suorituskykyprofiili"
 ],
 "Peripheral chassis": [
  null,
  "Kehäalusta"
 ],
 "Pick date": [
  null,
  "Valitse päivämäärä"
 ],
 "Pizza box": [
  null,
  "Pizza-laatikko"
 ],
 "Please authenticate to gain administrative access": [
  null,
  "Todenna saadaksesi hallinnolliset käyttöoikeudet"
 ],
 "Portable": [
  null,
  "Kannettava"
 ],
 "Present": [
  null,
  "Nykyinen"
 ],
 "Pretty host name": [
  null,
  "Pretty-isäntänimi"
 ],
 "Previous boot": [
  null,
  "Edellinen käynnistys"
 ],
 "Priority": [
  null,
  "Prioriteeetti"
 ],
 "Problem details": [
  null,
  "Ongelman yksityiskohdat"
 ],
 "Problem info": [
  null,
  "Ongelmatiedot"
 ],
 "Propagates reload to": [
  null,
  "Laajentaa latausta kohteeseen"
 ],
 "RAID chassis": [
  null,
  "RAID-runko"
 ],
 "Rack mount chassis": [
  null,
  "Telineen kiinnitysrunko"
 ],
 "Rank": [
  null,
  "Sijoitus"
 ],
 "Read more...": [
  null,
  "Lue lisää..."
 ],
 "Read-only": [
  null,
  "Luku-vain"
 ],
 "Real host name": [
  null,
  "Oikea isäntänimi"
 ],
 "Real host name can only contain lower-case characters, digits, dashes, and periods (with populated subdomains)": [
  null,
  "Oikea isäntänimi voi sisältää vain pieniä kirjaimia, numeroita, viivoja ja pisteitä (täytetyillä alitoimialueilla)"
 ],
 "Real host name must be 64 characters or less": [
  null,
  "Oikea isäntänimi saa sisältää enintään 64 merkkiä"
 ],
 "Reboot": [
  null,
  "Käynnistä uudelleen"
 ],
 "Reload": [
  null,
  "Lataa uudelleen"
 ],
 "Reload propagated from": [
  null,
  "Uudelleenlataus levitetty tältä"
 ],
 "Removals:": [
  null,
  "Poistot:"
 ],
 "Remove": [
  null,
  "Poista"
 ],
 "Removing $0": [
  null,
  "Poistetaan $0"
 ],
 "Repeat": [
  null,
  "Toista"
 ],
 "Repeat monthly": [
  null,
  "Toista joka kuukausi"
 ],
 "Repeat weekly": [
  null,
  "Toista joka viikko"
 ],
 "Report": [
  null,
  "Ilmoita"
 ],
 "Report to ABRT Analytics": [
  null,
  "Ilmoita ABRT Analytics :lle"
 ],
 "Reported; no links available": [
  null,
  "Ilmoitettu; linkkejä ei ole saatavilla"
 ],
 "Reporting failed": [
  null,
  "Raportointi epäonnistui"
 ],
 "Reporting was canceled": [
  null,
  "Raportointi peruutettiin"
 ],
 "Reports:": [
  null,
  "Ilmoitukset:"
 ],
 "Required by": [
  null,
  "Tämän edellyttämänä"
 ],
 "Required by ": [
  null,
  "Tämän edellyttämänä "
 ],
 "Requires": [
  null,
  "Vaatii"
 ],
 "Requires administration access to edit": [
  null,
  "Muokkaaminen edellyttää järjestelmänvalvojan käyttöoikeuksia"
 ],
 "Requisite": [
  null,
  "Vaaditaan"
 ],
 "Requisite of": [
  null,
  "Tämä vaaditaan"
 ],
 "Reset": [
  null,
  "Nollaa"
 ],
 "Restart": [
  null,
  "Käynnistä uudelleen"
 ],
 "Resume": [
  null,
  "Palauta"
 ],
 "Reviewing logs": [
  null,
  "Tarkistetaan lokeja"
 ],
 "Run": [
  null,
  "Suorita"
 ],
 "Running": [
  null,
  "Käynnissä"
 ],
 "Saturdays": [
  null,
  "Lauantai"
 ],
 "Save": [
  null,
  "Tallenna"
 ],
 "Save and reboot": [
  null,
  "Tallenna ja käynnistä uudelleen"
 ],
 "Save changes": [
  null,
  "Tallenna muutokset"
 ],
 "Sealed-case PC": [
  null,
  "Suljettu tietokonekotelo"
 ],
 "Search the logs with a combination of terms:": [
  null,
  "Hae lokista termien yhdistelmällä:"
 ],
 "Seconds": [
  null,
  "Sekunnit"
 ],
 "Secure shell keys": [
  null,
  "Suojaa komentotulkin avaimet"
 ],
 "Select unit state": [
  null,
  "Valitse uusi tila"
 ],
 "Send": [
  null,
  "Lähetä"
 ],
 "Server has closed the connection.": [
  null,
  "Palvelin on sulkenut yhteyden."
 ],
 "Server software": [
  null,
  "Palvelinohjelmisto"
 ],
 "Service logs": [
  null,
  "Palvelulokit"
 ],
 "Service name": [
  null,
  "Palvelun nimi"
 ],
 "Services": [
  null,
  "Palvelut"
 ],
 "Set hostname": [
  null,
  "Määritä isäntänimi"
 ],
 "Set time": [
  null,
  "Aseta aika"
 ],
 "Shift+Insert": [
  null,
  "Vaihto + Syöttö"
 ],
 "Show all threads": [
  null,
  "Näytä kaikki ketjut"
 ],
 "Show filters": [
  null,
  "Näytä suodattimet"
 ],
 "Show fingerprints": [
  null,
  "Näytä sormenjäljet"
 ],
 "Shut down": [
  null,
  "Sammuta"
 ],
 "Shutdown": [
  null,
  "Sammuta"
 ],
 "Single rank": [
  null,
  "Yksi sijoitus"
 ],
 "Size": [
  null,
  "Koko"
 ],
 "Slot": [
  null,
  "Aukko"
 ],
 "Sockets": [
  null,
  "Pistokkeet"
 ],
 "Software-based workarounds help prevent CPU security issues. These mitigations have the side effect of reducing performance. Change these settings at your own risk.": [
  null,
  "Ohjelmistopohjaiset ratkaisut auttavat estämään suorittimen tietoturvaongelmia. Näillä lievennyksillä on sivuvaikutus suorituskyvyn heikentämisessä. Muuta näitä asetuksia omalla vastuullasi."
 ],
 "Something went wrong": [
  null,
  "Jotain meni pieleen"
 ],
 "Space-saving computer": [
  null,
  "Tilaa säästävä tietokone"
 ],
 "Specific time": [
  null,
  "Tietty aika"
 ],
 "Speed": [
  null,
  "Nopeus"
 ],
 "Start": [
  null,
  "Käynnistä"
 ],
 "Start and enable": [
  null,
  "Käynnistä ja ota käyttöön"
 ],
 "Start service": [
  null,
  "Käynnistä palvelu"
 ],
 "State": [
  null,
  "Tila"
 ],
 "Static": [
  null,
  "Staattinen"
 ],
 "Status": [
  null,
  "Tila"
 ],
 "Stick PC": [
  null,
  "Tikku-PC"
 ],
 "Stop": [
  null,
  "Pysäytä"
 ],
 "Stop and disable": [
  null,
  "Pysäytä ja poista käytöstä"
 ],
 "Store metrics": [
  null,
  "Tallenna mittarit"
 ],
 "Sub-Chassis": [
  null,
  "Alirunko"
 ],
 "Sub-Notebook": [
  null,
  "Ali -kannettava tietokone"
 ],
 "Sundays": [
  null,
  "Sunnuntai"
 ],
 "Switch to limited access": [
  null,
  "Vaihda rajoitettuun pääsyyn"
 ],
 "Synchronized": [
  null,
  "Synkronoitu"
 ],
 "Synchronized with $0": [
  null,
  "Synkronoi $0:n kanssa"
 ],
 "Synchronizing": [
  null,
  "Synkronoidaan"
 ],
 "System information": [
  null,
  "Järjestelmätiedot"
 ],
 "System services": [
  null,
  "Järjestelmäpalvelut"
 ],
 "System time": [
  null,
  "Järjestelmän aika"
 ],
 "Systemd units": [
  null,
  "Systemd-yksiköt"
 ],
 "Tablet": [
  null,
  "Piirtopöytä"
 ],
 "Targets": [
  null,
  "Kohteet"
 ],
 "Terminal": [
  null,
  "Terminaali"
 ],
 "Text": [
  null,
  "Teksti"
 ],
 "The server refused to authenticate using any supported methods.": [
  null,
  "Palvelin kieltäytyi tunnistautumista käyttäen mitään tuetuista tavoista."
 ],
 "The user $0 is not permitted to change cpu security mitigations": [
  null,
  "Käyttäjä $0 ei saa muuttaa suorittimen suojauksen lievennyksiä"
 ],
 "There was $0 failed login attempt since the last successful login.": [
  "There were $0 failed login attempts since the last successful login.",
  "Edellisen onnistuneen kirjautumisen jälkeen kirjautuminen on epäonnistunut $0 kertaa.",
  "Edellisen onnistuneen kirjautumisen jälkeen kirjautuminen on epäonnistunut $0 kertaa."
 ],
 "This didn't work, please try again": [
  null,
  "Tämä ei toiminut, yritä uudelleen"
 ],
 "This field cannot be empty": [
  null,
  "Tämä kenttä ei voi olla tyhjä"
 ],
 "This may take a while": [
  null,
  "Tässä voi mennä hetki"
 ],
 "This unit is not designed to be enabled explicitly.": [
  null,
  "Tätä yksikköä ei ole suunniteltu nimenomaisesti käytettäväksi."
 ],
 "Thursdays": [
  null,
  "Torstai"
 ],
 "Time": [
  null,
  "Aika"
 ],
 "Time zone": [
  null,
  "Aikavyöhyke"
 ],
 "Timer creation failed": [
  null,
  "Ajastimen luonti epäonnistui"
 ],
 "Timers": [
  null,
  "Ajastimet"
 ],
 "Too much data": [
  null,
  "Liian paljon dataa"
 ],
 "Total size: $0": [
  null,
  "Koko yhteensä: $0"
 ],
 "Tower": [
  null,
  "Torni"
 ],
 "Triggered by": [
  null,
  "Tämän laukaisema"
 ],
 "Triggers": [
  null,
  "Liipaisimet"
 ],
 "Trying to synchronize with $0": [
  null,
  "Yritetään synkronoida $0:n kanssa"
 ],
 "Tuesdays": [
  null,
  "Tiistai"
 ],
 "Turn on administrative access": [
  null,
  "Ota järjestelmänvalvojan käyttöoikeudet käyttöön"
 ],
 "Type": [
  null,
  "Tyyppi"
 ],
 "Type to filter": [
  null,
  "Kirjoita suodattaaksesi"
 ],
 "Unit not found": [
  null,
  "Yksikköä ei löytynyt"
 ],
 "Unknown": [
  null,
  "Tuntematon"
 ],
 "Untrusted host": [
  null,
  "Epäluotettava isäntä"
 ],
 "Updating status...": [
  null,
  "Päivitetään tilaa ..."
 ],
 "Uptime": [
  null,
  "Käyttöaste"
 ],
 "Usage": [
  null,
  "Käyttö"
 ],
 "User name": [
  null,
  "Käyttäjänimi"
 ],
 "User password": [
  null,
  "Käyttäjäsalasana"
 ],
 "Validating address": [
  null,
  "Vahvistetaan osoite"
 ],
 "Vendor": [
  null,
  "Toimittaja"
 ],
 "Version": [
  null,
  "Versio"
 ],
 "View details and history": [
  null,
  "Tarkastele tietoja ja historiaa"
 ],
 "View hardware details": [
  null,
  "Tarkastele laitteiston yksityiskohdat"
 ],
 "View report": [
  null,
  "Tarkastele raportti"
 ],
 "Waiting for input…": [
  null,
  "Odotetaan syötettä…"
 ],
 "Waiting for other software management operations to finish": [
  null,
  "Odotetaan muiden ohjelmistojen hallintatoimintojen päättymistä"
 ],
 "Waiting to start…": [
  null,
  "Odotetaan aloittamista …"
 ],
 "Wanted by": [
  null,
  "Tämän haluama"
 ],
 "Wants": [
  null,
  "Haluaa"
 ],
 "Warning and above": [
  null,
  "Varoitus ja yli"
 ],
 "Web console is running in limited access mode.": [
  null,
  "Verkkokonsoli toimii rajoitetun pääsyn tilassa."
 ],
 "Wednesdays": [
  null,
  "Keskiviikko"
 ],
 "Weekly": [
  null,
  "Joka viikko"
 ],
 "Weeks": [
  null,
  "Viikot"
 ],
 "White": [
  null,
  "Valkoinen"
 ],
 "Yearly": [
  null,
  "Vuosittain"
 ],
 "Yes": [
  null,
  "Kyllä"
 ],
 "You can not gain administrative access.": [
  null,
  "Et voi hankkia järjestelmänvalvojan käyttöoikeuksia."
 ],
 "You may try to load older entries.": [
  null,
  "Voit yrittää ladata vanhempia merkintöjä."
 ],
 "You now have administrative access.": [
  null,
  "Sinulla on nyt järjestelmänvalvojan käyttöoikeus."
 ],
 "Your browser does not allow paste from the context menu. You can use Shift+Insert.": [
  null,
  ""
 ],
 "Your browser will remember your access level across sessions.": [
  null,
  "Selaimesi muistaa käyttöoikeustasosi istuntojen ajan."
 ],
 "Your session has been terminated.": [
  null,
  "Istuntosi on päätetty."
 ],
 "Your session has expired. Please log in again.": [
  null,
  "Istuntosi on vahventunut. Ole hyvä ja kirjaudu uudelleen sisään."
 ],
 "[$0 bytes of binary data]": [
  null,
  "[$0 tavua binääridatasta]"
 ],
 "[binary data]": [
  null,
  "[binääridata]"
 ],
 "[no data]": [
  null,
  "[ei dataa]"
 ],
 "abrt": [
  null,
  "abrt"
 ],
 "any free-form string as regular expression": [
  null,
  "mikä tahansa vapaamuotoinen merkkijono säännöllisenä lausekkeena"
 ],
 "asset tag": [
  null,
  "sisältötunniste"
 ],
 "bash": [
  null,
  "bash"
 ],
 "bios": [
  null,
  "bios"
 ],
 "boot": [
  null,
  "käynnistys"
 ],
 "cgroups": [
  null,
  "c-ryhmät"
 ],
 "command": [
  null,
  "komento"
 ],
 "console": [
  null,
  "konsoli"
 ],
 "coredump": [
  null,
  "ytimen tyhjennys"
 ],
 "cpu": [
  null,
  "suoritin"
 ],
 "crash": [
  null,
  "kaatuminen"
 ],
 "date": [
  null,
  "päivämäärä"
 ],
 "debug": [
  null,
  "virheenjäljitys"
 ],
 "dimm": [
  null,
  "dimm"
 ],
 "disable": [
  null,
  "poista käytöstä"
 ],
 "disks": [
  null,
  "levyt"
 ],
 "domain": [
  null,
  "toimialue"
 ],
 "e.g.": [
  null,
  "esim."
 ],
 "e.g. \"$0\"": [
  null,
  "esim. \"$0\""
 ],
 "edit": [
  null,
  "muokkaa"
 ],
 "enable": [
  null,
  "ota käyttöön"
 ],
 "error": [
  null,
  "virhe"
 ],
 "failed to list ssh host keys: $0": [
  null,
  "ssh-isäntäavainten luettelointi epäonnistui: $0"
 ],
 "graphs": [
  null,
  "kaaviot"
 ],
 "hardware": [
  null,
  "laitteisto"
 ],
 "history": [
  null,
  "historia"
 ],
 "host": [
  null,
  "isäntä"
 ],
 "journal": [
  null,
  "päiväkirja"
 ],
 "journalctl manpage": [
  null,
  "journalctl manpage"
 ],
 "log fields": [
  null,
  "lokikentät"
 ],
 "machine": [
  null,
  "kone"
 ],
 "mask": [
  null,
  "peite"
 ],
 "memory": [
  null,
  "muisti"
 ],
 "metrics": [
  null,
  "mittarit"
 ],
 "mitigation": [
  null,
  "lievennys"
 ],
 "network": [
  null,
  "verkko"
 ],
 "of $0 CPU": [
  "of $0 CPUs",
  "$0 CPU:sta",
  "$0 CPU:sta"
 ],
 "operating system": [
  null,
  "käyttöjärjestelmä"
 ],
 "os": [
  null,
  "käyttöjärjestelmä"
 ],
 "path": [
  null,
  "polku"
 ],
 "pci": [
  null,
  "pci"
 ],
 "pcp": [
  null,
  "pcp"
 ],
 "power": [
  null,
  "power"
 ],
 "qualifiers": [
  null,
  "karsinnat"
 ],
 "ram": [
  null,
  "ram-muisti"
 ],
 "restart": [
  null,
  "käynnistä uudelleen"
 ],
 "running $0": [
  null,
  "käynnissä $0"
 ],
 "serial": [
  null,
  "sarja"
 ],
 "service": [
  null,
  "palvelu"
 ],
 "shell": [
  null,
  "komentotulkki"
 ],
 "show less": [
  null,
  "näytä vähemmän"
 ],
 "show more": [
  null,
  "näytä enemmän"
 ],
 "shut": [
  null,
  "sulje"
 ],
 "socket": [
  null,
  "pistoke"
 ],
 "ssh": [
  null,
  "ssh"
 ],
 "systemctl": [
  null,
  "systemctl"
 ],
 "systemd": [
  null,
  "systemd"
 ],
 "target": [
  null,
  "kohde"
 ],
 "time": [
  null,
  "aika"
 ],
 "timer": [
  null,
  "ajastin"
 ],
 "unit": [
  null,
  "yksikkö"
 ],
 "unknown": [
  null,
  "tuntematon"
 ],
 "unmask": [
  null,
  "poista peite"
 ],
 "version": [
  null,
  "versio"
 ],
 "warning": [
  null,
  "varoitus"
 ],
 "<date> from <host>\u0004$0 from $1": [
  null,
  "$0 $1:sta"
 ],
 "<date> from <host> on <terminal>\u0004$0 from $1 on $2": [
  null,
  "$0 $1:sta $2:lla"
 ],
 "<date> on <terminal>\u0004$0 on $1": [
  null,
  "$0 $1:lla"
 ]
});
