cockpit.locale({
 "": {'plural-forms':function(n) {
var nplurals, plural;
nplurals=2; plural=n != 1;
return plural;
},
  "language": "ca",
  "x-generator": "Weblate 4.0.3"
 },
 "$0 critical hit": [
  "$0 hits, including critical",
  "",
  ""
 ],
 "$0 exited with code $1": [
  null,
  "$0 va sortir amb el codi $1"
 ],
 "$0 failed": [
  null,
  "$0 ha fallat"
 ],
 "$0 important hit": [
  "$0 hits, including important",
  "",
  ""
 ],
 "$0 is not available from any repository.": [
  null,
  ""
 ],
 "$0 killed with signal $1": [
  null,
  "$0 es va matar amb el senyal $1"
 ],
 "$0 low severity hit": [
  "$0 low severity hits",
  "",
  ""
 ],
 "$0 service has failed": [
  "$0 services have failed",
  ""
 ],
 "$0 will be installed.": [
  null,
  ""
 ],
 "$0: crash at $1": [
  null,
  ""
 ],
 "1 minute": [
  null,
  "1 minut"
 ],
 "10th": [
  null,
  "10è"
 ],
 "11th": [
  null,
  "11è"
 ],
 "12th": [
  null,
  "12è"
 ],
 "13th": [
  null,
  "13è"
 ],
 "14th": [
  null,
  "14è"
 ],
 "15th": [
  null,
  "15è"
 ],
 "16th": [
  null,
  "16è"
 ],
 "17th": [
  null,
  "17è"
 ],
 "18th": [
  null,
  "18è"
 ],
 "19th": [
  null,
  "19è"
 ],
 "1st": [
  null,
  "1r"
 ],
 "20 minutes": [
  null,
  "20 minuts"
 ],
 "20th": [
  null,
  "20è"
 ],
 "21th": [
  null,
  ""
 ],
 "22th": [
  null,
  ""
 ],
 "23th": [
  null,
  ""
 ],
 "24th": [
  null,
  "24è"
 ],
 "25th": [
  null,
  "25è"
 ],
 "26th": [
  null,
  "26è"
 ],
 "27th": [
  null,
  "27è"
 ],
 "28th": [
  null,
  "28è"
 ],
 "29th": [
  null,
  "29è"
 ],
 "2nd": [
  null,
  "2n"
 ],
 "30th": [
  null,
  "30è"
 ],
 "31st": [
  null,
  "31è"
 ],
 "3rd": [
  null,
  "3r"
 ],
 "40 minutes": [
  null,
  "40 minuts"
 ],
 "4th": [
  null,
  "4t"
 ],
 "5 minutes": [
  null,
  "5 minuts"
 ],
 "5th": [
  null,
  "5è"
 ],
 "60 minutes": [
  null,
  "60 minuts"
 ],
 "6th": [
  null,
  "6è"
 ],
 "7th": [
  null,
  "7è"
 ],
 "8th": [
  null,
  "8è"
 ],
 "9th": [
  null,
  "9è"
 ],
 "Absent": [
  null,
  ""
 ],
 "Active since ": [
  null,
  ""
 ],
 "Add": [
  null,
  "Afegeix"
 ],
 "Additional actions": [
  null,
  ""
 ],
 "Additional packages:": [
  null,
  ""
 ],
 "Administrator password": [
  null,
  "Contrasenya de l'administrador"
 ],
 "Advanced TCA": [
  null,
  ""
 ],
 "After": [
  null,
  "Després"
 ],
 "After leaving the domain, only users with local credentials will be able to log into this machine. This may also affect other services as DNS resolution settings and the list of trusted CAs may change.": [
  null,
  ""
 ],
 "After system boot": [
  null,
  "Després de l'arrencada del sistema"
 ],
 "Alert and above": [
  null,
  ""
 ],
 "All": [
  null,
  "Tots"
 ],
 "All logs": [
  null,
  ""
 ],
 "All-in-one": [
  null,
  ""
 ],
 "Allow running (unmask)": [
  null,
  ""
 ],
 "Appearance": [
  null,
  ""
 ],
 "Asset tag": [
  null,
  ""
 ],
 "At specific time": [
  null,
  "A l'instant específic"
 ],
 "Authentication": [
  null,
  "Autenticació"
 ],
 "Automatic": [
  null,
  "Automàtic"
 ],
 "Automatically starts": [
  null,
  ""
 ],
 "Automatically using NTP": [
  null,
  "Automàticament mitjançant NTP"
 ],
 "Automatically using specific NTP servers": [
  null,
  "Automàticament mitjançant servidors NTP específics"
 ],
 "BIOS": [
  null,
  "BIOS"
 ],
 "BIOS date": [
  null,
  "Data del BIOS"
 ],
 "BIOS version": [
  null,
  "Versió del BIOS"
 ],
 "Before": [
  null,
  ""
 ],
 "Binds to": [
  null,
  ""
 ],
 "Black": [
  null,
  "Negre"
 ],
 "Blade": [
  null,
  ""
 ],
 "Blade enclosure": [
  null,
  ""
 ],
 "Bound by": [
  null,
  ""
 ],
 "Bus expansion chassis": [
  null,
  ""
 ],
 "CPU": [
  null,
  "CPU"
 ],
 "CPU security": [
  null,
  "Seguretat de la CPU"
 ],
 "CPU security toggles": [
  null,
  ""
 ],
 "Can not find any logs using the current combination of filters.": [
  null,
  ""
 ],
 "Cancel": [
  null,
  "Cancel·la"
 ],
 "Cannot forward login credentials": [
  null,
  ""
 ],
 "Cannot join a domain because realmd is not available on this system": [
  null,
  ""
 ],
 "Cannot schedule event in the past": [
  null,
  "No es pot planificar un esdeveniment del passat"
 ],
 "Change": [
  null,
  "Canvia"
 ],
 "Change host name": [
  null,
  "Canvia el nom d'amfitrió"
 ],
 "Change system time": [
  null,
  "Canvia l'hora del sistema"
 ],
 "Checking installed software": [
  null,
  ""
 ],
 "Class": [
  null,
  "Classe"
 ],
 "Clear 'Failed to start'": [
  null,
  ""
 ],
 "Clear all filters": [
  null,
  ""
 ],
 "Client software": [
  null,
  ""
 ],
 "Close": [
  null,
  "Tanca"
 ],
 "Cockpit could not contact the given host.": [
  null,
  "Cockpit no ha pogut contactar amb l'amfitrió indicat."
 ],
 "Cockpit is not compatible with the software on the system.": [
  null,
  "Cockpit no és compatible amb el programari del sistema."
 ],
 "Cockpit is not installed on the system.": [
  null,
  "Cockpit no està instal·lat al sistema."
 ],
 "Command": [
  null,
  "Ordre"
 ],
 "Compact PCI": [
  null,
  "PCI compacte"
 ],
 "Computer OU": [
  null,
  "OU de l'ordinador"
 ],
 "Condition $0=$1 was not met": [
  null,
  ""
 ],
 "Condition failed": [
  null,
  "Ha fallat la condició"
 ],
 "Configuration": [
  null,
  "Configuració"
 ],
 "Conflicted by": [
  null,
  ""
 ],
 "Conflicts": [
  null,
  "Conflictes"
 ],
 "Connection has timed out.": [
  null,
  "La connexió ha excedit el temps."
 ],
 "Consists of": [
  null,
  ""
 ],
 "Contacted domain": [
  null,
  ""
 ],
 "Convertible": [
  null,
  "Convertible"
 ],
 "Copy": [
  null,
  ""
 ],
 "Crash reporting": [
  null,
  ""
 ],
 "Create timer": [
  null,
  "Crea un temporitzador"
 ],
 "Create timers": [
  null,
  "Crea temporitzadors"
 ],
 "Critical and above": [
  null,
  ""
 ],
 "Ctrl+Insert": [
  null,
  ""
 ],
 "Current boot": [
  null,
  "Arrencada actual"
 ],
 "Daily": [
  null,
  ""
 ],
 "Dark": [
  null,
  ""
 ],
 "Debug and above": [
  null,
  ""
 ],
 "Decrease by one": [
  null,
  ""
 ],
 "Delay": [
  null,
  "Retard"
 ],
 "Delete": [
  null,
  "Suprimeix"
 ],
 "Description": [
  null,
  "Descripció"
 ],
 "Desktop": [
  null,
  "Escriptori"
 ],
 "Detachable": [
  null,
  ""
 ],
 "Disable simultaneous multithreading": [
  null,
  ""
 ],
 "Disabled": [
  null,
  "Inhabilitat"
 ],
 "Disallow running (mask)": [
  null,
  ""
 ],
 "Docking station": [
  null,
  ""
 ],
 "Domain": [
  null,
  "Domini"
 ],
 "Domain $0 could not be contacted": [
  null,
  "No s'ha pogut contactar amb el domini $0"
 ],
 "Domain $0 is not supported": [
  null,
  "El domini $0 no és compatible"
 ],
 "Domain address": [
  null,
  "Adreça del domini"
 ],
 "Domain administrator name": [
  null,
  "Nom de l'administrador del domini"
 ],
 "Domain administrator password": [
  null,
  "Contrasenya de l'administrador del domini"
 ],
 "Don't repeat": [
  null,
  "No repeteixis"
 ],
 "Downloading $0": [
  null,
  ""
 ],
 "Dual rank": [
  null,
  ""
 ],
 "Embedded PC": [
  null,
  ""
 ],
 "Enable stored metrics": [
  null,
  ""
 ],
 "Enabled": [
  null,
  "Habilitat"
 ],
 "Entry at $0": [
  null,
  ""
 ],
 "Error": [
  null,
  "Error"
 ],
 "Error and above": [
  null,
  ""
 ],
 "Expansion chassis": [
  null,
  ""
 ],
 "Extended information": [
  null,
  ""
 ],
 "Failed to start": [
  null,
  ""
 ],
 "Filter": [
  null,
  ""
 ],
 "Forbidden from running": [
  null,
  ""
 ],
 "Frame number": [
  null,
  ""
 ],
 "Fridays": [
  null,
  ""
 ],
 "General": [
  null,
  "General"
 ],
 "Handheld": [
  null,
  ""
 ],
 "Hardware information": [
  null,
  "Informació del maquinari"
 ],
 "Health": [
  null,
  ""
 ],
 "Hide filters": [
  null,
  ""
 ],
 "Host key is incorrect": [
  null,
  "La clau d'amfitrió és incorrecta"
 ],
 "Host name should not be changed in a domain": [
  null,
  ""
 ],
 "Hostname": [
  null,
  ""
 ],
 "Hours": [
  null,
  "Hores"
 ],
 "ID": [
  null,
  ""
 ],
 "Identifier": [
  null,
  ""
 ],
 "Increase by one": [
  null,
  ""
 ],
 "Info and above": [
  null,
  ""
 ],
 "Insights: ": [
  null,
  ""
 ],
 "Install": [
  null,
  "Instal·la"
 ],
 "Install software": [
  null,
  ""
 ],
 "Installing $0": [
  null,
  ""
 ],
 "Internal error": [
  null,
  "Error intern"
 ],
 "Invalid date format": [
  null,
  "Format de data no vàlid"
 ],
 "Invalid date format and invalid time format": [
  null,
  "Format no vàlid de la data i l'hora"
 ],
 "Invalid time format": [
  null,
  "Format d'hora no vàlid"
 ],
 "IoT gateway": [
  null,
  ""
 ],
 "Join": [
  null,
  "Uneix-te"
 ],
 "Join a domain": [
  null,
  "Uneix-te a un domini"
 ],
 "Join domain": [
  null,
  "Uneix-te a un domini"
 ],
 "Joining this domain is not supported": [
  null,
  "La unió a aquest domini no està admesa"
 ],
 "Joins namespace of": [
  null,
  ""
 ],
 "Journal": [
  null,
  "Publicacions"
 ],
 "Journal entry": [
  null,
  "Entrada de les publicacions"
 ],
 "Journal entry not found": [
  null,
  "Entrada no trobada de les publicacions"
 ],
 "Laptop": [
  null,
  ""
 ],
 "Last 24 hours": [
  null,
  "Les últimes 24 hores"
 ],
 "Last 7 days": [
  null,
  "Els últims 7 dies"
 ],
 "Leave domain": [
  null,
  "Abandona el domini"
 ],
 "Light": [
  null,
  ""
 ],
 "Limit access": [
  null,
  ""
 ],
 "Limited access": [
  null,
  ""
 ],
 "Limited access mode restricts administrative privileges. Some parts of the web console will have reduced functionality.": [
  null,
  ""
 ],
 "Load earlier entries": [
  null,
  "Carrega les entrades anteriors"
 ],
 "Loading...": [
  null,
  "S'està carregant..."
 ],
 "Log messages": [
  null,
  "Missatges del registre"
 ],
 "Login failed": [
  null,
  "Ha fallat l'inici de sessió"
 ],
 "Login format": [
  null,
  ""
 ],
 "Logs": [
  null,
  "Registres"
 ],
 "Low profile desktop": [
  null,
  ""
 ],
 "Lunch box": [
  null,
  ""
 ],
 "Machine ID": [
  null,
  "Id. de màquina"
 ],
 "Machine SSH key fingerprints": [
  null,
  "Empremtes de les claus SSH de la màquina"
 ],
 "Main server chassis": [
  null,
  ""
 ],
 "Managing services": [
  null,
  ""
 ],
 "Manually": [
  null,
  "Manualment"
 ],
 "Mask service": [
  null,
  ""
 ],
 "Masked": [
  null,
  ""
 ],
 "Masking service prevents all dependent units from running. This can have bigger impact than anticipated. Please confirm that you want to mask this unit.": [
  null,
  ""
 ],
 "Memory": [
  null,
  "Memòria"
 ],
 "Memory technology": [
  null,
  ""
 ],
 "Message to logged in users": [
  null,
  "Missatge per als usuaris que hagin iniciat la sessió"
 ],
 "Method": [
  null,
  ""
 ],
 "Mini PC": [
  null,
  "Mini PC"
 ],
 "Mini tower": [
  null,
  "Mini torre"
 ],
 "Minute needs to be a number between 0-59": [
  null,
  "El minut ha de ser un nombre entre 0-59"
 ],
 "Minutes": [
  null,
  "Minuts"
 ],
 "Mitigations": [
  null,
  ""
 ],
 "Model": [
  null,
  "Model"
 ],
 "Mondays": [
  null,
  ""
 ],
 "Monthly": [
  null,
  ""
 ],
 "More": [
  null,
  "Més"
 ],
 "Multi-system chassis": [
  null,
  ""
 ],
 "NTP server": [
  null,
  "Servidor NTP"
 ],
 "Name": [
  null,
  "Nom"
 ],
 "Need at least one NTP server": [
  null,
  "Com a mínim es necessita un servidor NTP"
 ],
 "Next": [
  null,
  "Següent"
 ],
 "No": [
  null,
  "No"
 ],
 "No delay": [
  null,
  "Sense retard"
 ],
 "No host keys found.": [
  null,
  ""
 ],
 "No logs found": [
  null,
  ""
 ],
 "No matching results": [
  null,
  ""
 ],
 "No results match the filter criteria. Clear all filters to show results.": [
  null,
  ""
 ],
 "No rule hits": [
  null,
  ""
 ],
 "Not connected to Insights": [
  null,
  ""
 ],
 "Not permitted to perform this action.": [
  null,
  "No es permet realitzar aquesta acció."
 ],
 "Not running": [
  null,
  "No s'està executant"
 ],
 "Not synchronized": [
  null,
  "No sincronitzat"
 ],
 "Note": [
  null,
  "Nota"
 ],
 "Notebook": [
  null,
  ""
 ],
 "Notice and above": [
  null,
  ""
 ],
 "Ok": [
  null,
  "D'acord"
 ],
 "On failure": [
  null,
  "Amb la fallada"
 ],
 "One time password": [
  null,
  "Contrasenya d'un sol cop"
 ],
 "Only emergency": [
  null,
  "Només emergències"
 ],
 "Other": [
  null,
  "Altres"
 ],
 "Overview": [
  null,
  "Visió de conjunt"
 ],
 "PCI": [
  null,
  "PCI"
 ],
 "PCP": [
  null,
  ""
 ],
 "PackageKit crashed": [
  null,
  "PackageKit s'ha estavellat."
 ],
 "Part of": [
  null,
  ""
 ],
 "Password": [
  null,
  "Contrasenya"
 ],
 "Paste": [
  null,
  ""
 ],
 "Path": [
  null,
  "Camí"
 ],
 "Paths": [
  null,
  "Camins"
 ],
 "Pause": [
  null,
  ""
 ],
 "Performance profile": [
  null,
  ""
 ],
 "Peripheral chassis": [
  null,
  ""
 ],
 "Pick date": [
  null,
  ""
 ],
 "Pizza box": [
  null,
  ""
 ],
 "Please authenticate to gain administrative access": [
  null,
  ""
 ],
 "Portable": [
  null,
  "Portable"
 ],
 "Present": [
  null,
  ""
 ],
 "Pretty host name": [
  null,
  "Nom d'amfitrió bonic"
 ],
 "Previous boot": [
  null,
  ""
 ],
 "Priority": [
  null,
  "Prioritat"
 ],
 "Problem details": [
  null,
  "Detalls del problema"
 ],
 "Problem info": [
  null,
  "Informació del problema"
 ],
 "Propagates reload to": [
  null,
  ""
 ],
 "RAID chassis": [
  null,
  ""
 ],
 "Rack mount chassis": [
  null,
  ""
 ],
 "Rank": [
  null,
  ""
 ],
 "Read more...": [
  null,
  ""
 ],
 "Read-only": [
  null,
  ""
 ],
 "Real host name": [
  null,
  "Nom d'amfitrió real"
 ],
 "Real host name can only contain lower-case characters, digits, dashes, and periods (with populated subdomains)": [
  null,
  "El nom d'amfitrió real només pot contenir caràcters en minúscules, dígits, guions i punts (amb subdominis poblats)"
 ],
 "Real host name must be 64 characters or less": [
  null,
  "El nom d'amfitrió real pot tenir com a molt 64 caràcters"
 ],
 "Reboot": [
  null,
  "Rearrencada"
 ],
 "Reload": [
  null,
  "Recarrega"
 ],
 "Reload propagated from": [
  null,
  ""
 ],
 "Removals:": [
  null,
  ""
 ],
 "Remove": [
  null,
  "Suprimeix"
 ],
 "Removing $0": [
  null,
  ""
 ],
 "Repeat weekly": [
  null,
  "Repeteix cada setmana"
 ],
 "Report": [
  null,
  ""
 ],
 "Report to ABRT Analytics": [
  null,
  ""
 ],
 "Reported; no links available": [
  null,
  ""
 ],
 "Reporting failed": [
  null,
  ""
 ],
 "Reporting was canceled": [
  null,
  ""
 ],
 "Reports:": [
  null,
  ""
 ],
 "Required by": [
  null,
  ""
 ],
 "Required by ": [
  null,
  ""
 ],
 "Requires": [
  null,
  ""
 ],
 "Requires administration access to edit": [
  null,
  ""
 ],
 "Requisite": [
  null,
  ""
 ],
 "Requisite of": [
  null,
  ""
 ],
 "Reset": [
  null,
  "Restableix"
 ],
 "Restart": [
  null,
  "Reinicia"
 ],
 "Resume": [
  null,
  ""
 ],
 "Run": [
  null,
  "Executa"
 ],
 "Running": [
  null,
  "En execució"
 ],
 "Saturdays": [
  null,
  ""
 ],
 "Save": [
  null,
  "Desa"
 ],
 "Save and reboot": [
  null,
  ""
 ],
 "Sealed-case PC": [
  null,
  ""
 ],
 "Search the logs with a combination of terms:": [
  null,
  ""
 ],
 "Seconds": [
  null,
  "segons"
 ],
 "Secure shell keys": [
  null,
  ""
 ],
 "Send": [
  null,
  ""
 ],
 "Server has closed the connection.": [
  null,
  "El servidor ha tancat la connexió."
 ],
 "Server software": [
  null,
  ""
 ],
 "Service logs": [
  null,
  "Registres del servei"
 ],
 "Service name": [
  null,
  "Nom del servei"
 ],
 "Services": [
  null,
  "Serveis"
 ],
 "Set hostname": [
  null,
  ""
 ],
 "Set time": [
  null,
  "Ajusta l'hora"
 ],
 "Shift+Insert": [
  null,
  ""
 ],
 "Show fingerprints": [
  null,
  "Mostra les empremtes"
 ],
 "Shut down": [
  null,
  "Apaga"
 ],
 "Shutdown": [
  null,
  "Atura"
 ],
 "Single rank": [
  null,
  ""
 ],
 "Size": [
  null,
  "Mida"
 ],
 "Slot": [
  null,
  "Ranura"
 ],
 "Sockets": [
  null,
  "Sockets"
 ],
 "Software-based workarounds help prevent CPU security issues. These mitigations have the side effect of reducing performance. Change these settings at your own risk.": [
  null,
  ""
 ],
 "Something went wrong": [
  null,
  ""
 ],
 "Space-saving computer": [
  null,
  ""
 ],
 "Specific time": [
  null,
  "Instant concret"
 ],
 "Speed": [
  null,
  ""
 ],
 "Start": [
  null,
  "Inicia"
 ],
 "Start and enable": [
  null,
  ""
 ],
 "Start service": [
  null,
  ""
 ],
 "State": [
  null,
  "Estat"
 ],
 "Static": [
  null,
  "Estàtic"
 ],
 "Status": [
  null,
  "Estat"
 ],
 "Stick PC": [
  null,
  ""
 ],
 "Stop": [
  null,
  "Atura"
 ],
 "Stop and disable": [
  null,
  ""
 ],
 "Store metrics": [
  null,
  ""
 ],
 "Sub-Chassis": [
  null,
  ""
 ],
 "Sub-Notebook": [
  null,
  ""
 ],
 "Sundays": [
  null,
  ""
 ],
 "Switch to limited access": [
  null,
  ""
 ],
 "Synchronized": [
  null,
  "Sincronitzat"
 ],
 "System information": [
  null,
  "Informació del sistema"
 ],
 "System services": [
  null,
  "Serveis del sistema"
 ],
 "System time": [
  null,
  ""
 ],
 "Tablet": [
  null,
  "Tauleta"
 ],
 "Targets": [
  null,
  "Objectius"
 ],
 "Terminal": [
  null,
  "Terminal"
 ],
 "Text": [
  null,
  ""
 ],
 "The server refused to authenticate using any supported methods.": [
  null,
  "El servidor ha refusat l'autenticació mitjançant qualsevol dels mètodes compatibles."
 ],
 "The user $0 is not permitted to change cpu security mitigations": [
  null,
  ""
 ],
 "There was $0 failed login attempt since the last successful login.": [
  "There were $0 failed login attempts since the last successful login.",
  "",
  ""
 ],
 "This didn't work, please try again": [
  null,
  ""
 ],
 "This may take a while": [
  null,
  "Això pot trigar una estona"
 ],
 "This unit is not designed to be enabled explicitly.": [
  null,
  "Aquesta unitat no està dissenyada per estar explícitament activada."
 ],
 "Thursdays": [
  null,
  ""
 ],
 "Time zone": [
  null,
  "Zona horària"
 ],
 "Timers": [
  null,
  "Temporitzadors"
 ],
 "Too much data": [
  null,
  "Hi ha massa dades"
 ],
 "Total size: $0": [
  null,
  ""
 ],
 "Tower": [
  null,
  "Torre"
 ],
 "Triggered by": [
  null,
  ""
 ],
 "Triggers": [
  null,
  "Disparadors"
 ],
 "Tuesdays": [
  null,
  ""
 ],
 "Turn on administrative access": [
  null,
  ""
 ],
 "Type": [
  null,
  "Tipus"
 ],
 "Unknown": [
  null,
  "Desconegut"
 ],
 "Untrusted host": [
  null,
  "Amfitrió no fiable"
 ],
 "Updating status...": [
  null,
  ""
 ],
 "Uptime": [
  null,
  ""
 ],
 "Usage": [
  null,
  "Ús"
 ],
 "User name": [
  null,
  "Nom d'usuari"
 ],
 "User password": [
  null,
  "Contrasenya d'usuari"
 ],
 "Validating address": [
  null,
  ""
 ],
 "Vendor": [
  null,
  "Fabricant"
 ],
 "Version": [
  null,
  "Versió"
 ],
 "View details and history": [
  null,
  ""
 ],
 "View hardware details": [
  null,
  ""
 ],
 "View report": [
  null,
  ""
 ],
 "Waiting for input…": [
  null,
  ""
 ],
 "Waiting for other software management operations to finish": [
  null,
  ""
 ],
 "Waiting to start…": [
  null,
  ""
 ],
 "Wanted by": [
  null,
  ""
 ],
 "Wants": [
  null,
  ""
 ],
 "Warning and above": [
  null,
  ""
 ],
 "Web console is running in limited access mode.": [
  null,
  ""
 ],
 "Wednesdays": [
  null,
  ""
 ],
 "Weeks": [
  null,
  "Setmanes"
 ],
 "White": [
  null,
  ""
 ],
 "Yearly": [
  null,
  ""
 ],
 "Yes": [
  null,
  "Sí"
 ],
 "You can not gain administrative access.": [
  null,
  ""
 ],
 "You may try to load older entries.": [
  null,
  ""
 ],
 "You now have administrative access.": [
  null,
  ""
 ],
 "Your browser does not allow paste from the context menu. You can use Shift+Insert.": [
  null,
  ""
 ],
 "Your browser will remember your access level across sessions.": [
  null,
  ""
 ],
 "Your session has been terminated.": [
  null,
  "La vostra sessió ha estat finalitzada."
 ],
 "Your session has expired. Please log in again.": [
  null,
  "La vostra sessió ha vençut. Si us plau, torneu a iniciar la sessió."
 ],
 "[$0 bytes of binary data]": [
  null,
  "[$0 bytes de dades binàries]"
 ],
 "[binary data]": [
  null,
  "[dades binàries]"
 ],
 "[no data]": [
  null,
  "[sense dades]"
 ],
 "abrt": [
  null,
  ""
 ],
 "any free-form string as regular expression": [
  null,
  ""
 ],
 "asset tag": [
  null,
  ""
 ],
 "bash": [
  null,
  ""
 ],
 "bios": [
  null,
  ""
 ],
 "boot": [
  null,
  ""
 ],
 "cgroups": [
  null,
  ""
 ],
 "command": [
  null,
  ""
 ],
 "console": [
  null,
  ""
 ],
 "coredump": [
  null,
  ""
 ],
 "cpu": [
  null,
  ""
 ],
 "crash": [
  null,
  ""
 ],
 "date": [
  null,
  ""
 ],
 "debug": [
  null,
  ""
 ],
 "dimm": [
  null,
  ""
 ],
 "disable": [
  null,
  ""
 ],
 "domain": [
  null,
  ""
 ],
 "e.g. \"$0\"": [
  null,
  "p. ex. \"$0\""
 ],
 "edit": [
  null,
  ""
 ],
 "enable": [
  null,
  ""
 ],
 "error": [
  null,
  "error"
 ],
 "failed to list ssh host keys: $0": [
  null,
  "no s'han pogut llistar les claus d'amfitrions ssh: $0"
 ],
 "graphs": [
  null,
  ""
 ],
 "hardware": [
  null,
  ""
 ],
 "host": [
  null,
  "amfitrió"
 ],
 "journal": [
  null,
  ""
 ],
 "journalctl manpage": [
  null,
  ""
 ],
 "log fields": [
  null,
  ""
 ],
 "machine": [
  null,
  ""
 ],
 "mask": [
  null,
  ""
 ],
 "memory": [
  null,
  ""
 ],
 "mitigation": [
  null,
  ""
 ],
 "network": [
  null,
  "xarxa"
 ],
 "operating system": [
  null,
  ""
 ],
 "os": [
  null,
  ""
 ],
 "path": [
  null,
  ""
 ],
 "pci": [
  null,
  ""
 ],
 "pcp": [
  null,
  ""
 ],
 "power": [
  null,
  ""
 ],
 "qualifiers": [
  null,
  ""
 ],
 "ram": [
  null,
  ""
 ],
 "restart": [
  null,
  ""
 ],
 "running $0": [
  null,
  ""
 ],
 "serial": [
  null,
  ""
 ],
 "service": [
  null,
  ""
 ],
 "shell": [
  null,
  ""
 ],
 "show less": [
  null,
  "mostra menys"
 ],
 "show more": [
  null,
  "mostra més"
 ],
 "shut": [
  null,
  ""
 ],
 "socket": [
  null,
  ""
 ],
 "ssh": [
  null,
  ""
 ],
 "systemctl": [
  null,
  ""
 ],
 "systemd": [
  null,
  ""
 ],
 "target": [
  null,
  ""
 ],
 "time": [
  null,
  ""
 ],
 "timer": [
  null,
  ""
 ],
 "unit": [
  null,
  ""
 ],
 "unknown": [
  null,
  "desconegut"
 ],
 "unmask": [
  null,
  ""
 ],
 "version": [
  null,
  ""
 ],
 "warning": [
  null,
  ""
 ],
 "<date> from <host>\u0004$0 from $1": [
  null,
  ""
 ],
 "<date> from <host> on <terminal>\u0004$0 from $1 on $2": [
  null,
  ""
 ]
});
