cockpit.locale({
 "": {'plural-forms':function(n) {
var nplurals, plural;
nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;
return plural;
},
  "language": "cs",
  "x-generator": "Weblate 4.3.2"
 },
 "$0 exited with code $1": [
  null,
  "$0 skončilo s kódem $1"
 ],
 "$0 failed": [
  null,
  "$0 se nezdařilo"
 ],
 "$0 is not available from any repository.": [
  null,
  "$0 není k dispozici z žádného z repozitářů."
 ],
 "$0 killed with signal $1": [
  null,
  "$0 vynuceně ukončeno signálem $1"
 ],
 "$0 package": [
  "$0 packages",
  "$0 balíček",
  "$0 balíčky",
  "$0 balíčků"
 ],
 "$0 package needs a system reboot": [
  "$0 packages need a system reboot",
  "",
  "",
  ""
 ],
 "$0 will be installed.": [
  null,
  "$0 bude nainstalováno."
 ],
 ", including $1 security fix": [
  ", including $1 security fixes",
  ", včetně $1 opravy zabezpečení",
  ", včetně $1 oprav zabezpečení",
  ", včetně $1 oprav zabezpečení"
 ],
 "1 minute": [
  null,
  "1 minuta"
 ],
 "20 minutes": [
  null,
  "20 minut"
 ],
 "40 minutes": [
  null,
  "40 minut"
 ],
 "5 minutes": [
  null,
  "5 minut"
 ],
 "60 minutes": [
  null,
  "60 minut"
 ],
 "A service needs to be restarted for the updates to take effect:": [
  "Some services need to be restarted for the updates to take effect:",
  "",
  "",
  ""
 ],
 "Additional packages:": [
  null,
  "Další balíčky:"
 ],
 "Applying updates": [
  null,
  "Aplikují se aktualizace"
 ],
 "Applying updates failed": [
  null,
  "Aplikace aktualizací se nezdařila"
 ],
 "Automatic updates": [
  null,
  "Automatické aktualizace"
 ],
 "Automatically using NTP": [
  null,
  "Automatické použití NTP"
 ],
 "Automatically using specific NTP servers": [
  null,
  "Automatické použití uvedených NTP serverů"
 ],
 "Available updates": [
  null,
  "Dostupné aktualizace"
 ],
 "Bug fix updates available": [
  null,
  "Jsou k dispozici aktualizace opravující zabezpečení"
 ],
 "Bugs": [
  null,
  "Chyby"
 ],
 "CVE": [
  null,
  "CVE"
 ],
 "Cancel": [
  null,
  "Storno"
 ],
 "Cannot forward login credentials": [
  null,
  "Nedaří přeposlat přístupové údaje"
 ],
 "Cannot schedule event in the past": [
  null,
  "Nelze naplánovat událost v minulosti"
 ],
 "Change": [
  null,
  "Změnit"
 ],
 "Change system time": [
  null,
  "Změnit systémový čas"
 ],
 "Check for updates": [
  null,
  "Zkontrolovat aktualizace"
 ],
 "Checking for package updates...": [
  null,
  "Zjišťování aktualizací balíčků…"
 ],
 "Checking installed software": [
  null,
  "Zjišťuje se nainstalovaný sofware"
 ],
 "Cockpit could not contact the given host.": [
  null,
  "Cockpit se nepodařilo daný stroj kontaktovat."
 ],
 "Cockpit is not compatible with the software on the system.": [
  null,
  "Cockpit není kompatibilní se softwarem v systému."
 ],
 "Cockpit is not installed on the system.": [
  null,
  "Cockpit není v systému nainstalován."
 ],
 "Connection has timed out.": [
  null,
  "Překročen časový limit připojení."
 ],
 "Danger alert:": [
  null,
  ""
 ],
 "Delay": [
  null,
  "Prodleva"
 ],
 "Details": [
  null,
  "Podrobnosti"
 ],
 "Disabled": [
  null,
  "Vypnuto"
 ],
 "Downloaded": [
  null,
  "Staženo"
 ],
 "Downloading": [
  null,
  "Stahuje se"
 ],
 "Downloading $0": [
  null,
  "Stahuje se $0"
 ],
 "Edit": [
  null,
  "Upravit"
 ],
 "Enhancement updates available": [
  null,
  "Jsou k dispozici vylepšující aktualizace"
 ],
 "Errata": [
  null,
  "Errata"
 ],
 "Error message": [
  null,
  "Chybové hlášení"
 ],
 "Failed to parse unit files for dnf-automatic.timer or dnf-automatic-install.timer. Please remove custom overrides to enable this feature.": [
  null,
  ""
 ],
 "Fridays": [
  null,
  "Pátky"
 ],
 "History package count": [
  null,
  "Počet historie balíčku"
 ],
 "Host key is incorrect": [
  null,
  "Klíč stroje není správný"
 ],
 "Hours must be a number between 0 and 23": [
  null,
  "Je třeba, aby hodina bylo číslo z rozmezí 0 až 23"
 ],
 "Ignore": [
  null,
  "Ignorovat"
 ],
 "Info": [
  null,
  ""
 ],
 "Initializing...": [
  null,
  "Inicializace…"
 ],
 "Install": [
  null,
  "Nainstalovat"
 ],
 "Install all updates": [
  null,
  "Nainstalovat všechny aktualizace"
 ],
 "Install security updates": [
  null,
  "Nainstalovat aktualizace zabezpečení"
 ],
 "Install software": [
  null,
  "Nainstalovat software"
 ],
 "Installed": [
  null,
  "Nainstalováno"
 ],
 "Installing": [
  null,
  "Instaluje se"
 ],
 "Installing $0": [
  null,
  "Instaluje se $0"
 ],
 "Internal error": [
  null,
  "Vnitřní chyba"
 ],
 "Invalid date format": [
  null,
  "Neplatný formát data"
 ],
 "Invalid date format and invalid time format": [
  null,
  "Neplatný formát data a času"
 ],
 "Invalid time format": [
  null,
  "Neplatný formát času"
 ],
 "Invalid timezone": [
  null,
  "Neplatné časové pásmo"
 ],
 "Last checked: $0": [
  null,
  "Naposledy zkontrolováno: $0"
 ],
 "Learn more": [
  null,
  "Další informace naleznete"
 ],
 "Loading available updates failed": [
  null,
  "Načtení dostupných aktualizací se nezdařilo"
 ],
 "Loading available updates, please wait...": [
  null,
  "Načítání dostupných aktualizací, čekejte…"
 ],
 "Log messages": [
  null,
  "Zprávy záznamu událostí"
 ],
 "Login failed": [
  null,
  "Přihlášení se nezdařilo"
 ],
 "Managing software updates": [
  null,
  "Správa aktualizací software"
 ],
 "Manually": [
  null,
  "Ručně"
 ],
 "Message to logged in users": [
  null,
  "Zpráva přihlášeným uživatelům"
 ],
 "Minutes must be a number between 0 and 59": [
  null,
  "Je třeba, aby minuta bylo číslo z rozmezí 0-59"
 ],
 "Mondays": [
  null,
  "Pondělky"
 ],
 "NTP server": [
  null,
  "NTP server"
 ],
 "Name": [
  null,
  "Název"
 ],
 "Need at least one NTP server": [
  null,
  "Je třeba alespoň jeden NTP server"
 ],
 "No delay": [
  null,
  "Bez prodlevy"
 ],
 "Not permitted to perform this action.": [
  null,
  "Neoprávněni k provedení této akce."
 ],
 "Not registered": [
  null,
  "Nezaregistrováno"
 ],
 "Not synchronized": [
  null,
  "Nesynchronizováno"
 ],
 "Ok": [
  null,
  "Ok"
 ],
 "Package information": [
  null,
  "Informace o balíčku"
 ],
 "PackageKit crashed": [
  null,
  "PackageKit zhavaroval"
 ],
 "PackageKit is not installed": [
  null,
  "PackageKit není nainstalovaný"
 ],
 "PackageKit reported error code $0": [
  null,
  "PackageKit ohlásilo chybový kód $0"
 ],
 "Packages": [
  null,
  "Balíčky"
 ],
 "Please reload the page after resolving the issue.": [
  null,
  ""
 ],
 "Reboot": [
  null,
  "Restartovat"
 ],
 "Reboot system...": [
  null,
  ""
 ],
 "Refreshing package information": [
  null,
  "Obnovují se informace o balíčcích"
 ],
 "Register…": [
  null,
  "Zaregistrovat…"
 ],
 "Reloading the state of remaining services": [
  null,
  ""
 ],
 "Removals:": [
  null,
  "Odebrání:"
 ],
 "Removing $0": [
  null,
  "Odebírá se $0"
 ],
 "Restarting": [
  null,
  "Restartuje se"
 ],
 "Saturdays": [
  null,
  "Soboty"
 ],
 "Security updates available": [
  null,
  "Jsou k dispozici aktualizace zabezpečení"
 ],
 "Server has closed the connection.": [
  null,
  "Server zavřel spojení."
 ],
 "Set time": [
  null,
  "Nastavit čas"
 ],
 "Set up": [
  null,
  "Nastavit"
 ],
 "Severity": [
  null,
  "Závažnost"
 ],
 "Shut down": [
  null,
  "Vypnout"
 ],
 "Software Updates": [
  null,
  "Aktualizace software"
 ],
 "Software updates": [
  null,
  "Aktualizace software"
 ],
 "Some other program is currently using the package manager, please wait...": [
  null,
  "Správa balíčků je v tuto chvíli používána nějakým jiným programem, vyčkejte…"
 ],
 "Some software needs to be restarted manually": [
  null,
  ""
 ],
 "Specific time": [
  null,
  "Konkrétní čas"
 ],
 "Status": [
  null,
  "Stav"
 ],
 "Sundays": [
  null,
  "Neděle"
 ],
 "Synchronized": [
  null,
  "Synchronizováno"
 ],
 "Synchronized with $0": [
  null,
  "Synchronizováno s $0"
 ],
 "Synchronizing": [
  null,
  "Synchronizuje se"
 ],
 "System is up to date": [
  null,
  "Systém je aktuální"
 ],
 "The following service will be restarted:": [
  "The following services will be restarted:",
  "",
  "",
  ""
 ],
 "The server refused to authenticate using any supported methods.": [
  null,
  "Server odmítl ověřit u všech podporovaných metod."
 ],
 "This host will reboot after updates are installed.": [
  null,
  ""
 ],
 "This system is not registered": [
  null,
  "Tento systém není zaregistrován"
 ],
 "Thursdays": [
  null,
  "Čtvrtky"
 ],
 "Time": [
  null,
  "Čas"
 ],
 "Time zone": [
  null,
  "Časová zóna"
 ],
 "To get software updates, this system needs to be registered with Red Hat, either using the Red Hat Customer Portal or a local subscription server.": [
  null,
  "Pro získávání aktualizací software je třeba systém zaregistrovat u Red Hat, buď pomocí Red Hat portálu pro zákazníky nebo místního serveru předplatného."
 ],
 "Too much data": [
  null,
  "Příliš mnoho dat"
 ],
 "Total size: $0": [
  null,
  "Celková velikost: $0"
 ],
 "Trying to synchronize with $0": [
  null,
  "Pokus o synchronizaci se $0"
 ],
 "Tuesdays": [
  null,
  "Úterky"
 ],
 "Type": [
  null,
  "Typ"
 ],
 "Untrusted host": [
  null,
  "Nedůvěryhodný stroj"
 ],
 "Update history": [
  null,
  "Historie aktualizací"
 ],
 "Update log": [
  null,
  "Záznam událostí aktualizací"
 ],
 "Updated": [
  null,
  "Aktualizováno"
 ],
 "Updates available": [
  null,
  "Jsou k dispozici aktualizace"
 ],
 "Updates history": [
  null,
  "Historie aktualizací"
 ],
 "Updating": [
  null,
  "Aktualizuje se"
 ],
 "Verified": [
  null,
  "Ověřeno"
 ],
 "Verifying": [
  null,
  "Ověřuje se"
 ],
 "Version": [
  null,
  "Verze"
 ],
 "Waiting for other software management operations to finish": [
  null,
  "Čeká se na dokončení ostatních operací správy balíčků"
 ],
 "Wednesdays": [
  null,
  "Středy"
 ],
 "When": [
  null,
  ""
 ],
 "When the Web Console is restarted, you will no longer see progress information. However, the update process will continue in the background. Reconnect to continue watching the update process.": [
  null,
  ""
 ],
 "Your server will close the connection soon. You can reconnect after it has restarted.": [
  null,
  "Server brzy zavře spojení. Po dokončení jeho restartu se budete moci opět připojit."
 ],
 "Your session has been terminated.": [
  null,
  "Vaše sezení bylo ukončeno."
 ],
 "Your session has expired. Please log in again.": [
  null,
  "Platnost vašeho sezení skončila. Přihlaste se znovu."
 ],
 "apt-get": [
  null,
  "apt-get"
 ],
 "at": [
  null,
  "v"
 ],
 "bug fix": [
  null,
  "oprava chyby"
 ],
 "dnf": [
  null,
  "dnf"
 ],
 "enhancement": [
  null,
  "vylepšení"
 ],
 "every day": [
  null,
  "každý den"
 ],
 "package": [
  null,
  "balíček"
 ],
 "packagekit": [
  null,
  "packagekit"
 ],
 "security": [
  null,
  "zabezpečení"
 ],
 "show less": [
  null,
  "zobrazit méně"
 ],
 "show more": [
  null,
  "zobrazit více"
 ],
 "will be applied $0 at $1": [
  null,
  ""
 ],
 "yum": [
  null,
  "yum"
 ]
});
