cockpit.locale({
 "": {'plural-forms':function(n) {
var nplurals, plural;
nplurals=2; plural=n > 1;
return plural;
},
  "language": "fr",
  "x-generator": "Weblate 4.5.1"
 },
 "$0 exited with code $1": [
  null,
  "$0 quitté avec le code $1"
 ],
 "$0 failed": [
  null,
  "$0 échoué"
 ],
 "$0 killed with signal $1": [
  null,
  "$0 killed avec un signal $1"
 ],
 "Cancel": [
  null,
  "Annuler"
 ],
 "Cannot forward login credentials": [
  null,
  "Impossible de transférer les identifiants de connexion"
 ],
 "Change performance profile": [
  null,
  "Modifier le profil de performance"
 ],
 "Change profile": [
  null,
  "Modifier le profil"
 ],
 "Cockpit could not contact the given host.": [
  null,
  "Cockpit n’a pas pu contacter l’hôte indiqué."
 ],
 "Cockpit is not compatible with the software on the system.": [
  null,
  "Cockpit n’est pas compatible avec le logiciel sur le système."
 ],
 "Cockpit is not installed on the system.": [
  null,
  "Cockpit n’est pas installé sur le système."
 ],
 "Communication with tuned has failed": [
  null,
  "La communication avec tuned a échoué"
 ],
 "Connection has timed out.": [
  null,
  "La connexion a expiré."
 ],
 "Disable tuned": [
  null,
  "Désactiver tuned"
 ],
 "Failed to disable tuned": [
  null,
  "Échec de la désactivation de « tuned »"
 ],
 "Failed to disable tuned profile": [
  null,
  "Échec de la désactivation du profil « tuned »"
 ],
 "Failed to enable tuned": [
  null,
  "Échec de l’activation de « tuned »"
 ],
 "Failed to switch profile": [
  null,
  "Échec du changement de profil"
 ],
 "Host key is incorrect": [
  null,
  "La clé de l’hôte est incorrecte"
 ],
 "Internal error": [
  null,
  "Erreur interne"
 ],
 "Learn more": [
  null,
  "En savoir plus"
 ],
 "Login failed": [
  null,
  "Échec de la connexion"
 ],
 "None": [
  null,
  "Aucun"
 ],
 "Not permitted to perform this action.": [
  null,
  "Non autorisé à effectuer cette action."
 ],
 "Ok": [
  null,
  "Ok"
 ],
 "Server has closed the connection.": [
  null,
  "Le serveur a fermé la connexion."
 ],
 "The server refused to authenticate using any supported methods.": [
  null,
  "Le serveur a refusé d’authentifier en utilisant des méthodes prises en charge."
 ],
 "This system is using a custom profile": [
  null,
  "Ce système utilise un profil personnalisé"
 ],
 "This system is using the recommended profile": [
  null,
  "Ce système utilise le profil recommandé"
 ],
 "Too much data": [
  null,
  "Trop de données"
 ],
 "Tuned has failed to start": [
  null,
  "Tuned n’a pas pu démarrer"
 ],
 "Tuned is a service that monitors your system and optimizes the performance under certain workloads. The core of Tuned are profiles, which tune your system for different use cases.": [
  null,
  "Tuned est un service qui surveille votre système et optimise les performances sous certaines charges de travail. Le cœur de Tuned est constitué de profils, qui permettent de régler votre système pour différents cas d'utilisation."
 ],
 "Tuned is not available": [
  null,
  "Tuned n’est pas disponible"
 ],
 "Tuned is not running": [
  null,
  "Tuned ne fonctionne pas"
 ],
 "Tuned is off": [
  null,
  "Tuned est désactivé"
 ],
 "Untrusted host": [
  null,
  "Hôte non sécurisé"
 ],
 "Your session has been terminated.": [
  null,
  "Votre session a été interrompue."
 ],
 "Your session has expired. Please log in again.": [
  null,
  "Votre session a expiré. Veuillez vous reconnecter."
 ],
 "active": [
  null,
  "actif"
 ],
 "none": [
  null,
  "aucun"
 ],
 "recommended": [
  null,
  "conseillé"
 ]
});
