cockpit.locale({
 "": {'plural-forms':function(n) {
var nplurals, plural;
nplurals=2; plural=n != 1;
return plural;
},
  "language": "ca",
  "x-generator": "Weblate 4.0.3"
 },
 "$0 day": [
  "$0 days",
  "$0 dia",
  "$0 dies"
 ],
 "$0 disk is missing": [
  "$0 disks are missing",
  "falta $0 disc",
  "falten $0 discs"
 ],
 "$0 exited with code $1": [
  null,
  "$0 va sortir amb el codi $1"
 ],
 "$0 failed": [
  null,
  "$0 ha fallat"
 ],
 "$0 hour": [
  "$0 hours",
  "$0 hora",
  "$0 hores"
 ],
 "$0 killed with signal $1": [
  null,
  "$0 es va matar amb el senyal $1"
 ],
 "$0 minute": [
  "$0 minutes",
  "$0 minut",
  "$0 minuts"
 ],
 "$0 month": [
  "$0 months",
  "$0 mes",
  "$0 mesos"
 ],
 "$0 week": [
  "$0 weeks",
  "$0 setmana",
  "$0 setmanes"
 ],
 "$0 year": [
  "$0 years",
  "$0 any",
  "$0 anys"
 ],
 "1 day": [
  null,
  "1 dia"
 ],
 "1 hour": [
  null,
  "1 hora"
 ],
 "1 week": [
  null,
  "1 setmana"
 ],
 "5 minutes": [
  null,
  "5 minuts"
 ],
 "6 hours": [
  null,
  "6 hores"
 ],
 "Accounts": [
  null,
  "Comptes"
 ],
 "All logs": [
  null,
  ""
 ],
 "Cancel": [
  null,
  "Cancel·la"
 ],
 "Cannot forward login credentials": [
  null,
  ""
 ],
 "Cockpit could not contact the given host.": [
  null,
  "Cockpit no ha pogut contactar amb l'amfitrió indicat."
 ],
 "Cockpit is not compatible with the software on the system.": [
  null,
  "Cockpit no és compatible amb el programari del sistema."
 ],
 "Cockpit is not installed on the system.": [
  null,
  "Cockpit no està instal·lat al sistema."
 ],
 "Connection has timed out.": [
  null,
  "La connexió ha excedit el temps."
 ],
 "Control": [
  null,
  "Control"
 ],
 "Create": [
  null,
  "Crea"
 ],
 "Development": [
  null,
  "Desenvolupament"
 ],
 "Empty": [
  null,
  "Buida"
 ],
 "Error": [
  null,
  "Error"
 ],
 "Go to now": [
  null,
  "Vés a ara"
 ],
 "Host key is incorrect": [
  null,
  "La clau d'amfitrió és incorrecta"
 ],
 "Internal error": [
  null,
  "Error intern"
 ],
 "Login failed": [
  null,
  "Ha fallat l'inici de sessió"
 ],
 "Memory": [
  null,
  "Memòria"
 ],
 "No such file or directory": [
  null,
  "No existeix el fitxer o el directori"
 ],
 "Not permitted to perform this action.": [
  null,
  "No es permet realitzar aquesta acció."
 ],
 "Not ready": [
  null,
  "No a punt"
 ],
 "Ok": [
  null,
  "D'acord"
 ],
 "Path to file": [
  null,
  "Camí al fitxer"
 ],
 "Ready": [
  null,
  "A punt"
 ],
 "Reboot": [
  null,
  "Rearrencada"
 ],
 "Server has closed the connection.": [
  null,
  "El servidor ha tancat la connexió."
 ],
 "The server refused to authenticate using any supported methods.": [
  null,
  "El servidor ha refusat l'autenticació mitjançant qualsevol dels mètodes compatibles."
 ],
 "Too much data": [
  null,
  "Hi ha massa dades"
 ],
 "Unavailable": [
  null,
  "No disponible"
 ],
 "Untrusted host": [
  null,
  "Amfitrió no fiable"
 ],
 "User": [
  null,
  "Usuari"
 ],
 "Your session has been terminated.": [
  null,
  "La vostra sessió ha estat finalitzada."
 ],
 "Your session has expired. Please log in again.": [
  null,
  "La vostra sessió ha vençut. Si us plau, torneu a iniciar la sessió."
 ],
 "[$0 bytes of binary data]": [
  null,
  "[$0 bytes de dades binàries]"
 ],
 "[binary data]": [
  null,
  "[dades binàries]"
 ],
 "[no data]": [
  null,
  "[sense dades]"
 ],
 "disk-non-rotational\u0004$0 disk is missing": [
  "$0 disks are missing",
  "falta $0 disc",
  "falten $0 discs"
 ],
 "key\u0004Control": [
  null,
  "Control"
 ],
 "verb\u0004Empty": [
  null,
  "Buit"
 ],
 "verb\u0004Ready": [
  null,
  ""
 ]
});
