cockpit.locale({
 "": {'plural-forms':function(n) {
var nplurals, plural;
nplurals=2; plural=n != 1;
return plural;
},
  "language": "nb_NO",
  "x-generator": "Weblate 4.5.1"
 },
 "$0 exited with code $1": [
  null,
  "$0 avsluttet med koden $1"
 ],
 "$0 failed": [
  null,
  "$0 feilet"
 ],
 "$0 is not available from any repository.": [
  null,
  "$0 er ikke tilgjengelig fra noe depot."
 ],
 "$0 killed with signal $1": [
  null,
  "$0 drept med signal $1"
 ],
 "$0 package": [
  "$0 packages",
  "$0 pakke",
  "$0 pakker"
 ],
 "$0 package needs a system reboot": [
  "$0 packages need a system reboot",
  "$0 pakke trenger en omstart av systemet",
  "$0 pakker trenger en omstart av systemet"
 ],
 "$0 security fix available": [
  "$0 security fixes available",
  "$0 sikkerhetsrettelse tilgjengelig",
  "$0 sikkerhetsrettelser tilgjengelig"
 ],
 "$0 service needs to be restarted": [
  "$0 services need to be restarted",
  "$o tjeneste trenger omstart",
  "$o tjenester trenger omstart"
 ],
 "$0 update available": [
  "$0 updates available",
  "$0 oppdatering tilgjengelig",
  "$0 oppdateringer tilgjengelig"
 ],
 "$0 will be installed.": [
  null,
  "$0 vil bli installert."
 ],
 ", including $1 security fix": [
  ", including $1 security fixes",
  ", inkludert $1 sikkerhetsrettelse",
  ", inkludert $1 sikkerhetsrettelser"
 ],
 "1 minute": [
  null,
  "1 minutt"
 ],
 "20 minutes": [
  null,
  "20 minutter"
 ],
 "40 minutes": [
  null,
  "40 minutter"
 ],
 "5 minutes": [
  null,
  "5 minutter"
 ],
 "60 minutes": [
  null,
  "60 minutter"
 ],
 "A package needs a system reboot for the updates to take effect:": [
  "Some packages need a system reboot for the updates to take effect:",
  "En pakke trenger en omstart av systemet for at oppdateringene skal tre i kraft:",
  "Noen pakker trenger en omstart av systemet for at oppdateringene skal tre i kraft:"
 ],
 "A service needs to be restarted for the updates to take effect:": [
  "Some services need to be restarted for the updates to take effect:",
  "En tjeneste må startes på nytt for at oppdateringene skal tre i kraft:",
  "Noen tjenester må startes på nytt for at oppdateringene skal tre i kraft:"
 ],
 "Additional packages:": [
  null,
  "Ekstra pakker:"
 ],
 "All updates": [
  null,
  "Alle oppdateringer"
 ],
 "Applying updates": [
  null,
  "Tar i bruk oppdateringer"
 ],
 "Applying updates failed": [
  null,
  "Å ta i bruk oppdateringer feilet"
 ],
 "Automatic updates": [
  null,
  "Automatiske oppdateringer"
 ],
 "Automatically using NTP": [
  null,
  "Automatisk med bruk av NTP"
 ],
 "Automatically using specific NTP servers": [
  null,
  "Automatisk med bruk av spesifikke NTP servere"
 ],
 "Available updates": [
  null,
  "Tilgjengelige oppdateringer"
 ],
 "Bug fix updates available": [
  null,
  "Feilrettingsoppdateringer tilgjengelig"
 ],
 "Bugs": [
  null,
  "Feil"
 ],
 "CVE": [
  null,
  "CVE"
 ],
 "Cancel": [
  null,
  "Avbryt"
 ],
 "Cannot forward login credentials": [
  null,
  "Kan ikke videresende påloggingsinformasjonen"
 ],
 "Cannot schedule event in the past": [
  null,
  "Kan ikke tidsplanlegge hendelse i fortiden"
 ],
 "Change": [
  null,
  "Endre"
 ],
 "Change system time": [
  null,
  "Endre systemtid"
 ],
 "Check for updates": [
  null,
  "Se etter oppdateringer"
 ],
 "Checking for package updates...": [
  null,
  "Ser etter pakkeoppdateringer ..."
 ],
 "Checking installed software": [
  null,
  "Kontrollerer installert programvare"
 ],
 "Checking software status": [
  null,
  "Kontrollerer programvarestatus"
 ],
 "Cockpit could not contact the given host.": [
  null,
  "Cockpit kunne ikke kontakte den angitte verten."
 ],
 "Cockpit is not compatible with the software on the system.": [
  null,
  "Cockpit er ikke kompatibel med programvaren på systemet."
 ],
 "Cockpit is not installed on the system.": [
  null,
  "Cockpit er ikke installert på systemet."
 ],
 "Connection has timed out.": [
  null,
  "Tidsavbrudd for tilkoblingen."
 ],
 "Continue": [
  null,
  "Fortsett"
 ],
 "Danger alert:": [
  null,
  "Farevarsel:"
 ],
 "Delay": [
  null,
  "Forsinkelse"
 ],
 "Details": [
  null,
  "Detaljer"
 ],
 "Disabled": [
  null,
  "Deaktivert"
 ],
 "Downloaded": [
  null,
  "Nedlastet"
 ],
 "Downloading": [
  null,
  "Laster ned"
 ],
 "Downloading $0": [
  null,
  "Laster ned $0"
 ],
 "Edit": [
  null,
  "Rediger"
 ],
 "Enhancement updates available": [
  null,
  "Forbedringsoppdateringer tilgjengelig"
 ],
 "Errata": [
  null,
  ""
 ],
 "Error message": [
  null,
  "Feilmelding"
 ],
 "Failed to parse unit files for dnf-automatic.timer or dnf-automatic-install.timer. Please remove custom overrides to enable this feature.": [
  null,
  ""
 ],
 "Failed to restart service": [
  null,
  "Kan ikke omstarte tjenesten"
 ],
 "Fridays": [
  null,
  "Fredager"
 ],
 "History package count": [
  null,
  ""
 ],
 "Host key is incorrect": [
  null,
  "Vertsnøkkelen er feil"
 ],
 "Hours must be a number between 0 and 23": [
  null,
  "Timer må være et tall mellom 0 og 23"
 ],
 "Ignore": [
  null,
  "Ignorer"
 ],
 "Info": [
  null,
  "Info"
 ],
 "Initializing...": [
  null,
  "Initialiserer…"
 ],
 "Install": [
  null,
  "Installer"
 ],
 "Install all updates": [
  null,
  "Installer alle oppdateringer"
 ],
 "Install security updates": [
  null,
  "Installer sikkerhetsoppdateringer"
 ],
 "Install software": [
  null,
  "Installer programvare"
 ],
 "Installed": [
  null,
  "Installert"
 ],
 "Installing": [
  null,
  "Installerer"
 ],
 "Installing $0": [
  null,
  "Installerer $0"
 ],
 "Internal error": [
  null,
  "Intern feil"
 ],
 "Invalid date format": [
  null,
  "Ugyldig datoformat"
 ],
 "Invalid date format and invalid time format": [
  null,
  "Ugyldig datoformat og ugyldig tidsformat"
 ],
 "Invalid time format": [
  null,
  "Ugyldig tidsformat"
 ],
 "Invalid timezone": [
  null,
  "Ugyldig tidssone"
 ],
 "Last checked: $0": [
  null,
  "Sist sjekket: $0"
 ],
 "Learn more": [
  null,
  "Lær mer"
 ],
 "Loading available updates failed": [
  null,
  "Lasting av tilgjengelige oppdateringer feilet"
 ],
 "Loading available updates, please wait...": [
  null,
  "Laster tilgjengelige oppdateringer, vent ..."
 ],
 "Log messages": [
  null,
  "Logg meldinger"
 ],
 "Login failed": [
  null,
  "Innlogging feilet"
 ],
 "Managing software updates": [
  null,
  "Administrere programvareoppdateringer"
 ],
 "Manually": [
  null,
  "Manuelt"
 ],
 "Message to logged in users": [
  null,
  "Melding til innloggede brukere"
 ],
 "Minutes must be a number between 0 and 59": [
  null,
  "Minutter må være et tall mellom 0 og 59"
 ],
 "Mondays": [
  null,
  "Mandager"
 ],
 "More info...": [
  null,
  "Mer info..."
 ],
 "NTP server": [
  null,
  "NTP Server"
 ],
 "Name": [
  null,
  "Navn"
 ],
 "Need at least one NTP server": [
  null,
  "Trenger minst en NTP-server"
 ],
 "No delay": [
  null,
  "Ingen forsinkelse"
 ],
 "No updates": [
  null,
  "Ingen oppdateringer"
 ],
 "Not permitted to perform this action.": [
  null,
  "Ikke tillatt å utføre denne handlingen."
 ],
 "Not registered": [
  null,
  "Ikke registrert"
 ],
 "Not synchronized": [
  null,
  "Ikke synkronisert"
 ],
 "Ok": [
  null,
  "Ok"
 ],
 "Package information": [
  null,
  "Pakkeinformasjon"
 ],
 "PackageKit crashed": [
  null,
  "PackageKit krasjet"
 ],
 "PackageKit is not installed": [
  null,
  "PackageKit er ikke installert"
 ],
 "PackageKit reported error code $0": [
  null,
  "PackageKit rapporterte feilkode $ 0"
 ],
 "Packages": [
  null,
  "Pakker"
 ],
 "Pick date": [
  null,
  "Velg dato"
 ],
 "Please reload the page after resolving the issue.": [
  null,
  "Last siden på nytt etter å ha løst problemet."
 ],
 "Reboot": [
  null,
  "Omstart"
 ],
 "Reboot recommended": [
  null,
  "Omstart anbefales"
 ],
 "Reboot system...": [
  null,
  "Omstart systemet..."
 ],
 "Refreshing package information": [
  null,
  "Oppdaterer pakkeinformasjon"
 ],
 "Register…": [
  null,
  "Registrer…"
 ],
 "Reloading the state of remaining services": [
  null,
  "Last inn tilstanden på gjenværende tjenestene"
 ],
 "Removals:": [
  null,
  ""
 ],
 "Removing $0": [
  null,
  "Fjerner $0"
 ],
 "Restart services": [
  null,
  "Omstart tjenester"
 ],
 "Restart services...": [
  null,
  "Omstart tjenester..."
 ],
 "Restarting": [
  null,
  "Omstarter"
 ],
 "Saturdays": [
  null,
  "Lørdager"
 ],
 "Save changes": [
  null,
  "Lagre endringer"
 ],
 "Security updates ": [
  null,
  "Sikkerhetsoppdateringer "
 ],
 "Security updates available": [
  null,
  "Sikkerhetsoppdateringer tilgjengelig"
 ],
 "Security updates only": [
  null,
  "Bare sikkerhetsoppdateringer"
 ],
 "Server has closed the connection.": [
  null,
  "Serveren har lukket forbindelsen."
 ],
 "Set time": [
  null,
  "Sett tid"
 ],
 "Set up": [
  null,
  "Sett opp"
 ],
 "Setting up": [
  null,
  "Setter opp"
 ],
 "Severity": [
  null,
  "Alvorlighetsgrad"
 ],
 "Shut down": [
  null,
  "Slå av"
 ],
 "Software Updates": [
  null,
  "Programvare oppdateringer"
 ],
 "Software updates": [
  null,
  "Programvare oppdateringer"
 ],
 "Some other program is currently using the package manager, please wait...": [
  null,
  "Noen andre programmer bruker for øyeblikket pakkebehandling, vent ..."
 ],
 "Some software needs to be restarted manually": [
  null,
  "Noe programvare må startes på nytt manuelt"
 ],
 "Specific time": [
  null,
  "Spesifikk tid"
 ],
 "Status": [
  null,
  "Status"
 ],
 "Sundays": [
  null,
  "Søndager"
 ],
 "Synchronized": [
  null,
  "Synkronisert"
 ],
 "Synchronized with $0": [
  null,
  "Synkronisert med $0"
 ],
 "Synchronizing": [
  null,
  "Synkroniserer"
 ],
 "System is up to date": [
  null,
  "Systemet er oppdatert"
 ],
 "The following service will be restarted:": [
  "The following services will be restarted:",
  "Følgende tjeneste startes på nytt:",
  "Følgende tjenester startes på nytt:"
 ],
 "The server refused to authenticate using any supported methods.": [
  null,
  "Serveren nektet å godkjenne ved hjelp av de støttede metodene."
 ],
 "This host will reboot after updates are installed.": [
  null,
  "Denne verten vil starte på nytt etter at oppdateringer er installert."
 ],
 "This system is not registered": [
  null,
  "Dette systemet er ikke registrert"
 ],
 "Thursdays": [
  null,
  "Torsdager"
 ],
 "Time": [
  null,
  "Tid"
 ],
 "Time zone": [
  null,
  "Tidssone"
 ],
 "To get software updates, this system needs to be registered with Red Hat, either using the Red Hat Customer Portal or a local subscription server.": [
  null,
  "For å få programvareoppdateringer, må dette systemet registreres hos Red Hat, enten ved hjelp av Red Hat Customer Portal eller en lokal abonnementsserver."
 ],
 "Too much data": [
  null,
  "For mye data"
 ],
 "Total size: $0": [
  null,
  "Total størrelse: $0"
 ],
 "Trying to synchronize with $0": [
  null,
  "Prøver å synkronisere med $0"
 ],
 "Tuesdays": [
  null,
  "Tirsdager"
 ],
 "Type": [
  null,
  "Type"
 ],
 "Untrusted host": [
  null,
  ""
 ],
 "Update Success Table": [
  null,
  ""
 ],
 "Update history": [
  null,
  "Oppdateringshistorikk"
 ],
 "Update log": [
  null,
  "Oppdateringslogg"
 ],
 "Update was successful": [
  null,
  "Oppdateringen var vellykket"
 ],
 "Updated": [
  null,
  "Oppdatert"
 ],
 "Updated packages may require a reboot to take effect.": [
  null,
  "Oppdaterte pakker kan kreve omstart for å tre i kraft."
 ],
 "Updates ": [
  null,
  "Oppdateringer "
 ],
 "Updates available": [
  null,
  "Oppdateringer tilgjengelig"
 ],
 "Updates history": [
  null,
  "Oppdateringshistorikk"
 ],
 "Updating": [
  null,
  "Oppdaterer"
 ],
 "Verified": [
  null,
  "Verifisert"
 ],
 "Verifying": [
  null,
  "Verifiserer"
 ],
 "Version": [
  null,
  "Versjon"
 ],
 "Waiting for other software management operations to finish": [
  null,
  "Venter på at andre programvareadministrasjons-operasjoner skal fullføres"
 ],
 "Web Console will restart": [
  null,
  "Web konsoll starter på nytt"
 ],
 "Wednesdays": [
  null,
  "Onsdager"
 ],
 "When": [
  null,
  "Når"
 ],
 "When the Web Console is restarted, you will no longer see progress information. However, the update process will continue in the background. Reconnect to continue watching the update process.": [
  null,
  "Når Web konsoll startes på nytt, vil du ikke lenger se fremdrifts-informasjon. Oppdateringsprosessen vil imidlertid fortsette i bakgrunnen. Koble til igjen for å fortsette å se oppdateringsprosessen."
 ],
 "Your server will close the connection soon. You can reconnect after it has restarted.": [
  null,
  "Serveren din lukker tilkoblingen snart. Du kan koble til igjen etter at den har startet på nytt."
 ],
 "Your session has been terminated.": [
  null,
  "Økten din er avsluttet."
 ],
 "Your session has expired. Please log in again.": [
  null,
  "Økten din har utløpt. Vennligst logg inn igjen."
 ],
 "apt-get": [
  null,
  "apt-get"
 ],
 "at": [
  null,
  ""
 ],
 "bug fix": [
  null,
  "feilretting"
 ],
 "dnf": [
  null,
  "dnf"
 ],
 "enhancement": [
  null,
  ""
 ],
 "every day": [
  null,
  "hver dag"
 ],
 "package": [
  null,
  "pakke"
 ],
 "packagekit": [
  null,
  "packagekit"
 ],
 "security": [
  null,
  "sikkerhet"
 ],
 "show less": [
  null,
  "vis mindre"
 ],
 "show more": [
  null,
  "vis mer"
 ],
 "will be applied $0 at $1": [
  null,
  "vil bli brukt $0 til $1"
 ],
 "yum": [
  null,
  "yum"
 ]
});
