cockpit.locale({
 "": {'plural-forms':function(n) {
var nplurals, plural;
nplurals=2; plural=n > 1;
return plural;
},
  "language": "fr",
  "x-generator": "Weblate 4.5.1"
 },
 "$0 exited with code $1": [
  null,
  "$0 quitté avec le code $1"
 ],
 "$0 failed": [
  null,
  "$0 échoué"
 ],
 "$0 is not available from any repository.": [
  null,
  "$0 n’est disponible dans aucun référentiel."
 ],
 "$0 killed with signal $1": [
  null,
  "$0 killed avec un signal $1"
 ],
 "$0 package": [
  "$0 packages",
  "$0 paquet",
  "$0 paquets"
 ],
 "$0 package needs a system reboot": [
  "$0 packages need a system reboot",
  "$0 le paquet a besoin d'un redémarrage du système",
  "$0 les paquets doivent être redémarrés"
 ],
 "$0 security fix available": [
  "$0 security fixes available",
  "$1 correctif de sécurité disponible",
  "$1 correctifs de sécurité disponibles"
 ],
 "$0 service needs to be restarted": [
  "$0 services need to be restarted",
  "$0 le service doit être relancé",
  "$0 les services doivent être redémarrés"
 ],
 "$0 update available": [
  "$0 updates available",
  "$0 mise à jour disponible",
  "$0 mises à jour disponibles"
 ],
 "$0 will be installed.": [
  null,
  "$0 sera installé."
 ],
 ", including $1 security fix": [
  ", including $1 security fixes",
  ", y compris $1 correctif de sécurité",
  ", y compris $1 correctifs de sécurité"
 ],
 "1 minute": [
  null,
  "1 minute"
 ],
 "20 minutes": [
  null,
  "20 minutes"
 ],
 "40 minutes": [
  null,
  "40 minutes"
 ],
 "5 minutes": [
  null,
  "5 minutes"
 ],
 "60 minutes": [
  null,
  "60 minutes"
 ],
 "A package needs a system reboot for the updates to take effect:": [
  "Some packages need a system reboot for the updates to take effect:",
  "Un paquet nécessite un redémarrage du système pour que les mises à jour prennent effet :",
  "Certains paquets nécessitent un redémarrage du système pour que les mises à jour prennent effet :"
 ],
 "A service needs to be restarted for the updates to take effect:": [
  "Some services need to be restarted for the updates to take effect:",
  "Un service doit être redémarré pour que les mises à jour prennent effet :",
  "Certains services doivent être redémarrés pour que les mises à jour prennent effet :"
 ],
 "Additional packages:": [
  null,
  "Paquets supplémentaires :"
 ],
 "All updates": [
  null,
  "Toutes les mises à jour"
 ],
 "Applying updates": [
  null,
  "Application des mises à jour"
 ],
 "Applying updates failed": [
  null,
  "L’application des mises à jour a échoué"
 ],
 "Automatic updates": [
  null,
  "Mises à jour automatiques"
 ],
 "Automatically using NTP": [
  null,
  "Utiliser automatiquement NTP"
 ],
 "Automatically using specific NTP servers": [
  null,
  "Utiliser automatiquement des serveurs NTP spécifiques"
 ],
 "Available updates": [
  null,
  "Mises à jour disponibles"
 ],
 "Bug fix updates available": [
  null,
  "Mises à jour des corrections de bogues disponibles"
 ],
 "Bugs": [
  null,
  "Anomalies"
 ],
 "CVE": [
  null,
  "CVE"
 ],
 "Cancel": [
  null,
  "Annuler"
 ],
 "Cannot forward login credentials": [
  null,
  "Impossible de transférer les identifiants de connexion"
 ],
 "Cannot schedule event in the past": [
  null,
  "Impossible de planifier un événement dans le passé"
 ],
 "Change": [
  null,
  "Modification"
 ],
 "Change system time": [
  null,
  "Modifier l’heure du système"
 ],
 "Check for updates": [
  null,
  "Vérifier les mises à jour"
 ],
 "Checking for package updates...": [
  null,
  "Vérification des mises à jour des paquets…"
 ],
 "Checking installed software": [
  null,
  "Vérification des logiciels installés"
 ],
 "Checking software status": [
  null,
  "Vérification de l'état des logiciels"
 ],
 "Cockpit could not contact the given host.": [
  null,
  "Cockpit n’a pas pu contacter l’hôte indiqué."
 ],
 "Cockpit is not compatible with the software on the system.": [
  null,
  "Cockpit n’est pas compatible avec le logiciel sur le système."
 ],
 "Cockpit is not installed on the system.": [
  null,
  "Cockpit n’est pas installé sur le système."
 ],
 "Connection has timed out.": [
  null,
  "La connexion a expiré."
 ],
 "Continue": [
  null,
  "Poursuivre"
 ],
 "Danger alert:": [
  null,
  "Alerte de danger :"
 ],
 "Delay": [
  null,
  "Retard"
 ],
 "Details": [
  null,
  "Détails"
 ],
 "Disabled": [
  null,
  "Désactivé"
 ],
 "Downloaded": [
  null,
  "Téléchargé"
 ],
 "Downloading": [
  null,
  "Téléchargement"
 ],
 "Downloading $0": [
  null,
  "Téléchargement $0"
 ],
 "Edit": [
  null,
  "Modifier"
 ],
 "Enhancement updates available": [
  null,
  "Mises à jour des améliorations disponibles"
 ],
 "Errata": [
  null,
  "Errata"
 ],
 "Error message": [
  null,
  "Message d'erreur"
 ],
 "Failed to parse unit files for dnf-automatic.timer or dnf-automatic-install.timer. Please remove custom overrides to enable this feature.": [
  null,
  ""
 ],
 "Failed to restart service": [
  null,
  "Échec du redémarrage du service"
 ],
 "Fridays": [
  null,
  "Vendredis"
 ],
 "History package count": [
  null,
  "Comptage des paquets d'historique"
 ],
 "Host key is incorrect": [
  null,
  "La clé de l’hôte est incorrecte"
 ],
 "Hours must be a number between 0 and 23": [
  null,
  "Les heures doivent être un nombre compris entre 0 et 23"
 ],
 "Ignore": [
  null,
  "Ignorer"
 ],
 "Info": [
  null,
  "Info"
 ],
 "Initializing...": [
  null,
  "Initialisation…"
 ],
 "Install": [
  null,
  "Installer"
 ],
 "Install all updates": [
  null,
  "Installer toutes les mises à jour"
 ],
 "Install security updates": [
  null,
  "Installer les mises à jour de sécurité"
 ],
 "Install software": [
  null,
  "Installer le logiciel"
 ],
 "Installed": [
  null,
  "installée"
 ],
 "Installing": [
  null,
  "Installation"
 ],
 "Installing $0": [
  null,
  "Installation de $0"
 ],
 "Internal error": [
  null,
  "Erreur interne"
 ],
 "Invalid date format": [
  null,
  "Format de date non valide"
 ],
 "Invalid date format and invalid time format": [
  null,
  "Format de date non valide et format d’heure non valide"
 ],
 "Invalid time format": [
  null,
  "Format d’heure non valide"
 ],
 "Invalid timezone": [
  null,
  "Fuseau horaire incorrect"
 ],
 "Last checked: $0": [
  null,
  "Dernière vérification : $0"
 ],
 "Learn more": [
  null,
  "En savoir plus"
 ],
 "Loading available updates failed": [
  null,
  "Le chargement des mises à jour disponibles a échoué"
 ],
 "Loading available updates, please wait...": [
  null,
  "Le chargement des mises à jour disponibles est en cours, veuillez patienter…"
 ],
 "Log messages": [
  null,
  "Enregistrer les messages"
 ],
 "Login failed": [
  null,
  "Échec de la connexion"
 ],
 "Managing software updates": [
  null,
  "Gestion des mises à jour logicielles"
 ],
 "Manually": [
  null,
  "Manuellement"
 ],
 "Message to logged in users": [
  null,
  "Message aux utilisateurs connectés"
 ],
 "Minutes must be a number between 0 and 59": [
  null,
  "Les minutes doivent correspondre à un nombre compris entre 0 et 59"
 ],
 "Mondays": [
  null,
  "lundis"
 ],
 "More info...": [
  null,
  "Plus d'infos..."
 ],
 "NTP server": [
  null,
  "Serveur NTP"
 ],
 "Name": [
  null,
  "Nom"
 ],
 "Need at least one NTP server": [
  null,
  "Besoin d’au moins un serveur NTP"
 ],
 "No delay": [
  null,
  "Aucun délai"
 ],
 "No updates": [
  null,
  "Pas de mise à jour"
 ],
 "Not permitted to perform this action.": [
  null,
  "Non autorisé à effectuer cette action."
 ],
 "Not registered": [
  null,
  "Non inscrit"
 ],
 "Not synchronized": [
  null,
  "Non synchronisé"
 ],
 "Ok": [
  null,
  "Ok"
 ],
 "Package information": [
  null,
  "Informations sur le paquet"
 ],
 "PackageKit crashed": [
  null,
  "Plantage de « PackageKit »"
 ],
 "PackageKit is not installed": [
  null,
  "PackageKit non installé"
 ],
 "PackageKit reported error code $0": [
  null,
  "PackageKit a signalé le code d’erreur $0"
 ],
 "Packages": [
  null,
  "Paquets"
 ],
 "Pick date": [
  null,
  "Choisissez une date"
 ],
 "Please reload the page after resolving the issue.": [
  null,
  "Veuillez recharger la page après avoir résolu le problème."
 ],
 "Reboot": [
  null,
  "Redémarrer"
 ],
 "Reboot recommended": [
  null,
  "Redémarrage recommandé"
 ],
 "Reboot system...": [
  null,
  "Redémarrer le système..."
 ],
 "Refreshing package information": [
  null,
  "Actualisation des informations sur le paquet"
 ],
 "Register…": [
  null,
  "Enregistrement…"
 ],
 "Reloading the state of remaining services": [
  null,
  "Recharger l'état des services restants"
 ],
 "Removals:": [
  null,
  "Suppressions :"
 ],
 "Removing $0": [
  null,
  "Suppression de $0"
 ],
 "Restart services": [
  null,
  "Redémarrage des services"
 ],
 "Restart services...": [
  null,
  "Redémarrer les services..."
 ],
 "Restarting": [
  null,
  "Redémarrage"
 ],
 "Saturdays": [
  null,
  "Samedis"
 ],
 "Save changes": [
  null,
  "Enregistrer les modifications"
 ],
 "Security updates ": [
  null,
  "Mises à jour de sécurité "
 ],
 "Security updates available": [
  null,
  "Mises à jour de sécurité disponibles"
 ],
 "Security updates only": [
  null,
  "Mises à jour de sécurité uniquement"
 ],
 "Server has closed the connection.": [
  null,
  "Le serveur a fermé la connexion."
 ],
 "Set time": [
  null,
  "Régler l’heure"
 ],
 "Set up": [
  null,
  "Installation"
 ],
 "Setting up": [
  null,
  "Mise en place"
 ],
 "Severity": [
  null,
  "Gravité"
 ],
 "Shut down": [
  null,
  "Fermeture"
 ],
 "Software Updates": [
  null,
  "Mises à jour logicielles"
 ],
 "Software updates": [
  null,
  "Mises à jour de logiciel"
 ],
 "Some other program is currently using the package manager, please wait...": [
  null,
  "Un autre programme utilise actuellement le gestionnaire de paquets, veuillez patienter…"
 ],
 "Some software needs to be restarted manually": [
  null,
  "Certains logiciels doivent être redémarrés manuellement"
 ],
 "Specific time": [
  null,
  "Temps spécifique"
 ],
 "Status": [
  null,
  "Statut"
 ],
 "Sundays": [
  null,
  "Dimanches"
 ],
 "Synchronized": [
  null,
  "Synchronisé"
 ],
 "Synchronized with $0": [
  null,
  "Synchronisé avec $0"
 ],
 "Synchronizing": [
  null,
  "Synchronisation"
 ],
 "System is up to date": [
  null,
  "Le système est à jour"
 ],
 "The following service will be restarted:": [
  "The following services will be restarted:",
  "Le service suivant sera redémarré :",
  "Les services suivants seront redémarrés :"
 ],
 "The server refused to authenticate using any supported methods.": [
  null,
  "Le serveur a refusé d’authentifier en utilisant des méthodes prises en charge."
 ],
 "This host will reboot after updates are installed.": [
  null,
  "Cet hôte redémarrera après l'installation des mises à jour."
 ],
 "This system is not registered": [
  null,
  "Ce système n’est pas enregistré"
 ],
 "Thursdays": [
  null,
  "Jeudis"
 ],
 "Time": [
  null,
  "Temps"
 ],
 "Time zone": [
  null,
  "Fuseau horaire"
 ],
 "To get software updates, this system needs to be registered with Red Hat, either using the Red Hat Customer Portal or a local subscription server.": [
  null,
  "Pour obtenir des mises à jour logicielles, ce système doit être enregistré auprès de Red Hat, en utilisant le portail client Red Hat ou un serveur d’abonnement local."
 ],
 "Too much data": [
  null,
  "Trop de données"
 ],
 "Total size: $0": [
  null,
  "Taille totale : $0"
 ],
 "Trying to synchronize with $0": [
  null,
  "Essaye de synchroniser avec $0"
 ],
 "Tuesdays": [
  null,
  "Mardis"
 ],
 "Type": [
  null,
  "Type"
 ],
 "Untrusted host": [
  null,
  "Hôte non sécurisé"
 ],
 "Update Success Table": [
  null,
  "Mise à jour du tableau des réussites"
 ],
 "Update history": [
  null,
  "Mise à jour Historique"
 ],
 "Update log": [
  null,
  "Journaux de la mise à jour"
 ],
 "Update was successful": [
  null,
  "La mise à jour est réussie"
 ],
 "Updated": [
  null,
  "Actualisé"
 ],
 "Updated packages may require a reboot to take effect.": [
  null,
  "Les paquets mis à jour peuvent nécessiter un redémarrage pour prendre effet."
 ],
 "Updates ": [
  null,
  "Mises à jour "
 ],
 "Updates available": [
  null,
  "Mises à jour disponibles"
 ],
 "Updates history": [
  null,
  "Historique des mises à jour"
 ],
 "Updating": [
  null,
  "Mise à jour en cours"
 ],
 "Verified": [
  null,
  "Vérifié"
 ],
 "Verifying": [
  null,
  "Vérification"
 ],
 "Version": [
  null,
  "Version"
 ],
 "Waiting for other software management operations to finish": [
  null,
  "Attente de la fin des autres opérations de gestion du logiciel"
 ],
 "Web Console will restart": [
  null,
  "La console Web va redémarrer"
 ],
 "Wednesdays": [
  null,
  "Mercredis"
 ],
 "When": [
  null,
  "Quand"
 ],
 "When the Web Console is restarted, you will no longer see progress information. However, the update process will continue in the background. Reconnect to continue watching the update process.": [
  null,
  "Lorsque la console Web est redémarrée, vous ne verrez plus les informations relatives à la progression. Toutefois, le processus de mise à jour se poursuivra en arrière-plan. Reconnectez-vous pour continuer à suivre le processus de mise à jour."
 ],
 "Your server will close the connection soon. You can reconnect after it has restarted.": [
  null,
  "Votre serveur fermera la connexion bientôt. Vous pouvez vous reconnecter après le redémarrage."
 ],
 "Your session has been terminated.": [
  null,
  "Votre session a été interrompue."
 ],
 "Your session has expired. Please log in again.": [
  null,
  "Votre session a expiré. Veuillez vous reconnecter."
 ],
 "apt-get": [
  null,
  "apt-get"
 ],
 "at": [
  null,
  "à"
 ],
 "bug fix": [
  null,
  "Correctif de bogue"
 ],
 "dnf": [
  null,
  "dnf"
 ],
 "enhancement": [
  null,
  "amélioration"
 ],
 "every day": [
  null,
  "tous les jours"
 ],
 "package": [
  null,
  "package"
 ],
 "packagekit": [
  null,
  "packagekit"
 ],
 "security": [
  null,
  "sécurité"
 ],
 "show less": [
  null,
  "montrer moins"
 ],
 "show more": [
  null,
  "montrer plus"
 ],
 "will be applied $0 at $1": [
  null,
  "sera appliqué $0 à $1"
 ],
 "yum": [
  null,
  "yum"
 ]
});
