window.cockpit_po = {
 "": {'plural-forms':function(n) {
var nplurals, plural;
nplurals=2; plural=n != 1;
return plural;
},
  "language": "ca",
  "x-generator": "Weblate 4.0.3"
 },
 "$0 error": [
  null,
  ""
 ],
 "$0 exited with code $1": [
  null,
  "$0 va sortir amb el codi $1"
 ],
 "$0 failed": [
  null,
  "$0 ha fallat"
 ],
 "$0 killed with signal $1": [
  null,
  "$0 es va matar amb el senyal $1"
 ],
 "A modern browser is required for security, reliability, and performance.": [
  null,
  ""
 ],
 "Accept key and log in": [
  null,
  ""
 ],
 "Authentication failed: Server closed connection": [
  null,
  "Ha fallat l'autenticació: el servidor ha tancat la connexió"
 ],
 "Cancel": [
  null,
  "Cancel·la"
 ],
 "Cannot forward login credentials": [
  null,
  ""
 ],
 "Changed keys are often the result of an operating system reinstallation. However, an unexpected change may indicate a third-party attempt to intercept your connection.": [
  null,
  ""
 ],
 "Cockpit": [
  null,
  "Cockpit"
 ],
 "Cockpit authentication is configured incorrectly.": [
  null,
  "L'autenticació de Cockpit està configurada incorrectament."
 ],
 "Cockpit could not contact the given host.": [
  null,
  "Cockpit no ha pogut contactar amb l'amfitrió indicat."
 ],
 "Cockpit is a server manager that makes it easy to administer your Linux servers via a web browser. Jumping between the terminal and the web tool is no problem. A service started via Cockpit can be stopped via the terminal. Likewise, if an error occurs in the terminal, it can be seen in the Cockpit journal interface.": [
  null,
  "Cockpit és una eina de gestió de servidors que facilita l'administració dels vostres servidors Linux a través d'un navegador web. Saltar entre el terminal i l'eina web no és cap problema. Un servei iniciat a través de Cockpit es pot aturar a través del terminal. De la mateixa manera, si es produeix un error en el terminal, es pot observar en la interfície de les publicacions de Cockpit."
 ],
 "Cockpit is not compatible with the software on the system.": [
  null,
  "Cockpit no és compatible amb el programari del sistema."
 ],
 "Cockpit is not installed on the system.": [
  null,
  "Cockpit no està instal·lat al sistema."
 ],
 "Cockpit is perfect for new sysadmins, allowing them to easily perform simple tasks such as storage administration, inspecting journals and starting and stopping services. You can monitor and administer several servers at the same time. Just add them with a single click and your machines will look after its buddies.": [
  null,
  "Cockpit és perfecte per als nous administradors de sistemes, els permet realitzar fàcilment les tasques senzilles com ara l'administració de l'emmagatzematge, la inspecció de les publicacions i iniciar i aturar els serveis. Podeu monitorar i administrar diversos servidors a la vegada. Només heu d'afegir-los amb tan sols un clic i les vostres màquines es veuran al cantó de les altres."
 ],
 "Connect to": [
  null,
  "Connecta't a"
 ],
 "Connection has timed out.": [
  null,
  "La connexió ha excedit el temps."
 ],
 "Download a new browser for free": [
  null,
  ""
 ],
 "Host key is incorrect": [
  null,
  "La clau d'amfitrió és incorrecta"
 ],
 "If the fingerprint matches, click \"Accept key and log in\". Otherwise, do not log in and contact your administrator.": [
  null,
  ""
 ],
 "Internal error": [
  null,
  "Error intern"
 ],
 "Internal error: Invalid challenge header": [
  null,
  ""
 ],
 "Log in": [
  null,
  "Inicia la sessió"
 ],
 "Log in with your server user account.": [
  null,
  ""
 ],
 "Login again": [
  null,
  "Torna a iniciar la sessió"
 ],
 "Login failed": [
  null,
  "Ha fallat l'inici de sessió"
 ],
 "Logout successful": [
  null,
  "S'ha tancat la sessió amb èxit"
 ],
 "Not permitted to perform this action.": [
  null,
  "No es permet realitzar aquesta acció."
 ],
 "Once Cockpit is installed, enable it with \"systemctl enable --now cockpit.socket\".": [
  null,
  ""
 ],
 "Or use a bundled browser": [
  null,
  ""
 ],
 "Other options": [
  null,
  "Altres opcions"
 ],
 "Password": [
  null,
  "Contrasenya"
 ],
 "Permission denied": [
  null,
  "Permís denegat"
 ],
 "Please enable JavaScript to use the Web Console.": [
  null,
  ""
 ],
 "Please specify the host to connect to": [
  null,
  ""
 ],
 "Refusing to connect. Host is unknown": [
  null,
  "Es nega a connectar. L'amfitrió és desconegut"
 ],
 "Refusing to connect. Hostkey does not match": [
  null,
  "Es nega a connectar. La clau d'amfitrió no coincideix"
 ],
 "Refusing to connect. Hostkey is unknown": [
  null,
  "Es nega a connectar. La clau d'amfitrió és desconeguda"
 ],
 "Server": [
  null,
  "Servidor"
 ],
 "Server has closed the connection.": [
  null,
  "El servidor ha tancat la connexió."
 ],
 "The resulting fingerprint is fine to share via public methods, including email.": [
  null,
  ""
 ],
 "The server refused to authenticate '$0' using password authentication, and no other supported authentication methods are available.": [
  null,
  ""
 ],
 "The server refused to authenticate using any supported methods.": [
  null,
  "El servidor ha refusat l'autenticació mitjançant qualsevol dels mètodes compatibles."
 ],
 "The web browser configuration prevents Cockpit from running (inaccessible $0)": [
  null,
  "La configuració del navegador web impedeix que s'executi Cockpit (inaccessible $0)"
 ],
 "To ensure that your connection is not intercepted by a malicious third-party, please verify the host key fingerprint:": [
  null,
  ""
 ],
 "To verify a fingerprint, run the following on $0 while physically sitting at the machine or through a trusted network:": [
  null,
  ""
 ],
 "Too much data": [
  null,
  "Hi ha massa dades"
 ],
 "Try again": [
  null,
  "Torna-ho a intentar"
 ],
 "Unable to connect to that address": [
  null,
  "No es pot connectar a aquesta adreça"
 ],
 "Untrusted host": [
  null,
  "Amfitrió no fiable"
 ],
 "User name": [
  null,
  "Nom d'usuari"
 ],
 "User name cannot be empty": [
  null,
  "El nom d'usuari no pot estar en blanc"
 ],
 "Validating authentication token": [
  null,
  "Validació del testimoni d'autenticació"
 ],
 "Web Console for Linux servers": [
  null,
  ""
 ],
 "Wrong user name or password": [
  null,
  "Contrasenya o nom d'usuari incorrecte"
 ],
 "You are connecting to $0 for the first time.": [
  null,
  ""
 ],
 "Your session has been terminated.": [
  null,
  "La vostra sessió ha estat finalitzada."
 ],
 "Your session has expired. Please log in again.": [
  null,
  "La vostra sessió ha vençut. Si us plau, torneu a iniciar la sessió."
 ]
};
