// we don't want the list of pages to overflow our dialog
#active-pages-dialog .modal-body {
    overflow-y: auto;
    max-height: 340px;
    padding: 0;
    border: 1px solid $pf-color-black-300;
}

// don't waste space over the table
#active-pages-dialog table.listing {
    margin-top: 0;
}
