cockpit.locale({
 "": {'plural-forms':function(n) {
var nplurals, plural;
nplurals=2; plural=n != 1;
return plural;
},
  "language": "nb_NO",
  "x-generator": "Weblate 4.5.1"
 },
 "$0 critical hit": [
  "$0 hits, including critical",
  "$0 kritisk treff",
  "$0 treff, inkludert kritiske"
 ],
 "$0 exited with code $1": [
  null,
  "$0 avsluttet med koden $1"
 ],
 "$0 failed": [
  null,
  "$0 feilet"
 ],
 "$0 important hit": [
  "$0 hits, including important",
  "$0 viktig treff",
  "$0 viktige treff"
 ],
 "$0 is not available from any repository.": [
  null,
  "$0 er ikke tilgjengelig fra noe depot."
 ],
 "$0 killed with signal $1": [
  null,
  "$0 drept med signal $1"
 ],
 "$0 low severity hit": [
  "$0 low severity hits",
  "$0 treff med lav alvorlighetsgrad",
  "$0 treff med lave alvorlighetsgrader"
 ],
 "$0 moderate hit": [
  "$0 hits, including moderate",
  "$0 moderat treff",
  "$0 moderate treff"
 ],
 "$0 service has failed": [
  "$0 services have failed",
  "$0 tjeneste har feilet",
  "$0 tjenester har feilet"
 ],
 "$0 will be installed.": [
  null,
  "$0 vil bli installert."
 ],
 "$0: crash at $1": [
  null,
  "$0: krasj på $1"
 ],
 "1 minute": [
  null,
  "1 minutt"
 ],
 "10th": [
  null,
  "10."
 ],
 "11th": [
  null,
  "11."
 ],
 "12th": [
  null,
  "12."
 ],
 "13th": [
  null,
  "13."
 ],
 "14th": [
  null,
  "14."
 ],
 "15th": [
  null,
  "15."
 ],
 "16th": [
  null,
  "16."
 ],
 "17th": [
  null,
  "17."
 ],
 "18th": [
  null,
  "18."
 ],
 "19th": [
  null,
  "19."
 ],
 "1st": [
  null,
  "1."
 ],
 "20 minutes": [
  null,
  "20 minutter"
 ],
 "20th": [
  null,
  "20."
 ],
 "21th": [
  null,
  "21."
 ],
 "22th": [
  null,
  "22."
 ],
 "23th": [
  null,
  "23."
 ],
 "24th": [
  null,
  "24."
 ],
 "25th": [
  null,
  "25."
 ],
 "26th": [
  null,
  "26."
 ],
 "27th": [
  null,
  "27."
 ],
 "28th": [
  null,
  "28."
 ],
 "29th": [
  null,
  "29."
 ],
 "2nd": [
  null,
  "2."
 ],
 "30th": [
  null,
  "30."
 ],
 "31st": [
  null,
  "31."
 ],
 "3rd": [
  null,
  "3."
 ],
 "40 minutes": [
  null,
  "40 minutter"
 ],
 "4th": [
  null,
  "4."
 ],
 "5 minutes": [
  null,
  "5 minutter"
 ],
 "5th": [
  null,
  "5."
 ],
 "60 minutes": [
  null,
  "60 minutter"
 ],
 "6th": [
  null,
  "6."
 ],
 "7th": [
  null,
  "7."
 ],
 "8th": [
  null,
  "8."
 ],
 "9th": [
  null,
  "9."
 ],
 "Absent": [
  null,
  "Fraværende"
 ],
 "Active since ": [
  null,
  "Aktiv siden "
 ],
 "Add": [
  null,
  "Legg til"
 ],
 "Additional actions": [
  null,
  "Ekstra handlinger"
 ],
 "Additional packages:": [
  null,
  "Ekstra pakker:"
 ],
 "Administrative access": [
  null,
  "Administrativ tilgang"
 ],
 "Administrator password": [
  null,
  "Administratorpassord"
 ],
 "Advanced TCA": [
  null,
  "Avansert TCA"
 ],
 "After": [
  null,
  "Etter"
 ],
 "After leaving the domain, only users with local credentials will be able to log into this machine. This may also affect other services as DNS resolution settings and the list of trusted CAs may change.": [
  null,
  "Etter å ha forlatt domenet, er det bare brukere med lokal legitimasjon som kan logge på denne maskinen. Dette kan også påvirke andre tjenester ettersom innstillinger for DNS-oppløsning og listen over klarerte CAer kan endres."
 ],
 "After system boot": [
  null,
  "Etter systemstart"
 ],
 "Alert and above": [
  null,
  "Varsel og over"
 ],
 "All": [
  null,
  "Alle"
 ],
 "All logs": [
  null,
  "Alle logger"
 ],
 "All-in-one": [
  null,
  "Alt i ett"
 ],
 "Allow running (unmask)": [
  null,
  "Tillat å kjøre (umaskert)"
 ],
 "Appearance": [
  null,
  "Utseende"
 ],
 "Asset tag": [
  null,
  "Eiendomsmerke"
 ],
 "At specific time": [
  null,
  "På et bestemt tidspunkt"
 ],
 "Authenticate": [
  null,
  "Autentiser"
 ],
 "Authentication": [
  null,
  "Autentisering"
 ],
 "Automatic": [
  null,
  "Automatisk"
 ],
 "Automatically starts": [
  null,
  "Starter automatisk"
 ],
 "Automatically using NTP": [
  null,
  "Automatisk med bruk av NTP"
 ],
 "Automatically using specific NTP servers": [
  null,
  "Automatisk med bruk av spesifikke NTP servere"
 ],
 "BIOS": [
  null,
  "BIOS"
 ],
 "BIOS date": [
  null,
  "BIOS dato"
 ],
 "BIOS version": [
  null,
  "BIOS versjon"
 ],
 "Before": [
  null,
  "Før"
 ],
 "Binds to": [
  null,
  "Binder seg til"
 ],
 "Black": [
  null,
  "Svart"
 ],
 "Blade": [
  null,
  "Blad"
 ],
 "Blade enclosure": [
  null,
  "Blad-kabinett"
 ],
 "Bound by": [
  null,
  "Bundet av"
 ],
 "Bus expansion chassis": [
  null,
  ""
 ],
 "CPU": [
  null,
  "CPU"
 ],
 "CPU security": [
  null,
  "CPU-sikkerhet"
 ],
 "CPU security toggles": [
  null,
  ""
 ],
 "Can not find any logs using the current combination of filters.": [
  null,
  "Finner ingen logger med den nåværende kombinasjonen av filtre."
 ],
 "Cancel": [
  null,
  "Avbryt"
 ],
 "Cannot be enabled": [
  null,
  "Kan ikke aktiveres"
 ],
 "Cannot forward login credentials": [
  null,
  "Kan ikke videresende påloggingsinformasjonen"
 ],
 "Cannot join a domain because realmd is not available on this system": [
  null,
  "Kan ikke bli med i et domene fordi realmd ikke er tilgjengelig på dette systemet"
 ],
 "Cannot schedule event in the past": [
  null,
  "Kan ikke tidsplanlegge hendelse i fortiden"
 ],
 "Change": [
  null,
  "Endre"
 ],
 "Change host name": [
  null,
  "Endre vertsnavn"
 ],
 "Change system time": [
  null,
  "Endre systemtid"
 ],
 "Checking installed software": [
  null,
  "Kontrollerer installert programvare"
 ],
 "Class": [
  null,
  "Klasse"
 ],
 "Clear 'Failed to start'": [
  null,
  "Fjern 'Kunne ikke starte'"
 ],
 "Clear all filters": [
  null,
  "Fjern alle filtre"
 ],
 "Client software": [
  null,
  "Klient programvare"
 ],
 "Close": [
  null,
  "Lukk"
 ],
 "Cockpit could not contact the given host.": [
  null,
  "Cockpit kunne ikke kontakte den angitte verten."
 ],
 "Cockpit is not compatible with the software on the system.": [
  null,
  "Cockpit er ikke kompatibel med programvaren på systemet."
 ],
 "Cockpit is not installed on the system.": [
  null,
  "Cockpit er ikke installert på systemet."
 ],
 "Command": [
  null,
  "Kommando"
 ],
 "Compact PCI": [
  null,
  ""
 ],
 "Computer OU": [
  null,
  "Datamaskin OU"
 ],
 "Condition $0=$1 was not met": [
  null,
  "Betingelse $0=$1 ble ikke oppfylt"
 ],
 "Condition failed": [
  null,
  "Betingelse feilet"
 ],
 "Configuration": [
  null,
  "Konfigurasjon"
 ],
 "Configuring system settings": [
  null,
  "Konfigurere systeminnstillinger"
 ],
 "Conflicted by": [
  null,
  ""
 ],
 "Conflicts": [
  null,
  "Konflikter"
 ],
 "Connection has timed out.": [
  null,
  "Tidsavbrudd for tilkoblingen."
 ],
 "Consists of": [
  null,
  "Består av"
 ],
 "Contacted domain": [
  null,
  "Kontaktet domene"
 ],
 "Convertible": [
  null,
  "Konverterbar"
 ],
 "Copy": [
  null,
  "Kopier"
 ],
 "Crash reporting": [
  null,
  "Krasjrapportering"
 ],
 "Create timer": [
  null,
  "Lag timer"
 ],
 "Create timers": [
  null,
  "Lag timere"
 ],
 "Critical and above": [
  null,
  "Kritisk og over"
 ],
 "Ctrl+Insert": [
  null,
  "Ctrl+Insert"
 ],
 "Current boot": [
  null,
  "Nåværende oppstart"
 ],
 "Daily": [
  null,
  "Daglig"
 ],
 "Dark": [
  null,
  "Mørk"
 ],
 "Debug and above": [
  null,
  "Debug og over"
 ],
 "Decrease by one": [
  null,
  "Reduser med en"
 ],
 "Delay": [
  null,
  "Forsinkelse"
 ],
 "Delete": [
  null,
  "Slett"
 ],
 "Description": [
  null,
  "Beskrivelse"
 ],
 "Desktop": [
  null,
  ""
 ],
 "Detachable": [
  null,
  ""
 ],
 "Disable simultaneous multithreading": [
  null,
  "Deaktiver samtidig multitråding"
 ],
 "Disabled": [
  null,
  "Deaktivert"
 ],
 "Disallow running (mask)": [
  null,
  "Ikke tillat å kjøre (masker)"
 ],
 "Docking station": [
  null,
  "Dokkingstasjon"
 ],
 "Does not automatically start": [
  null,
  "Starter ikke automatisk"
 ],
 "Domain": [
  null,
  "Domene"
 ],
 "Domain $0 could not be contacted": [
  null,
  "Domene $0 kunne ikke kontaktes"
 ],
 "Domain $0 is not supported": [
  null,
  "Domene $0 støttes ikke"
 ],
 "Domain address": [
  null,
  "Domene adresse"
 ],
 "Domain administrator name": [
  null,
  "Domene administratornavn"
 ],
 "Domain administrator password": [
  null,
  "Domeneadministrator passord"
 ],
 "Don't repeat": [
  null,
  "Ikke gjenta"
 ],
 "Downloading $0": [
  null,
  "Laster ned $0"
 ],
 "Dual rank": [
  null,
  "Dobbel rangering"
 ],
 "Edit /etc/motd": [
  null,
  "Rediger /etc/motd"
 ],
 "Edit motd": [
  null,
  "Rediger motd"
 ],
 "Embedded PC": [
  null,
  "Innebygd PC"
 ],
 "Enable stored metrics": [
  null,
  "Aktiver lagret metrikk"
 ],
 "Enabled": [
  null,
  "Aktivert"
 ],
 "Entry at $0": [
  null,
  "Oppføring på $0"
 ],
 "Error": [
  null,
  "Feil"
 ],
 "Error and above": [
  null,
  "Feil og over"
 ],
 "Error message": [
  null,
  "Feilmelding"
 ],
 "Expansion chassis": [
  null,
  ""
 ],
 "Extended information": [
  null,
  "Utvidet informasjon"
 ],
 "Failed to save changes in /etc/motd": [
  null,
  "Kunne ikke lagre endringene i /etc/motd"
 ],
 "Failed to start": [
  null,
  "Kunne ikke starte"
 ],
 "Filter": [
  null,
  "Filter"
 ],
 "Filter by name or description": [
  null,
  "Filtrer etter navn eller beskrivelse"
 ],
 "Font size": [
  null,
  "Skriftstørrelse"
 ],
 "Forbidden from running": [
  null,
  "Forbudt å kjøre"
 ],
 "Frame number": [
  null,
  ""
 ],
 "Fridays": [
  null,
  "Fredager"
 ],
 "General": [
  null,
  "Generelt"
 ],
 "Go to $0": [
  null,
  "Gå til $0"
 ],
 "Handheld": [
  null,
  "Håndholdt"
 ],
 "Hardware information": [
  null,
  "Maskinvareinformasjon"
 ],
 "Health": [
  null,
  "Helse"
 ],
 "Hide filters": [
  null,
  "Skjul filtre"
 ],
 "Host key is incorrect": [
  null,
  "Vertsnøkkelen er feil"
 ],
 "Host name should not be changed in a domain": [
  null,
  "Vertsnavnet skal ikke endres i et domene"
 ],
 "Hostname": [
  null,
  "Vertsnavn"
 ],
 "Hourly": [
  null,
  "Hver time"
 ],
 "Hours": [
  null,
  "Timer"
 ],
 "Hours must be a number between 0 and 23": [
  null,
  "Timer må være et tall mellom 0 og 23"
 ],
 "ID": [
  null,
  "ID"
 ],
 "Identifier": [
  null,
  "Identifikator"
 ],
 "Increase by one": [
  null,
  "Øk med en"
 ],
 "Info and above": [
  null,
  "Info og over"
 ],
 "Insights: ": [
  null,
  "Innsikt: "
 ],
 "Install": [
  null,
  "Installer"
 ],
 "Install software": [
  null,
  "Installer programvare"
 ],
 "Installing $0": [
  null,
  "Installerer $0"
 ],
 "Internal error": [
  null,
  "Intern feil"
 ],
 "Invalid date format": [
  null,
  "Ugyldig datoformat"
 ],
 "Invalid date format and invalid time format": [
  null,
  "Ugyldig datoformat og ugyldig tidsformat"
 ],
 "Invalid time format": [
  null,
  "Ugyldig tidsformat"
 ],
 "Invalid timezone": [
  null,
  "Ugyldig tidssone"
 ],
 "IoT gateway": [
  null,
  "IoT-gateway"
 ],
 "Join": [
  null,
  "Bli med"
 ],
 "Join a domain": [
  null,
  "Bli med i et domene"
 ],
 "Join domain": [
  null,
  "Bli med i domene"
 ],
 "Joining a domain requires installation of realmd": [
  null,
  "Å bli med i et domene krever installasjon av realmd"
 ],
 "Joining this domain is not supported": [
  null,
  "Å bli med i dette domenet støttes ikke"
 ],
 "Joins namespace of": [
  null,
  ""
 ],
 "Journal": [
  null,
  "Journal"
 ],
 "Journal entry": [
  null,
  "Journaloppføring"
 ],
 "Journal entry not found": [
  null,
  "Journaloppføring ikke funnet"
 ],
 "Laptop": [
  null,
  ""
 ],
 "Last 24 hours": [
  null,
  "Siste 24 timer"
 ],
 "Last 7 days": [
  null,
  "Siste 7 dager"
 ],
 "Last failed login:": [
  null,
  "Siste feilede pålogging:"
 ],
 "Last login:": [
  null,
  "Siste innlogging:"
 ],
 "Learn more": [
  null,
  "Lær mer"
 ],
 "Leave domain": [
  null,
  "Forlat domene"
 ],
 "Light": [
  null,
  "Lys"
 ],
 "Limit access": [
  null,
  "Begrens tilgang"
 ],
 "Limited access": [
  null,
  "Begrenset tilgang"
 ],
 "Limited access mode restricts administrative privileges. Some parts of the web console will have reduced functionality.": [
  null,
  "Begrenset tilgangsmodus begrenser administrative rettigheter. Noen deler av webkonsollet har redusert funksjonalitet."
 ],
 "Load earlier entries": [
  null,
  "Last tidligere oppføringer"
 ],
 "Loading keys...": [
  null,
  "Laster nøkler..."
 ],
 "Loading of SSH keys failed": [
  null,
  "Lasting av SSH-nøkler feilet"
 ],
 "Loading...": [
  null,
  "Laster..."
 ],
 "Log messages": [
  null,
  "Logg meldinger"
 ],
 "Login failed": [
  null,
  "Innlogging feilet"
 ],
 "Login format": [
  null,
  ""
 ],
 "Logs": [
  null,
  "Logger"
 ],
 "Low profile desktop": [
  null,
  ""
 ],
 "Lunch box": [
  null,
  "Lunsjboks"
 ],
 "Machine ID": [
  null,
  "Maskin ID"
 ],
 "Machine SSH key fingerprints": [
  null,
  "Fingeravtrykk for maskinens SSH-nøkler"
 ],
 "Main server chassis": [
  null,
  ""
 ],
 "Managing services": [
  null,
  "Administrere tjenester"
 ],
 "Manually": [
  null,
  "Manuelt"
 ],
 "Mask service": [
  null,
  "Masker tjeneste"
 ],
 "Masked": [
  null,
  "Maskert"
 ],
 "Masking service prevents all dependent units from running. This can have bigger impact than anticipated. Please confirm that you want to mask this unit.": [
  null,
  "Maskering av en tjeneste forhindrer alle avhengige enheter fra å kjøre. Dette kan ha større innvirkning enn forventet. Vennligst bekreft at du vil maskere denne enheten."
 ],
 "Memory": [
  null,
  "Minne"
 ],
 "Memory technology": [
  null,
  "Minneteknologi"
 ],
 "Message to logged in users": [
  null,
  "Melding til innloggede brukere"
 ],
 "Method": [
  null,
  "Metode"
 ],
 "Mini PC": [
  null,
  "Mini-PC"
 ],
 "Mini tower": [
  null,
  ""
 ],
 "Minute needs to be a number between 0-59": [
  null,
  "Minutt må være et tall mellom 0-59"
 ],
 "Minutes": [
  null,
  "Minutter"
 ],
 "Minutes must be a number between 0 and 59": [
  null,
  "Minutter må være et tall mellom 0 og 59"
 ],
 "Mitigations": [
  null,
  ""
 ],
 "Model": [
  null,
  "Modell"
 ],
 "Mondays": [
  null,
  "Mandager"
 ],
 "Monthly": [
  null,
  "Månedlig"
 ],
 "More": [
  null,
  "Mer"
 ],
 "Multi-system chassis": [
  null,
  ""
 ],
 "NTP server": [
  null,
  "NTP Server"
 ],
 "Name": [
  null,
  "Navn"
 ],
 "Need at least one NTP server": [
  null,
  "Trenger minst en NTP-server"
 ],
 "Next": [
  null,
  "Neste"
 ],
 "No": [
  null,
  "Nei"
 ],
 "No delay": [
  null,
  "Ingen forsinkelse"
 ],
 "No host keys found.": [
  null,
  "Ingen vertsnøkler funnet."
 ],
 "No log entries": [
  null,
  "Ingen loggoppføringer"
 ],
 "No logs found": [
  null,
  "Ingen logger funnet"
 ],
 "No matching results": [
  null,
  "Ingen samsvarende resultater"
 ],
 "No results match the filter criteria. Clear all filters to show results.": [
  null,
  "Ingen resultater samsvarer med filterkriteriene. Fjern alle filtre for å vise resultater."
 ],
 "No rule hits": [
  null,
  "Ingen regel treff"
 ],
 "Not connected to Insights": [
  null,
  "Ikke koblet til Insights"
 ],
 "Not joined": [
  null,
  ""
 ],
 "Not permitted to perform this action.": [
  null,
  "Ikke tillatt å utføre denne handlingen."
 ],
 "Not running": [
  null,
  "Kjører ikke"
 ],
 "Not synchronized": [
  null,
  "Ikke synkronisert"
 ],
 "Note": [
  null,
  "Notat"
 ],
 "Notebook": [
  null,
  ""
 ],
 "Notice and above": [
  null,
  "Notis og over"
 ],
 "Ok": [
  null,
  "Ok"
 ],
 "On failure": [
  null,
  "Ved feil"
 ],
 "One time password": [
  null,
  "Engangspassord"
 ],
 "Only alphabets, numbers, : , _ , . , @ , - are allowed": [
  null,
  "Bare biokstaver, tall,:, _,. , @ , - er tillatt"
 ],
 "Only emergency": [
  null,
  "Bare nødsituasjon"
 ],
 "Other": [
  null,
  "Annen"
 ],
 "Overview": [
  null,
  "Oversikt"
 ],
 "PCI": [
  null,
  "PCI"
 ],
 "PCP": [
  null,
  "PCP"
 ],
 "PackageKit crashed": [
  null,
  "PackageKit krasjet"
 ],
 "Part of": [
  null,
  "Del av"
 ],
 "Password": [
  null,
  "Passord"
 ],
 "Paste": [
  null,
  "Lim inn"
 ],
 "Path": [
  null,
  "Sti"
 ],
 "Paths": [
  null,
  "Stier"
 ],
 "Pause": [
  null,
  "Pause"
 ],
 "Performance profile": [
  null,
  "Ytelsesprofil"
 ],
 "Peripheral chassis": [
  null,
  "Perifert chassis"
 ],
 "Pick date": [
  null,
  "Velg dato"
 ],
 "Pizza box": [
  null,
  "Pizzaboks"
 ],
 "Please authenticate to gain administrative access": [
  null,
  "Autentiser for å få administrativ tilgang"
 ],
 "Portable": [
  null,
  "Bærbar"
 ],
 "Present": [
  null,
  "Til stede"
 ],
 "Pretty host name": [
  null,
  "\"Pent\" vertsnavn"
 ],
 "Previous boot": [
  null,
  "Forrige oppstart"
 ],
 "Priority": [
  null,
  "Prioritet"
 ],
 "Problem details": [
  null,
  "Problemdetaljer"
 ],
 "Problem info": [
  null,
  "Problem info"
 ],
 "Propagates reload to": [
  null,
  "Videreformidler omlasting til"
 ],
 "RAID chassis": [
  null,
  "RAID chassis"
 ],
 "Rack mount chassis": [
  null,
  ""
 ],
 "Rank": [
  null,
  ""
 ],
 "Read more...": [
  null,
  "Les mer…"
 ],
 "Read-only": [
  null,
  "Skrivebeskyttet"
 ],
 "Real host name": [
  null,
  "Faktisk vertsnavn"
 ],
 "Real host name can only contain lower-case characters, digits, dashes, and periods (with populated subdomains)": [
  null,
  "Faktisk vertsnavn kan bare inneholde små bokstaver, sifre, bindestreker og punktum (med befolket underdomener)"
 ],
 "Real host name must be 64 characters or less": [
  null,
  "Faktisk vertsnavn må være på 64 tegn eller mindre"
 ],
 "Reboot": [
  null,
  "Omstart"
 ],
 "Reload": [
  null,
  "Last på nytt"
 ],
 "Reload propagated from": [
  null,
  "Last videreformidlet fra"
 ],
 "Removals:": [
  null,
  ""
 ],
 "Remove": [
  null,
  "Fjern"
 ],
 "Removing $0": [
  null,
  "Fjerner $0"
 ],
 "Repeat": [
  null,
  "Gjenta"
 ],
 "Repeat monthly": [
  null,
  "Gjenta månedlig"
 ],
 "Repeat weekly": [
  null,
  "Gjenta ukentlig"
 ],
 "Report": [
  null,
  "Rapport"
 ],
 "Report to ABRT Analytics": [
  null,
  "Rapporter til ABRT Analytics"
 ],
 "Reported; no links available": [
  null,
  "Rapportert; ingen lenker tilgjengelig"
 ],
 "Reporting failed": [
  null,
  "Rapportering feilet"
 ],
 "Reporting was canceled": [
  null,
  "Rapportering ble kansellert"
 ],
 "Reports:": [
  null,
  "Rapporter:"
 ],
 "Required by": [
  null,
  "Kreves av"
 ],
 "Required by ": [
  null,
  "Kreves av "
 ],
 "Requires": [
  null,
  "Krever"
 ],
 "Requires administration access to edit": [
  null,
  "Krever administrasjonstilgang for å redigere"
 ],
 "Requisite": [
  null,
  "Nødvendig"
 ],
 "Requisite of": [
  null,
  ""
 ],
 "Reset": [
  null,
  "Tilbakestill"
 ],
 "Restart": [
  null,
  "Omstart"
 ],
 "Resume": [
  null,
  "Gjenoppta"
 ],
 "Reviewing logs": [
  null,
  ""
 ],
 "Run": [
  null,
  "Kjør"
 ],
 "Running": [
  null,
  "Kjører"
 ],
 "Saturdays": [
  null,
  "Lørdager"
 ],
 "Save": [
  null,
  "Lagre"
 ],
 "Save and reboot": [
  null,
  "Lagre og start på nytt"
 ],
 "Save changes": [
  null,
  "Lagre endringer"
 ],
 "Sealed-case PC": [
  null,
  ""
 ],
 "Search the logs with a combination of terms:": [
  null,
  "Søk i loggene med en kombinasjon av termer:"
 ],
 "Seconds": [
  null,
  "Sekunder"
 ],
 "Secure shell keys": [
  null,
  "Secure Shell nøkler"
 ],
 "Select unit state": [
  null,
  ""
 ],
 "Send": [
  null,
  "Send"
 ],
 "Server has closed the connection.": [
  null,
  "Serveren har lukket forbindelsen."
 ],
 "Server software": [
  null,
  "Server programvare"
 ],
 "Service logs": [
  null,
  "Tjenestelogger"
 ],
 "Service name": [
  null,
  "Tjeneste navn"
 ],
 "Services": [
  null,
  "Tjenester"
 ],
 "Set hostname": [
  null,
  "Sett vertsnavn"
 ],
 "Set time": [
  null,
  "Sett tid"
 ],
 "Shift+Insert": [
  null,
  "Shift+Insert"
 ],
 "Show all threads": [
  null,
  "Vis alle tråder"
 ],
 "Show filters": [
  null,
  "Vis filtre"
 ],
 "Show fingerprints": [
  null,
  "Vis fingeravtrykk"
 ],
 "Shut down": [
  null,
  "Slå av"
 ],
 "Shutdown": [
  null,
  "Slå av"
 ],
 "Single rank": [
  null,
  ""
 ],
 "Size": [
  null,
  "Størrelse"
 ],
 "Slot": [
  null,
  "Slot"
 ],
 "Sockets": [
  null,
  ""
 ],
 "Software-based workarounds help prevent CPU security issues. These mitigations have the side effect of reducing performance. Change these settings at your own risk.": [
  null,
  "Programvarebasert løsning hjelper til med å forhindre CPU-sikkerhetsproblemer. Disse begrensningene har bivirkningen at ytelsen reduseres. Endre disse innstillingene på egen risiko."
 ],
 "Something went wrong": [
  null,
  "Noe gikk galt"
 ],
 "Space-saving computer": [
  null,
  "Plassbesparende datamaskin"
 ],
 "Specific time": [
  null,
  "Spesifikk tid"
 ],
 "Speed": [
  null,
  "Hastighet"
 ],
 "Start": [
  null,
  "Start"
 ],
 "Start and enable": [
  null,
  "Start og aktiver"
 ],
 "Start service": [
  null,
  "Start tjenesten"
 ],
 "State": [
  null,
  "Tilstand"
 ],
 "Static": [
  null,
  "Statisk"
 ],
 "Status": [
  null,
  "Status"
 ],
 "Stick PC": [
  null,
  ""
 ],
 "Stop": [
  null,
  "Stopp"
 ],
 "Stop and disable": [
  null,
  "Stopp og deaktiver"
 ],
 "Store metrics": [
  null,
  ""
 ],
 "Sub-Chassis": [
  null,
  ""
 ],
 "Sub-Notebook": [
  null,
  ""
 ],
 "Sundays": [
  null,
  "Søndager"
 ],
 "Switch to limited access": [
  null,
  "Bytt til begrenset tilgang"
 ],
 "Synchronized": [
  null,
  "Synkronisert"
 ],
 "Synchronized with $0": [
  null,
  "Synkronisert med $0"
 ],
 "Synchronizing": [
  null,
  "Synkroniserer"
 ],
 "System information": [
  null,
  "Systeminformasjon"
 ],
 "System services": [
  null,
  "Systemtjenester"
 ],
 "System time": [
  null,
  "Systemtid"
 ],
 "Systemd units": [
  null,
  "Systemd enheter"
 ],
 "Tablet": [
  null,
  "Nettbrett"
 ],
 "Targets": [
  null,
  "Mål"
 ],
 "Terminal": [
  null,
  "Terminal"
 ],
 "Text": [
  null,
  "Tekst"
 ],
 "The server refused to authenticate using any supported methods.": [
  null,
  "Serveren nektet å godkjenne ved hjelp av de støttede metodene."
 ],
 "The user $0 is not permitted to change cpu security mitigations": [
  null,
  "Brukeren $0 har ikke lov til å endre CPU-sikkerhetsreduksjoner"
 ],
 "There was $0 failed login attempt since the last successful login.": [
  "There were $0 failed login attempts since the last successful login.",
  "Det var $0 mislykket påloggingsforsøk siden forrige vellykkede pålogging.",
  "Det var $0 mislykkede påloggingsforsøk siden forrige vellykkede pålogging."
 ],
 "This didn't work, please try again": [
  null,
  "Dette fungerte ikke. Prøv på nytt"
 ],
 "This field cannot be empty": [
  null,
  "Dette feltet kan ikke være tomt"
 ],
 "This may take a while": [
  null,
  "Dette kan ta en stund"
 ],
 "This unit is not designed to be enabled explicitly.": [
  null,
  ""
 ],
 "Thursdays": [
  null,
  "Torsdager"
 ],
 "Time": [
  null,
  "Tid"
 ],
 "Time zone": [
  null,
  "Tidssone"
 ],
 "Timer creation failed": [
  null,
  "Oppretting av timer feilet"
 ],
 "Timers": [
  null,
  "Timere"
 ],
 "Too much data": [
  null,
  "For mye data"
 ],
 "Total size: $0": [
  null,
  "Total størrelse: $0"
 ],
 "Tower": [
  null,
  ""
 ],
 "Triggered by": [
  null,
  "Utløst av"
 ],
 "Triggers": [
  null,
  "Utløsere"
 ],
 "Trying to synchronize with $0": [
  null,
  "Prøver å synkronisere med $0"
 ],
 "Tuesdays": [
  null,
  "Tirsdager"
 ],
 "Turn on administrative access": [
  null,
  "Slå på administrativ tilgang"
 ],
 "Type": [
  null,
  "Type"
 ],
 "Type to filter": [
  null,
  "Skriv for å filtrere"
 ],
 "Unit not found": [
  null,
  "Enheten ble ikke funnet"
 ],
 "Unknown": [
  null,
  "Ukjent"
 ],
 "Untrusted host": [
  null,
  ""
 ],
 "Updating status...": [
  null,
  "Oppdaterer status ..."
 ],
 "Uptime": [
  null,
  "Oppetid"
 ],
 "Usage": [
  null,
  "Bruk"
 ],
 "User name": [
  null,
  "Brukernavn"
 ],
 "User password": [
  null,
  "Bruker passord"
 ],
 "Validating address": [
  null,
  "Validerer adresse"
 ],
 "Vendor": [
  null,
  "Leverandør"
 ],
 "Version": [
  null,
  "Versjon"
 ],
 "View details and history": [
  null,
  "Vis detaljer og historikk"
 ],
 "View hardware details": [
  null,
  "Se maskinvaredetaljer"
 ],
 "View report": [
  null,
  "Vis rapport"
 ],
 "Waiting for input…": [
  null,
  "Venter på input…"
 ],
 "Waiting for other software management operations to finish": [
  null,
  "Venter på at andre programvareadministrasjons-operasjoner skal fullføres"
 ],
 "Waiting to start…": [
  null,
  "Venter på å starte…"
 ],
 "Wanted by": [
  null,
  "Ønsket av"
 ],
 "Wants": [
  null,
  "Ønsker"
 ],
 "Warning and above": [
  null,
  "Advarsel og over"
 ],
 "Web console is running in limited access mode.": [
  null,
  "Web konsoll kjører i begrenset tilgangsmodus."
 ],
 "Wednesdays": [
  null,
  "Onsdager"
 ],
 "Weekly": [
  null,
  "Ukentlig"
 ],
 "Weeks": [
  null,
  "Uker"
 ],
 "White": [
  null,
  "Hvit"
 ],
 "Yearly": [
  null,
  "Årlig"
 ],
 "Yes": [
  null,
  "Ja"
 ],
 "You can not gain administrative access.": [
  null,
  "Du kan ikke få administrativ tilgang."
 ],
 "You may try to load older entries.": [
  null,
  "Du kan prøve å laste inn eldre oppføringer."
 ],
 "You now have administrative access.": [
  null,
  "Du har nå administrativ tilgang."
 ],
 "Your browser does not allow paste from the context menu. You can use Shift+Insert.": [
  null,
  ""
 ],
 "Your browser will remember your access level across sessions.": [
  null,
  "Nettleseren din husker tilgangsnivået ditt på tvers av øktene."
 ],
 "Your session has been terminated.": [
  null,
  "Økten din er avsluttet."
 ],
 "Your session has expired. Please log in again.": [
  null,
  "Økten din har utløpt. Vennligst logg inn igjen."
 ],
 "[$0 bytes of binary data]": [
  null,
  "[$0 bytes med binære data]"
 ],
 "[binary data]": [
  null,
  "[binære data]"
 ],
 "[no data]": [
  null,
  "[ingen data]"
 ],
 "abrt": [
  null,
  "abrt"
 ],
 "any free-form string as regular expression": [
  null,
  "hvilken som helst friformstreng som regulært uttrykk"
 ],
 "asset tag": [
  null,
  "eiendomsmerke"
 ],
 "bash": [
  null,
  "bash"
 ],
 "bios": [
  null,
  "bios"
 ],
 "boot": [
  null,
  "oppstart"
 ],
 "cgroups": [
  null,
  "cgroups"
 ],
 "command": [
  null,
  "kommando"
 ],
 "console": [
  null,
  "konsoll"
 ],
 "coredump": [
  null,
  "coredump"
 ],
 "cpu": [
  null,
  "cpu"
 ],
 "crash": [
  null,
  "krasj"
 ],
 "date": [
  null,
  "dato"
 ],
 "debug": [
  null,
  "debug"
 ],
 "dimm": [
  null,
  "dimm"
 ],
 "disable": [
  null,
  "deaktiver"
 ],
 "disks": [
  null,
  "disker"
 ],
 "domain": [
  null,
  "domene"
 ],
 "e.g.": [
  null,
  "f.eks."
 ],
 "e.g. \"$0\"": [
  null,
  "f.eks. \"$0\""
 ],
 "edit": [
  null,
  "rediger"
 ],
 "enable": [
  null,
  "aktiver"
 ],
 "error": [
  null,
  "feil"
 ],
 "failed to list ssh host keys: $0": [
  null,
  "kunne ikke liste ssh vertsnøkler: $0"
 ],
 "graphs": [
  null,
  "grafer"
 ],
 "hardware": [
  null,
  "maskinvare"
 ],
 "history": [
  null,
  "historikk"
 ],
 "host": [
  null,
  "vert"
 ],
 "journal": [
  null,
  "journal"
 ],
 "journalctl manpage": [
  null,
  "journalctl manpage"
 ],
 "log fields": [
  null,
  "logg-felt"
 ],
 "machine": [
  null,
  "maskin"
 ],
 "mask": [
  null,
  "maske"
 ],
 "memory": [
  null,
  "minne"
 ],
 "metrics": [
  null,
  ""
 ],
 "mitigation": [
  null,
  ""
 ],
 "network": [
  null,
  "nettverk"
 ],
 "of $0 CPU": [
  "of $0 CPUs",
  "av $0 CPU",
  "av $0 CPUer"
 ],
 "operating system": [
  null,
  "operativsystem"
 ],
 "os": [
  null,
  "os"
 ],
 "path": [
  null,
  "sti"
 ],
 "pci": [
  null,
  "pci"
 ],
 "pcp": [
  null,
  "pcp"
 ],
 "power": [
  null,
  ""
 ],
 "qualifiers": [
  null,
  "kvalifikatorer"
 ],
 "ram": [
  null,
  "ram"
 ],
 "restart": [
  null,
  "omstart"
 ],
 "running $0": [
  null,
  "kjører $0"
 ],
 "serial": [
  null,
  ""
 ],
 "service": [
  null,
  "tjeneste"
 ],
 "shell": [
  null,
  "skall"
 ],
 "show less": [
  null,
  "vis mindre"
 ],
 "show more": [
  null,
  "vis mer"
 ],
 "shut": [
  null,
  ""
 ],
 "socket": [
  null,
  ""
 ],
 "ssh": [
  null,
  "ssh"
 ],
 "systemctl": [
  null,
  "systemctl"
 ],
 "systemd": [
  null,
  "systemd"
 ],
 "target": [
  null,
  "mål"
 ],
 "time": [
  null,
  "tid"
 ],
 "timer": [
  null,
  "timer"
 ],
 "unit": [
  null,
  "enhet"
 ],
 "unknown": [
  null,
  "ukjent"
 ],
 "unmask": [
  null,
  "unmask"
 ],
 "version": [
  null,
  "versjon"
 ],
 "warning": [
  null,
  "advarsel"
 ],
 "<date> from <host>\u0004$0 from $1": [
  null,
  "$0 fra $1"
 ],
 "<date> from <host> on <terminal>\u0004$0 from $1 on $2": [
  null,
  "$0 fra $1 på $2"
 ],
 "<date> on <terminal>\u0004$0 on $1": [
  null,
  "$0 på $1"
 ]
});
