cockpit.locale({
 "": {'plural-forms':function(n) {
var nplurals, plural;
nplurals=2; plural=n != 1;
return plural;
},
  "language": "nb_NO",
  "x-generator": "Weblate 4.5.1"
 },
 "$0 block device": [
  null,
  "$0 blokk enhet"
 ],
 "$0 chunk size": [
  null,
  ""
 ],
 "$0 data + $1 overhead used of $2 ($3)": [
  null,
  "$0 data + $1 overhead brukt av $2 ($3)"
 ],
 "$0 day": [
  "$0 days",
  "$0 dag",
  "$0 dager"
 ],
 "$0 disk is missing": [
  "$0 disks are missing",
  "$0 disk mangler",
  "$0 disker mangler"
 ],
 "$0 disks": [
  null,
  "$0 disker"
 ],
 "$0 exited with code $1": [
  null,
  "$0 avsluttet med koden $1"
 ],
 "$0 failed": [
  null,
  "$0 feilet"
 ],
 "$0 filesystems can not be made larger.": [
  null,
  "$0 filsystemer kan ikke gjøres større."
 ],
 "$0 filesystems can not be made smaller.": [
  null,
  "$0 filsystemer kan ikke gjøres mindre."
 ],
 "$0 filesystems can not be resized here.": [
  null,
  "$0 filsystemer kan ikke endres størrelse på her."
 ],
 "$0 hour": [
  "$0 hours",
  "$0 time",
  "$0 timer"
 ],
 "$0 is in active use": [
  null,
  "$0 er i aktiv bruk"
 ],
 "$0 is not available from any repository.": [
  null,
  "$0 er ikke tilgjengelig fra noe depot."
 ],
 "$0 killed with signal $1": [
  null,
  "$0 drept med signal $1"
 ],
 "$0 minute": [
  "$0 minutes",
  "$0 minutt",
  "$0 minutter"
 ],
 "$0 month": [
  "$0 months",
  "$0 måned",
  "$0 måneder"
 ],
 "$0 of $1": [
  null,
  "$0 av $1"
 ],
 "$0 slot remains": [
  "$0 slots remain",
  "$0 slot gjenstår",
  "$0 slot-er gjenstår"
 ],
 "$0 used of $1 ($2 saved)": [
  null,
  "$0 brukt av $1 ($2 lagret)"
 ],
 "$0 week": [
  "$0 weeks",
  "$0 uke",
  "$0 uker"
 ],
 "$0 will be installed.": [
  null,
  "$0 vil bli installert."
 ],
 "$0 year": [
  "$0 years",
  "$0 år",
  "$0 år"
 ],
 "$0, $1 free": [
  null,
  "$0, $1 ledig"
 ],
 "$name (from $host)": [
  null,
  "$name (fra $host)"
 ],
 "(none)": [
  null,
  "(ingen)"
 ],
 "1 MiB": [
  null,
  "1 MiB"
 ],
 "1 day": [
  null,
  "1 dag"
 ],
 "1 hour": [
  null,
  "1 time"
 ],
 "1 week": [
  null,
  "1 uke"
 ],
 "128 KiB": [
  null,
  "128 KiB"
 ],
 "16 KiB": [
  null,
  "16 KiB"
 ],
 "2 MiB": [
  null,
  "2 MiB"
 ],
 "32 KiB": [
  null,
  "32 KiB"
 ],
 "4 KiB": [
  null,
  "4 KiB"
 ],
 "5 minutes": [
  null,
  "5 minutter"
 ],
 "512 KiB": [
  null,
  "512 KiB"
 ],
 "6 hours": [
  null,
  "6 timer"
 ],
 "64 KiB": [
  null,
  "64 KiB"
 ],
 "8 KiB": [
  null,
  "8 KiB"
 ],
 "A disk is needed.": [
  null,
  "En disk er nødvendig."
 ],
 "A spare disk needs to be added first before this disk can be removed.": [
  null,
  "En ekstra disk må legges til først før denne disken kan fjernes."
 ],
 "Actions": [
  null,
  "Handlinger"
 ],
 "Activate": [
  null,
  "Aktiver"
 ],
 "Activating $target": [
  null,
  "Aktiverer $target"
 ],
 "Active since": [
  null,
  "Aktiv siden"
 ],
 "Add": [
  null,
  "Legg til"
 ],
 "Add disks": [
  null,
  "Legg til disker"
 ],
 "Add iSCSI portal": [
  null,
  "Legg til iSCSI-portal"
 ],
 "Add key": [
  null,
  "Legg til nøkkel"
 ],
 "Adding physical volume to $target": [
  null,
  "Legger til fysisk volum til $target"
 ],
 "Additional packages:": [
  null,
  "Ekstra pakker:"
 ],
 "Address": [
  null,
  "Adresse"
 ],
 "Address cannot be empty": [
  null,
  "Adressen kan ikke være tom"
 ],
 "Address is not a valid URL": [
  null,
  "Adressen er ikke en gyldig URL"
 ],
 "Affected locations": [
  null,
  "Berørte plasseringer"
 ],
 "All logs": [
  null,
  "Alle logger"
 ],
 "Apply": [
  null,
  "Bruk"
 ],
 "At least $0 disk is needed.": [
  "At least $0 disks are needed.",
  "Minst $0 disk er nødvendig.",
  "Minst $0 disker er nødvendige."
 ],
 "At least one disk is needed.": [
  null,
  "Minst én disk er nødvendig."
 ],
 "Authentication required": [
  null,
  "Autentisering kreves"
 ],
 "Available targets on $0": [
  null,
  "Tilgjengelige mål på $0"
 ],
 "Backing device": [
  null,
  ""
 ],
 "Block": [
  null,
  "Blokk"
 ],
 "Block device for filesystems": [
  null,
  "Blokk enhet for filsystemer"
 ],
 "Blocked": [
  null,
  "Blokkert"
 ],
 "Cancel": [
  null,
  "Avbryt"
 ],
 "Cannot forward login credentials": [
  null,
  "Kan ikke videresende påloggingsinformasjonen"
 ],
 "Change": [
  null,
  "Endre"
 ],
 "Change iSCSI initiator name": [
  null,
  "Endre navn på iSCSI Initiator"
 ],
 "Change passphrase": [
  null,
  "Endre passfrase"
 ],
 "Checking $target": [
  null,
  "Sjekker $target"
 ],
 "Checking RAID device $target": [
  null,
  "Kontrollerer RAID-enheten $target"
 ],
 "Checking and repairing RAID device $target": [
  null,
  "Kontrollerer og reparerer RAID-enhet $target"
 ],
 "Checking installed software": [
  null,
  "Kontrollerer installert programvare"
 ],
 "Chunk size": [
  null,
  ""
 ],
 "Cleaning up for $target": [
  null,
  "Rydder opp for $target"
 ],
 "Clear mount point configuration": [
  null,
  "Fjern monteringspunkt-konfigurasjonen"
 ],
 "Close": [
  null,
  "Lukk"
 ],
 "Cockpit could not contact the given host.": [
  null,
  "Cockpit kunne ikke kontakte den angitte verten."
 ],
 "Cockpit is not compatible with the software on the system.": [
  null,
  "Cockpit er ikke kompatibel med programvaren på systemet."
 ],
 "Cockpit is not installed on the system.": [
  null,
  "Cockpit er ikke installert på systemet."
 ],
 "Compatible with all systems and devices (MBR)": [
  null,
  "Kompatibel med alle systemer og enheter (MBR)"
 ],
 "Compatible with modern system and hard disks > 2TB (GPT)": [
  null,
  "Kompatibel med moderne system og harddisker> 2TB (GPT)"
 ],
 "Compression": [
  null,
  "Komprimering"
 ],
 "Confirm": [
  null,
  "Bekreft"
 ],
 "Confirm removal with passphrase": [
  null,
  "Bekreft fjerning med passfrase"
 ],
 "Connection has timed out.": [
  null,
  "Tidsavbrudd for tilkoblingen."
 ],
 "Content": [
  null,
  "Innhold"
 ],
 "Create": [
  null,
  "Opprett"
 ],
 "Create RAID device": [
  null,
  "Opprett RAID-enhet"
 ],
 "Create VDO device": [
  null,
  "Opprett VDO-enhet"
 ],
 "Create devices": [
  null,
  "Opprett enheter"
 ],
 "Create logical volume": [
  null,
  "Opprett logisk volum"
 ],
 "Create new logical volume": [
  null,
  "Opprett nytt logisk volum"
 ],
 "Create partition": [
  null,
  "Opprett partisjon"
 ],
 "Create partition on $0": [
  null,
  "Opprett partisjon på $0"
 ],
 "Create partition table": [
  null,
  "Opprett partisjonstabell"
 ],
 "Create snapshot": [
  null,
  "Opprett øyeblikksbilde"
 ],
 "Create thin volume": [
  null,
  "Opprett tynt volum"
 ],
 "Create volume group": [
  null,
  "Opprett volumgruppe"
 ],
 "Creating RAID device $target": [
  null,
  "Oppretter RAID-enhet $target"
 ],
 "Creating filesystem on $target": [
  null,
  "Oppretter filsystem på $target"
 ],
 "Creating logical volume $target": [
  null,
  "Oppretter logisk volum $target"
 ],
 "Creating partition $target": [
  null,
  "Oppretter partisjon $target"
 ],
 "Creating snapshot of $target": [
  null,
  "Oppretter øyeblikksbilde av $target"
 ],
 "Creating volume group $target": [
  null,
  "Oppretter volumgruppe $target"
 ],
 "Custom encryption options": [
  null,
  "Tilpassede krypteringsalternativer"
 ],
 "Custom mount options": [
  null,
  "Tilpassede monteringsalternativer"
 ],
 "DISK IS FAILING": [
  null,
  "DISKEN FEILER"
 ],
 "Data used": [
  null,
  "Data brukt"
 ],
 "Deactivate": [
  null,
  "Deaktiver"
 ],
 "Deactivating $target": [
  null,
  "Deaktiverer $target"
 ],
 "Deduplication": [
  null,
  "Deduplisering"
 ],
 "Delete": [
  null,
  "Slett"
 ],
 "Deleting $target": [
  null,
  "Sletter $target"
 ],
 "Deleting a RAID device will erase all data on it.": [
  null,
  "Hvis du sletter en RAID-enhet, slettes alle dataene på den."
 ],
 "Deleting a VDO device will erase all data on it.": [
  null,
  "Sletting av en VDO-enhet vil slette alle dataene på den."
 ],
 "Deleting a logical volume will delete all data in it.": [
  null,
  "Hvis du sletter et logisk volum, slettes alle dataene i det."
 ],
 "Deleting a partition will delete all data in it.": [
  null,
  "Sletting av en partisjon vil slette alle dataene i den."
 ],
 "Deleting a volume group will erase all data on it.": [
  null,
  "Sletting av en volumgruppe vil slette alle dataene på den."
 ],
 "Deleting volume group $target": [
  null,
  "Sletter volumgruppe $target"
 ],
 "Device": [
  null,
  "Enhet"
 ],
 "Device file": [
  null,
  "Enhetsfil"
 ],
 "Device is read-only": [
  null,
  "Enheten er skrivebeskyttet"
 ],
 "Devices": [
  null,
  "Enheter"
 ],
 "Disk": [
  null,
  "Disk"
 ],
 "Disk is OK": [
  null,
  "Disken er OK"
 ],
 "Disk passphrase": [
  null,
  "Disk passfrase"
 ],
 "Disks": [
  null,
  "Disker"
 ],
 "Do not mount automatically on boot": [
  null,
  "Ikke monter automatisk ved oppstart"
 ],
 "Don't overwrite existing data": [
  null,
  "Ikke overskriv eksisterende data"
 ],
 "Downloading $0": [
  null,
  "Laster ned $0"
 ],
 "Drive": [
  null,
  "DIsk"
 ],
 "Drives": [
  null,
  "Disker"
 ],
 "Edit": [
  null,
  "Rediger"
 ],
 "Edit Tang keyserver": [
  null,
  "Rediger Tang nøkkelserver"
 ],
 "Editing a key requires a free slot": [
  null,
  "Redigering av en nøkkel krever en ledig slot"
 ],
 "Ejecting $target": [
  null,
  "Løser ut $target"
 ],
 "Emptying $target": [
  null,
  "Tømmer $target"
 ],
 "Encrypt data": [
  null,
  "Krypter data"
 ],
 "Encrypted $0": [
  null,
  "Kryptert $0"
 ],
 "Encrypted logical volume of $0": [
  null,
  "Kryptert logisk volum på $0"
 ],
 "Encrypted partition of $0": [
  null,
  "Kryptert partisjon på $0"
 ],
 "Encrypted volumes can not be resized here.": [
  null,
  "Krypterte volumer kan ikke endres her."
 ],
 "Encrypted volumes need to be unlocked before they can be resized.": [
  null,
  "Krypterte volumer må låses opp før de kan endres."
 ],
 "Encryption": [
  null,
  "Kryptering"
 ],
 "Encryption options": [
  null,
  "Krypteringsalternativer"
 ],
 "Erase": [
  null,
  ""
 ],
 "Erasing $target": [
  null,
  ""
 ],
 "Error": [
  null,
  "Feil"
 ],
 "Extended partition": [
  null,
  "Utvidet partisjon"
 ],
 "Failed": [
  null,
  "Feilet"
 ],
 "Filesystem": [
  null,
  "Filsystem"
 ],
 "Filesystem name": [
  null,
  "Filsystem navn"
 ],
 "Filesystems": [
  null,
  "Filsystemer"
 ],
 "For legacy applications only. Reduces performance.": [
  null,
  "Bare for eldre applikasjoner. Reduserer ytelsen."
 ],
 "Force remove passphrase in $0": [
  null,
  "Tving fjerning av passfrase i $0"
 ],
 "Format": [
  null,
  "Format"
 ],
 "Format $0": [
  null,
  "Formater $0"
 ],
 "Format disk $0": [
  null,
  "Formater disk $0"
 ],
 "Formatting a disk will erase all data on it.": [
  null,
  "Formatering av en disk vil slette alle dataene på den."
 ],
 "Formatting a storage device will erase all data on it.": [
  null,
  "Formatering av en lagringsenhet vil slette alle dataene på den."
 ],
 "Free": [
  null,
  "Ledig"
 ],
 "Free space": [
  null,
  "Ledig plass"
 ],
 "Free up space in this group: Shrink or delete other logical volumes or add another physical volume.": [
  null,
  "Frigjør plass i denne gruppen: Krymp eller slett andre logiske volumer eller legg til et annet fysisk volum."
 ],
 "Go to now": [
  null,
  "Gå til nå"
 ],
 "Grow": [
  null,
  ""
 ],
 "Grow content": [
  null,
  ""
 ],
 "Grow logical size of $0": [
  null,
  "Øk logisk størrelse på $0"
 ],
 "Grow logical volume": [
  null,
  "Øk logisk volum"
 ],
 "Grow to take all space": [
  null,
  "Voks for å ta all plass"
 ],
 "Host key is incorrect": [
  null,
  "Vertsnøkkelen er feil"
 ],
 "If tang-show-keys is not available, run the following:": [
  null,
  "Hvis tang-show-keys ikke er tilgjengelig, kjører du følgende:"
 ],
 "In sync": [
  null,
  "I synk"
 ],
 "Inactive volume": [
  null,
  "Inaktivt volum"
 ],
 "Inconsistent filesystem mount": [
  null,
  "Inkonsistent filsystemmontering"
 ],
 "Index memory": [
  null,
  "Indeks minne"
 ],
 "Install": [
  null,
  "Installer"
 ],
 "Install NFS support": [
  null,
  "Installer NFS-støtte"
 ],
 "Install VDO support": [
  null,
  "Installer VDO-støtte"
 ],
 "Install software": [
  null,
  "Installer programvare"
 ],
 "Installing $0": [
  null,
  "Installerer $0"
 ],
 "Internal error": [
  null,
  "Intern feil"
 ],
 "Invalid username or password": [
  null,
  "Ugyldig brukernavn eller passord"
 ],
 "Jobs": [
  null,
  "Jobber"
 ],
 "Key slots with unknown types can not be edited here": [
  null,
  "Nøkkel-slots med ukjente typer kan ikke redigeres her"
 ],
 "Key source": [
  null,
  "Nøkkelkilde"
 ],
 "Keys": [
  null,
  "Nøkler"
 ],
 "Keyserver": [
  null,
  "Nøkkelserver"
 ],
 "Keyserver address": [
  null,
  "Nøkkelserver adresse"
 ],
 "Keyserver removal may prevent unlocking $0.": [
  null,
  "Fjerning av nøkkelserver kan forhindre opplåsing av $0."
 ],
 "Learn more": [
  null,
  "Lær mer"
 ],
 "Loading...": [
  null,
  "Laster..."
 ],
 "Local mount point": [
  null,
  "Lokalt monteringspunkt"
 ],
 "Lock": [
  null,
  "Lås"
 ],
 "Locked devices": [
  null,
  "Låste enheter"
 ],
 "Locking $target": [
  null,
  "Låser $target"
 ],
 "Logical": [
  null,
  "Logisk"
 ],
 "Logical size": [
  null,
  "Logisk størrelse"
 ],
 "Logical volume": [
  null,
  "Logisk volum"
 ],
 "Logical volume (snapshot)": [
  null,
  "Logisk volum (øyeblikksbilde)"
 ],
 "Logical volume of $0": [
  null,
  "Logisk volum på $0"
 ],
 "Logical volumes": [
  null,
  "Logiske volumer"
 ],
 "Login failed": [
  null,
  "Innlogging feilet"
 ],
 "Make sure the key hash from the Tang server matches:": [
  null,
  "Forsikre deg om at nøkkelhash fra Tang-serveren samsvarer med:"
 ],
 "Managing LVMs": [
  null,
  "Administrere LVMer"
 ],
 "Managing NFS mounts": [
  null,
  "Administrere NFS-monteringer"
 ],
 "Managing RAIDs": [
  null,
  "Administrere RAIDer"
 ],
 "Managing VDOs": [
  null,
  "Administrere VDOer"
 ],
 "Managing partitions": [
  null,
  "Administrere partisjoner"
 ],
 "Managing physical drives": [
  null,
  "Administrere fysiske disker"
 ],
 "Manually check with SSH: ": [
  null,
  "Sjekk manuelt med SSH: "
 ],
 "Marking $target as faulty": [
  null,
  "Markerer $target som feilende"
 ],
 "Member of RAID device": [
  null,
  "Medlem av RAID-enhet"
 ],
 "Member of RAID device $0": [
  null,
  "Medlem av RAID-enhet $0"
 ],
 "Metadata used": [
  null,
  "Metadata brukt"
 ],
 "Modifying $target": [
  null,
  "Endrer $target"
 ],
 "Mount": [
  null,
  "Montér"
 ],
 "Mount also automatically on boot": [
  null,
  "Monter også automatisk ved oppstart"
 ],
 "Mount at boot": [
  null,
  "Monter ved oppstart"
 ],
 "Mount automatically on $0 on boot": [
  null,
  "Monter automatisk på $0 ved oppstart"
 ],
 "Mount configuration": [
  null,
  "Monterings-konfigurasjon"
 ],
 "Mount filesystem": [
  null,
  "Monter filsystem"
 ],
 "Mount now": [
  null,
  "Monter nå"
 ],
 "Mount on $0 now": [
  null,
  "Monter på $0 nå"
 ],
 "Mount options": [
  null,
  "Innstillinger for montering"
 ],
 "Mount point": [
  null,
  "Monteringspunkt"
 ],
 "Mount point cannot be empty": [
  null,
  "Monteringspunkt kan ikke være tomt"
 ],
 "Mount point cannot be empty.": [
  null,
  "Monteringspunkt kan ikke være tomt."
 ],
 "Mount point is already used for $0": [
  null,
  "Monteringspunktet er allerede brukt for $0"
 ],
 "Mount point must start with \"/\".": [
  null,
  "Monteringspunktet må starte med \"/\"."
 ],
 "Mount read only": [
  null,
  "Monter skrivebeskyttet"
 ],
 "Mounting $target": [
  null,
  "Monterer $target"
 ],
 "NFS mount": [
  null,
  "NFS-montering"
 ],
 "NFS mounts": [
  null,
  "NFS monteringer"
 ],
 "NFS support not installed": [
  null,
  "NFS-støtte ikke installert"
 ],
 "Name": [
  null,
  "Navn"
 ],
 "Name can not be empty.": [
  null,
  "Navnet kan ikke være tomt."
 ],
 "Name cannot be empty.": [
  null,
  "Navnet kan ikke være tomt."
 ],
 "Name cannot be longer than $0 bytes": [
  null,
  "Navnet kan ikke være lengre enn $0 byte"
 ],
 "Name cannot be longer than $0 characters": [
  null,
  "Navnet kan ikke være lengre enn $0 tegn"
 ],
 "Name cannot be longer than 127 characters.": [
  null,
  "Navnet kan ikke være lengre enn 127 tegn."
 ],
 "Name cannot contain the character '$0'.": [
  null,
  "Navnet kan ikke inneholde tegnet '$0'."
 ],
 "Name cannot contain whitespace.": [
  null,
  "Navnet kan ikke inneholde mellomrom."
 ],
 "New NFS mount": [
  null,
  "Ny NFS-montering"
 ],
 "New passphrase": [
  null,
  "Ny passfrase"
 ],
 "Next": [
  null,
  "Neste"
 ],
 "No NFS mounts set up": [
  null,
  "Ingen NFS-monteringer er satt opp"
 ],
 "No available slots": [
  null,
  "Ingen tilgjengelige slots"
 ],
 "No devices": [
  null,
  "Ingen enheter"
 ],
 "No disks are available.": [
  null,
  "Ingen disker er tilgjengelige."
 ],
 "No drives attached": [
  null,
  "Ingen stasjoner tilkoblet"
 ],
 "No filesystem": [
  null,
  "Ingen filsystem"
 ],
 "No free key slots": [
  null,
  "Ingen ledige nøkkelslots"
 ],
 "No free space": [
  null,
  "Ingen ledig plass"
 ],
 "No iSCSI targets set up": [
  null,
  "Ingen iSCSI-mål er satt opp"
 ],
 "No keys added": [
  null,
  "Ingen nøkler lagt til"
 ],
 "No logical volumes": [
  null,
  "Ingen logiske volumer"
 ],
 "No media inserted": [
  null,
  "Ingen medier satt inn"
 ],
 "No partitioning": [
  null,
  "Ingen partisjonering"
 ],
 "Not enough space to grow.": [
  null,
  "Ikke nok plass til å vokse."
 ],
 "Not found": [
  null,
  "Ikke funnet"
 ],
 "Not mounted": [
  null,
  "Ikke montert"
 ],
 "Not permitted to perform this action.": [
  null,
  "Ikke tillatt å utføre denne handlingen."
 ],
 "Not running": [
  null,
  "Kjører ikke"
 ],
 "Ok": [
  null,
  "Ok"
 ],
 "Old passphrase": [
  null,
  "Gammel passordfrase"
 ],
 "Only $0 of $1 are used.": [
  null,
  "Bare $0 av $1 brukes."
 ],
 "Operation '$operation' on $target": [
  null,
  "Operasjon '$operation' på $target"
 ],
 "Options": [
  null,
  "Alternativer"
 ],
 "Other devices": [
  null,
  "Andre enheter"
 ],
 "Overwrite existing data with zeros": [
  null,
  "Overskriv eksisterende data med nuller"
 ],
 "PackageKit crashed": [
  null,
  "PackageKit krasjet"
 ],
 "Partition": [
  null,
  "Partisjon"
 ],
 "Partition of $0": [
  null,
  "Partisjon på $0"
 ],
 "Partitioning": [
  null,
  "Partisjonering"
 ],
 "Passphrase": [
  null,
  "Passfrase"
 ],
 "Passphrase cannot be empty": [
  null,
  "Passfrasen kan ikke være tom"
 ],
 "Passphrase removal may prevent unlocking $0.": [
  null,
  "Fjerning av passfrase kan forhindre opplåsing av $0."
 ],
 "Passphrases do not match": [
  null,
  "Passfraser stemmer ikke overens"
 ],
 "Password": [
  null,
  "Passord"
 ],
 "Path on server": [
  null,
  "Sti på server"
 ],
 "Path on server cannot be empty.": [
  null,
  "Sti på server kan ikke være tom."
 ],
 "Path on server must start with \"/\".": [
  null,
  "Stien på serveren må starte med \"/\"."
 ],
 "Physical": [
  null,
  "Fysisk"
 ],
 "Physical volume": [
  null,
  "Fysisk volum"
 ],
 "Physical volume of $0": [
  null,
  "Fysisk volum på $0"
 ],
 "Physical volumes": [
  null,
  "Fysiske volumer"
 ],
 "Physical volumes can not be resized here.": [
  null,
  "Fysiske volumer kan ikke endres her."
 ],
 "Please confirm deletion of $0": [
  null,
  "Bekreft sletting av $0"
 ],
 "Please confirm stopping of $0": [
  null,
  "Bekreft stopping av $0"
 ],
 "Pool": [
  null,
  "Pool"
 ],
 "Pool for thin logical volumes": [
  null,
  "Pool for tynne logiske volumer"
 ],
 "Pool for thin volumes": [
  null,
  "Pool for tynne volumer"
 ],
 "Pool for thinly provisioned volumes": [
  null,
  "Pool for tynt provisjonerte volumer"
 ],
 "Port": [
  null,
  "Port"
 ],
 "Process": [
  null,
  "Prosess"
 ],
 "Purpose": [
  null,
  "Formål"
 ],
 "RAID ($0)": [
  null,
  "RAID ($0)"
 ],
 "RAID 0": [
  null,
  "RAID 0"
 ],
 "RAID 0 (stripe)": [
  null,
  "RAID 0 (stripe)"
 ],
 "RAID 1": [
  null,
  "RAID 1"
 ],
 "RAID 1 (mirror)": [
  null,
  "RAID 1 (speil)"
 ],
 "RAID 10": [
  null,
  "RAID 10"
 ],
 "RAID 10 (stripe of mirrors)": [
  null,
  "RAID 10 (stripe av speil)"
 ],
 "RAID 4": [
  null,
  "RAID 4"
 ],
 "RAID 4 (dedicated parity)": [
  null,
  "RAID 4 (dedikert paritet)"
 ],
 "RAID 5": [
  null,
  "RAID 5"
 ],
 "RAID 5 (distributed parity)": [
  null,
  "RAID 5 (distribuert paritet)"
 ],
 "RAID 6": [
  null,
  "RAID 6"
 ],
 "RAID 6 (double distributed parity)": [
  null,
  "RAID 6 (dobbel fordelt paritet)"
 ],
 "RAID device": [
  null,
  "RAID-enhet"
 ],
 "RAID device $0": [
  null,
  "RAID-enhet $0"
 ],
 "RAID level": [
  null,
  "RAID-nivå"
 ],
 "RAID member": [
  null,
  "RAID-medlem"
 ],
 "Reboot": [
  null,
  "Omstart"
 ],
 "Recommended default": [
  null,
  "Anbefalt standard"
 ],
 "Recovering": [
  null,
  "Gjenoppretter"
 ],
 "Recovering RAID device $target": [
  null,
  "Gjenoppretter RAID enhet $target"
 ],
 "Removals:": [
  null,
  ""
 ],
 "Remove": [
  null,
  "Fjern"
 ],
 "Remove $0?": [
  null,
  "Fjern $0?"
 ],
 "Remove Tang keyserver": [
  null,
  "Fjern Tang nøkkelserver"
 ],
 "Remove device": [
  null,
  "Fjern enheten"
 ],
 "Remove passphrase": [
  null,
  "Fjern passfrasen"
 ],
 "Remove passphrase in $0?": [
  null,
  "Fjern passfrasen i $0?"
 ],
 "Removing $0": [
  null,
  "Fjerner $0"
 ],
 "Removing $target from RAID device": [
  null,
  "Fjerner $target fra RAID-enhet"
 ],
 "Removing physical volume from $target": [
  null,
  "Fjerner fysisk volum fra $target"
 ],
 "Rename": [
  null,
  "Omdøp"
 ],
 "Rename logical volume": [
  null,
  "Omdøp logisk volum"
 ],
 "Rename volume group": [
  null,
  "Omdøp volumgruppe"
 ],
 "Renaming $target": [
  null,
  "Omdøper $target"
 ],
 "Repairing $target": [
  null,
  "Reparerer $target"
 ],
 "Repeat passphrase": [
  null,
  "Gjenta passfrasen"
 ],
 "Resizing $target": [
  null,
  ""
 ],
 "Resizing an encrypted filesystem requires unlocking the disk. Please provide a current disk passphrase.": [
  null,
  "Å endre størrelse på et kryptert filsystem krever at du låser opp disken. Oppgi en aktuell passfrase."
 ],
 "Running": [
  null,
  "Kjører"
 ],
 "SMART self-test of $target": [
  null,
  "SMART selvtest av $target"
 ],
 "Save": [
  null,
  "Lagre"
 ],
 "Save space by compressing individual blocks with LZ4": [
  null,
  "Spar plass ved å komprimere individuelle blokker med LZ4"
 ],
 "Save space by storing identical data blocks just once": [
  null,
  "Spar plass ved å lagre identiske datablokker bare en gang"
 ],
 "Saving a new passphrase requires unlocking the disk. Please provide a current disk passphrase.": [
  null,
  "For å lagre en ny passfrase, må du låse opp disken. Oppgi en aktuell passfrase."
 ],
 "Securely erasing $target": [
  null,
  ""
 ],
 "Server": [
  null,
  "Server"
 ],
 "Server address": [
  null,
  "Serveradresse"
 ],
 "Server address cannot be empty.": [
  null,
  "Serveradressen kan ikke være tom."
 ],
 "Server cannot be empty.": [
  null,
  "Serveren kan ikke være tom."
 ],
 "Server has closed the connection.": [
  null,
  "Serveren har lukket forbindelsen."
 ],
 "Service": [
  null,
  "Tjeneste"
 ],
 "Session": [
  null,
  "Økt"
 ],
 "Setting up loop device $target": [
  null,
  ""
 ],
 "Show $0 device": [
  "Show all $0 devices",
  "Vis $0 enhet",
  "Vis alle $0 enheter"
 ],
 "Show $0 drive": [
  "Show all $0 drives",
  "Vis $0 stasjon",
  "Vis alle $0 stasjoner"
 ],
 "Show all": [
  null,
  "Vis alle"
 ],
 "Shrink": [
  null,
  "Krymp"
 ],
 "Shrink logical volume": [
  null,
  "Krymp logisk volum"
 ],
 "Shrink volume": [
  null,
  "Krymp volum"
 ],
 "Size": [
  null,
  "Størrelse"
 ],
 "Size cannot be negative": [
  null,
  "Størrelse kan ikke være negativ"
 ],
 "Size cannot be zero": [
  null,
  "Størrelsen kan ikke være null"
 ],
 "Size is too large": [
  null,
  "Størrelsen er for stor"
 ],
 "Size must be a number": [
  null,
  "Størrelsen må være et tall"
 ],
 "Size must be at least $0": [
  null,
  "Størrelsen må være minst $0"
 ],
 "Slot $0": [
  null,
  "Slot $0"
 ],
 "Spare": [
  null,
  "Reserve"
 ],
 "Start": [
  null,
  "Start"
 ],
 "Start multipath": [
  null,
  ""
 ],
 "Starting RAID device $target": [
  null,
  "Starter RAID-enhet $target"
 ],
 "Starting swapspace $target": [
  null,
  ""
 ],
 "Stop": [
  null,
  "Stopp"
 ],
 "Stop and remove": [
  null,
  "Stopp og fjern"
 ],
 "Stop and unmount": [
  null,
  "Stopp og demonter"
 ],
 "Stop device": [
  null,
  "Stopp enhet"
 ],
 "Stopping RAID device $target": [
  null,
  "Stopper RAID-enhet $target"
 ],
 "Stopping swapspace $target": [
  null,
  ""
 ],
 "Storage": [
  null,
  "Lagring"
 ],
 "Storage can not be managed on this system.": [
  null,
  "Lagring kan ikke administreres på dette systemet."
 ],
 "Storage logs": [
  null,
  "Lagringslogger"
 ],
 "Store passphrase": [
  null,
  ""
 ],
 "Stored passphrase": [
  null,
  ""
 ],
 "Support is installed.": [
  null,
  "Support er installert."
 ],
 "Swap": [
  null,
  "Swap"
 ],
 "Synchronizing RAID device $target": [
  null,
  "Synkroniserer RAID-enhet $target"
 ],
 "Tang keyserver": [
  null,
  "Tang nøkkelserver"
 ],
 "The $0 package must be installed to create VDO devices.": [
  null,
  "$0-pakken må være installert for å opprette VDO-enheter."
 ],
 "The RAID array is in a degraded state": [
  null,
  "RAID-matrisen er i degradert tilstand"
 ],
 "The RAID device must be running in order to add spare disks.": [
  null,
  "RAID-enheten må kjøre for å kunne legge til ekstra disker."
 ],
 "The RAID device must be running in order to remove disks.": [
  null,
  "RAID-enheten må kjøre for å kunne fjerne disker."
 ],
 "The creation of this VDO device did not finish and the device can't be used.": [
  null,
  "Opprettelsen av denne VDO-enheten ble ikke fullført, og enheten kan ikke brukes."
 ],
 "The currently logged in user is not permitted to see information about keys.": [
  null,
  "Den påloggede brukeren har ikke lov til å se informasjon om nøkler."
 ],
 "The filesystem has no permanent mount point.": [
  null,
  "Filsystemet har ikke noe permanent monteringspunkt."
 ],
 "The filesystem is already mounted at $0. Proceeding will unmount it.": [
  null,
  "Filsystemet er allerede montert på $0. Hvis du fortsetter, demonteres det."
 ],
 "The filesystem is configured to be automatically mounted on boot but its encryption container will not be unlocked at that time.": [
  null,
  "Filsystemet er konfigurert til å monteres automatisk ved oppstart, men krypteringsbeholderen blir ikke låst opp på det tidspunktet."
 ],
 "The filesystem is currently mounted but will not be mounted after the next boot.": [
  null,
  "Filsystemet er for øyeblikket montert, men blir ikke montert etter neste oppstart."
 ],
 "The filesystem is currently mounted on $0 but will be mounted on $1 on the next boot.": [
  null,
  "Filsystemet er for øyeblikket montert på $0, men vil bli montert på $1 ved neste oppstart."
 ],
 "The filesystem is currently mounted on $0 but will not be mounted after the next boot.": [
  null,
  "Filsystemet er for øyeblikket montert på $0, men blir ikke montert etter neste oppstart."
 ],
 "The filesystem is currently not mounted but will be mounted on the next boot.": [
  null,
  "Filsystemet er foreløpig ikke montert, men vil bli montert på neste oppstart."
 ],
 "The filesystem is in use by login sessions and system services. Proceeding will stop these.": [
  null,
  "Filsystemet er i bruk av påloggingsøkter og systemtjenester. Dersom du fortsetter vil disse stoppes."
 ],
 "The filesystem is in use by login sessions. Proceeding will stop these.": [
  null,
  "Filsystemet er i bruk av påloggingsøkter. Dersom du fortsetter vil disse stoppes."
 ],
 "The filesystem is in use by system services. Proceeding will stop these.": [
  null,
  "Filsystemet er i bruk av systemtjenester. Dersom du fortsetter vil disse stoppes."
 ],
 "The filesystem is not mounted.": [
  null,
  "Filsystemet er ikke montert."
 ],
 "The last disk of a RAID device cannot be removed.": [
  null,
  "Den siste disken til en RAID-enhet kan ikke fjernes."
 ],
 "The last key slot can not be removed": [
  null,
  "Den siste nøkkel-sloten kan ikke fjernes"
 ],
 "The last physical volume of a volume group cannot be removed.": [
  null,
  "Du kan ikke fjerne det siste fysiske volumet i en volumgruppe."
 ],
 "The server refused to authenticate using any supported methods.": [
  null,
  "Serveren nektet å godkjenne ved hjelp av de støttede metodene."
 ],
 "There are devices with multiple paths on the system, but the multipath service is not running.": [
  null,
  ""
 ],
 "There is not enough free space elsewhere to remove this physical volume. At least $0 more free space is needed.": [
  null,
  "Det er ikke nok ledig plass andre steder for å fjerne dette fysiske volumet. Minst $0 mer ledig plass er nødvendig."
 ],
 "Thin logical volume": [
  null,
  "Tynt logisk volum"
 ],
 "This NFS mount is in use and only its options can be changed.": [
  null,
  "Denne NFS-monteringen er i bruk, og bare alternativene kan endres."
 ],
 "This VDO device does not use all of its backing device.": [
  null,
  ""
 ],
 "This device has filesystems that are currently in use. Proceeding will unmount all filesystems on it.": [
  null,
  "Denne enheten har filsystemer som er i bruk for øyeblikket. Hvis du fortsetter, demonteres alle filsystemene på den."
 ],
 "This device is currently used for RAID devices.": [
  null,
  "Denne enheten brukes for øyeblikket til RAID-enheter."
 ],
 "This device is currently used for RAID devices. Proceeding will remove it from its RAID devices.": [
  null,
  "Denne enheten brukes for øyeblikket til RAID-enheter. Hvis du fortsetter, fjernes den fra RAID-enhetene."
 ],
 "This device is currently used for VDO devices.": [
  null,
  "Denne enheten brukes for øyeblikket til VDO-enheter."
 ],
 "This device is currently used for volume groups.": [
  null,
  "Denne enheten brukes for øyeblikket for volumgrupper."
 ],
 "This device is currently used for volume groups. Proceeding will remove it from its volume groups.": [
  null,
  "Denne enheten brukes for øyeblikket for volumgrupper. Hvis du fortsetter, fjernes den fra volumgruppene."
 ],
 "This disk cannot be removed while the device is recovering.": [
  null,
  "Denne disken kan ikke fjernes mens enheten gjenoppretter."
 ],
 "This logical volume is not completely used by its content.": [
  null,
  "Dette logiske volumet brukes ikke fullstendig av innholdet."
 ],
 "This volume needs to be activated before it can be resized.": [
  null,
  "Dette volumet må aktiveres før det kan endres."
 ],
 "Toggle": [
  null,
  ""
 ],
 "Toggle bitmap": [
  null,
  ""
 ],
 "Too much data": [
  null,
  "For mye data"
 ],
 "Total size: $0": [
  null,
  "Total størrelse: $0"
 ],
 "Trust key": [
  null,
  ""
 ],
 "Type": [
  null,
  "Type"
 ],
 "UUID": [
  null,
  "UUID"
 ],
 "Unable to reach server": [
  null,
  "Kan ikke nå serveren"
 ],
 "Unable to remove mount": [
  null,
  "Kan ikke fjerne monteringen"
 ],
 "Unable to unmount filesystem": [
  null,
  "Kan ikke avmontere filsystemet"
 ],
 "Unit": [
  null,
  "Enhet"
 ],
 "Unknown": [
  null,
  "Ukjent"
 ],
 "Unknown ($0)": [
  null,
  "Ukjent ($0)"
 ],
 "Unknown host name": [
  null,
  "Ukjent vertsnavn"
 ],
 "Unknown type": [
  null,
  "Ukjent type"
 ],
 "Unlock": [
  null,
  "Lås opp"
 ],
 "Unlock at boot": [
  null,
  "Lås opp ved oppstart"
 ],
 "Unlock read only": [
  null,
  "Lås opp skrivebeskyttet"
 ],
 "Unlocking $target": [
  null,
  "Låser opp $target"
 ],
 "Unlocking disk...": [
  null,
  "Låser opp disk ..."
 ],
 "Unmount": [
  null,
  "Demonter"
 ],
 "Unmount filesystem": [
  null,
  "Demonter filsystemet"
 ],
 "Unmount now": [
  null,
  "Demonter nå"
 ],
 "Unmounting $target": [
  null,
  "Demonterer $target"
 ],
 "Unrecognized data": [
  null,
  "Ukjente data"
 ],
 "Unrecognized data can not be made smaller here.": [
  null,
  ""
 ],
 "Unsupported volume": [
  null,
  "Volum som ikke støttes"
 ],
 "Untrusted host": [
  null,
  ""
 ],
 "Usage": [
  null,
  "Bruk"
 ],
 "Use 512 byte emulation": [
  null,
  "Bruk 512 byte-emulering"
 ],
 "Use compression": [
  null,
  "Bruk komprimering"
 ],
 "Use deduplication": [
  null,
  "Bruk deduplisering"
 ],
 "Used": [
  null,
  "Brukt"
 ],
 "Username": [
  null,
  "Brukernavn"
 ],
 "Using LUKS encryption": [
  null,
  "Bruker LUKS-kryptering"
 ],
 "Using Tang server": [
  null,
  "Bruker Tang-server"
 ],
 "VDO backing": [
  null,
  ""
 ],
 "VDO backing devices can not be made smaller": [
  null,
  ""
 ],
 "VDO device": [
  null,
  "VDO-enhet"
 ],
 "VDO device $0": [
  null,
  "VDO-enhet $0"
 ],
 "Verify key": [
  null,
  "Verifiser nøkkel"
 ],
 "Very securely erasing $target": [
  null,
  ""
 ],
 "Volume": [
  null,
  "Volum"
 ],
 "Volume group": [
  null,
  "Volumgruppe"
 ],
 "Volume group $0": [
  null,
  "Volumgruppe $0"
 ],
 "Volume size is $0. Content size is $1.": [
  null,
  "Volumstørrelsen er $0. Innholdsstørrelsen er $1."
 ],
 "Waiting for other software management operations to finish": [
  null,
  "Venter på at andre programvareadministrasjons-operasjoner skal fullføres"
 ],
 "What if tang-show-keys is not available?": [
  null,
  "Hva om tang-show-keys ikke er tilgjengelig?"
 ],
 "Write-mostly": [
  null,
  ""
 ],
 "Your session has been terminated.": [
  null,
  "Økten din er avsluttet."
 ],
 "Your session has expired. Please log in again.": [
  null,
  "Økten din har utløpt. Vennligst logg inn igjen."
 ],
 "[$0 bytes of binary data]": [
  null,
  "[$0 bytes med binære data]"
 ],
 "[binary data]": [
  null,
  "[binære data]"
 ],
 "[no data]": [
  null,
  "[ingen data]"
 ],
 "disk": [
  null,
  "disk"
 ],
 "drive": [
  null,
  "dIsk"
 ],
 "encryption": [
  null,
  "kryptering"
 ],
 "filesystem": [
  null,
  "filsystem"
 ],
 "format": [
  null,
  "format"
 ],
 "fstab": [
  null,
  "fstab"
 ],
 "iSCSI targets": [
  null,
  "iSCSI mål"
 ],
 "iscsi": [
  null,
  "iscsi"
 ],
 "key slot $0": [
  null,
  "nøkkel-slot $0"
 ],
 "luks": [
  null,
  "luks"
 ],
 "lvm2": [
  null,
  "lvm2"
 ],
 "mkfs": [
  null,
  "mkfs"
 ],
 "mount": [
  null,
  "monter"
 ],
 "nbde": [
  null,
  "nbde"
 ],
 "nfs": [
  null,
  "nfs"
 ],
 "partition": [
  null,
  "partisjon"
 ],
 "raid": [
  null,
  "raid"
 ],
 "read only": [
  null,
  "skrivebeskyttet"
 ],
 "tang": [
  null,
  "tang"
 ],
 "udisks": [
  null,
  "udisks"
 ],
 "unknown target": [
  null,
  "ukjent mål"
 ],
 "unmount": [
  null,
  "unmount"
 ],
 "unpartitioned space on $0": [
  null,
  "upartisjonert plass på $0"
 ],
 "vdo": [
  null,
  "vdo"
 ],
 "volume": [
  null,
  "volum"
 ],
 "storage-id-desc\u0004$0 file system": [
  null,
  "$0 filsystem"
 ],
 "storage-id-desc\u0004Encrypted data": [
  null,
  "Krypterte data"
 ],
 "storage-id-desc\u0004Other data": [
  null,
  "Andre data"
 ],
 "storage-id-desc\u0004Swap space": [
  null,
  ""
 ],
 "storage-id-desc\u0004Unrecognized data": [
  null,
  "Ukjente data"
 ],
 "storage-id-desc\u0004VDO backing": [
  null,
  ""
 ],
 "storage\u0004Assessment": [
  null,
  "Vurdering"
 ],
 "storage\u0004Bitmap": [
  null,
  "Bitmap"
 ],
 "storage\u0004Capacity": [
  null,
  "Kapasitet"
 ],
 "storage\u0004Device": [
  null,
  "Enhet"
 ],
 "storage\u0004Device file": [
  null,
  "Enhetsfil"
 ],
 "storage\u0004Firmware version": [
  null,
  "Fastvareversjon"
 ],
 "storage\u0004Model": [
  null,
  "Modell"
 ],
 "storage\u0004Multipathed devices": [
  null,
  ""
 ],
 "storage\u0004Optical drive": [
  null,
  "Optisk disk"
 ],
 "storage\u0004RAID level": [
  null,
  "RAID-nivå"
 ],
 "storage\u0004Removable drive": [
  null,
  "Avtakbar stasjon"
 ],
 "storage\u0004Serial number": [
  null,
  "Serienummer"
 ],
 "storage\u0004State": [
  null,
  "Tilstand"
 ],
 "storage\u0004UUID": [
  null,
  "UUID"
 ],
 "storage\u0004World wide name": [
  null,
  ""
 ],
 "format-bytes\u0004bytes": [
  null,
  "bytes"
 ]
});
