/*
 * This file is part of Cockpit.
 *
 * Copyright (C) 2016 Red Hat, Inc.
 *
 * Cockpit is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * Cockpit is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with Cockpit; If not, see <http://www.gnu.org/licenses/>.
 */

@import "../lib/page.scss";
@import "../lib/ct-card.scss";

#app .pf-c-card {
    @extend .ct-card;
}

.setroubleshoot-log {
    font-family: monospace;
}

.setroubleshoot-progress-spinner {
    display: inline-block;
}

.setroubleshoot-progress-message {
    vertical-align: top;
}

/* Table cells should collapse on mobile */
.ct-table.pf-c-table tbody > tr > * {
    word-break: break-word;
}

.selinux-details {
    display: flex;
    flex-wrap: wrap;
    justify-content: space-between;

    > div:first-child {
        width: 70%;
    }

    + hr {
        margin-bottom: var(--pf-global--spacer--sm);
    }

    .pf-c-expandable-section__content {
        margin-top: unset;
    }
}

.selinux-details textarea {
    margin-top: var(--pf-global--spacer--xs);
    resize: none;
}

.selinux-policy-ct > .note {
    margin-bottom: 0.5rem;
    display: flex;
    align-items: center;
}

.selinux-policy-ct .pficon-info {
    padding-right: 0.5rem;
}
